@@ -1,5 +1,7 @@
-
-/* standard good AI code */
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
 
 #include "../simconvoi.h"
 #include "../simfab.h"
@@ -69,7 +71,6 @@ ai_goods_t::ai_goods_t(uint8 nr) : ai_t(nr)
 
 /**
  * Methode fuer jaehrliche Aktionen
- * @author Hj. Malthaner, Owen Rudge, hsiegeln
  */
 void ai_goods_t::new_year()
 {
@@ -98,8 +99,8 @@ void ai_goods_t::rotate90( const sint16 y_size )
 
 
 
-/* Activates/deactivates a player
- * @author prissi
+/**
+ * Activates/deactivates a player
  */
 bool ai_goods_t::set_active(bool new_state)
 {
@@ -180,7 +181,7 @@ bool ai_goods_t::get_factory_tree_lowest_missing( fabrik_t *fab )
  */
 int ai_goods_t::get_factory_tree_missing_count( fabrik_t *fab )
 {
-	int numbers=0;	// how many missing?
+	int numbers=0; // how many missing?
 
 	factory_desc_t const& d = *fab->get_desc();
 	// ok, this is a source ...
@@ -192,7 +193,7 @@ int ai_goods_t::get_factory_tree_missing_count( fabrik_t *fab )
 	for (int i = 0; i < d.get_supplier_count(); ++i) {
 		goods_desc_t const* const ware = d.get_supplier(i)->get_input_type();
 
-		bool complete = false;	// found at least one factory
+		bool complete = false; // found at least one factory
 		FOR(vector_tpl<koord>, const& q, fab->get_suppliers()) {
 			fabrik_t* const qfab = fabrik_t::get_fab(q);
 			if(!qfab) {
@@ -350,8 +351,8 @@ bool ai_goods_t::suche_platz1_platz2(fabrik_t *qfab, fabrik_t *zfab, int length
 
 
 
-/* build docks and ships
- * @author prissi
+/**
+ * build docks and ships
  */
 bool ai_goods_t::create_ship_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 {
@@ -430,7 +431,7 @@ bool ai_goods_t::create_ship_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 		}
 		vehicle_t* v = vehicle_builder_t::build( qfab->get_pos(), this, NULL, ship_vehicle);
 		convoi_t* cnv = new convoi_t(this);
-		// V.Meyer: give the new convoi name from first vehicle
+		// give the new convoi name from first vehicle
 		cnv->set_name(v->get_desc()->get_name());
 		cnv->add_vehikel( v );
 
@@ -450,10 +451,6 @@ bool ai_goods_t::create_ship_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 }
 
 
-
-/* changed to use vehicles searched before
- * @author prissi
- */
 void ai_goods_t::create_road_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 {
 	const building_desc_t* fh = hausbauer_t::get_random_station(building_desc_t::generic_stop, road_wt, welt->get_timeline_year_month(), haltestelle_t::WARE);
@@ -462,11 +459,11 @@ void ai_goods_t::create_road_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 		koord3d pos1 = welt->lookup_kartenboden(platz1)->get_pos();
 		koord3d pos2 = welt->lookup_kartenboden(platz2)->get_pos();
 
-		int	start_location=0;
+		int start_location=0;
 		// sometimes, when factories are very close, we need exact calculation
 		const koord3d& qpos = qfab->get_pos();
 		if ((qpos.x - platz1.x) * (qpos.x - platz1.x) + (qpos.y - platz1.y) * (qpos.y - platz1.y) >
-				(qpos.x - platz2.x) * (qpos.x - platz2.x) + (qpos.y - platz2.y) * (qpos.y - platz2.y)) {
+		    (qpos.x - platz2.x) * (qpos.x - platz2.x) + (qpos.y - platz2.y) * (qpos.y - platz2.y)) {
 			start_location = 1;
 		}
 
@@ -493,7 +490,7 @@ void ai_goods_t::create_road_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 			}
 			vehicle_t* v = vehicle_builder_t::build(startpos, this, NULL, road_vehicle);
 			convoi_t* cnv = new convoi_t(this);
-			// V.Meyer: give the new convoi name from first vehicle
+			// give the new convoi name from first vehicle
 			cnv->set_name(v->get_desc()->get_name());
 			cnv->add_vehikel( v );
 
@@ -504,12 +501,9 @@ void ai_goods_t::create_road_transport_vehikel(fabrik_t *qfab, int anz_vehikel)
 }
 
 
-
-/* now obeys timeline and use "more clever" scheme for vehicle selection *
- * @author prissi
- */
 void ai_goods_t::create_rail_transport_vehikel(const koord platz1, const koord platz2, int anz_vehikel, int minimum_loading)
 {
+	// now obeys timeline and use "more clever" scheme for vehicle selection
 	schedule_t *schedule;
 	if(  convoihandle_t::is_exhausted()  ) {
 		// too many convois => cannot do anything about this ...
@@ -534,7 +528,7 @@ void ai_goods_t::create_rail_transport_vehikel(const koord platz1, const koord p
 	koord3d start_pos = welt->lookup_kartenboden(pos1.get_2d() + (abs(size1.x)>abs(size1.y) ? koord(size1.x,0) : koord(0,size1.y)))->get_pos();
 	vehicle_t* v = vehicle_builder_t::build( start_pos, this, NULL, rail_engine);
 
-	// V.Meyer: give the new convoi name from first vehicle
+	// give the new convoi name from first vehicle
 	cnv->set_name(rail_engine->get_name());
 	cnv->add_vehikel( v );
 
@@ -562,9 +556,9 @@ void ai_goods_t::create_rail_transport_vehikel(const koord platz1, const koord p
 
 
 
-/* built a station
+/**
+ * build a station
  * Can fail even though check has been done before
- * @author prissi
  */
 int ai_goods_t::baue_bahnhof(const koord* p, int anz_vehikel)
 {
@@ -628,9 +622,9 @@ int ai_goods_t::baue_bahnhof(const koord* p, int anz_vehikel)
 
 
 
-/* built a very simple track with just the minimum effort
+/**
+ * built a very simple track with just the minimum effort
  * usually good enough, since it can use road crossings
- * @author prissi
  */
 bool ai_goods_t::create_simple_rail_transport()
 {
@@ -851,7 +845,6 @@ void ai_goods_t::step()
 			 * the KI just chooses the way to run the operation at maximum profit (minimum loss).
 			 * The KI will built also a loosing route; this might be required by future versions to
 			 * be able to built a network!
-			 * @author prissi
 			 */
 
 			/* for the calculation we need:
@@ -904,7 +897,7 @@ DBG_MESSAGE("do_ki()","road vehicle %p",road_vehicle);
 
 DBG_MESSAGE("do_ki()","check railway");
 			/* calculate number of cars for railroad */
-			count_rail=255;	// no cars yet
+			count_rail=255; // no cars yet
 			if(  rail_vehicle!=NULL  ) {
 				// if our car is faster: well use slower speed to save money
 				best_rail_speed = min(51, rail_vehicle->get_topspeed());
@@ -944,7 +937,7 @@ DBG_MESSAGE("ai_goods_t::do_ki()","No railway possible.");
 
 DBG_MESSAGE("do_ki()","check railway");
 			/* calculate number of cars for road; much easier */
-			count_road=255;	// no cars yet
+			count_road=255; // no cars yet
 			if(  road_vehicle!=NULL  ) {
 				best_road_speed = road_vehicle->get_topspeed();
 				// find cheapest road
@@ -965,8 +958,8 @@ DBG_MESSAGE("ai_goods_t::do_ki()","No roadway possible.");
 
 			// find the cheapest transport ...
 			// assume maximum cost
-			int	cost_rail=0x7FFFFFFF, cost_road=0x7FFFFFFF;
-			int	income_rail=0, income_road=0;
+			int cost_rail=0x7FFFFFFF, cost_road=0x7FFFFFFF;
+			int income_rail=0, income_road=0;
 
 			// calculate cost for rail
 			if(  count_rail<255  ) {
@@ -984,7 +977,7 @@ DBG_MESSAGE("ai_goods_t::do_ki()","No roadway possible.");
 			if(  count_road<255  ) {
 				// for short distance: reduce number of cars
 				// calculated here, since the above number was based on production
-				count_road = CLIP( (sint32)(dist*15)/best_road_speed, 2, count_road );
+				count_road = clamp( (sint32)(dist*15)/best_road_speed, 2, count_road );
 				int freight_price = (freight->get_value()*road_vehicle->get_capacity()*count_road)/24*((8000+(best_road_speed-80)*freight->get_speed_bonus())/1000);
 				cost_road = road_weg->get_maintenance() + 300/dist + (count_road*road_vehicle->get_running_cost()*best_road_speed)/(2*dist+5);
 				income_road = (freight_price*best_road_speed)/(2*dist+5);
@@ -1015,7 +1008,7 @@ DBG_MESSAGE("ai_goods_t::do_ki()","No roadway possible.");
 			if(state==NR_BAUE_ROUTE1) {
 				// maybe this route is not builtable ... add to forbidden connections
 				forbidden_connections.append( new fabconnection_t( start, ziel, freight ) );
-				ziel = NULL;	// otherwise it may always try to built the same route!
+				ziel = NULL; // otherwise it may always try to built the same route!
 				state = CHECK_CONVOI;
 			}
 		}
@@ -1258,7 +1251,7 @@ DBG_MESSAGE("ai_goods_t::step()","remove already constructed rail between %i,%i
 
 					cnv->self_destruct();
 					if(cnv.is_bound()) {
-						cnv->step();	// to really get rid of it
+						cnv->step(); // to really get rid of it
 					}
 
 					// last vehicle on that connection (no line => railroad)
@@ -1451,7 +1444,7 @@ void ai_goods_t::rdwr(loadsave_t *file)
 		while(  cnt-->0  ) {
 			fabconnection_t *fc = new fabconnection_t(0,0,0);
 			fc->rdwr(file);
-			// @author Bernd Gabriel, Jan 01, 2010: Don't add, if fab or ware no longer in the game.
+			// Don't add if fab or ware no longer in the game.
 			if(  fc->fab1  &&  fc->fab2  &&  fc->ware  ) {
 				forbidden_connections.append(fc);
 			}
@@ -1506,8 +1499,6 @@ void ai_goods_t::fabconnection_t::rdwr(loadsave_t *file)
  * Dealing with stuck  or lost vehicles:
  * - delete lost ones
  * - ignore stuck ones
- * @author prissi
- * @date 30-Dec-2008
  */
 void ai_goods_t::report_vehicle_problem(convoihandle_t cnv,const koord3d ziel)
 {
@@ -1523,7 +1514,6 @@ void ai_goods_t::report_vehicle_problem(convoihandle_t cnv,const koord3d ziel)
 /**
  * Tells the player that a fabrik_t is going to be deleted.
  * It could also tell, that a fab has been created, but by now the factory_builder_t does not.
- * @author Bernd Gabriel, Jan 01, 2010
  */
 void ai_goods_t::notify_factory(notification_factory_t flag, const fabrik_t* fab)
 {
