@@ -1,16 +1,16 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- *
- * Simple goods transport AI
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
+#ifndef PLAYER_AI_GOODS_H
+#define PLAYER_AI_GOODS_H
+
 
 #include "ai.h"
 
 
+/// Simple goods transport AI
 class ai_goods_t : public ai_t
 {
 private:
@@ -31,9 +31,9 @@ private:
 	// vars for the KI
 	state state;
 
-	/* test more than one supplier and more than one good *
+	/**
+	 * test more than one supplier and more than one good *
 	 * save last factory for building next supplier/consumer *
-	 * @author prissi
 	 */
 	fabrik_t *root;
 
@@ -68,7 +68,7 @@ private:
 	class fabconnection_t{
 		friend class ai_goods_t;
 		fabrik_t *fab1;
-		fabrik_t *fab2;	// koord1 must be always "smaller" than koord2
+		fabrik_t *fab2; // koord1 must be always "smaller" than koord2
 		const goods_desc_t *ware;
 
 	public:
@@ -130,3 +130,5 @@ public:
 
 	void notify_factory(notification_factory_t flag, const fabrik_t*) OVERRIDE;
 };
+
+#endif
