@@ -1,12 +1,8 @@
 /*
- * Copyright (c) 2008 Markus Pristovsek
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/* simple passenger AI (not using trains, not pre-optimized network) */
-
 #include "../simcity.h"
 #include "../simconvoi.h"
 #include "../simfab.h"
@@ -56,8 +52,8 @@ ai_passenger_t::ai_passenger_t(uint8 nr) : ai_t( nr )
 }
 
 
-/* Activates/deactivates a player
- * @author prissi
+/**
+ * Activates/deactivates a player
  */
 bool ai_passenger_t::set_active(bool new_state)
 {
@@ -69,8 +65,7 @@ bool ai_passenger_t::set_active(bool new_state)
 }
 
 
-/* return the hub of a city (always the very first stop) or zero
- * @author prissi
+/** return the hub of a city (always the very first stop) or zero
  */
 halthandle_t ai_passenger_t::get_our_hub( const stadt_t *s ) const
 {
@@ -130,8 +125,8 @@ DBG_MESSAGE("ai_passenger_t::find_area_for_hub()","suggest hub at (%i,%i)",best_
 }
 
 
-/* tries to built a hub near the koordinate
- * @author prissi
+/**
+ * tries to built a hub near the koordinate
  */
 koord ai_passenger_t::find_place_for_hub( const stadt_t *s ) const
 {
@@ -614,8 +609,7 @@ static koord find_airport_pos(karte_t* welt, const stadt_t *s )
 }
 
 
-/* build airports and planes
- * @author prissi
+/** build airports and planes
  */
 bool ai_passenger_t::create_air_transport_vehikel(const stadt_t *start_stadt, const stadt_t *end_stadt)
 {
@@ -769,8 +763,7 @@ bool ai_passenger_t::create_air_transport_vehikel(const stadt_t *start_stadt, co
 }
 
 
-/* creates a more general road transport
- * @author prissi
+/** creates a more general road transport
  */
 void ai_passenger_t::create_bus_transport_vehikel(koord startpos2d,int anz_vehikel,koord *stops,int count,bool do_wait)
 {
@@ -782,7 +775,7 @@ DBG_MESSAGE("ai_passenger_t::create_bus_transport_vehikel()","bus at (%i,%i)",st
 	schedule_t *schedule=new truck_schedule_t();
 	// do not start at current stop => wont work ...
 	for(int j=0;  j<count;  j++) {
-		schedule->append(welt->lookup_kartenboden(stops[j]), j == 0 || !do_wait ? 0 : 10);
+		schedule->append(welt->lookup_kartenboden(stops[j]), j == 0 || !do_wait ? 0 : 10, j == 0 || !do_wait ? 0 : 15 );
 	}
 	schedule->set_current_stop( stops[0]==startpos2d );
 	schedule->finish_editing();
@@ -797,7 +790,7 @@ DBG_MESSAGE("ai_passenger_t::create_bus_transport_vehikel()","bus at (%i,%i)",st
 			return;
 		}
 		convoi_t* cnv = new convoi_t(this);
-		// V.Meyer: give the new convoi name from first vehicle
+		// give the new convoi name from first vehicle
 		cnv->set_name(v->get_desc()->get_name());
 		cnv->add_vehikel( v );
 
@@ -849,7 +842,7 @@ void ai_passenger_t::walk_city(linehandle_t const line, grund_t* const start, in
 							for( uint8 own=0;  own<pl->get_haltlist_count();  own++  ) {
 								if(  hl[own]->is_enabled(goods_manager_t::INDEX_PAS)  ) {
 									// our stop => nothing to do
-#if AUTOJOIN_PUBLIC
+#ifdef AUTOJOIN_PUBLIC
 									// we leave also public stops alone
 									if(  hl[own]->get_owner()==this  ||  hl[own]->get_owner()==welt->get_public_player()  ) {
 #else
@@ -998,12 +991,13 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","searching attraction");
 				const weighted_vector_tpl<gebaeude_t*> &attractions = welt->get_attractions();
 				// this way, we are sure, our factory is connected to this town ...
 				const vector_tpl<stadt_t::factory_entry_t> &fabriken = start_stadt->get_target_factories_for_pax().get_entries();
-				unsigned	last_dist = 0xFFFFFFFF;
-				bool ausflug=simrand(2)!=0;	// holidays first ...
+				unsigned last_dist = 0xFFFFFFFF;
+				bool ausflug=simrand(2)!=0; // holidays first ...
 				int ziel_count=ausflug?attractions.get_count():fabriken.get_count();
 				for( int i=0;  i<ziel_count;  i++  ) {
-					unsigned	dist;
+					unsigned dist;
 					koord pos, size;
+
 					if(ausflug) {
 						const gebaeude_t* a = attractions[i];
 						if (a->get_mail_level() <= 25) {
@@ -1148,7 +1142,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 		// built a simple road (no bridges, no tunnels)
 		case NR_BAUE_STRASSEN_ROUTE:
 		{
-			state = NR_BAUE_WATER_ROUTE;	// assume failure
+			state = NR_BAUE_WATER_ROUTE; // assume failure
 			if(  !ai_t::road_transport  ) {
 				// no overland bus lines
 				break;
@@ -1335,8 +1329,8 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 				}
 				// next: check for stuck convois ...
 
-				sint64	free_cap = line->get_finance_history(0,LINE_CAPACITY);
-				sint64	used_cap = line->get_finance_history(0,LINE_TRANSPORTED_GOODS);
+				sint64 free_cap = line->get_finance_history(0,LINE_CAPACITY);
+				sint64 used_cap = line->get_finance_history(0,LINE_TRANSPORTED_GOODS);
 
 				if(free_cap+used_cap==0) {
 					continue;
@@ -1372,7 +1366,7 @@ DBG_MESSAGE("ai_passenger_t::do_passenger_ki()","using %s on %s",road_vehicle->g
 		break;
 
 		default:
-			DBG_MESSAGE("ai_passenger_t::do_passenger_ki()",	"Illegal state %d!", state );
+			DBG_MESSAGE("ai_passenger_t::do_passenger_ki()", "Illegal state %d!", state );
 			end_stadt = NULL;
 			state = NR_INIT;
 	}
@@ -1442,16 +1436,21 @@ void ai_passenger_t::rdwr(loadsave_t *file)
 		k3d.rdwr(file);
 		ziel = fabrik_t::get_fab(k3d.get_2d() );
 	}
-}
 
+	if (file->is_version_atleast(122, 1)) {
+		plainstring road_vehicle_name = road_vehicle ? road_vehicle->get_name() : "";
+		file->rdwr_str(road_vehicle_name);
+		if (file->is_loading() && road_vehicle_name != "") {
+			road_vehicle = vehicle_builder_t::get_info(road_vehicle_name);
+		}
+	}
+}
 
 
 /**
  * Dealing with stuck  or lost vehicles:
  * - delete lost ones
  * - ignore stuck ones
- * @author prissi
- * @date 30-Dec-2008
  */
 void ai_passenger_t::report_vehicle_problem(convoihandle_t cnv,const koord3d ziel)
 {
@@ -1466,7 +1465,11 @@ void ai_passenger_t::report_vehicle_problem(convoihandle_t cnv,const koord3d zie
 
 void ai_passenger_t::finish_rd()
 {
-	road_vehicle = vehikel_search( road_wt, 50, 80, goods_manager_t::passengers, false);
+	if (!road_vehicle) {
+		dbg->warning("ai_passenger_t::finish_rd", "Default road vehicle could not be loaded, searching for one...");
+		road_vehicle = vehikel_search( road_wt, 50, 80, goods_manager_t::passengers, false);
+	}
+
 	if (road_vehicle == NULL) {
 		// reset state
 		end_stadt = NULL;
