@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include "api.h"
 
 /** @file api_factory.cc exports factory related functions. */
@@ -202,10 +207,10 @@ void export_factory(HSQUIRRELVM vm)
 	 * To print a list of all available goods names use this example:
 	 * @code
 	 * foreach(key,value in input) {
-	 * 	// print raw name of the good
-	 * 	print("Input slot key: " + key)
-	 * 	// print current storage
-	 * 	print("Input slot storage: " + value.get_storage()[0])
+	 *     // print raw name of the good
+	 *     print("Input slot key: " + key)
+	 *     // print current storage
+	 *     print("Input slot storage: " + value.get_storage()[0])
 	 * }
 	 * @endcode
 	 * To catch the output of this example see @ref sec_err.
@@ -328,6 +333,24 @@ void export_factory(HSQUIRRELVM vm)
 	 */
 	register_method(vm, &factory_get_halt_list, "get_halt_list", true);
 
+	/**
+	 * Checks whether a transformer is connected.
+	 * @returns name
+	 */
+	register_method(vm, &fabrik_t::is_transformer_connected,  "is_transformer_connected");
+	/**
+	 * Get connected transformer (if any).
+	 * @returns transformer
+	 */
+	register_method(vm, &fabrik_t::get_transformer, "get_transformer");
+	/**
+	 * @returns number of fields belonging to this factory
+	 */
+	register_method(vm, &fabrik_t::get_field_count, "get_field_count");
+	/**
+	 * @returns minimum number of fields required
+	 */
+	register_method(vm, &fabrik_t::get_min_field_count, "get_min_field_count");
 	// pop class
 	end_class(vm);
 
