@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include "api.h"
 
 /** @file api_halt.cc exports halt/station related functions. */
@@ -9,9 +14,13 @@
 #include "../api_function.h"
 #include "../../simhalt.h"
 
+halthandle_t get_halt_from_koord3d(koord3d pos, const player_t *player ); // api_schedule.cc, interfaces haltestelle_t::get_halt
+
+
 namespace script_api {
 
 	declare_specialized_param(haltestelle_t::tile_t, "t|x|y", "tile_x");
+	declare_specialized_param(haltestelle_t::connection_t, "t|x|y", "halt_x");
 
 
 	SQInteger param<haltestelle_t::tile_t>::push(HSQUIRRELVM vm, haltestelle_t::tile_t const& v)
@@ -19,8 +28,13 @@ namespace script_api {
 		return param<grund_t*>::push(vm, v.grund);
 	}
 
+	SQInteger param<haltestelle_t::connection_t>::push(HSQUIRRELVM vm, haltestelle_t::connection_t const& v)
+	{
+		return param<halthandle_t>::push(vm, v.halt);
+	}
 };
 
+
 using namespace script_api;
 
 vector_tpl<sint64> const& get_halt_stat(const haltestelle_t *halt, sint32 INDEX)
@@ -115,6 +129,14 @@ SQInteger halt_compare(halthandle_t a, halthandle_t b)
 }
 
 
+vector_tpl<haltestelle_t::connection_t> const& halt_get_connections(const haltestelle_t *halt, const goods_desc_t* freight)
+{
+	static vector_tpl<haltestelle_t::connection_t> dummy;
+	dummy.clear();
+	return freight ? halt->get_connections(freight->get_catg_index()) : dummy;
+}
+
+
 void export_halt(HSQUIRRELVM vm)
 {
 	/**
@@ -267,6 +289,18 @@ void export_halt(HSQUIRRELVM vm)
 	 * @param freight freight type
 	 */
 	register_method(vm, &halt_get_capacity, "get_capacity", true);
+	/**
+	 * Returns list of connected halts for the specific @p freight type.
+	 * @param freight freight type
+	 */
+	register_method(vm, &halt_get_connections, "get_connections", true);
+	/**
+	 * Returns halt at given position.
+	 * @param pos coordinate
+	 * @param pl player that wants to use halt here
+	 * @return halt instance
+	 */
+	STATIC register_method(vm, &get_halt_from_koord3d, "get_halt", false, true);
 
 	end_class(vm);
 }
