@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include "api.h"
 
 /** @file api_line.cc exports line related functions. */
@@ -66,7 +71,7 @@ call_tool_init line_change_schedule(simline_t* line, player_t *player, schedule_
 
 call_tool_init line_delete(simline_t* line, player_t *player)
 {
-	if (line->count_convoys() > 0) {
+	if (line->count_convoys() == 0) {
 		cbuffer_t buf;
 		buf.printf( "d,%i", line->get_handle().get_id() );
 
