@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include "api.h"
 
 /** @file api_map_objects.cc exports all map-objects. */
@@ -12,9 +17,12 @@
 #include "../../simworld.h"
 #include "../../boden/grund.h"
 #include "../../dataobj/scenario.h"
+#include "../../descriptor/ground_desc.h"
 #include "../../obj/baum.h"
 #include "../../obj/gebaeude.h"
+#include "../../obj/field.h"
 #include "../../obj/label.h"
+#include "../../obj/leitung2.h"
 #include "../../obj/roadsign.h"
 #include "../../obj/signal.h"
 #include "../../player/simplay.h"
@@ -58,6 +66,10 @@ template<class D> struct access_objs {
 				// object or tile disappeared: clear userpointer
 				sq_setinstanceup(vm, index, NULL);
 			}
+			sq_raise_error(vm, "Object of type %s vanished from (%s).", param<D>::squirrel_type, pos.get_str());
+		}
+		else {
+			sq_raise_error(vm, "Object is not of type %s.", param<D>::squirrel_type);
 		}
 		return NULL;
 	}
@@ -82,8 +94,11 @@ template<class D> struct access_objs {
 				return SQ_ERROR;
 			}
 		}
-		else{
-			assert(bind_code<D>::objtype == obj->get_typ());
+		else if (bind_code<D>::objtype != obj->get_typ()) {
+			// obj is instance of derived class
+			return script_api::param<obj_t*>::push(vm, obj);
+		}
+		else {
 			// specific object with its own constructor, type already preset as default parameter
 			if (!SQ_SUCCEEDED(push_instance(vm, script_api::param<D*>::squirrel_type(), x, y, z))) {
 				return SQ_ERROR;
@@ -105,11 +120,18 @@ SQInteger exp_obj_pos_constructor(HSQUIRRELVM vm) // parameters: sint16 x, sint1
 	// set coordinates
 	set_slot(vm, "x", x, 1);
 	set_slot(vm, "y", y, 1);
-	set_slot(vm, "z", z, 1);
 	koord pos(x,y);
 	coordinate_transform_t::koord_sq2w(pos);
+	// find tile - some objects have larger z-coordinate (e.g., on foundations)
+	grund_t *gr = welt->lookup(koord3d(pos, z));
+	for(uint8 i=1, end = ground_desc_t::double_grounds ? 2 : 1; gr == NULL  &&  i<=end; i++) {
+		gr = welt->lookup(koord3d(pos, z-i));
+	}
 	// find object and set instance up
-	if (grund_t *gr = welt->lookup(koord3d(pos, z))) {
+	if (gr) {
+		// correct z-coordinate
+		set_slot(vm, "z", gr->get_pos().z, 1);
+		// search for object
 		obj_t::typ type = (obj_t::typ)param<uint8>::get(vm, 5);
 		obj_t *obj = NULL;
 		if (type == obj_t::roadsign  ||  type == obj_t::signal) {
@@ -119,6 +141,12 @@ SQInteger exp_obj_pos_constructor(HSQUIRRELVM vm) // parameters: sint16 x, sint1
 				obj = gr->suche_obj(obj_t::signal);
 			}
 		}
+		else if (type == obj_t::pumpe  ||  type == obj_t::senke) {
+			obj = gr->suche_obj(obj_t::pumpe);
+			if (obj == NULL) {
+				obj = gr->suche_obj(obj_t::senke);
+			}
+		}
 		else if (type != obj_t::old_airdepot) { // special treatment of depots
 			obj = gr->suche_obj(type);
 		}
@@ -152,6 +180,8 @@ getpush_obj_pos(baum_t, obj_t::baum);
 getpush_obj_pos(gebaeude_t, obj_t::gebaeude);
 getpush_obj_pos(label_t, obj_t::label);
 getpush_obj_pos(weg_t, obj_t::way);
+getpush_obj_pos(leitung_t, obj_t::leitung);
+getpush_obj_pos(field_t, obj_t::field);
 
 namespace script_api {
 	// each depot has its own class
@@ -169,7 +199,11 @@ namespace script_api {
 	declare_specialized_param(roadsign_t*, "t|x|y", "sign_x");
 	declare_specialized_param(signal_t*, "t|x|y", "sign_x");
 
+	//  map all to one transformer class
+	declare_specialized_param(pumpe_t*,  "t|x|y", "transformer_x");
+	declare_specialized_param(senke_t*,  "t|x|y", "transformer_x");
 };
+
 // base depot class, use old_airdepot as identifier here
 getpush_obj_pos(depot_t, obj_t::old_airdepot);
 // now all the derived classes
@@ -184,6 +218,10 @@ getpush_obj_pos(maglevdepot_t, obj_t::maglevdepot);
 // roadsigns/signals
 getpush_obj_pos(roadsign_t, obj_t::roadsign);
 getpush_obj_pos(signal_t, obj_t::signal);
+//  powerlines
+getpush_obj_pos(pumpe_t, obj_t::pumpe);
+getpush_obj_pos(senke_t, obj_t::senke);
+
 
 #define case_resolve_obj(D) \
 	case bind_code<D>::objtype: \
@@ -204,6 +242,7 @@ SQInteger script_api::param<obj_t*>::push(HSQUIRRELVM vm, obj_t* const& obj)
 		case_resolve_obj(weg_t);
 		case_resolve_obj(roadsign_t);
 		case_resolve_obj(signal_t);
+		case_resolve_obj(field_t);
 
 		case_resolve_obj(airdepot_t);
 		case_resolve_obj(narrowgaugedepot_t);
@@ -214,6 +253,10 @@ SQInteger script_api::param<obj_t*>::push(HSQUIRRELVM vm, obj_t* const& obj)
 		case_resolve_obj(tramdepot_t);
 		case_resolve_obj(maglevdepot_t);
 
+		case_resolve_obj(leitung_t);
+		case_resolve_obj(pumpe_t);
+		case_resolve_obj(senke_t);
+
 		default:
 			return access_objs<obj_t>::push_with_pos(vm, obj);
 	}
@@ -346,6 +389,47 @@ vector_tpl<convoihandle_t> const& depot_get_convoy_list(depot_t *depot)
 	return list;
 }
 
+vector_tpl<depot_t*> const& get_depot_list(player_t *player, waytype_t wt)
+{
+	static vector_tpl<depot_t*> list;
+	list.clear();
+	// do the conversion of waytype_t to depot-type by linetype
+	simline_t::linetype line_type = simline_t::waytype_to_linetype(wt);
+	if (player == NULL  ||  line_type == simline_t::MAX_LINE_TYPE) {
+		return list;
+	}
+	// fill list
+	const slist_tpl<depot_t*> &depot_list = depot_t::get_depot_list();
+
+	FOR(slist_tpl<depot_t*>, d, depot_list) {
+		if(d->get_line_type()==line_type  &&  d->get_owner()==player) {
+			list.append(d);
+		}
+	}
+	return list;
+}
+
+
+const fabrik_t* transformer_get_factory(leitung_t *lt)
+{
+	if (pumpe_t *p = dynamic_cast<pumpe_t*>(lt)) {
+		return p->get_factory();
+	}
+	if (senke_t *s = dynamic_cast<senke_t*>(lt)) {
+		return s->get_factory();
+	}
+	return NULL;
+}
+
+bool leitung_is_connected(leitung_t* lt1, leitung_t* lt2)
+{
+	return lt2 != NULL  &&  lt1->get_net() == lt2->get_net();
+}
+
+bool field_is_deleteable(field_t* f)
+{
+	return f->is_deletable( welt->get_player(1) ) == NULL;
+}
 
 void export_map_objects(HSQUIRRELVM vm)
 {
@@ -497,6 +581,13 @@ void export_map_objects(HSQUIRRELVM vm)
 	 * @returns list of convoys sitting in this depot
 	 */
 	register_method(vm, &depot_get_convoy_list, "get_convoy_list", true);
+	/**
+	 * List of all depots of player @p pl of way-type @p wt
+	 * @param pl
+	 * @param wt
+	 * @returns depot list of player
+	 */
+	STATIC register_method(vm, &get_depot_list, "get_depot_list", false, true);
 	end_class(vm);
 
 	/**
@@ -588,4 +679,46 @@ void export_map_objects(HSQUIRRELVM vm)
 	 */
 	register_method(vm, &roadsign_can_pass, "can_pass", true);
 	end_class(vm);
+
+	/**
+	 * Powerlines.
+	 * (Including transformers. Can be differentiated by @ref obj_x::get_type.
+	 */
+	begin_obj_class<leitung_t>(vm, "powerline_x", "map_object_x");
+
+	/**
+	 * Checkes whether powerline (or transformer) is connected to @p pl are connected.
+	 * @param pl other powerline/transformer
+	 */
+	register_method(vm, &leitung_is_connected, "is_connected", true);
+	end_class(vm);
+
+	/**
+	 * Transformers.
+	 * Sink and source can be differentiated by @ref obj_x::get_type.
+	 */
+	begin_obj_class<pumpe_t>(vm, "transformer_x", "powerline_x");
+
+	/**
+	 * Get factory connected to this transformer.
+	 */
+	register_method(vm, &transformer_get_factory, "get_factory", true);
+	end_class(vm);
+
+	/**
+	 * Fields
+	 */
+	begin_obj_class<field_t>(vm, "field_x", "map_object_x");
+	/**
+	 * Fields can only be deleted if enough are present.
+	 * @see factory_x::get_field_count, factory_x::get_min_field_count
+	 * @return whether this one can be deleted
+	 */
+	register_method(vm, &field_is_deleteable, "is_deletable", true);
+	/**
+	 * @returns factory this field belongs to
+	 * @see factory_x::get_field_count, factory_x::get_min_field_count
+	 */
+	register_method(vm, &field_t::get_factory, "get_factory");
+	end_class(vm);
 }
