@@ -1,12 +1,15 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef tpl_array2d_tpl_h
-#define tpl_array2d_tpl_h
+#ifndef TPL_ARRAY2D_TPL_H
+#define TPL_ARRAY2D_TPL_H
+
+
+
+#include <stdio.h>
+#include <string.h>
 
 #include "../dataobj/koord.h"
 #include "../simdebug.h"
@@ -15,11 +18,7 @@
  * A template class for bounds checked 2-dimensional arrays.
  * This is kept as simple as possible. Does not use exceptions
  * for error handling.
- *
- * @author Hj. Malthaner
- * @see array_tpl
  */
-
 template <class T>
 class array2d_tpl
 {
@@ -52,6 +51,13 @@ public:
 		return h;
 	}
 
+	void clear()
+	{
+		delete [] data;
+		data = 0;
+		w = h = 0;
+	}
+
 	void init( T value )
 	{
 		if(sizeof(T)==1) {
@@ -65,7 +71,7 @@ public:
 		}
 	}
 
-	// YOu will loose all informations in the array
+	// all informations in the array are lost
 	void resize(unsigned resize_x, unsigned resize_y )
 	{
 		if( w*h != resize_x*resize_y  ) {
@@ -77,6 +83,47 @@ public:
 		h = resize_y;
 	}
 
+	void rotate90()
+	{
+		if(  w*h > 0  ) {
+			T *new_data = new T[w*h];
+			for(  unsigned y=0;  y<h;  y++  ) {
+				for(  unsigned x=0;  x<w;  x++  ) {
+					const unsigned nr = x+(y*w);
+					const unsigned new_nr = (h-y-1)+(x*h);
+					new_data[new_nr] = data[nr];
+				}
+			}
+			delete [] data;
+			data = new_data;
+			unsigned temp = w;
+			w = h;
+			h = temp;
+		}
+	}
+
+	// kepp old informations, new cell get default
+	void resize(unsigned resize_x, unsigned resize_y, T default_value )
+	{
+		if( w*h != resize_x*resize_y  ) {
+			T* new_data = new T[resize_x*resize_y];
+			for( uint y = 0; y < resize_y; y++ ) {
+				for( uint x = 0; x < resize_x; x++ ) {
+					if( x < w   &&  y < h  ) {
+						new_data[ x + y*resize_x ] = data[x+y*w];
+					}
+					else {
+						new_data[ x + y*resize_x ] = default_value;
+					}
+				}
+			}
+			delete [] data;
+			data = new_data;
+		}
+		w = resize_x;
+		h = resize_y;
+	}
+
 	T& at(unsigned x, unsigned y)
 	{
 		if(  (int)((w-x)|(h-y))<0  ) {
@@ -100,8 +147,7 @@ public:
 
 	array2d_tpl<T> & operator = (const array2d_tpl <T> &other)
 	{
-		if(  this != &other  ) // protect against invalid self-assignment
-        {
+		if(  this != &other  ) {// protect against invalid self-assignment
 			if(  h != other.h  &&  w != other.w  ) {
 				if(  h*w!=0  ) {
 					dbg->error("array2d_tpl<T>::=()","source has different size!");
