@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <math.h>
@@ -48,7 +46,7 @@ static image_id tree_id_to_image[256][5*5];
 
 
 // distributes trees on a map
-void baum_t::distribute_trees(int dichte)
+void baum_t::distribute_trees(int dichte, sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom )
 {
 	// now we can proceed to tree planting routine itself
 	// best forests results are produced if forest size is tied to map size -
@@ -64,10 +62,10 @@ DBG_MESSAGE("verteile_baeume()","creating %i forest",c_forest_count);
 		// to have same execution order for simrand
 		koord const start = koord::koord_random(x, y);
 		koord const size  = koord(t_forest_size,t_forest_size) + koord::koord_random(t_forest_size, t_forest_size);
-		create_forest( start, size );
+		create_forest( start, size, xtop, ytop, xbottom, ybottom );
 	}
 
-	fill_trees(dichte);
+	fill_trees( dichte, xtop, ytop, xbottom, ybottom );
 }
 
 
@@ -180,7 +178,7 @@ bool baum_t::plant_tree_on_coordinate(koord pos, const tree_desc_t *desc, const
 }
 
 
-uint32 baum_t::create_forest(koord new_center, koord wh )
+uint32 baum_t::create_forest(koord new_center, koord wh, sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom )
 {
 	// none there
 	if(  desc_table.empty()  ) {
@@ -195,6 +193,13 @@ uint32 baum_t::create_forest(koord new_center, koord wh )
 			const sint32 x_tree_pos = (j-(wh.x>>1));
 			const sint32 y_tree_pos = (i-(wh.y>>1));
 
+			if( xtop > x_tree_pos  ||  x_tree_pos >= xbottom ) {
+				continue;
+			}
+			if( ytop > y_tree_pos  ||  y_tree_pos >= ybottom ) {
+				continue;
+			}
+
 			const uint64 distance = 1 + sqrt_i64( ((uint64)x_tree_pos*x_tree_pos*(wh.y*wh.y) + (uint64)y_tree_pos*y_tree_pos*(wh.x*wh.x)));
 			const uint32 tree_probability = (uint32)( ( 8 * (uint32)((wh.x*wh.x)+(wh.y*wh.y)) ) / distance );
 
@@ -218,7 +223,7 @@ uint32 baum_t::create_forest(koord new_center, koord wh )
 }
 
 
-void baum_t::fill_trees(int dichte)
+void baum_t::fill_trees(int dichte, sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom )
 {
 	// none there
 	if(  desc_table.empty()  ) {
@@ -226,8 +231,8 @@ void baum_t::fill_trees(int dichte)
 	}
 DBG_MESSAGE("verteile_baeume()","distributing single trees");
 	koord pos;
-	for(  pos.y=0;  pos.y<welt->get_size().y;  pos.y++  ) {
-		for(  pos.x=0;  pos.x<welt->get_size().x;  pos.x++  ) {
+	for(  pos.y=ytop;  pos.y<ybottom;  pos.y++  ) {
+		for(  pos.x=xtop;  pos.x<xbottom;  pos.x++  ) {
 			grund_t *gr = welt->lookup_kartenboden(pos);
 			if(gr->get_top() == 0  &&  gr->get_typ() == grund_t::boden)  {
 				// plant spare trees, (those with low preffered density) or in an entirely tree climate
@@ -244,8 +249,7 @@ DBG_MESSAGE("verteile_baeume()","distributing single trees");
 
 static bool compare_tree_desc(const tree_desc_t* a, const tree_desc_t* b)
 {
-	/* Gleiches Level - wir fhren eine knstliche, aber eindeutige Sortierung
-	 * ber den Namen herbei. */
+	// same level - we do an artificial but unique sorting by (untranslated) name
 	return strcmp(a->get_name(), b->get_name())<0;
 }
 
@@ -321,7 +325,7 @@ bool baum_t::register_desc(tree_desc_t *desc)
 // takes care of slopes
 void baum_t::calc_off(uint8 slope, sint8 x_, sint8 y_)
 {
-	sint16 random = (sint16)( get_pos().x + get_pos().y + get_pos().z + slope + (long)this );
+	sint16 random = (sint16)( get_pos().x + get_pos().y + get_pos().z + slope + (sint16)(intptr_t)this );
 	// point on tile (imaginary origin at sw corner, x axis: north, y axis: east
 	sint16 x = x_==-128 ? (random + tree_id) & 31  : x_;
 	sint16 y = y_==-128 ? (random + get_age()) & 31 : y_;
@@ -419,8 +423,8 @@ uint32 baum_t::get_age() const
 }
 
 
-/* also checks for distribution values
- * @author prissi
+/**
+ * also checks for distribution values
  */
 uint16 baum_t::random_tree_for_climate_intern(climate cl)
 {
@@ -585,10 +589,6 @@ void baum_t::finish_rd()
 }
 
 
-/**
- * ffnet ein neues Beobachtungsfenster fr das Objekt.
- * @author Hj. Malthaner
- */
 void baum_t::show_info()
 {
 	if(env_t::tree_info) {
@@ -597,11 +597,6 @@ void baum_t::show_info()
 }
 
 
-/**
- * @return Einen Beschreibungsstring fr das Objekt, der z.B. in einem
- * Beobachtungsfenster angezeigt wird.
- * @author Hj. Malthaner
- */
 void baum_t::info(cbuffer_t & buf) const
 {
 	obj_t::info(buf);
