@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef obj_baum_h
-#define obj_baum_h
+#ifndef OBJ_BAUM_H
+#define OBJ_BAUM_H
+
 
 #include <string>
 #include "../tpl/stringhashtable_tpl.h"
@@ -18,8 +17,6 @@
 
 /**
  * Simulated trees for Simutrans.
- *
- * @author Hj. Malthaner
  */
 class baum_t : public obj_t
 {
@@ -53,8 +50,6 @@ private:
 
 	static uint16 random_tree_for_climate_intern(climate cl);
 
-	static uint8 plant_tree_on_coordinate(koord pos, const uint8 maximum_count, const uint8 count);
-
 public:
 	/**
 	 * Only the load save constructor should be called outside
@@ -81,7 +76,6 @@ public:
 
 	/**
 	 * Calculates tree image dependent on tree age
-	 * @author Hj. Malthaner
 	 */
 	void calc_image() OVERRIDE;
 
@@ -119,16 +113,19 @@ public:
 	// static functions to handle trees
 
 	// distributes trees on a map
-	static void distribute_trees(int dichte);
+	static void distribute_trees(int dichte,  sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
+
+	static void fill_trees(int dichte, sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
+
+	static uint32 create_forest(koord center, koord size, sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
 
 	static bool plant_tree_on_coordinate(koord pos, const tree_desc_t *desc, const bool check_climate, const bool random_age );
 
+	static uint8 plant_tree_on_coordinate(koord pos, const uint8 maximum_count, const uint8 count);
+
 	static bool register_desc(tree_desc_t *desc);
 	static bool successfully_loaded();
 
-	static uint32 create_forest(koord center, koord size );
-	static void fill_trees(int dichte);
-
 	// return list to descriptors
 	static vector_tpl<tree_desc_t const*> const& get_all_desc() { return tree_list; }
 
