@@ -1,9 +1,11 @@
 /*
- * The trees builder
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_baum_edit_h
-#define gui_baum_edit_h
+#ifndef GUI_BAUM_EDIT_H
+#define GUI_BAUM_EDIT_H
+
 
 #include "extend_edit.h"
 #include "components/gui_image.h"
@@ -12,6 +14,9 @@
 class tree_desc_t;
 class tool_plant_tree_t;
 
+/*
+ * The trees builder
+ */
 class baum_edit_frame_t : public extend_edit_gui_t
 {
 private:
@@ -34,14 +39,12 @@ public:
 	/**
 	* in top-level windows the name is displayed in titlebar
 	* @return the non-translated component name
-	* @author Hj. Malthaner
 	*/
 	const char* get_name() const { return "baum builder"; }
 
 	/**
 	* Set the window associated helptext
 	* @return the filename for the helptext, or NULL
-	* @author Hj. Malthaner
 	*/
 	const char* get_help_filename() const OVERRIDE { return "baum_build.txt"; }
 };
