@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string.h>
@@ -199,7 +197,7 @@ const char *check_tile( const grund_t *gr, const player_t *player, waytype_t wt,
 				ribi = gr->get_weg_ribi_unmasked(wt);
 			}
 			// same waytype, same direction, no stop or depot or any other stuff */
-			if(  gr->get_weg(wt)  &&  ribi_t::doubles(ribi) == ribi_t::doubles( check_ribi )  ) {
+			if(  gr->get_weg(wt)  &&  ribi_check(ribi, check_ribi)  ) {
 				// ok too
 				return NULL;
 			}
@@ -238,7 +236,7 @@ const char *check_tile( const grund_t *gr, const player_t *player, waytype_t wt,
 			return err_msg;
 		}
 	}
-	return "";	// could end here but need not end here
+	return ""; // could end here but need not end here
 }
 
 bool bridge_builder_t::is_blocked(koord3d pos, ribi_t::ribi check_ribi, const char *&error_msg)
@@ -600,6 +598,61 @@ bool bridge_builder_t::can_place_ramp(player_t *player, const grund_t *gr, wayty
 	     gr->get_typ()!=grund_t::tunnelboden  ) {
 		return false;
 	}
+	// wrong slope
+	if(!slope_t::is_way(gr->get_grund_hang())) {
+		return false;
+	}
+	// blocked from above
+	koord3d pos = gr->get_pos();
+	if(  welt->lookup( pos + koord3d(0, 0, 1))  ||  (welt->get_settings().get_way_height_clearance()==2  &&  welt->lookup( pos + koord3d(0, 0, 2) ))  ) {
+		return false;
+	}
+	// check for ribis and crossings
+	bool test_ribi = r != ribi_t::none;
+	if (wt==powerline_wt) {
+		if (gr->hat_wege()) {
+			return false;
+		}
+		if (test_ribi  &&  gr->find<leitung_t>()  &&  (gr->find<leitung_t>()->get_ribi() & ~r) != 0) {
+			return false;
+		}
+	}
+	else {
+		if (gr->find<leitung_t>()) {
+			return false;
+		}
+
+		if(wt!=road_wt) {
+			// only road bridges can have other ways on it (ie trams)
+			if(gr->has_two_ways()  ||  (gr->hat_wege()  && gr->get_weg(wt) == NULL) ) {
+				return false;
+			}
+			if (test_ribi  &&  (gr->get_weg_ribi_unmasked(wt) & ~r) != 0) {
+				return false;
+			}
+		}
+		else {
+			// If road and tram, we have to check both ribis.
+			ribi_t::ribi ribi = ribi_t::none;
+			for(int i=0;i<2;i++) {
+				if (const weg_t *w = gr->get_weg_nr(i)) {
+					if (w->get_waytype()!=road_wt  &&  !w->get_desc()->is_tram()) {
+						return false;
+					}
+					ribi |= w->get_ribi_unmasked();
+				}
+				else break;
+			}
+			if (test_ribi  &&  (ribi & ~r) != 0) {
+				return false;
+			}
+		}
+	}
+	// ribi from slope
+	if (test_ribi  &&  gr->get_grund_hang()  &&  (ribi_type(gr->get_grund_hang()) & ~r) != 0) {
+		return false;
+	}
+	// check everything else
 	const char *error_msg = check_tile( gr, player, wt, r );
 	return (error_msg == NULL  ||  *error_msg == 0  );
 }
@@ -877,7 +930,7 @@ void bridge_builder_t::build_bridge(player_t *player, const koord3d start, const
 
 void bridge_builder_t::build_ramp(player_t* player, koord3d end, ribi_t::ribi ribi_neu, slope_t::type weg_hang, const bridge_desc_t* desc)
 {
-	assert(weg_hang < 81);
+	assert(weg_hang <= slope_t::max_number);
 
 	grund_t *alter_boden = welt->lookup(end);
 	brueckenboden_t *bruecke;
@@ -938,7 +991,7 @@ const char *bridge_builder_t::remove(player_t *player, koord3d pos_start, waytyp
 	do {
 		pos = tmp_list.remove_first();
 
-		// V.Meyer: weg_position_t changed to grund_t::get_neighbour()
+		// weg_position_t changed to grund_t::get_neighbour()
 		grund_t *from = welt->lookup(pos);
 		grund_t *to;
 		koord zv = koord::invalid;
@@ -1035,7 +1088,7 @@ const char *bridge_builder_t::remove(player_t *player, koord3d pos_start, waytyp
 							w->set_ribi( (~ribi_t::backward( ribi_t::nsew[i] )) & w->get_ribi_unmasked() );
 							if(  w->get_ribi_unmasked() == 0  ) {
 								// nowthing left => then remove completel
-								prev->remove_everything_from_way( player, wegtyp, bridge_ribi );	// removes stop and signals correctly
+								prev->remove_everything_from_way( player, wegtyp, bridge_ribi ); // removes stop and signals correctly
 								prev->weg_entfernen( wegtyp, true );
 								if(  prev->get_typ() == grund_t::monorailboden  ) {
 									welt->access( prev->get_pos().get_2d() )->boden_entfernen( prev );
@@ -1057,7 +1110,7 @@ const char *bridge_builder_t::remove(player_t *player, koord3d pos_start, waytyp
 		br->cleanup(player);
 		delete br;
 
-		gr->remove_everything_from_way(player,wegtyp,ribi_t::none);	// removes stop and signals correctly
+		gr->remove_everything_from_way(player,wegtyp,ribi_t::none); // removes stop and signals correctly
 		// remove also the second way on the bridge
 		if(gr->get_weg_nr(0)!=0) {
 			gr->remove_everything_from_way(player,gr->get_weg_nr(0)->get_waytype(),ribi_t::none);
@@ -1098,7 +1151,7 @@ const char *bridge_builder_t::remove(player_t *player, koord3d pos_start, waytyp
 						w->set_ribi( (~ribi_t::backward( ribi_t::nsew[i] )) & w->get_ribi_unmasked() );
 						if(  w->get_ribi_unmasked() == 0  ) {
 							// nowthing left => then remove completel
-							prev->remove_everything_from_way( player, wegtyp, bridge_ribi );	// removes stop and signals correctly
+							prev->remove_everything_from_way( player, wegtyp, bridge_ribi ); // removes stop and signals correctly
 							prev->weg_entfernen( wegtyp, true );
 							if(  prev->get_typ() == grund_t::monorailboden  ) {
 								welt->access( prev->get_pos().get_2d() )->boden_entfernen( prev );
@@ -1164,7 +1217,7 @@ const char *bridge_builder_t::remove(player_t *player, koord3d pos_start, waytyp
 			if(weg) {
 				gr->remove_everything_from_way(player,weg->get_waytype(),bridge_ribi);
 			}
-			gr->remove_everything_from_way(player,wegtyp,bridge_ribi);	// removes stop and signals correctly
+			gr->remove_everything_from_way(player,wegtyp,bridge_ribi); // removes stop and signals correctly
 
 			// corrects the ways
 			weg = gr->get_weg(wegtyp);
