@@ -1,10 +1,11 @@
 /*
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __simbridge_h
-#define __simbridge_h
+#ifndef BAUER_BRUECKENBAUER_H
+#define BAUER_BRUECKENBAUER_H
+
 
 #include "../simtypes.h"
 #include "../dataobj/koord.h"
@@ -13,7 +14,7 @@
 class bridge_desc_t;
 class grund_t;
 class karte_ptr_t;
-class player_t;               // Hajo: 22-Nov-01: Added forward declaration
+class player_t;
 class way_desc_t;
 class tool_selector_t;
 
@@ -56,6 +57,7 @@ public:
 	 *
 	 * @param player the player wanting to build the  bridge.
 	 * @param gr the ground to check.
+	 * @param r is ribi_t::none of the direction from bridge to ground.
 	 * @return true, if bridge ramp can be built here.
 	 */
 	static bool can_place_ramp(player_t *player, const grund_t *gr, waytype_t wt, ribi_t::ribi r );
