@@ -1,11 +1,11 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __BUILDING_DESC_H
-#define __BUILDING_DESC_H
+#ifndef DESCRIPTOR_BUILDING_DESC_H
+#define DESCRIPTOR_BUILDING_DESC_H
+
 
 #include <assert.h>
 #include "image_array.h"
@@ -18,27 +18,23 @@ class tool_t;
 class karte_t;
 class checksum_t;
 
-/*
- *  Author:
- *      Volker Meyer
- *
- *  Description:
- *      Data for one tile of a potentially multi-tile building.
+/**
+ * Data for one tile of a potentially multi-tile building.
  *
  *  Child nodes:
  *   0   Imagelist2D season 0 back
  *   1   Imagelist2D season 0 front
  *   2   Imagelist2D season 1 back
  *   3   Imagelist2D season 1 front
- *	... ...
+ * ... ...
  */
 class building_tile_desc_t : public obj_desc_t {
 	friend class tile_reader_t;
 
-	const building_desc_t	*building;
+	const building_desc_t *building;
 
 	uint8  seasons;
-	uint8  phases;	    ///< number of animation phases
+	uint8  phases;  ///< number of animation phases
 	uint16 index;
 
 public:
@@ -100,19 +96,15 @@ public:
 	uint8 get_layout() const;
 };
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * Data for one building, consists of potentially more than one tile.
  *
- *  Description:
- *      Data for one building, consists of potentially more than one tile.
- *
- *  Child nodes:
- *	0   Name
- *	1   Copyright
- *	2   Tile 1
- *	3   Tile 2
- *	... ...
+ * Child nodes:
+ *  0   Name
+ *  1   Copyright
+ *  2   Tile 1
+ *  3   Tile 2
+ * ... ...
  */
 class building_desc_t : public obj_desc_timelined_t {
 	friend class building_reader_t;
@@ -176,7 +168,7 @@ private:
 		};
 
 	building_desc_t::btype type;
-	uint16 animation_time;	// in ms
+	uint16 animation_time; // in ms
 	uint32 extra_data;
 		// extra data:
 		// minimum population to build for city attractions,
@@ -185,13 +177,13 @@ private:
 		// cluster number for city buildings (0 means no clustering)
 	koord  size;
 	flag_t flags;
-	uint16 level;          // or passengers;
-	uint8  layouts;        // 1 2, 4, 8  or 16
-	uint8  enables;		// if it is a stop, what is enabled ...
-	uint8  distribution_weight;         // Hajo: chance to build, special buildings, only other is weight factor
+	uint16 level;               // or passengers;
+	uint8  layouts;             // 1 2, 4, 8  or 16
+	uint8  enables;             // if it is a stop, what is enabled ...
+	uint8  distribution_weight; // chance to build, special buildings, only other is weight factor
 
 
-	/** @author: jamespetts.
+	/**
 	 * Additional fields for separate capacity/maintenance
 	 * If these are not specified in the .dat file, they are set to
 	 * PRICE_MAGIC then calculated from the "level" in the old way.
@@ -204,7 +196,7 @@ private:
 #define PRICE_MAGIC (2147483647)
 
 
-	climate_bits	allowed_climates;
+	climate_bits allowed_climates;
 
 	/**
 	 * Whether this building can or must be built underground.
@@ -215,6 +207,8 @@ private:
 	 */
 	uint8 allow_underground;
 
+	uint16 preservation_year_month;
+
 	bool is_type(building_desc_t::btype u) const {
 		return type == u;
 	}
@@ -252,6 +246,9 @@ public:
 	// do not open info for this
 	bool no_info_window() const { return (flags & FLAG_NO_INFO) != 0; }
 
+	// never replace this building for renovation (to create historic city centres)
+	uint16 no_renovation_month() const { return preservation_year_month; }
+
 	building_desc_t::btype get_type() const { return type; }
 
 	bool is_townhall()      const { return is_type(townhall); }
@@ -269,13 +266,11 @@ public:
 
 	/**
 	* the level is used in many places: for price, for capacity, ...
-	* @author Hj. Malthaner
 	*/
 	uint16 get_level() const { return level; }
 
 	/**
 	 * Mail generation level
-	 * @author Hj. Malthaner
 	 */
 	uint16 get_mail_level() const;
 
@@ -310,7 +305,6 @@ public:
 
 	/**
 	* Skin: cursor (index 0) and icon (index 1)
-	* @author Hj. Malthaner
 	*/
 	const skin_desc_t * get_cursor() const {
 		return flags & FLAG_HAS_CURSOR ? get_child<skin_desc_t>(2 + size.x * size.y * layouts) : 0;
@@ -327,19 +321,16 @@ public:
 
 	/**
 	* @return station flags (only used for station buildings and oil rigs)
-	* @author prissi
 	*/
 	uint8 get_enabled() const { return enables; }
 
 	/**
 	* @return time for doing one step
-	* @author prissi
 	*/
 	uint16 get_animation_time() const { return animation_time; }
 
 	/**
 	* @see above for maintenance/price/capacity variable information
-	* @author Kieron Green/jamespetts
 	*/
 	sint32 get_maintenance(karte_t *world) const;
 	sint32 get_price(karte_t *world) const;
