@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_stadt_info_h
-#define gui_stadt_info_h
+#ifndef GUI_CITY_INFO_H
+#define GUI_CITY_INFO_H
+
 
 #include "../simcity.h"
 #include "simwin.h"
@@ -26,7 +25,6 @@ class gui_city_minimap_t;
 
 /**
  * Window containing information about a city.
- * @author Hj. Malthaner
  */
 class city_info_t : public gui_frame_t, private action_listener_t
 {
@@ -82,7 +80,6 @@ public:
 	/**
 	 * Does this window need a min size button in the title bar?
 	 * @return true if such a button is needed
-	 * @author Hj. Malthaner
 	 */
 	bool has_min_sizer() const OVERRIDE {return true;}
 
