@@ -1,9 +1,11 @@
 /*
- * The citylist dialog
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef citylist_frame_t_h
-#define citylist_frame_t_h
+#ifndef GUI_CITYLIST_FRAME_T_H
+#define GUI_CITYLIST_FRAME_T_H
+
 
 #include "gui_frame.h"
 #include "citylist_stats_t.h"
@@ -12,6 +14,7 @@
 #include "components/gui_button_to_chart.h"
 #include "components/gui_label.h"
 #include "components/gui_chart.h"
+#include "components/gui_combobox.h"
 #include "components/gui_scrolled_list.h"
 #include "components/gui_scrollpane.h"
 #include "components/gui_tab_panel.h"
@@ -21,7 +24,6 @@
 
 /**
  * City list window
- * @author Hj. Malthaner
  */
 class citylist_frame_t : public gui_frame_t, private action_listener_t
 {
@@ -34,6 +36,8 @@ private:
 
 	button_t sortedby;
 	button_t sorteddir;
+	button_t filter_by_owner;
+	gui_combobox_t filterowner;
 
 	gui_scrolled_list_t scrolly;
 
@@ -46,6 +50,8 @@ private:
 	gui_aligned_container_t list, statistics;
 	gui_label_buf_t citizens;
 
+	uint32 old_city_count;
+
 	void fill_list();
 	void update_label();
 /*
@@ -57,24 +63,15 @@ static bool sortreverse;
 public:
 	citylist_frame_t();
 
-	/**
-	 * Draw new component. The values to be passed refer to the window
-	 * i.e. It's the screen coordinates of the window where the
-	 * component is displayed.
-	 * @author Hj. Malthaner
-	*/
 	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
 	bool has_min_sizer() const OVERRIDE {return true;}
 
-	/**
-	 * Set the window associated helptext
-	 * @return the filename for the helptext, or NULL
-	 * @author V. Meyer
-	*/
-	const char * get_help_filename() const OVERRIDE {return "citylist_filter.txt"; }
+	const char *get_help_filename() const OVERRIDE {return "citylist_filter.txt"; }
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
+
+	void map_rotate90( sint16 ) OVERRIDE { fill_list(); }
 };
 
 #endif
