@@ -1,12 +1,6 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- */
-
-/*
- * Where the citylist status are calculated (for graphs and statistics)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "citylist_stats_t.h"
@@ -81,7 +75,7 @@ bool citylist_stats_t::infowin_event(const event_t *ev)
 
 
 citylist_stats_t::sort_mode_t citylist_stats_t::sort_mode = citylist_stats_t::SORT_BY_NAME;
-
+uint8 citylist_stats_t::player_nr = -1;
 
 bool citylist_stats_t::compare(const gui_component_t *aa, const gui_component_t *bb)
 {
@@ -101,7 +95,7 @@ bool citylist_stats_t::compare(const gui_component_t *aa, const gui_component_t
 
 	if(  sort_mode != SORT_BY_NAME  ) {
 		switch(  sort_mode  ) {
-			case SORT_BY_NAME:	// default
+			case SORT_BY_NAME: // default
 				break;
 			case SORT_BY_SIZE:
 				return a->city->get_einwohner() < b->city->get_einwohner();
