@@ -1,14 +1,11 @@
 /*
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Where the citylist status are calculated (for graphs and statistics)
- */
+#ifndef GUI_CITYLIST_STATS_T_H
+#define GUI_CITYLIST_STATS_T_H
 
-#ifndef CITYLIST_STATS_T_H
-#define CITYLIST_STATS_T_H
 
 #include "components/gui_aligned_container.h"
 #include "components/gui_label.h"
@@ -18,7 +15,10 @@
 class stadt_t;
 
 
-// City list stats display
+/*
+ * City list stats display
+ * Where the citylist status are calculated (for graphs and statistics)
+ */
 class citylist_stats_t : public gui_aligned_container_t, public gui_scrolled_list_t::scrollitem_t
 {
 private:
@@ -29,6 +29,7 @@ private:
 public:
 	enum sort_mode_t { SORT_BY_NAME=0, SORT_BY_SIZE, SORT_BY_GROWTH, SORT_MODES, SORT_REVERSE=0x80 };
 	static sort_mode_t sort_mode;
+	static uint8 player_nr;
 
 public:
 	citylist_stats_t(stadt_t *);
