@@ -1,26 +1,27 @@
 /*
- * dialog for setting the climate border and other map related parameters
- *
- * Hj. Malthaner
- * April 2000
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef climate_gui_h
-#define climate_gui_h
+#ifndef GUI_CLIMATES_H
+#define GUI_CLIMATES_H
+
 
 #include "gui_frame.h"
+#include "components/gui_aligned_container.h"
 #include "components/gui_button.h"
+#include "components/gui_combobox.h"
 #include "components/gui_label.h"
 #include "components/gui_numberinput.h"
-#include "components/action_listener.h"
+#include "components/gui_tab_panel.h"
 #include "components/gui_textinput.h"
+#include "components/action_listener.h"
 
 class settings_t;
 
 
 /**
  * set the climate borders
- * @author prissi
  */
 class climate_gui_t  : public gui_frame_t, private action_listener_t
 {
@@ -31,30 +32,41 @@ private:
 		water_level,
 		mountain_height,
 		mountain_roughness,
+		climate_borders_ui[MAX_CLIMATES][2],
+		// this is only for height based climates
+		patch_size,
+		// this is only for humidity based climates
 		snowline_winter,
-		climate_borders_ui[rocky_climate];
+		snowline_summer,
+		moistering,
+		moistering_water,
+		humidities[2],
+		temperatures[5];
 
-	gui_label_buf_t
-		summer_snowline;
+	gui_combobox_t
+		tree;
 
-	button_t
-		no_tree; // without tree
-
-	button_t
-		lake; // lake
+	gui_numberinput_t
+		lake; // lake height
 
 	gui_numberinput_t
 		river_n,
 		river_min,
 		river_max;
 
+	gui_tab_panel_t
+		climate_generator;
+
+
+	gui_aligned_container_t height_climate;
+	gui_aligned_container_t humidity_climate;
+
 public:
 	climate_gui_t(settings_t*);
 
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char * get_help_filename() const OVERRIDE {return "climates.txt";}
 
