@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2010 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_fixedwidth_textarea_h
-#define gui_fixedwidth_textarea_h
+#ifndef GUI_COMPONENTS_GUI_FIXEDWIDTH_TEXTAREA_H
+#define GUI_COMPONENTS_GUI_FIXEDWIDTH_TEXTAREA_H
+
 
 #include "gui_component.h"
 #include "gui_container.h"
@@ -15,11 +14,10 @@
 class cbuffer_t;
 
 /**
- * Knightly :
- *	A fixed-width, automatically line-wrapping text-area,
- *	optionally with a reserved area in the upper right corner.
- *	It does *not* add 10px margins from the top and the left.
- *	Core code borrowed from ding_infowin_t::calc_draw_info() with adaptation.
+ * A fixed-width, automatically line-wrapping text-area,
+ * optionally with a reserved area in the upper right corner.
+ * It does *not* add 10px margins from the top and the left.
+ * Core code borrowed from ding_infowin_t::calc_draw_info() with adaptation.
  */
 class gui_fixedwidth_textarea_t : public gui_component_t
 {
