@@ -1,13 +1,6 @@
 /*
- * Copyright (c) 2008 Dwachs
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- */
-
-/*
- * An input field for integer numbers (with arrow buttons for dec/inc)
- * @author Dwachs 2008
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "gui_numberinput.h"
@@ -37,7 +30,7 @@ gui_numberinput_t::gui_numberinput_t() :
 	bt_right.add_listener(this );
 
 	set_limits(0, 9999);
-	textbuffer[0] = 0;	// start with empty buffer
+	textbuffer[0] = 0; // start with empty buffer
 	value = 0;
 	textinp.set_text(textbuffer, 20);
 	set_increment_mode( 1 );
@@ -73,8 +66,10 @@ scr_size gui_numberinput_t::get_min_size() const
 }
 
 void gui_numberinput_t::set_value(sint32 new_value)
-{	// range check
+{
+	// range check
 	value = clamp( new_value, min_value, max_value );
+
 	gui_frame_t *win = win_get_top();
 	if(  win  &&  win->get_focus()!=this  ) {
 		// final value should be correct, but during editing wrong values are allowed
@@ -276,12 +271,12 @@ bool gui_numberinput_t::infowin_event(const event_t *ev)
 				case '-':
 					call_textinp = min_value <0;
 					break;
-				case 1:		// allow Ctrl-A (select all text) to function
-				case 3:		// allow Ctrl-C (copy text to clipboard)
+				case 1:   // allow Ctrl-A (select all text) to function
+				case 3:   // allow Ctrl-C (copy text to clipboard)
 				case 8:
-				case 9:		// allow text input to handle unfocus event
-				case 22:	// allow Ctrl-V (paste text from clipboard)
-				case 24:	// allow Ctrl-X (cut text and copy to clipboard)
+				case 9:   // allow text input to handle unfocus event
+				case 22:  // allow Ctrl-V (paste text from clipboard)
+				case 24:  // allow Ctrl-X (cut text and copy to clipboard)
 				case 127:
 				case '0':
 				case '1':
@@ -338,7 +333,6 @@ bool gui_numberinput_t::infowin_event(const event_t *ev)
 
 /**
  * Draw the component
- * @author Dwachs
  */
 void gui_numberinput_t::draw(scr_coord offset)
 {
