@@ -1,19 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- *
- * @author Dwachs
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * An input field for integer numbers (with arrow buttons for dec/inc)
- * @author Dwachs
- */
+#ifndef GUI_COMPONENTS_GUI_NUMBERINPUT_H
+#define GUI_COMPONENTS_GUI_NUMBERINPUT_H
 
-#ifndef gui_components_gui_numberinput_h
-#define gui_components_gui_numberinput_h
 
 #include "../../simtypes.h"
 #include "../../display/scr_coord.h"
@@ -24,6 +16,9 @@
 #include "../gui_theme.h"
 
 
+/**
+ * An input field for integer numbers (with arrow buttons for dec/inc)
+ */
 class gui_numberinput_t :
 	public gui_action_creator_t,
 	public gui_component_t,
@@ -106,7 +101,6 @@ public:
 
 	/**
 	 * Draw the component
-	 * @author Dwachs
 	 */
 	void draw(scr_coord offset) OVERRIDE;
 
