@@ -1,22 +1,16 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_components_gui_speedbar_h
-#define gui_components_gui_speedbar_h
+#ifndef GUI_COMPONENTS_GUI_SPEEDBAR_H
+#define GUI_COMPONENTS_GUI_SPEEDBAR_H
+
 
 #include "gui_component.h"
 #include "../../tpl/slist_tpl.h"
 
 
-/**
- *
- * @author Volker Meyer
- * @date  12.06.2003
- */
 class gui_speedbar_t : public gui_component_t
 {
 private:
@@ -50,4 +44,30 @@ public:
 	scr_size get_max_size() const OVERRIDE;
 };
 
+
+// route progress bar
+class gui_routebar_t : public gui_component_t
+{
+private:
+	const sint32 *value;
+	sint32 base;
+	uint8 state;
+
+public:
+	gui_routebar_t() { base = 100; state = 0; }
+	void set_base(sint32 base);
+	void init(const sint32 *value, uint8 state);
+
+	void set_state(uint8 state);
+
+	/**
+	 * Draw the component
+	 */
+	void draw(scr_coord offset);
+
+	scr_size get_min_size() const OVERRIDE;
+
+	scr_size get_max_size() const OVERRIDE;
+};
+
 #endif
