@@ -1,29 +1,24 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * A text display component
- *
- * @author Hj. Malthaner
- */
+#ifndef GUI_COMPONENTS_GUI_TEXTAREA_H
+#define GUI_COMPONENTS_GUI_TEXTAREA_H
 
-#ifndef gui_textarea_h
-#define gui_textarea_h
 
 #include "gui_component.h"
 
 class cbuffer_t;
 
+/**
+ * A text display component
+ */
 class gui_textarea_t : public gui_component_t
 {
 private:
 	/**
 	* The text to display. May be multi-lined.
-	* @author Hj. Malthaner
 	*/
 	cbuffer_t* buf;
 
@@ -46,7 +41,6 @@ public:
 
 	/**
 	* Draw the component
-	* @author Hj. Malthaner
 	*/
 	void draw(scr_coord offset) OVERRIDE;
 
