@@ -1,18 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Displays a filter settings dialog for the convoi list
- *
- * @author V. Meyer
- */
+#ifndef GUI_CONVOI_FILTER_FRAME_H
+#define GUI_CONVOI_FILTER_FRAME_H
 
-#ifndef CONVOI_FILTER_FRAME_H
-#define  CONVOI_FILTER_FRAME_H
 
 #include "gui_frame.h"
 #include "components/gui_label.h"
@@ -25,6 +18,9 @@ class convoi_frame_t;
 class player_t;
 class goods_desc_t;
 
+/**
+ * Displays a filter settings dialog for the convoi list
+ */
 class convoi_filter_frame_t : public gui_frame_t , private action_listener_t
 {
 public:
@@ -80,12 +76,12 @@ private:
 
 		bool infowin_event(event_t const* const ev) OVERRIDE
 		{
-			bool b = button_t::infowin_event(ev);
-			if(IS_LEFTRELEASE(ev)) {
+			bool swallow = button_t::infowin_event(ev);
+			if(  IS_LEFTRELEASE(ev)  &&  swallow   ) {
 				pressed ^= 1;
 				parent->sort_list();
 			}
-			return b;
+			return swallow;
 		}
 	};
 
@@ -122,7 +118,6 @@ public:
 
 	/**
 	 * Constructor. Generates all necessary Subcomponents.
-	 * @author V. Meyer
 	 */
 	convoi_filter_frame_t(player_t *player, convoi_frame_t *parent);
 
@@ -135,7 +130,6 @@ public:
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author V. Meyer
 	 */
 	const char *get_help_filename() const OVERRIDE {return "convoi_filter.txt"; }
 
