@@ -1,12 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- */
-
-/*
- * Displays an information window for a convoi
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -66,7 +60,6 @@ bool convoi_info_t::route_search_in_progress=false;
  *                 1 = via
  *                 2 = via_amount
  *                 3 = amount
- * @author prissi
  */
 const char *convoi_info_t::sort_text[SORT_MODES] = {
 	"Zielort",
@@ -77,8 +70,8 @@ const char *convoi_info_t::sort_text[SORT_MODES] = {
 
 
 
-convoi_info_t::convoi_info_t(convoihandle_t cnv)
-:	gui_frame_t(""),
+convoi_info_t::convoi_info_t(convoihandle_t cnv) :
+	gui_frame_t(""),
 	text(&freight_info),
 	view(scr_size(max(64, get_base_tile_raster_width()), max(56, (get_base_tile_raster_width() * 7) / 8))),
 	scroll_freight(&container_freight, true, true)
@@ -133,7 +126,7 @@ void convoi_info_t::init(convoihandle_t cnv)
 			container_line.add_component(&line_label);
 			// goto line button
 			line_button.init( button_t::posbutton, NULL, scr_coord(D_MARGIN_LEFT, D_MARGIN_TOP + D_BUTTON_HEIGHT + D_V_SPACE + LINESPACE*4 ) );
-			line_button.set_targetpos( koord(0,0) );
+			line_button.set_targetpos3d( koord3d::invalid );
 			line_button.add_listener( this );
 			line_bound = false;
 		}
@@ -230,7 +223,8 @@ void convoi_info_t::init(convoihandle_t cnv)
 	speed_bar.set_vertical(false);
 	speed_bar.add_color_value(&mean_convoi_speed, color_idx_to_rgb(COL_GREEN));
 	// we update this ourself!
-	route_bar.add_color_value(&cnv_route_index, color_idx_to_rgb(COL_GREEN));
+	route_bar.init(&cnv_route_index, 0);
+	route_bar.set_height(9);
 
 	update_labels();
 
@@ -251,6 +245,24 @@ convoi_info_t::~convoi_info_t()
 
 void convoi_info_t::update_labels()
 {
+	switch (cnv->get_state())
+	{
+		case convoi_t::DRIVING:
+			route_bar.set_state(0);
+			break;
+		case convoi_t::WAITING_FOR_CLEARANCE_ONE_MONTH:
+		case convoi_t::WAITING_FOR_CLEARANCE_TWO_MONTHS:
+		case convoi_t::CAN_START_ONE_MONTH:
+		case convoi_t::CAN_START_TWO_MONTHS:
+			route_bar.set_state(2);
+			break;
+		case convoi_t::NO_ROUTE:
+			route_bar.set_state(3);
+			break;
+		default:
+			route_bar.set_state(1);
+			break;
+	}
 	// use median speed to avoid flickering
 	mean_convoi_speed += speed_to_kmh(cnv->get_akt_speed()*4);
 	mean_convoi_speed /= 2;
@@ -302,7 +314,6 @@ void convoi_info_t::update_labels()
  * Draw new component. The values to be passed refer to the window
  * i.e. It's the screen coordinates of the window where the
  * component is displayed.
- * @author Hj. Malthaner
  */
 void convoi_info_t::draw(scr_coord pos, scr_size size)
 {
@@ -375,14 +386,13 @@ koord3d convoi_info_t::get_weltpos( bool set )
 		return koord3d::invalid;
 	}
 	else {
-		return cnv->get_pos();
+		return cnv.is_bound() ?  cnv->get_pos() : koord3d::invalid;
 	}
 }
 
 
 /**
  * This method is called if an action is triggered
- * @author Hj. Malthaner
  */
 bool convoi_info_t::action_triggered( gui_action_creator_t *comp,value_t /* */)
 {
@@ -508,7 +518,7 @@ void convoi_info_t::rdwr(loadsave_t *file)
 	if(  file->is_loading()  &&  cnv.is_bound())
 	{
 		init(cnv);
-
+		win_set_magic(this, magic_convoi_info+cnv.get_id());
 		reset_min_windowsize();
 		set_windowsize(size);
 	}
