@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 2007 prissi
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef obj_crossing_h
-#define obj_crossing_h
+#ifndef OBJ_CROSSING_H
+#define OBJ_CROSSING_H
+
 
 #include "../simtypes.h"
 #include "../display/simimg.h"
@@ -17,14 +16,13 @@ class vehicle_base_t;
 
 /**
  * road sign for traffic (one way minimum speed, traffic lights)
- * @author Hj. Malthaner
  */
 class crossing_t : public obj_no_info_t
 {
 protected:
 	image_id foreground_image, image;
-	uint8 ns;				// direction
-	uint8 state;	// only needed for loading ...
+	uint8 ns;       // direction
+	uint8 state;    // only needed for loading ...
 	crossing_logic_t *logic;
 	const crossing_desc_t *desc;
 
@@ -44,7 +42,6 @@ public:
 
 	/**
 	 * crossing logic is removed here
-	 * @author prissi
 	 */
 	virtual ~crossing_t();
 
@@ -54,13 +51,11 @@ public:
 
 	/**
 	 * @return string (only used for debug at the moment)
-	 * @author prissi
 	 */
 	void info(cbuffer_t & buf) const OVERRIDE;
 
 	/**
 	 * @return NULL when OK, otherwise an error message
-	 * @author Hj. Malthaner
 	 */
 	const char *is_deletable(const player_t *player) OVERRIDE;
 
@@ -85,7 +80,6 @@ public:
 
 	/**
 	 * Dient zur Neuberechnung des Bildes
-	 * @author Hj. Malthaner
 	 */
 	void calc_image() OVERRIDE;
 
@@ -100,7 +94,6 @@ public:
 
 	/**
 	* For the front image hiding vehicles
-	* @author prissi
 	*/
 	image_id get_front_image() const OVERRIDE { return foreground_image; }
 
