@@ -1,15 +1,20 @@
 /*
- * Curiosity (attractions) builder dialog
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_curiosity_edit_h
-#define gui_curiosity_edit_h
+#ifndef GUI_CURIOSITY_EDIT_H
+#define GUI_CURIOSITY_EDIT_H
+
 
 #include "extend_edit.h"
 
 class tool_build_house_t;
 class building_desc_t;
 
+/*
+ * Curiosity (attractions) builder dialog
+ */
 class curiosity_edit_frame_t : public extend_edit_gui_t
 {
 private:
@@ -34,14 +39,12 @@ public:
 	/**
 	* in top-level windows the name is displayed in titlebar
 	* @return the non-translated component name
-	* @author Hj. Malthaner
 	*/
 	const char* get_name() const { return "curiosity builder"; }
 
 	/**
 	* Set the window associated helptext
 	* @return the filename for the helptext, or NULL
-	* @author Hj. Malthaner
 	*/
 	const char* get_help_filename() const OVERRIDE { return "curiosity_build.txt"; }
 
@@ -49,7 +52,6 @@ public:
 	* Draw new component. The values to be passed refer to the window
 	* i.e. It's the screen coordinates of the window where the
 	* component is displayed.
-	* @author Hj. Malthaner
 	*/
 	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
