@@ -1,13 +1,6 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- */
-
-/**
- * Where curiosity (attractions) stats are calculated for list dialog
- * @author Hj. Malthaner
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "curiositylist_stats_t.h"
@@ -68,7 +61,7 @@ curiositylist_stats_t::curiositylist_stats_t(gebaeude_t *att)
 	set_table_layout(4,1);
 	button_t *b = new_component<button_t>();
 	b->set_typ(button_t::posbutton_automatic);
-	b->set_targetpos(attraction->get_pos().get_2d());
+	b->set_targetpos3d(attraction->get_pos());
 	// indicator bar
 	add_component(&indicator);
 	indicator.set_max_size(scr_size(D_INDICATOR_WIDTH,D_INDICATOR_HEIGHT));
@@ -121,7 +114,6 @@ bool curiositylist_stats_t::is_valid() const
 /**
  * Events werden hiermit an die GUI-Komponenten
  * gemeldet
- * @author Hj. Malthaner
  */
 bool curiositylist_stats_t::infowin_event(const event_t * ev)
 {
@@ -136,7 +128,6 @@ bool curiositylist_stats_t::infowin_event(const event_t * ev)
 
 /**
  * Draw the component
- * @author Hj. Malthaner
  */
 void curiositylist_stats_t::draw(scr_coord offset)
 {
