@@ -1,17 +1,11 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/**
- * Where curiosity (attractions) stats are calculated for list dialog
- * @author Hj. Malthaner
- */
+#ifndef GUI_CURIOSITYLIST_STATS_T_H
+#define GUI_CURIOSITYLIST_STATS_T_H
 
-#ifndef curiositylist_stats_t_h
-#define curiositylist_stats_t_h
 
 #include "components/gui_aligned_container.h"
 #include "components/gui_colorbox.h"
@@ -20,9 +14,12 @@
 class gebaeude_t;
 
 namespace curiositylist {
-    enum sort_mode_t { by_name=0, by_paxlevel/*, by_maillevel*/, SORT_MODES };
+	enum sort_mode_t { by_name=0, by_paxlevel/*, by_maillevel*/, SORT_MODES };
 };
 
+/**
+ * Where curiosity (attractions) stats are calculated for list dialog
+ */
 class curiositylist_stats_t : public gui_aligned_container_t, public gui_scrolled_list_t::scrollitem_t
 {
 private:
@@ -43,7 +40,6 @@ public:
 
 	/**
 	* Draw the component
-	* @author Hj. Malthaner
 	*/
 	void draw(scr_coord offset) OVERRIDE;
 };
