@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 /*
@@ -56,21 +54,10 @@
 
 #include "../boden/wege/weg.h"
 
+#include "../unicode.h"
 
 char depot_frame_t::name_filter_value[64] = "";
 
-static const char* engine_type_names[9] =
-{
-	"unknown",
-	"steam",
-	"diesel",
-	"electric",
-	"bio",
-	"sail",
-	"fuel_cell",
-	"hydrogene",
-	"battery"
-};
 
 static int sort_by_action;
 
@@ -139,7 +126,7 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 
 	// goto line button
 	line_button.set_typ(button_t::posbutton);
-	line_button.set_targetpos(koord(0,0));
+	line_button.set_targetpos3d(koord3d::invalid);
 	line_button.add_listener(this);
 	add_component(&line_button);
 
@@ -152,7 +139,7 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 	cont_convoi.add_component(&lb_convoi_number);
 	cont_convoi.add_component(&convoi);
 
-	//	add_component(&convoi);
+	// add_component(&convoi);
 
 	add_component(&lb_convoi_count);
 	add_component(&lb_convoi_speed);
@@ -345,24 +332,23 @@ void depot_frame_t::layout(scr_size *size)
 	}
 
 	/*
-	*	Dialog format:
-	*
-	*	Main structure are these parts from top to bottom:
-	*
-	*	    [SELECT]		convoi-selector
-	*	    [CONVOI]		current convoi
-	*	    [ACTIONS]		convoi action buttons
-	*	    [PANEL]		vehicle panel
-	*	    [VINFO]		vehicle infotext
-	*
-	*
-	*	Structure of [SELECT] is:
-	*
-	*	    [Info]
-	*	    [PREV][LABEL][NEXT]
-	*
-	*  PREV and NEXT are small buttons - Label is adjusted to total width.
-	*/
+	 * Dialog format:
+	 *
+	 * Main structure are these parts from top to bottom:
+	 *
+	 *     [SELECT]    convoi-selector
+	 *     [CONVOI]    current convoi
+	 *     [ACTIONS]   convoi action buttons
+	 *     [PANEL]     vehicle panel
+	 *     [VINFO]     vehicle infotext
+	 *
+	 * Structure of [SELECT] is:
+	 *
+	 *     [Info]
+	 *     [PREV][LABEL][NEXT]
+	 *
+	 *  PREV and NEXT are small buttons - Label is adjusted to total width.
+	 */
 	const scr_coord_val SELECT_HEIGHT = D_BUTTON_HEIGHT;
 	const scr_coord_val selector_x = max(max(max(max(max(102, proportional_string_width(translator::translate("no convois")) + 4),
 		proportional_string_width(translator::translate("1 convoi")) + 4),
@@ -374,32 +360,32 @@ void depot_frame_t::layout(scr_size *size)
 	const scr_coord_val BUTTON_WIDTH_DEPOT = max(D_BUTTON_WIDTH,(win_size.w - D_MARGIN_LEFT - D_MARGIN_RIGHT - 4*D_H_SPACE) / 4);
 
 	/*
-	*	Structure of [CONVOI] is a image_list and an infos:
-	*
-	*	    [List]
-	*	    [Info]
-	*
-	* The image list is horizontally "condensed".
-	*/
+	 * Structure of [CONVOI] is a image_list and an infos:
+	 *
+	 *     [List]
+	 *     [Info]
+	 *
+	 * The image list is horizontally "condensed".
+	 */
 	const scr_coord_val CLIST_WIDTH = depot->get_max_convoi_length() * (grid.x - grid_dx) + 2 * gui_image_list_t::BORDER;
 	const scr_coord_val CLIST_HEIGHT = grid.y + 2 * gui_image_list_t::BORDER + 5;
 	const scr_coord_val CINFO_HEIGHT = LINESPACE * 3 + D_BUTTON_HEIGHT + 1;
 
 	/*
-	*	Structure of [ACTIONS] is a row of buttons:
-	*
-	*	    [Start][Schedule][Destroy][Sell]
-	*	    [new Route][change Route][delete Route]
-	*/
+	 * Structure of [ACTIONS] is a row of buttons:
+	 *
+	 *     [Start][Schedule][Destroy][Sell]
+	 *     [new Route][change Route][delete Route]
+	 */
 	/*
-	*	Structure of [VINFO] is one multiline text.
-	*/
+	 * Structure of [VINFO] is one multiline text.
+	 */
 	const scr_coord_val VINFO_HEIGHT =  7*LINESPACE + D_BUTTON_HEIGHT + D_EDIT_HEIGHT + 5*D_V_SPACE;
 
 	/*
-	*  Now we can do the first vertical adjustment:
-	*  Calculate position of each element to tabs.
-	*/
+	 *  Now we can do the first vertical adjustment:
+	 *  Calculate position of each element to tabs.
+	 */
 	const scr_coord_val SELECT_VSTART = D_MARGIN_TOP;
 	const scr_coord_val CONVOI_VSTART = SELECT_VSTART + SELECT_HEIGHT + LINESPACE + D_V_SPACE;
 	const scr_coord_val CINFO_VSTART = CONVOI_VSTART + CLIST_HEIGHT +  D_SCROLLBAR_HEIGHT*(CLIST_WIDTH >= win_size.w-D_MARGIN_LEFT-D_MARGIN_RIGHT);
@@ -407,11 +393,11 @@ void depot_frame_t::layout(scr_size *size)
 	const scr_coord_val PANEL_VSTART = ACTIONS_VSTART + D_BUTTON_HEIGHT;
 
 	/*
-	* Now we determine the row/col layout for the panel and the total panel
-	* size.
-	* build_vehicle_lists() fills loks_vec and waggon_vec.
-	* Total width will be expanded to match complete columns in panel.
-	*/
+	 * Now we determine the row/col layout for the panel and the total panel
+	 * size.
+	 * build_vehicle_lists() fills loks_vec and waggon_vec.
+	 * Total width will be expanded to match complete columns in panel.
+	 */
 	const scr_coord_val TAB_HEADER_HEIGHT = tabs.get_required_size().h;
 	const scr_coord_val total_h = PANEL_VSTART + VINFO_HEIGHT + D_TITLEBAR_HEIGHT + TAB_HEADER_HEIGHT + 2 * gui_image_list_t::BORDER + D_MARGIN_BOTTOM + 1;
 	scr_coord_val PANEL_ROWS = max(1, ((win_size.h - total_h) / grid.y));
@@ -423,8 +409,8 @@ void depot_frame_t::layout(scr_size *size)
 	const scr_coord_val INFO_VSTART = PANEL_VSTART + PANEL_HEIGHT + div_tabbottom.get_size().h;
 
 	/*
-	*  Now we can do the complete vertical adjustment:
-	*/
+	 *  Now we can do the complete vertical adjustment:
+	 */
 	const scr_coord_val TOTAL_HEIGHT = PANEL_VSTART + PANEL_HEIGHT + D_V_SPACE + VINFO_HEIGHT + D_TITLEBAR_HEIGHT + 1 + D_MARGIN_BOTTOM;
 	const scr_coord_val MIN_TOTAL_HEIGHT = PANEL_VSTART + MIN_PANEL_HEIGHT + D_V_SPACE + VINFO_HEIGHT + D_TITLEBAR_HEIGHT + 1 + D_MARGIN_BOTTOM;
 
@@ -441,8 +427,8 @@ void depot_frame_t::layout(scr_size *size)
 	set_min_windowsize(scr_size(D_DEFAULT_WIDTH, MIN_TOTAL_HEIGHT));
 
 	/*
-	* DONE with layout planning - now build everything.
-	*/
+	 * DONE with layout planning - now build everything.
+	 */
 
 	/*
 	 * [SELECT]:
@@ -456,7 +442,6 @@ void depot_frame_t::layout(scr_size *size)
 
 	/*
 	 * [SELECT ROUTE]:
-	 * @author hsiegeln
 	 */
 	line_button.set_pos(scr_coord(D_MARGIN_LEFT, SELECT_VSTART + D_BUTTON_HEIGHT));
 	lb_convoi_line.set_pos(scr_coord(D_MARGIN_LEFT + line_button.get_size().w + 2, SELECT_VSTART + D_BUTTON_HEIGHT));
@@ -634,7 +619,7 @@ void depot_frame_t::set_windowsize( scr_size size )
 
 void depot_frame_t::activate_convoi( convoihandle_t c )
 {
-	icnv = -1;	// deselect
+	icnv = -1; // deselect
 	for(  uint i = 0;  i < depot->convoi_count();  i++  ) {
 		if(  c == depot->get_convoi(i)  ) {
 			icnv = i;
@@ -660,10 +645,6 @@ bool depot_frame_t::is_in_vehicle_list(const vehicle_desc_t *info)
 // add a single vehicle (helper function)
 void depot_frame_t::add_to_vehicle_list(const vehicle_desc_t *info)
 {
-	// prissi: is it a non-electric track?
-	// Hajo: check for timeline
-	// prissi: and retirement date
-
 	// Check if vehicle should be filtered
 	const goods_desc_t *freight = info->get_freight_type();
 	// Only filter when required and never filter engines
@@ -699,7 +680,7 @@ void depot_frame_t::add_to_vehicle_list(const vehicle_desc_t *info)
 	if(  info->get_engine_type() == vehicle_desc_t::electric  &&  (info->get_freight_type()==goods_manager_t::passengers  ||  info->get_freight_type()==goods_manager_t::mail)  ) {
 		electrics_vec.append(img_data);
 	}
-	// since they come "pre-sorted" for the vehikelbauer, we have to do nothing to keep them sorted
+	// since they come "pre-sorted" from the vehikelbauer, we have to do nothing to keep them sorted
 	else if(info->get_freight_type() == goods_manager_t::passengers  ||  info->get_freight_type() == goods_manager_t::mail) {
 		pas_vec.append(img_data);
 	}
@@ -791,7 +772,7 @@ void depot_frame_t::build_vehicle_lists()
 				}
 				if(append) {
 					// name filter. Try to check both object name and translation name (case sensitive though!)
-					if(  name_filter_value[0]==0  ||  (strstr(info->get_name(), name_filter_value)  ||  strstr(translator::translate(info->get_name()), name_filter_value))  ) {
+					if(  name_filter_value[0]==0  ||  (utf8caseutf8(info->get_name(), name_filter_value)  ||  utf8caseutf8(translator::translate(info->get_name()), name_filter_value))  ) {
 						add_to_vehicle_list( info );
 					}
 				}
@@ -813,7 +794,6 @@ static void get_line_list(const depot_t* depot, vector_tpl<linehandle_t>* lines)
 void depot_frame_t::update_data()
 {
 	static const char *txt_veh_action[3] = { "anhaengen", "voranstellen", "verkaufen" };
-	static const char *txt_sort_by[sb_length] = { "Vehicle Name", "Capacity", "Price", "Cost", "Cost per unit", "Max. speed", "Vehicle Power", "Weight", "Intro. date", "Retire date" };
 
 	// change green into blue for retired vehicles
 	const int month_now = welt->get_timeline_year_month();
@@ -894,10 +874,10 @@ void depot_frame_t::update_data()
 		for(  unsigned i = 0;  i < cnv->get_vehicle_count();  i++  ) {
 			if(  !cnv->get_vehikel(i)->get_desc()->is_available(month_now)  ) {
 				if(  convoi_pics[i]->lcolor == color_idx_to_rgb(COL_GREEN)  ) {
-					convoi_pics[i]->lcolor = color_idx_to_rgb(COL_BLUE);
+					convoi_pics[i]->lcolor = gui_theme_t::gui_color_obsolete;
 				}
 				if(  convoi_pics[i]->rcolor == color_idx_to_rgb(COL_GREEN)  ) {
-					convoi_pics[i]->rcolor = color_idx_to_rgb(COL_BLUE);
+					convoi_pics[i]->rcolor = gui_theme_t::gui_color_obsolete;
 				}
 			}
 		}
@@ -908,7 +888,7 @@ void depot_frame_t::update_data()
 	FOR(vehicle_image_map, const& i, vehicle_map) {
 		vehicle_desc_t const* const    info = i.key;
 		gui_image_list_t::image_data_t& img  = *i.value;
-		const PIXVAL ok_color = color_idx_to_rgb(info->is_available(month_now) ? COL_GREEN : COL_BLUE);
+		const PIXVAL ok_color = info->is_available(month_now) ? color_idx_to_rgb(COL_GREEN) : gui_theme_t::gui_color_obsolete;
 
 		img.count = 0;
 		img.lcolor = ok_color;
@@ -916,10 +896,10 @@ void depot_frame_t::update_data()
 
 		/*
 		* color bars for current convoi:
-		*  green/green	okay to append/insert
-		*  red/red		cannot be appended/inserted
-		*  green/yellow	append okay, cannot be end of train
-		*  yellow/green	insert okay, cannot be start of train
+		*  green/green  okay to append/insert
+		*  red/red      cannot be appended/inserted
+		*  green/yellow append okay, cannot be end of train
+		*  yellow/green insert okay, cannot be start of train
 		*/
 
 		if(veh_action == va_insert) {
@@ -1033,12 +1013,11 @@ void depot_frame_t::update_data()
 	vehicle_filter.set_selection(depot->selected_filter);
 
 	sort_by.clear_elements();
-	for(int i = 0; i < sb_length; i++)
-	{
-		sort_by.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate(txt_sort_by[i]), SYSCOL_TEXT);
+	for(int i = 0; i < vehicle_builder_t::sb_length; i++) {
+		sort_by.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate(vehicle_builder_t::vehicle_sort_by[i]), SYSCOL_TEXT);
 	}
 	if(  depot->selected_sort_by > sort_by.count_elements()  ) {
-		depot->selected_sort_by = sb_name;
+		depot->selected_sort_by = vehicle_builder_t::sb_name;
 	}
 	sort_by.set_selection(depot->selected_sort_by);
 
@@ -1178,8 +1157,8 @@ void depot_frame_t::update_data()
 				txt_convoi_value.printf("%s %8s", translator::translate("Restwert:"), buf );
 
 				txt_convoi_cost.clear();
-				if(  sint64 fix_cost = welt->scale_with_month_length((sint64)cnv->get_fix_cost())  ) {
-					money_to_string(  buf, (double)fix_cost / 100.0, false );
+				if(  sint64 fix_cost = cnv->get_fixed_cost()  ) {
+					money_to_string(  buf, (double)cnv->get_purchase_cost() / 100.0, false );
 					txt_convoi_cost.printf( translator::translate("Cost: %8s (%.2f$/km %.2f$/m)\n"), buf, (double)cnv->get_running_cost()/100.0, (double)fix_cost/100.0 );
 				}
 				else {
@@ -1296,7 +1275,7 @@ bool depot_frame_t::action_triggered( gui_action_creator_t *comp, value_t p)
 		return true;
 	}
 
-	if(  comp != NULL  ) {	// message from outside!
+	if(  comp != NULL  ) { // message from outside!
 		if(  comp == &bt_start  ) {
 			if(  cnv.is_bound()  ) {
 				//first: close schedule (will update schedule on clients)
@@ -1387,12 +1366,14 @@ bool depot_frame_t::action_triggered( gui_action_creator_t *comp, value_t p)
 		}
 		else if(  comp == &convoy_selector  ) {
 			icnv = p.i - 1;
-/*			if(  !depot->get_convoi(icnv).is_bound()  ) {
+/*
+			if(  !depot->get_convoi(icnv).is_bound()  ) {
 				set_focus( NULL );
 			}
 			else {
 				set_focus( (gui_component_t *)&convoy_selector );
-			}*/
+			}
+*/
 		}
 		else if(  comp == &line_selector  ) {
 			const int selection = p.i;
@@ -1413,7 +1394,8 @@ bool depot_frame_t::action_triggered( gui_action_creator_t *comp, value_t p)
 							schedule->sprintf_schedule( buf );
 						}
 					}
-					last_selected_line = linehandle_t();	// clear last selected line so we can get a new one ...
+
+					last_selected_line = linehandle_t(); // clear last selected line so we can get a new one ...
 					depot->call_depot_tool('l', convoihandle_t(), buf);
 				}
 				return true;
@@ -1478,10 +1460,7 @@ bool depot_frame_t::infowin_event(const event_t *ev)
 		}
 
 		if(next_dep  &&  next_dep!=this->depot) {
-			/**
-			 * Replace our depot_frame_t with a new at the same position.
-			 * Volker Meyer
-			 */
+			//  Replace our depot_frame_t with a new at the same position.
 			scr_coord const pos = win_get_pos(this);
 			destroy_win( this );
 
@@ -1666,13 +1645,13 @@ void depot_frame_t::draw_vehicle_info_text(scr_coord pos)
 		buf.printf( "%s", translator::translate( veh_type->get_name(), welt->get_settings().get_name_language_id() ) );
 
 		if(  veh_type->get_power() > 0  ) { // LOCO
-			buf.printf( " (%s)\n", translator::translate( engine_type_names[veh_type->get_engine_type()+1] ) );
+			buf.printf( " (%s)\n", translator::translate( vehicle_builder_t::engine_type_names[veh_type->get_engine_type()+1] ) );
 		}
 		else {
 			buf.append( "\n" );
 		}
 
-		if(  sint64 fix_cost = welt->scale_with_month_length(veh_type->get_maintenance())  ) {
+		if(  sint64 fix_cost = welt->scale_with_month_length( veh_type->get_fixed_cost() )  ) {
 			char tmp[128];
 			money_to_string( tmp, veh_type->get_price() / 100.0, false );
 			buf.printf( translator::translate("Cost: %8s (%.2f$/km %.2f$/m)\n"), tmp, veh_type->get_running_cost()/100.0, fix_cost/100.0 );
@@ -1706,7 +1685,7 @@ void depot_frame_t::draw_vehicle_info_text(scr_coord pos)
 		}
 
 		int yyy = pos.y + D_TITLEBAR_HEIGHT + div_action_bottom.get_pos().y + div_action_bottom.get_size().h + 2;
- 		display_multiline_text_rgb( pos.x + D_MARGIN_LEFT, yyy, buf, SYSCOL_TEXT);
+		display_multiline_text_rgb( pos.x + D_MARGIN_LEFT, yyy, buf, SYSCOL_TEXT);
 
 		// column 2
 		buf.clear();
