@@ -1,16 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * The depot window, where to buy convois
- */
+#ifndef GUI_DEPOT_FRAME_H
+#define GUI_DEPOT_FRAME_H
 
-#ifndef gui_depot_frame2_t_h
-#define gui_depot_frame2_t_h
 
 #include "gui_frame.h"
 #include "components/gui_label.h"
@@ -35,6 +30,9 @@ class depot_t;
 class vehicle_desc_t;
 
 
+/*
+ * The depot window, where to buy convois
+ */
 class depot_convoi_capacity_t : public gui_container_t
 {
 private:
@@ -50,41 +48,32 @@ public:
 
 /**
  * Depot frame, handles all interaction with a vehicle depot.
- *
- * @author Hansjrg Malthaner
- * @date 22-Nov-01
  */
-class depot_frame_t : public gui_frame_t,
-                      public action_listener_t
+class depot_frame_t : public gui_frame_t, public action_listener_t
 {
 private:
 	/**
 	 * The depot to display
-	 * @author Hansjrg Malthaner
 	 */
 	depot_t *depot;
 
 	/**
 	 * The current convoi to display.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	int icnv;
 
-	/* show retired vehicles (same for all depot)
-	* @author prissi
-	*/
+	/**
+	 * show retired vehicles (same for all depot)
+	 */
 	static bool show_retired_vehicles;
 
-	/* show retired vehicles (same for all depot)
-	* @author prissi
-	*/
+	/**
+	 * show retired vehicles (same for all depot)
+	 */
 	static bool show_all;
 
 	/**
 	 * Gui elements
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	gui_label_t lb_convois;
 
@@ -92,7 +81,7 @@ private:
 	const char* new_convoy_text;
 	gui_combobox_t convoy_selector;
 
-	button_t line_button;	// goto line ...
+	button_t line_button; // goto line ...
 
 	gui_label_t lb_convoi_count;
 
@@ -134,7 +123,6 @@ private:
 
 	/**
 	 * buttons for new route-management
-	 * @author hsiegeln
 	 */
 	button_t bt_new_line;
 	button_t bt_change_line;
@@ -206,64 +194,42 @@ private:
 	/**
 	 * A helper map to update loks_vec and waggons_Vec. All entries from
 	 * loks_vec and waggons_vec are referenced here.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	typedef ptrhashtable_tpl<vehicle_desc_t const*, gui_image_list_t::image_data_t*> vehicle_image_map;
 	vehicle_image_map vehicle_map;
 
 	/**
 	 * Draw the info text for the vehicle the mouse is over - if any.
-	 * @author Volker Meyer, Hj. Malthaner
-	 * @date  09.06.2003
-	 * @update 09-Jan-04
 	 */
 	void draw_vehicle_info_text(scr_coord pos);
 
 	/**
 	 * Calculate the values of the vehicles of the given type owned by the
 	 * player.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	sint64 calc_restwert(const vehicle_desc_t *veh_type);
 
 	/**
 	 * Does this window need a min size button in the title bar?
 	 * @return true if such a button is needed
-	 * @author Hj. Malthaner
 	 */
 	bool has_min_sizer() const OVERRIDE {return true;}
 
-	// true if already stored here
+	/// true if already stored here
 	bool is_in_vehicle_list(const vehicle_desc_t *info);
 
-	// add a single vehicle (helper function)
+	/// add a single vehicle (helper function)
 	void add_to_vehicle_list(const vehicle_desc_t *info);
 
-	// for convoi image
+	/// for convoi image
 	void image_from_convoi_list(uint nr, bool to_end);
 
 	void image_from_storage_list(gui_image_list_t::image_data_t *image_data);
 
-	// initialize everything
+	/// initialize everything
 	void init(depot_t *depot);
 
 public:
-	// sorting categories
-	enum {
-		sb_name,
-		sb_capacity,
-		sb_price,
-		sb_cost,
-		sb_cost_per_unit,
-		sb_speed, sb_power,
-		sb_weight,
-		sb_intro_date,
-		sb_retire_date,
-		sb_length
-	};
-
 	// the next two are only needed for depot_t update notifications
 	void activate_convoi( convoihandle_t cnv );
 
@@ -271,15 +237,11 @@ public:
 
 	/**
 	 * Do the dynamic dialog layout
-	 * @author Volker Meyer
-	 * @date  18.06.2003
 	 */
 	void layout(scr_size *);
 
 	/**
 	 * Update texts, image lists and buttons according to the current state.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	void update_data();
 
@@ -290,36 +252,28 @@ public:
 
 	/**
 	 * Set the window size
-	 * @author (Mathew Hounsell)
-	 * @date   11-Mar-2003
 	 */
 	void set_windowsize(scr_size size) OVERRIDE;
 
 	/**
 	 * Create and fill loks_vec and waggons_vec.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	void build_vehicle_lists();
 
-	/*
+	/**
 	 * Will update the tabs (don't show empty ones).
-	 * @author Gerd Wachsmuth
-	 * @date 08.05.2009
 	 */
 	void update_tabs();
 
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char * get_help_filename() const OVERRIDE {return "depot.txt";}
 
 	/**
 	 * Does this window need a next button in the title bar?
 	 * @return true if such a button is needed
-	 * @author Volker Meyer
 	 */
 	bool has_next() const OVERRIDE {return true;}
 
@@ -328,7 +282,6 @@ public:
 
 	/**
 	 * Open dialog for schedule entry.
-	 * @author Hj. Malthaner
 	 */
 	void open_schedule_editor();
 
@@ -336,11 +289,9 @@ public:
 
 	/**
 	 * Draw the Frame
-	 * @author Hansjrg Malthaner
 	 */
 	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
-	// @author hsiegeln
 	void apply_line();
 
 	void set_selected_line(linehandle_t line) { selected_line = line; }
