@@ -1,14 +1,7 @@
 /*
-* Copyright (c) 1997 - 2001 Hansjrg Malthaner
-*
-* This file is part of the Simutrans project under the artistic licence.
-* (see licence.txt)
-*/
-
-/*
-* Menu with display settings
-* @author Hj. Malthaner
-*/
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
 
 #include "display_settings.h"
 #include "../simdebug.h"
@@ -68,12 +61,18 @@ public:
 	{
 		scr_coord p = pos + offset;
 
-		FLAGGED_PIXVAL pc = welt->get_active_player() ? color_idx_to_rgb(welt->get_active_player()->get_player_color1()+4) : color_idx_to_rgb(COL_ORANGE);
+		FLAGGED_PIXVAL pc = welt->get_active_player() ? color_idx_to_rgb(welt->get_active_player()->get_player_color1()+3) : color_idx_to_rgb(COL_ORANGE);
 		const char *text = get_text_pointer();
 
-		switch( env_t::show_names >> 2 ) {
+		char ddd[ 16 ];
+		sprintf( ddd, "%d", env_t::show_names );
+		display_proportional_rgb( p.x, p.y + get_size().h/2, ddd, 0, color_idx_to_rgb(COL_BLACK), 1 );
+		p.x += 20;
+		switch( env_t::show_names>>2 ) {
 		case 0:
-			display_ddd_proportional_clip( p.x, p.y + get_size().h/2, proportional_string_width(text)+7, 0, pc, color_idx_to_rgb(COL_BLACK), text, 1 );
+			if(  env_t::show_names & 1  ) {
+				display_ddd_proportional_clip( p.x, p.y + get_size().h/2, proportional_string_width(text)+7, 0, pc, color_idx_to_rgb(COL_BLACK), text, 1 );
+			}
 			break;
 		case 1:
 			display_outline_proportional_rgb( p.x, p.y, pc+1, color_idx_to_rgb(COL_BLACK), text, 1 );
@@ -83,8 +82,6 @@ public:
 			display_ddd_box_clip_rgb(         p.x,                     p.y,   LINESPACE,   LINESPACE,   pc-2, pc+2 );
 			display_fillbox_wh_clip_rgb(      p.x+1,                   p.y+1, LINESPACE-2, LINESPACE-2, pc,   true);
 			break;
-		case 3: // show nothing
-			break;
 		}
 	}
 
@@ -108,7 +105,7 @@ gui_settings_t::gui_settings_t()
 	add_component( buttons + IDBTN_CHANGE_FONT );
 
 	// add controls to info container
-	add_table(2,3);
+	add_table(2,4);
 	set_alignment(ALIGN_LEFT);
 	// Frame time label
 	new_component<gui_label_t>("Frame time:");
@@ -142,7 +139,7 @@ void gui_settings_t::draw(scr_coord offset)
 	idle_time_value_label.update();
 
 	// fps_label
-	uint32 target_fps = world()->is_fast_forward() ? 10 : env_t::fps;
+	uint32 target_fps = world()->is_fast_forward() ? env_t::ff_fps : env_t::fps;
 	uint32 loops = world()->get_realFPS();
 	PIXVAL color = SYSCOL_TEXT_HIGHLIGHT;
 	if(  loops < (target_fps*16*3)/4  ) {
@@ -301,6 +298,14 @@ bool transparency_settings_t::action_triggered( gui_action_creator_t *comp, valu
 }
 
 
+void transparency_settings_t::draw( scr_coord offset )
+{
+	hide_buildings.set_selection( env_t::hide_buildings );
+
+	gui_aligned_container_t::draw(offset);
+}
+
+
 station_settings_t::station_settings_t()
 {
 	set_table_layout( 1, 0 );
@@ -362,6 +367,7 @@ traffic_settings_t::traffic_settings_t()
 	convoy_tooltip.set_focusable(false);
 	convoy_tooltip.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate("convoi error tooltips"), SYSCOL_TEXT);
 	convoy_tooltip.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate("convoi mouseover tooltips"), SYSCOL_TEXT);
+	convoy_tooltip.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate("line name mouseover tooltips"), SYSCOL_TEXT);
 	convoy_tooltip.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate("all convoi tooltips"), SYSCOL_TEXT);
 	convoy_tooltip.set_selection(env_t::show_vehicle_states);
 	add_component(&convoy_tooltip, 2);
@@ -416,7 +422,7 @@ bool traffic_settings_t::action_triggered( gui_action_creator_t *comp, value_t v
 	if( &follow_mode == comp ) {
 		env_t::follow_convoi_underground = v.i;
 	}
-		
+
 	if( &money_booking == comp ) {
 		env_t::show_money_message = v.i;
 	}
@@ -585,6 +591,7 @@ void color_gui_t::draw(scr_coord pos, scr_size size)
 	buttons[IDBTN_UNDERGROUND_VIEW].pressed = grund_t::underground_mode == grund_t::ugm_all;
 	buttons[IDBTN_TRANSPARENT_STATION_COVERAGE].pressed = env_t::use_transparency_station_coverage;
 	buttons[IDBTN_TRANSPARENT_INSTEAD_OF_HIDDEN].pressed = env_t::hide_with_transparency;
+	
 
 	// All components are updated, now draw them...
 	gui_frame_t::draw(pos, size);
