@@ -1,10 +1,11 @@
 /*
- * Menu with display settings
- * @author Hj. Malthaner
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef _display_settings_h_
-#define _display_settings_h_
+#ifndef GUI_DISPLAY_SETTINGS_H
+#define GUI_DISPLAY_SETTINGS_H
+
 
 #include "gui_frame.h"
 #include "components/gui_divider.h"
@@ -14,7 +15,9 @@
 #include "components/gui_combobox.h"
 #include "components/gui_tab_panel.h"
 
-
+/**
+ * Menu with display settings
+ */
 class gui_settings_t : public gui_aligned_container_t
 {
 private:
@@ -25,7 +28,7 @@ private:
 		simloops_value_label;
 public:
 	gui_settings_t();
-	virtual void draw( scr_coord offset ) override;
+	virtual void draw( scr_coord offset ) OVERRIDE;
 };
 
 class map_settings_t : public gui_aligned_container_t, public action_listener_t
@@ -36,7 +39,7 @@ public:
 		brightness,
 		scrollspeed;
 	map_settings_t();
-	virtual bool action_triggered( gui_action_creator_t *comp, value_t v ) override;
+	virtual bool action_triggered( gui_action_creator_t *comp, value_t v ) OVERRIDE;
 };
 
 class station_settings_t : public gui_aligned_container_t
@@ -53,6 +56,7 @@ private:
 public:
 	transparency_settings_t();
 	virtual bool action_triggered( gui_action_creator_t *comp, value_t v );
+	void draw(scr_coord offset) OVERRIDE;
 };
 
 
@@ -68,7 +72,6 @@ public:
 
 /**
  * Display settings dialog
- * @author Hj. Malthaner
  */
 class color_gui_t : public gui_frame_t, private action_listener_t
 {
@@ -79,17 +82,16 @@ private:
 	station_settings_t station_settings;
 	traffic_settings_t traffic_settings;
 	gui_scrollpane_t scrolly_gui, scrolly_map, scrolly_transparency, scrolly_station, scrolly_traffic;
-	gui_tab_panel_t	tabs;
+	gui_tab_panel_t tabs;
 
 public:
 	color_gui_t();
 
-	virtual bool has_min_sizer() const {return true;}
+	virtual bool has_min_sizer() const OVERRIDE {return true;}
 
 	/**
 	 * Some windows have associated help text.
 	 * @return The help file name or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char * get_help_filename() const OVERRIDE { return "display.txt"; }
 
