@@ -1,4 +1,10 @@
 #!/bin/bash
+
+#
+# This file is part of the Simutrans project under the Artistic License.
+# (see LICENSE.txt)
+#
+
 #
 # parameters (in this order):
 # "-no-lang" prevents downloading the translations
@@ -31,6 +37,41 @@ getDLL()
 	fi
 }
 
+getSDL2mac()
+{
+	# Use curl if available, else use wget
+	curl -h > /dev/null
+	if [ $? -eq 0 ]; then
+	    curl http://www.libsdl.org/release/SDL2-2.0.10.dmg > SDL2-2.0.10.dmg || {
+	      echo "Error: download of file SDL2-2.0.10.dmg failed (curl returned $?)" >&2
+	      rm -f "SDL2-2.0.10.dmg"
+	      exit 4
+	    }
+	    curl http://www.libsdl.org/release/SDL2-2.0.10.dmg > SDL2-2.0.10.dmg || {
+	      echo "Error: download of file SDL2-2.0.10.dmg failed (curl returned $?)" >&2
+	      rm -f "SDL2-2.0.10.dmg"
+	      exit 4
+	    }
+	else
+	    wget --help > /dev/null
+	    if [ $? -eq 0 ]; then
+	        wget -N  http://www.libsdl.org/release/SDL2-2.0.10.dmg || {
+	          echo "Error: download of file SDL2-2.0.10.dmg failed (wget returned $?)" >&2
+	          rm -f "SDL2-2.0.10.dmg"
+	          exit 4
+	        }
+	        wget -N http://www.libsdl.org/release/SDL2-2.0.10.dmg || {
+	          echo "Error: download of file SDL2-2.0.10.dmg failed (wget returned $?)" >&2
+	          rm -f "SDL2-2.0.10.dmg"
+	          exit 4
+	        }
+	    else
+	        echo "Error: Neither curl or wget are available on your system, please install either and try again!" >&2
+	        exit 6
+	    fi
+	fi
+}
+
 # first assume unix name defaults ...
 simexe=
 updatepath="/"
@@ -93,17 +134,23 @@ fi
 
 # now add revision number without any modificators
 # fetch language files
-if [ `expr match "$*" ".*-rev="` != "0" ]; then
-  REV_NR=$(echo $* | sed "s/.*-rev=[ ]*//" | sed "s/[^0-9]*//")
+if [ "$#" = "0"  ]; then
+  # try local answer assuming we use svn
+  REV_NR=`svnversion`
+  if [ -z "$REV_NR" ]; then
+		# nothing, then use revision number from server (assuming we are up to date)
+		REV_NR=`svn info --show-item revision svn://servers.simutrans.org/simutrans | sed "s/[0-9]*://" | sed "s/M.*//"`
+  fi
   simarchiv=$simarchivbase-$REV_NR
-elif [ "$#" = "0"  ]  ||  [ `expr match "$*" ".*-no-rev"` = "0" ]; then
-  REV_NR=`svnversion | sed "s/[0-9]*://" | sed "s/M.*//"`
+elif [ `expr match "$*" ".*-rev="` > 0 ]; then
+  REV_NR=$(echo $* | sed "s/.*-rev=[ ]*//" | sed "s/[^0-9]*//")
   simarchiv=$simarchivbase-$REV_NR
 else
   echo "No revision given!"
   simarchiv=$simarchivbase
 fi
 
+echo "Targeting archive $simarchiv"
 
 # (otherwise there will be many .svn included under windows)
 distribute()
@@ -115,12 +162,25 @@ distribute()
 
 buildOSX()
 {
+  echo "Build Mac OS package"
 	# builds a bundle for MAC OS
 	mkdir -p "simutrans.app/Contents/MacOS"
 	mkdir -p "simutrans.app/Contents/Resources"
-	cp $BUILDDIRsim.exe   "simutrans.app/Contents/MacOS/simutrans"
+	cp $BUILDDIR$simexe   "simutrans.app/Contents/MacOS/simutrans"
 	strip "simutrans.app/Contents/MacOS/simutrans"
 	cp "../OSX/simutrans.icns" "simutrans.app/Contents/Resources/simutrans.icns"
+	localostype=`uname -o`
+	if [ "Msys" == "$localostype" ] || [ "Linux" == "$localostype" ]; then
+		# only 7z on linux and windows can do that ...
+		getSDL2mac
+		7z x "SDL2-2.0.10.dmg"
+		rm SDL2-2.0.10.dmg
+	else
+		# assume MacOS
+		hdiutil attach ../SDL2-2.0.10.dmg >>/dev/stderr
+		cp -R -v /Volumes/SDL2 .
+		hdiutil eject /Volumes/SDL2 >>/dev/stderr 
+	fi
 	echo "APPL????" > "simutrans.app/Contents/PkgInfo"
 	sh ../OSX/plistgen.sh "simutrans.app" "simutrans"
 }
@@ -132,18 +192,28 @@ fi
 
 # now built the archive for distribution
 cd simutrans
-if [ $OSTYPE = darwin* ]; then
+
+if [ "$OST" = "mac" ]; then
   buildOSX
+  cd ..
+  ls 
+  pwd
+  zip -r -9 simumac.zip simutrans
+  cd simutrans
+  rm -rf SDL2
+  rm -rf simutrans.app
+  exit 0
 else
+  echo "Build default zip archive"
   cp $BUILDDIR$simexe ./simutrans$simexe
   strip simutrans$simexe
+  cp ..$updatepath$updater $updater
+  cd ..
+  distribute
+  # .. finally delete executable and language files
+  rm simutrans/simutrans$simexe
 fi
-cp ..$updatepath$updater $updater
-cd ..
-distribute
 
-# .. finally delete executable and language files
-rm simutrans/simutrans$simexe
 
 # cleanup dll's
 if [ "$PGC" -ne 0 ]; then
