@@ -1,12 +1,18 @@
-#ifndef obj_dummy_h
-#define obj_dummy_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef OBJ_DUMMY_H
+#define OBJ_DUMMY_H
+
 
 #include "../simobj.h"
 #include "../display/simimg.h"
 
 
 /**
- * prissi: a dummy typ for old things, which are now ignored
+ * A dummy type for old things, which are now ignored
  */
 class dummy_obj_t : public obj_t
 {
