@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include <string>
 #include "environment.h"
 #include "loadsave.h"
@@ -63,8 +68,10 @@ std::string env_t::nickname = "";
 const char *env_t::language_iso = "en";
 sint16 env_t::scroll_multi = -1; // start with same scrool as mouse as nowadays standard
 sint16 env_t::global_volume = 127;
+uint32 env_t::sound_distance_scaling;
 sint16 env_t::midi_volume = 127;
-bool env_t::mute_sound = false;
+uint16 env_t::specific_volume[MAX_SOUND_TYPES];
+bool env_t::global_mute_sound = false;
 bool env_t::mute_midi = false;
 bool env_t::shuffle_midi = true;
 sint16 env_t::window_snap_distance = 8;
@@ -115,6 +122,7 @@ plainstring env_t::river_type[10];
 uint8 env_t::river_types;
 sint32 env_t::autosave;
 uint32 env_t::fps;
+uint32 env_t::ff_fps;
 sint16 env_t::max_acceleration;
 uint8 env_t::num_threads;
 bool env_t::show_tooltips;
@@ -122,8 +130,8 @@ uint32 env_t::tooltip_color_rgb;
 PIXVAL env_t::tooltip_color;
 uint32 env_t::tooltip_textcolor_rgb;
 PIXVAL env_t::tooltip_textcolor;
-uint8 env_t::toolbar_max_width;
-uint8 env_t::toolbar_max_height;
+sint8 env_t::toolbar_max_width;
+sint8 env_t::toolbar_max_height;
 uint32 env_t::cursor_overlay_color_rgb;
 PIXVAL env_t::cursor_overlay_color;
 uint32 env_t::background_color_rgb;
@@ -138,6 +146,9 @@ uint32 env_t::tooltip_delay;
 uint32 env_t::tooltip_duration;
 sint8 env_t::show_money_message;
 
+uint8 env_t::gui_player_color_dark = 1;
+uint8 env_t::gui_player_color_bright = 4;
+
 std::string env_t::fontname = FONT_PATH_X "prop.fnt";
 uint8 env_t::fontsize = 11;
 
@@ -158,7 +169,7 @@ bool env_t::hide_keyboard = false;
 
 
 
-// Hajo: Define default settings.
+// Define default settings.
 void env_t::init()
 {
 	// settings for messages
@@ -204,8 +215,8 @@ void env_t::init()
 	// debug level (0: only fatal, 1: error, 2: warning, 3: all
 	verbose_debug = 0;
 
-	default_sortmode = 1;	// sort by amount
-	default_mapmode = 0;	// show cities
+	default_sortmode = 1; // sort by amount
+	default_mapmode = 0;  // show cities
 
 	savegame_version_str = SAVEGAME_VER_NR;
 
@@ -216,11 +227,12 @@ void env_t::init()
 	river_types = 0;
 
 
-	/* prissi: autosave every x months (0=off) */
+	// autosave every x months (0=off)
 	autosave = 0;
 
-	// default: make 25 frames per second (if possible)
-	fps=25;
+	// default: make 25 frames per second (if possible) and 10 for faster fast forward
+	fps = 25;
+	ff_fps = 10;
 
 	// maximum speedup set to 1000 (effectively no limit)
 	max_acceleration=50;
@@ -231,6 +243,8 @@ void env_t::init()
 	num_threads = 1;
 #endif
 
+	sound_distance_scaling = 10;
+
 	show_tooltips = true;
 	tooltip_color_rgb = 0x3964D0; // COL_SOFT_BLUE
 	tooltip_textcolor_rgb = 0x000000; // COL_BLACK
@@ -251,9 +265,12 @@ void env_t::init()
 	// midi/sound option
 	global_volume = 127;
 	midi_volume = 127;
-	mute_sound = false;
+	global_mute_sound = false;
 	mute_midi = false;
 	shuffle_midi = true;
+	for( int i = 0; i < MAX_SOUND_TYPES; i++ ) {
+		specific_volume[ i ] = 255;
+	}
 
 	left_to_right_graphs = false;
 
@@ -338,6 +355,9 @@ void env_t::rdwr(loadsave_t *file)
 
 	file->rdwr_long( autosave );
 	file->rdwr_long( fps );
+	if (file->is_version_atleast(121, 1)) {
+		file->rdwr_long(ff_fps);
+	}
 	file->rdwr_short( max_acceleration );
 
 	file->rdwr_bool( road_user_info );
@@ -385,7 +405,12 @@ void env_t::rdwr(loadsave_t *file)
 
 	file->rdwr_short( global_volume );
 	file->rdwr_short( midi_volume );
-	file->rdwr_bool( mute_sound );
+	file->rdwr_bool( global_mute_sound );
+	if(  file->is_version_atleast( 121, 1 )  ) {
+		for( int i = 0; i <= 5; i++ ) {
+			file->rdwr_short( specific_volume[ i ] );
+		}
+	}
 	file->rdwr_bool( mute_midi );
 	file->rdwr_bool( shuffle_midi );
 
@@ -483,6 +508,13 @@ void env_t::rdwr(loadsave_t *file)
 	if (file->is_version_atleast(120, 9)) {
 		file->rdwr_byte(follow_convoi_underground);
 	}
+
+	if (file->is_version_atleast(121, 1)) {
+		file->rdwr_long(sound_distance_scaling);
+		file->rdwr_byte( gui_player_color_dark );
+		file->rdwr_byte( gui_player_color_bright );
+	}
+
 	// server settings are not saved, since they are server specific
 	// and could be different on different servers on the same computers
 }
