@@ -1,5 +1,11 @@
-#ifndef dataobj_environment_h
-#define dataobj_environment_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DATAOBJ_ENVIRONMENT_H
+#define DATAOBJ_ENVIRONMENT_H
+
 
 #include <string>
 #include "../simtypes.h"
@@ -18,8 +24,6 @@
  * Class to save all environment parameters, ie everything that changes
  * the look and feel of the game. Most of them can be changed by command-line
  * parameters or simuconf.tab files.
- *
- * @author Hj. Malthaner
  */
 class env_t
 {
@@ -178,7 +182,6 @@ public:
 	 * message_flags[i] is bitfield, where bit is set if message should be show at location i,
 	 * where 0 = show message in ticker, 1 = open auto-close window, 2 = open persistent window, 3 = ignore message
 	 * @see message_option_t
-	 * @author prissi
 	 */
 	static sint32 message_flags[4];
 
@@ -186,7 +189,6 @@ public:
 
 	/**
 	 * window button at right corner (like Windows)
-	 * @author prissi
 	 */
 	static bool window_buttons_right;
 
@@ -208,8 +210,8 @@ public:
 	static uint32 tooltip_duration;
 
 	/// limit width and height of menu toolbars
-	static uint8 toolbar_max_width;
-	static uint8 toolbar_max_height;
+	static sint8 toolbar_max_width;
+	static sint8 toolbar_max_height;
 
 	// how to highlight topped (untopped windows)
 	static bool window_frame_active;
@@ -221,6 +223,9 @@ public:
 	static PIXVAL default_window_title_color;
 	static uint8 bottom_window_darkness;
 
+	static uint8 gui_player_color_dark;
+	static uint8 gui_player_color_bright;
+
 	// default font name and -size
 	static std::string fontname;
 	static uint8 fontsize;
@@ -274,8 +279,6 @@ public:
 	/**
 	 * Set to true to hide all trees. "Hiding" is implemented by showing the
 	 * first pic which should be very small.
-	 * @author Volker Meyer
-	 * @date  10.06.2003
 	 */
 	static bool hide_trees;
 
@@ -290,7 +293,7 @@ public:
 	static uint32 cursor_overlay_color_rgb;
 	static PIXVAL cursor_overlay_color;
 
-	static sint8 show_money_message; 
+	static sint8 show_money_message;
 
 	/// color used for solid background draw
 	static uint32 background_color_rgb;
@@ -351,8 +354,6 @@ public:
 
 	/**
 	 * show month in date?
-	 *
-	 * @author hsiegeln
 	 */
 	static uint8 show_month;
 
@@ -364,8 +365,10 @@ public:
 	 */
 	/// @{
 
-	/// set the frame rate for the display
-	static uint32 fps;
+	static uint32 fps;                ///< target frame rate
+	static uint32 ff_fps;             ///< target fps during fast forward
+	static const uint32 min_fps = 5;  ///< minimum target fps (actual fps may be lower for large zoom out on slow machines)
+	static const uint32 max_fps = 100;
 
 	/// maximum acceleration with fast forward
 	static sint16 max_acceleration;
@@ -398,7 +401,6 @@ public:
 
 	/**
 	 * Name of rivers; first the river with the lowest number
-	 * @author prissi
 	 */
 	static plainstring river_type[10];
 
@@ -410,13 +412,11 @@ public:
 	/**
 	* Produce more debug info:
 	* can be set by command-line switch '-debug'
-	* @author Hj. Malthaner
 	*/
 	static uint8 verbose_debug;
 
 
 	/// do autosave every month?
-	/// @author prissi
 	static sint32 autosave;
 
 
@@ -426,7 +426,12 @@ public:
 	/// @{
 
 	static sint16 global_volume, midi_volume;
-	static bool mute_sound, mute_midi, shuffle_midi;
+	static bool mute_midi, shuffle_midi;
+	static bool global_mute_sound;
+	static uint16 specific_volume[MAX_SOUND_TYPES];
+
+	/// how dast are distant sounds fading (1: very fast 25: very little)
+	static uint32 sound_distance_scaling;
 
 	/// @}
 
