@@ -1,16 +1,11 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Factory info dialog
- */
+#ifndef GUI_FABRIK_INFO_H
+#define GUI_FABRIK_INFO_H
 
-#ifndef fabrikinfo_t_h
-#define fabrikinfo_t_h
 
 #include "simwin.h"
 
@@ -36,7 +31,6 @@ class button_t;
 
 /**
  * Info window for factories
- * @author Hj. Malthaner
  */
 class fabrik_info_t : public gui_frame_t, public action_listener_t
 {
@@ -83,7 +77,6 @@ public:
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char *get_help_filename() const OVERRIDE {return "industry_info.txt";}
 
@@ -97,7 +90,6 @@ public:
 	* Draw new component. The values to be passed refer to the window
 	* i.e. It's the screen coordinates of the window where the
 	* component is displayed.
-	* @author Hj. Malthaner
 	*/
 	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
