@@ -1,11 +1,11 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __FACTORY_DESC_H
-#define __FACTORY_DESC_H
+#ifndef DESCRIPTOR_FACTORY_DESC_H
+#define DESCRIPTOR_FACTORY_DESC_H
+
 
 #include "obj_desc.h"
 #include "building_desc.h"
@@ -14,17 +14,24 @@
 #include "../dataobj/koord.h"
 #include "../tpl/weighted_vector_tpl.h"
 
+
+#define DEFAULT_FACTORYSMOKE_TIME (2499)
+#define DEFAULT_SMOKE_UPLIFT (16)
+#define LEGACY_SMOKE_YOFFSET (8)
+
+
 class checksum_t;
 
-/* Knightly : this desc will store data specific to each class of fields
+/**
+ * this desc will store data specific to each class of fields
  * Fields are xref'ed from skin_desc_t
  */
 class field_class_desc_t : public obj_desc_t {
 	friend class factory_field_class_reader_t;
-	friend class factory_field_group_reader_t;		// Knightly : this is a special case due to desc restructuring
+	friend class factory_field_group_reader_t; // this is a special case due to desc restructuring
 
 private:
-	uint8  snow_image;			// 0 or 1 for snow
+	uint8  snow_image;           // 0 or 1 for snow
 	uint16 production_per_field;
 	uint16 storage_capacity;
 	uint16 spawn_weight;
@@ -43,16 +50,16 @@ public:
 };
 
 
-// Knightly : this desc now only contains common, shared data regarding fields
+// this desc now only contains common, shared data regarding fields
 class field_group_desc_t : public obj_desc_t {
 	friend class factory_field_group_reader_t;
 
 private:
-	uint16 probability;		// between 0 ...10000
-	uint16 max_fields;		// maximum number of fields around a single factory
-	uint16 min_fields;		// minimum number of fields around a single factory
-	uint16 start_fields;	// number of fields between min and start_fields to spawn on creation
-	uint16 field_classes;	// number of field classes
+	uint16 probability;     // between 0 ...10000
+	uint16 max_fields;      // maximum number of fields around a single factory
+	uint16 min_fields;      // minimum number of fields around a single factory
+	uint16 start_fields;    // number of fields between min and start_fields to spawn on creation
+	uint16 field_classes;   // number of field classes
 
 	weighted_vector_tpl<uint16> field_class_indices;
 
@@ -83,15 +90,11 @@ public:
 
 
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * Smoke objects for factories.
  *
- *  Description:
- *      Smoke objects for factories.
- *
- *  Child nodes:
- *	0   SKin
+ * Child nodes:
+ *  0   SKin
  */
 class smoke_desc_t : public obj_desc_t {
 	friend class factory_smoke_reader_t;
@@ -127,15 +130,11 @@ public:
 };
 
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * Information about required goods for production
  *
- *  Description:
- *      Information about required goods for production
- *
- *  Child nodes:
- *	0   Ware
+ * Child nodes:
+ *  0   Ware
  */
 class factory_supplier_desc_t : public obj_desc_t {
 	friend class factory_supplier_reader_t;
@@ -154,28 +153,23 @@ public:
 };
 
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * Information about produced goods of a factory
  *
- *  Description:
- *      Information about produced goods of a factory
- *
- *  Child nodes:
- *	0   Ware
+ * Child nodes:
+ *  0   Ware
  */
 class factory_product_desc_t : public obj_desc_t {
 	friend class factory_product_reader_t;
 
 private:
-    uint16 capacity;
+	uint16 capacity;
 
-    /**
-     * How much of this product is derived from one unit of factory
-     * production? 256 means 1.0
-     * @author Hj. Malthaner
-     */
-    uint16 factor;
+	/**
+	 * How much of this product is derived from one unit of factory
+	 * production? 256 means 1.0
+	 */
+	uint16 factor;
 
 public:
 	goods_desc_t const* get_output_type() const { return get_child<goods_desc_t>(0); }
@@ -185,23 +179,19 @@ public:
 };
 
 
-/*
- *  Author:
- *      Volker Meyer
+/**
+ * Factory.
  *
- *  Description:
- *      Factory.
- *
- *  Child nodes:
- *	0   House descriptor
- *	1   Smoke descriptor
- *	2   Supplier descriptor 1
- *	3   Supplier descriptor 2
- *	... ...
- *	n+1 Supplier descriptor n
- *	n+2 Consumer descriptor 1
- *	n+3 Consumer descriptor 2
- *	... ...
+ * Child nodes:
+ *  0   House descriptor
+ *  1   Smoke descriptor
+ *  2   Supplier descriptor 1
+ *  3   Supplier descriptor 2
+ * ... ...
+ *  n+1 Supplier descriptor n
+ *  n+2 Consumer descriptor 1
+ *  n+3 Consumer descriptor 2
+ * ... ...
  */
 class factory_desc_t : public obj_desc_t {
 	friend class factory_reader_t;
@@ -213,11 +203,11 @@ private:
 	site_t placement;
 	uint16 productivity;
 	uint16 range;
-	uint16 distribution_weight;	// probability of construction of this factory
+	uint16 distribution_weight; // probability of construction of this factory
 	uint8 color;
 	uint16 supplier_count;
 	uint16 product_count;
-	uint8 fields;	// only if there are any ...
+	uint8 fields; // only if there are any ...
 	uint16 pax_level;
 	bool electricity_producer;
 	uint16 expand_probability;
@@ -230,14 +220,25 @@ private:
 	uint16 electric_demand;
 	uint16 pax_demand;
 	uint16 mail_demand;
-	sint8 sound_id;
+	uint16 smokeuplift;
+	uint16 smokelifetime;
+	koord  smoketile[4];
+	koord  smokeoffset[4];
+	uint8  smokerotations;
+	sint8  sound_id;
 	uint32 sound_interval;
 
 public:
 	const char *get_name() const { return get_building()->get_name(); }
 	const char *get_copyright() const { return get_building()->get_copyright(); }
 	building_desc_t  const* get_building()  const { return get_child<building_desc_t>(0); }
+
 	smoke_desc_t const* get_smoke() const { return get_child<smoke_desc_t>(1); }
+	void correct_smoke();
+	koord get_smoketile( uint8 rot ) const { return smoketile[ rot%smokerotations ]; }
+	koord get_smokeoffset( uint8 rot ) const { return smokeoffset[ rot%smokerotations ]; }
+	uint16 get_smokeuplift() const { return smokeuplift; }
+	uint16 get_smokelifetime() const { return smokelifetime; }
 
 	// we must take care, for the case of no producer/consumer
 	const factory_supplier_desc_t *get_supplier(uint16 i) const
