@@ -1,16 +1,11 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Where factory stats are calculated for list dialog
- */
+#ifndef GUI_FACTORYLIST_STATS_T_H
+#define GUI_FACTORYLIST_STATS_T_H
 
-#ifndef factorylist_stats_t_h
-#define factorylist_stats_t_h
 
 #include "components/gui_colorbox.h"
 #include "components/gui_image.h"
@@ -22,12 +17,12 @@ class fabrik_t;
 
 
 namespace factorylist {
-    enum sort_mode_t { by_name=0, by_available, by_output, by_maxprod, by_status, by_power, SORT_MODES, by_input, by_transit,  };	// the last two not used
+	enum sort_mode_t { by_name=0, by_available, by_output, by_maxprod, by_status, by_power, SORT_MODES, by_input, by_transit,  }; // the last two not used
 };
 
 /**
  * Factory list stats display
- * @author Hj. Malthaner
+ * Where factory stats are calculated for list dialog
  */
 class factorylist_stats_t : public gui_aligned_container_t, public gui_scrolled_list_t::scrollitem_t
 {
