@@ -1,5 +1,11 @@
-#ifndef obj_field_h
-#define obj_field_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef OBJ_FIELD_H
+#define OBJ_FIELD_H
+
 
 #include "../simobj.h"
 #include "../display/simimg.h"
@@ -22,20 +28,17 @@ public:
 
 	image_id get_image() const OVERRIDE;
 
-	/**
-	 * @return Einen Beschreibungsstring fr das Objekt, der z.B. in einem
-	 * Beobachtungsfenster angezeigt wird.
-	 * @author Hj. Malthaner
-	 */
+	/// @copydoc obj_t::show_info
 	void show_info() OVERRIDE;
 
 	/**
 	 * @return NULL when OK, otherwise an error message
-	 * @author Hj. Malthaner
 	 */
 	const char * is_deletable(const player_t *) OVERRIDE;
 
 	void cleanup(player_t *player) OVERRIDE;
+
+	fabrik_t* get_factory() const { return fab; }
 };
 
 #endif
