@@ -1,10 +1,11 @@
 /*
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef finance_h
-#define finance_h
+#ifndef PLAYER_FINANCE_H
+#define PLAYER_FINANCE_H
+
 
 #include <assert.h>
 
@@ -25,7 +26,6 @@
  * waytype_t was not used because of values assigned to air_wt and powerline_wt.
  * There are also buildings like railway station that can be distinguished
  * by transport_type and can not be distinguished by waytype_t.
- * @author jk271
  */
 enum transport_type {
 	TT_ALL=0,
@@ -51,8 +51,8 @@ enum transport_type {
  * - the data are concerning to whole company
  */
 enum accounting_type_common {
-	ATC_CASH = 0,		///< Cash
-	ATC_NETWEALTH,		///< Total Cash + Assets
+	ATC_CASH = 0,           ///< Cash
+	ATC_NETWEALTH,          ///< Total Cash + Assets
 	ATC_ALL_CONVOIS,        ///< Convoy count
 	ATC_SCENARIO_COMPLETED, ///< Scenario success (only useful if there is one ... )
 	ATC_MAX
@@ -62,28 +62,27 @@ enum accounting_type_common {
 /**
  * ATV = accounting type vehicles.
  * Supersedes COST_ types, that CAN be distinguished by type of transport.
- * @author jk271
  */
 enum accounting_type_vehicles {
 	ATV_REVENUE_PASSENGER=0, ///< Revenue from passenger transport
 	ATV_REVENUE_MAIL,        ///< Revenue from mail transport
 	ATV_REVENUE_GOOD,        ///< Revenue from good transport
-	ATV_REVENUE_TRANSPORT,	 ///< Operating profit = passenger + mail + goods = was: COST_INCOME
-	ATV_TOLL_RECEIVED,	 ///< Toll paid to you by another player
+	ATV_REVENUE_TRANSPORT,   ///< Operating profit = passenger + mail + goods = was: COST_INCOME
+	ATV_TOLL_RECEIVED,       ///< Toll paid to you by another player
 	ATV_REVENUE,             ///< Operating profit = revenue_transport + toll = passenger + mail+ goods + toll_received
 
 	ATV_RUNNING_COST,               ///< Distance based running costs, was: COST_VEHICLE_RUN
 	ATV_VEHICLE_MAINTENANCE,        ///< Monthly vehicle maintenance. Unused.
 	ATV_INFRASTRUCTURE_MAINTENANCE, ///< Infrastructure maintenance (roads, railway, ...), was: COST_MAINTENANCE
-	ATV_TOLL_PAID,			  ///< Toll paid by you to another player
-	ATV_EXPENDITURE,		        ///< Total expenditure = RUNNING_COSTS+VEHICLE_MAINTENANCE+INFRACTRUCTURE_MAINTENANCE+TOLL_PAID
-	ATV_OPERATING_PROFIT,		  ///< ATV_REVENUE - ATV_EXPENDITURE, was: COST_OPERATING_PROFIT
-	ATV_NEW_VEHICLE,			  ///< New vehicles
-	ATV_CONSTRUCTION_COST,		  ///< Construction cost, COST_CONSTRUCTION mapped here
-	ATV_PROFIT,			        ///< ATV_OPERATING_PROFIT - (CONSTRUCTION_COST + NEW_VEHICLE), was: COST_PROFIT
-	ATV_WAY_TOLL,			  ///< = ATV_TOLL_PAID + ATV_TOLL_RECEIVED, was: COST_WAY_TOLLS
-	ATV_NON_FINANCIAL_ASSETS,	  ///< Value of vehicles owned by your company, was: COST_ASSETS
-	ATV_PROFIT_MARGIN,		  ///< ATV_OPERATING_PROFIT / ATV_REVENUE, was: COST_MARGIN
+	ATV_TOLL_PAID,                  ///< Toll paid by you to another player
+	ATV_EXPENDITURE,                ///< Total expenditure = RUNNING_COSTS+VEHICLE_MAINTENANCE+INFRACTRUCTURE_MAINTENANCE+TOLL_PAID
+	ATV_OPERATING_PROFIT,           ///< ATV_REVENUE - ATV_EXPENDITURE, was: COST_OPERATING_PROFIT
+	ATV_NEW_VEHICLE,                ///< New vehicles
+	ATV_CONSTRUCTION_COST,          ///< Construction cost, COST_CONSTRUCTION mapped here
+	ATV_PROFIT,                     ///< ATV_OPERATING_PROFIT - (CONSTRUCTION_COST + NEW_VEHICLE), was: COST_PROFIT
+	ATV_WAY_TOLL,                   ///< = ATV_TOLL_PAID + ATV_TOLL_RECEIVED, was: COST_WAY_TOLLS
+	ATV_NON_FINANCIAL_ASSETS,       ///< Value of vehicles owned by your company, was: COST_ASSETS
+	ATV_PROFIT_MARGIN,              ///< ATV_OPERATING_PROFIT / ATV_REVENUE, was: COST_MARGIN
 
 	ATV_TRANSPORTED_PASSENGER, ///< Number of transported passengers
 	ATV_TRANSPORTED_MAIL,      ///< Number of transported mail
@@ -107,7 +106,6 @@ class scenario_t;
 
 /**
  * Encapsulate margin calculation  (Operating_Profit / Income)
- * @author Ben Love
  */
 inline sint64 calc_margin(sint64 operating_profit, sint64 proceeds)
 {
@@ -134,14 +132,12 @@ class finance_t {
 	karte_t * world;
 
 	/**
- 	 * Amount of money, previously known as "konto"
- 	 * @author Hj. Malthaner
- 	 */
+	 * Amount of money, previously known as "konto"
+	 */
 	sint64 account_balance;
 
 	/**
 	 * Shows how many months you have been in red numbers.
-	 * @author Hj. Malthaner
 	 */
 	sint32 account_overdrawn;
 
@@ -153,8 +149,7 @@ class finance_t {
 	/**
 	 * Contains values having relation with whole company but not with particular
 	 * type of transport (com - common).
- 	 * @author jk271
- 	 */
+	 */
 	sint64 com_year[MAX_PLAYER_HISTORY_YEARS][ATC_MAX];
 
 	/**
@@ -164,21 +159,18 @@ class finance_t {
 
 	/**
 	 * Finance history having relation with particular type of service
- 	 * @author jk271
- 	 */
+	 */
 	sint64 veh_year[TT_MAX][MAX_PLAYER_HISTORY_YEARS][ATV_MAX];
 	sint64 veh_month[TT_MAX][MAX_PLAYER_HISTORY_MONTHS][ATV_MAX];
 
 	/**
- 	 * Monthly maintenance cost
- 	 * @author Hj. Malthaner
- 	 */
+	 * Monthly maintenance cost
+	 */
 	sint64 maintenance[TT_MAX];
 
 	/**
 	 * Monthly vehicle maintenance cost per transport type.
- 	 * @author jk271
- 	 */
+	 */
 	sint64 vehicle_maintenance[TT_MAX];
 
 public:
@@ -192,15 +184,14 @@ public:
 	 */
 	inline void book_construction_costs(const sint64 amount, const waytype_t wt) {
 		transport_type tt = translate_waytype_to_tt(wt);
-		veh_year[tt][0][ATV_CONSTRUCTION_COST] += (sint64) amount;
-		veh_month[tt][0][ATV_CONSTRUCTION_COST] += (sint64) amount;
+		veh_year[tt][0][ATV_CONSTRUCTION_COST] += amount;
+		veh_month[tt][0][ATV_CONSTRUCTION_COST] += amount;
 
 		account_balance += amount;
 	}
 
 	/**
 	 * Adds count to number of convois in statistics.
-	 * @author jk271
 	 */
 	inline void book_convoi_number( const int count ) {
 		com_year[0][ATC_ALL_CONVOIS] += count;
@@ -223,17 +214,17 @@ public:
 
 	/**
 	 * Account purchase of new vehicle: Subtracts money, increases assets.
-	 * @param amount money paid for vehicle
+	 * @param amount money paid for vehicle (negative)
 	 * @param wt - waytype of vehicle
 	 */
 	inline void book_new_vehicle(const sint64 amount, const waytype_t wt)
 	{
 		const transport_type tt = translate_waytype_to_tt(wt);
 
-		veh_year[ tt][0][ATV_NEW_VEHICLE] += (sint64) amount;
-		veh_month[tt][0][ATV_NEW_VEHICLE] += (sint64) amount;
-		veh_year[ tt][0][ATV_NON_FINANCIAL_ASSETS] -= (sint64) amount;
-		veh_month[tt][0][ATV_NON_FINANCIAL_ASSETS] -= (sint64) amount;
+		veh_year[ tt][0][ATV_NEW_VEHICLE] += amount;
+		veh_month[tt][0][ATV_NEW_VEHICLE] += amount;
+
+		update_assets(-amount, wt);
 
 		account_balance += amount;
 	}
@@ -250,8 +241,8 @@ public:
 
 		index = ((0 <= index) && (index <= 2)? index : 2);
 
-		veh_year[tt][0][ATV_REVENUE_PASSENGER+index] += (sint64) amount;
-		veh_month[tt][0][ATV_REVENUE_PASSENGER+index] += (sint64) amount;
+		veh_year[tt][0][ATV_REVENUE_PASSENGER+index] += amount;
+		veh_month[tt][0][ATV_REVENUE_PASSENGER+index] += amount;
 
 		account_balance += amount;
 	}
@@ -277,8 +268,8 @@ public:
 	inline void book_toll_paid(const sint64 amount, const waytype_t wt)
 	{
 		const transport_type tt =  translate_waytype_to_tt(wt);
-		veh_year[tt][0][ATV_TOLL_PAID] += (sint64) amount;
-		veh_month[tt][0][ATV_TOLL_PAID] += (sint64) amount;
+		veh_year[tt][0][ATV_TOLL_PAID] += amount;
+		veh_month[tt][0][ATV_TOLL_PAID] += amount;
 		account_balance += amount;
 	}
 
@@ -290,8 +281,8 @@ public:
 	inline void book_toll_received(const sint64 amount, const waytype_t wt)
 	{
 		const transport_type tt = translate_waytype_to_tt(wt);
-		veh_year[tt][0][ATV_TOLL_RECEIVED] += (sint64) amount;
-		veh_month[tt][0][ATV_TOLL_RECEIVED] += (sint64) amount;
+		veh_year[tt][0][ATV_TOLL_RECEIVED] += amount;
+		veh_month[tt][0][ATV_TOLL_RECEIVED] += amount;
 		account_balance += amount;
 	}
 
@@ -337,7 +328,6 @@ public:
 	/**
 	 * Calculates the finance history for player.
 	 * This method has to be called before reading any variables besides account_balance!
-	 * @author hsiegeln
 	 */
 	void calc_finance_history();
 
@@ -364,7 +354,6 @@ public:
 	 * Call calc_finance_history before use!
 	 * @param year 0 .. current year, 1 .. last year, etc
 	 * @param type one of accounting_type_common
-	 * @author jk271
 	 */
 	sint64 get_history_com_year(int year, int type) const { return com_year[year][type]; }
 	sint64 get_history_com_month(int month, int type) const { return com_month[month][type]; }
@@ -375,7 +364,6 @@ public:
 	 * @param tt one of transport_type
 	 * @param year 0 .. current year, 1 .. last year, etc
 	 * @param type one of accounting_type_vehicles
-	 * @author jk271
 	 */
 	sint64 get_history_veh_year(transport_type tt, int year, int type) const { return veh_year[tt][year][type]; }
 	sint64 get_history_veh_month(transport_type tt, int month, int type) const { return veh_month[tt][month][type]; }
@@ -393,7 +381,6 @@ public:
 
 	/**
 	 * @returns maintenance scaled with bits_per_month
-	 * @author jk271
 	 */
 	sint64 get_maintenance_with_bits(transport_type tt=TT_ALL) const;
 
@@ -412,7 +399,6 @@ public:
 
 	/**
 	 * @returns vehicle maintenance scaled with bits_per_month
-	 * @author jk271
 	 */
 	sint64 get_vehicle_maintenance_with_bits(transport_type tt=TT_ALL) const;
 
@@ -443,7 +429,6 @@ public:
 
 	/**
 	 * rolls the finance history for player (needed when new_year() or new_month()) triggered
-	 * @author hsiegeln, jk271
 	 */
 	void roll_history_year();
 	void roll_history_month();
@@ -475,14 +460,12 @@ public:
 	/**
 	 * Translates building_desc_t to transport_type
 	 * Building can be assigned to transport type using utyp
- 	 * @author jk271
- 	 */
+	 */
 	static transport_type translate_utyp_to_tt(int utyp);
 
 	/**
- 	 * Translates waytype_t to transport_type
- 	 * @author jk271
- 	 */
+	 * Translates waytype_t to transport_type
+	 */
 	static transport_type translate_waytype_to_tt(waytype_t wt);
 
 	void update_assets(sint64 delta, waytype_t wt);
@@ -492,7 +475,6 @@ private:
 	/**
 	 * Translates finance statistics from new format to old one.
 	 * Used for saving data in old format
-	 * @author jk271
 	 */
 	void export_to_cost_month(sint64 finance_history_month[][OLD_MAX_PLAYER_COST]);
 	void export_to_cost_year( sint64 finance_history_year[][OLD_MAX_PLAYER_COST]);
@@ -501,7 +483,6 @@ private:
 	/**
 	 * Translates finance statistics from old format to new one.
 	 * Used for loading data from old format
-	 * @author jk271
 	 */
 	void import_from_cost_month(const sint64 finance_history_month[][OLD_MAX_PLAYER_COST]);
 	void import_from_cost_year( const sint64 finance_history_year[][OLD_MAX_PLAYER_COST]);
