@@ -1,5 +1,11 @@
-#ifndef dataobj_gameinfo_h
-#define dataobj_gameinfo_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DATAOBJ_GAMEINFO_H
+#define DATAOBJ_GAMEINFO_H
+
 
 #include <string>
 #include "../simtypes.h"
@@ -11,7 +17,9 @@
 class karte_t;
 class loadsave_t;
 
-
+/**
+ * Info about the current game
+ */
 class gameinfo_t
 {
 private:
@@ -53,7 +61,7 @@ private:
 
 	// 0 = empty, otherwise some value from simplay
 	uint8 player_type[MAX_PLAYER_COUNT];
-	uint8 clients;	// currently connected players
+	uint8 clients; // currently connected players
 
 public:
 	gameinfo_t( karte_t *welt );
