@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string.h>
@@ -16,7 +14,7 @@ static pthread_mutex_t add_to_city_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 
 #include "../bauer/hausbauer.h"
-#include "../gui/money_frame.h"
+#include "../gui/headquarter_info.h"
 #include "../simworld.h"
 #include "../simobj.h"
 #include "../simfab.h"
@@ -52,8 +50,7 @@ static pthread_mutex_t add_to_city_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 
 /**
- * Initializes all variables with save, usable values
- * @author Hj. Malthaner
+ * Initializes all variables with safe, usable values
  */
 void gebaeude_t::init()
 {
@@ -81,7 +78,7 @@ gebaeude_t::gebaeude_t(loadsave_t *file) : obj_t()
 {
 	init();
 	rdwr(file);
-	if(file->get_version()<88002) {
+	if(file->is_version_less(88, 2)) {
 		set_yoff(0);
 	}
 	if(tile  &&  tile->get_phases()>1) {
@@ -92,13 +89,13 @@ gebaeude_t::gebaeude_t(loadsave_t *file) : obj_t()
 
 
 gebaeude_t::gebaeude_t(koord3d pos, player_t *player, const building_tile_desc_t *t) :
-    obj_t(pos)
+	obj_t(pos)
 {
 	set_owner( player );
 
 	init();
 	if(t) {
-		set_tile(t,true);	// this will set init time etc.
+		set_tile(t,true); // this will set init time etc.
 		player_t::add_maintenance(get_owner(), tile->get_desc()->get_maintenance(welt), tile->get_desc()->get_finance_waytype() );
 	}
 
@@ -112,8 +109,6 @@ gebaeude_t::gebaeude_t(koord3d pos, player_t *player, const building_tile_desc_t
 
 /**
  * Destructor. Removes this from the list of sync objects if necessary.
- *
- * @author Hj. Malthaner
  */
 gebaeude_t::~gebaeude_t()
 {
@@ -203,8 +198,7 @@ void gebaeude_t::rotate90()
 }
 
 
-/* sets the corresponding pointer to a factory
- * @author prissi
+/** sets the corresponding pointer to a factory
  */
 void gebaeude_t::set_fab(fabrik_t *fd)
 {
@@ -222,8 +216,7 @@ void gebaeude_t::set_fab(fabrik_t *fd)
 }
 
 
-/* sets the corresponding city
- * @author prissi
+/** sets the corresponding city
  */
 void gebaeude_t::set_stadt(stadt_t *s)
 {
@@ -328,7 +321,7 @@ sync_result gebaeude_t::sync_step(uint32 delta_t)
 					image_id image = tile->get_foreground( anim_frame, season );
 					mark_image_dirty( image, 0 );
 				}
- 			}
+			}
 		}
 	}
 	return SYNC_OK;
@@ -441,7 +434,7 @@ image_id gebaeude_t::get_front_image() const
 	if(zeige_baugrube) {
 		return IMG_EMPTY;
 	}
-	if (env_t::hide_buildings != 0 && tile->get_desc()->get_type() < building_desc_t::others) {
+	if (env_t::hide_buildings != 0   &&  (is_city_building()  ||  (env_t::hide_buildings == env_t::ALL_HIDDEN_BUILDING  &&  tile->get_desc()->get_type() < building_desc_t::others))) {
 		return IMG_EMPTY;
 	}
 	else {
@@ -479,7 +472,6 @@ int gebaeude_t::get_mail_level() const
 
 /**
  * @return eigener Name oder Name der Fabrik falls Teil einer Fabrik
- * @author Hj. Malthaner
  */
 const char *gebaeude_t::get_name() const
 {
@@ -547,7 +539,7 @@ void gebaeude_t::show_info()
 	bool special = is_headquarter() || is_townhall();
 
 	if(is_headquarter()) {
-		create_win( new money_frame_t(get_owner()), w_info, magic_finances_t+get_owner()->get_player_nr() );
+		create_win( new headquarter_info_t(get_owner()), w_info, magic_headquarter+get_owner()->get_player_nr() );
 	}
 	else if (is_townhall()) {
 		ptr.stadt->open_info_window();
@@ -555,6 +547,27 @@ void gebaeude_t::show_info()
 
 	if(!tile->get_desc()->no_info_window()) {
 		if(!special  ||  (env_t::townhall_info  &&  old_count==win_get_open_count()) ) {
+			// iterate over all places to check if there is already an open window
+			const building_desc_t* const building_desc = tile->get_desc();
+			const uint8 layout = tile->get_layout();
+			koord k;
+			for (k.x = 0; k.x<building_desc->get_x(layout); k.x++) {
+				for (k.y = 0; k.y<building_desc->get_y(layout); k.y++) {
+					const building_tile_desc_t *tile = building_desc->get_tile(layout, k.x, k.y);
+					if (tile == NULL || !tile->has_image()) {
+						continue;
+					}
+					if (grund_t *gr = welt->lookup(get_pos() - get_tile()->get_offset() + k)) {
+						gebaeude_t *gb = gr->find<gebaeude_t>();
+						if (gb  &&  gb->get_tile() == tile) {
+							if (win_get_magic((ptrdiff_t)gb)) {
+								// already open
+								return;
+							}
+						}
+					}
+				}
+			}
 			// open info window for the first tile of our building (not relying on presence of (0,0) tile)
 			get_first_tile()->obj_t::show_info();
 		}
@@ -562,6 +575,46 @@ void gebaeude_t::show_info()
 }
 
 
+
+// returns true, if there is a halt serving at least one tile
+bool gebaeude_t::is_within_players_network(const player_t* player) const
+{
+	if(  get_fabrik()  ) {
+		return ptr.fab->is_within_players_network( player );
+	}
+	if(  is_townhall()  ) {
+		ptr.stadt->is_within_players_network( player );
+	}
+
+	// normal building: iterate over all tiles
+	const building_desc_t* const building_desc = tile->get_desc();
+	const uint8 layout = tile->get_layout();
+	koord k;
+	for (k.x = 0; k.x<building_desc->get_x(layout); k.x++) {
+		for (k.y = 0; k.y<building_desc->get_y(layout); k.y++) {
+			// check for hole in the building ...
+			const building_tile_desc_t *tile = building_desc->get_tile(layout, k.x, k.y);
+			if (tile == NULL || !tile->has_image()) {
+				continue;
+			}
+			// now search for stops serving this tile
+			if(  const planquadrat_t *plan = welt->access( get_pos().get_2d() - get_tile()->get_offset() + k )  ) {
+				if(  plan->get_haltlist_count() > 0   ) {
+					const halthandle_t *const halt_list = plan->get_haltlist();
+					for(  int h = 0;  h < plan->get_haltlist_count();  h++  ) {
+						if(  halt_list[h].is_bound()  &&  (halt_list[h]->get_pax_enabled()  || halt_list[h]->get_mail_enabled() )  &&  halt_list[h]->has_available_network(player)  ) {
+							return true;
+						}
+					}
+				}
+			}
+		}
+	}
+	return false;
+}
+
+
+
 bool gebaeude_t::is_same_building(const gebaeude_t* other) const
 {
 	if (other) {
@@ -691,6 +744,13 @@ void gebaeude_t::info(cbuffer_t & buf) const
 			buf.append("\n");
 			buf.printf(translator::translate("Constructed by %s"), maker);
 		}
+#ifdef DEBUG
+		buf.append( "\n\nrotation " );
+		buf.append( tile->get_layout(), 0 );
+		buf.append( " best layout " );
+		buf.append( stadt_t::orient_city_building( get_pos().get_2d() - tile->get_offset(), tile->get_desc(), koord(3,3) ), 0 );
+		buf.append( "\n" );
+#endif
 	}
 }
 
@@ -778,9 +838,9 @@ void gebaeude_t::rdwr(loadsave_t *file)
 				switch(type) {
 					case building_desc_t::city_res:
 						{
-							const building_desc_t *bdsc = hausbauer_t::get_residential( level, welt->get_timeline_year_month(), welt->get_climate( get_pos().get_2d() ) );
+							const building_desc_t *bdsc = hausbauer_t::get_residential( level, welt->get_timeline_year_month(), welt->get_climate( get_pos().get_2d() ), 0, koord(1,1), koord(1,1) );
 							if(bdsc==NULL) {
-								bdsc = hausbauer_t::get_residential(level,0, MAX_CLIMATES );
+								bdsc = hausbauer_t::get_residential(level,0, MAX_CLIMATES, 0, koord(1,1), koord(1,1) );
 							}
 							if( bdsc) {
 								dbg->message("gebaeude_t::rwdr", "replace unknown building %s with residence level %i by %s",buf,level,bdsc->get_name());
@@ -791,9 +851,10 @@ void gebaeude_t::rdwr(loadsave_t *file)
 
 					case building_desc_t::city_com:
 						{
-							const building_desc_t *bdsc = hausbauer_t::get_commercial( level, welt->get_timeline_year_month(), welt->get_climate( get_pos().get_2d() ) );
+							// for replacement, ignore cluster and size
+							const building_desc_t *bdsc = hausbauer_t::get_commercial( level, welt->get_timeline_year_month(), welt->get_climate( get_pos().get_2d() ), 0, koord(1,1), koord(1,1) );
 							if(bdsc==NULL) {
-								bdsc = hausbauer_t::get_commercial(level,0, MAX_CLIMATES );
+								bdsc = hausbauer_t::get_commercial(level, 0, MAX_CLIMATES, 0, koord(1,1), koord(1,1) );
 							}
 							if(bdsc) {
 								dbg->message("gebaeude_t::rwdr", "replace unknown building %s with commercial level %i by %s",buf,level,bdsc->get_name());
@@ -804,11 +865,11 @@ void gebaeude_t::rdwr(loadsave_t *file)
 
 					case building_desc_t::city_ind:
 						{
-							const building_desc_t *bdsc = hausbauer_t::get_industrial( level, welt->get_timeline_year_month(), welt->get_climate( get_pos().get_2d() ) );
+							const building_desc_t *bdsc = hausbauer_t::get_industrial( level, welt->get_timeline_year_month(), welt->get_climate( get_pos().get_2d() ), 0, koord(1,1), koord(1,1) );
 							if(bdsc==NULL) {
-								bdsc = hausbauer_t::get_industrial(level,0, MAX_CLIMATES );
+								bdsc = hausbauer_t::get_industrial(level, 0, MAX_CLIMATES, 0, koord(1,1), koord(1,1) );
 								if(bdsc==NULL) {
-									bdsc = hausbauer_t::get_residential(level,0, MAX_CLIMATES );
+									bdsc = hausbauer_t::get_residential(level, 0, MAX_CLIMATES, 0, koord(1,1), koord(1,1) );
 								}
 							}
 							if (bdsc) {
@@ -823,7 +884,9 @@ void gebaeude_t::rdwr(loadsave_t *file)
 						welt->add_missing_paks( buf, karte_t::MISSING_BUILDING );
 				}
 			}
-		}	// here we should have a valid tile pointer or nothing ...
+		}
+
+		// here we should have a valid tile pointer or nothing ...
 
 		/* avoid double construction of monuments:
 		 * remove them from selection lists
@@ -836,14 +899,14 @@ void gebaeude_t::rdwr(loadsave_t *file)
 		}
 	}
 
-	if(file->get_version()<99006) {
+	if(file->is_version_less(99, 6)) {
 		// ignore the sync flag
 		uint8 dummy=sync;
 		file->rdwr_byte(dummy);
 	}
 
 	// restore city pointer here
-	if(  file->get_version()>=99014  ) {
+	if(  file->is_version_atleast(99, 14)  ) {
 		sint32 city_index = -1;
 		if(  file->is_saving()  &&  ptr.stadt!=NULL  ) {
 			city_index = welt->get_cities().index_of( ptr.stadt );
@@ -859,7 +922,7 @@ void gebaeude_t::rdwr(loadsave_t *file)
 		anim_time = 0;
 		sync = false;
 
-		// Hajo: rebuild tourist attraction list
+		// rebuild tourist attraction list
 		if(tile && tile->get_desc()->is_attraction()) {
 			welt->add_attraction( this );
 		}
@@ -867,12 +930,6 @@ void gebaeude_t::rdwr(loadsave_t *file)
 }
 
 
-/**
- * Wird nach dem Laden der Welt aufgerufen - blicherweise benutzt
- * um das Aussehen des Dings an Boden und Umgebung anzupassen
- *
- * @author Hj. Malthaner
- */
 void gebaeude_t::finish_rd()
 {
 	player_t::add_maintenance(get_owner(), tile->get_desc()->get_maintenance(welt), tile->get_desc()->get_finance_waytype());
