@@ -1,16 +1,11 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Goods list dialog
- */
+#ifndef GUI_GOODS_FRAME_T_H
+#define GUI_GOODS_FRAME_T_H
 
-#ifndef goods_frame_t_h
-#define goods_frame_t_h
 
 #include "gui_frame.h"
 #include "components/gui_button.h"
@@ -28,7 +23,6 @@ class goods_desc_t;
 
 /**
  * Shows statistics. Only goods so far.
- * @author Hj. Malthaner
  */
 class goods_frame_t : public gui_frame_t, private action_listener_t
 {
@@ -67,19 +61,19 @@ private:
 
 	static simline_t::linetype last_scheduletype;
 
-	cbuffer_t	speed_message;
+	cbuffer_t speed_message;
 	vector_tpl<const goods_desc_t*> good_list;
 
-	button_t	sortedby;
-	button_t	sorteddir;
+	button_t sortedby;
+	button_t sorteddir;
 
-	gui_numberinput_t	speed;
-	gui_combobox_t	scheduletype;
+	gui_numberinput_t speed;
+	gui_combobox_t    scheduletype;
 
 	gui_textarea_t speed_text;
 	gui_aligned_container_t *sort_row;
 
-	button_t	filter_goods_toggle;
+	button_t filter_goods_toggle;
 
 	goods_stats_t goods_stats;
 	gui_scrollpane_t scrolly;
@@ -117,7 +111,6 @@ public:
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author V. Meyer
 	 */
 	const char * get_help_filename() const OVERRIDE {return "goods_filter.txt"; }
 
