@@ -1,19 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/**
- * An adapter class to display info windows for ground (floor) objects
- *
- * @author Hj. Malthaner
- * @date 20-Nov-2001
- */
+#ifndef GUI_GROUND_INFO_H
+#define GUI_GROUND_INFO_H
 
-#ifndef gui_ground_info_h
-#define gui_ground_info_h
 
 #include "base_info.h"
 #include "components/gui_location_view_t.h"
@@ -28,7 +20,6 @@ protected:
 	/**
 	 * The ground we observe. The ground will delete this object
 	 * if self deleted.
-	 * @author Hj. Malthaner
 	 */
 	const grund_t* gr;
 
