@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef obj_groundobj_h
-#define obj_groundobj_h
+#ifndef OBJ_GROUNDOBJ_H
+#define OBJ_GROUNDOBJ_H
+
 
 #include "../tpl/stringhashtable_tpl.h"
 #include "../tpl/vector_tpl.h"
