@@ -1,6 +1,6 @@
 /*
- * Base class for grounds in simutrans.
- * by Hj. Malthaner
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string.h>
@@ -35,7 +35,7 @@
 #include "../obj/crossing.h"
 #include "../obj/groundobj.h"
 #include "../obj/label.h"
-#include "../obj/leitung2.h"	// for construction of new ways ...
+#include "../obj/leitung2.h"
 #include "../obj/roadsign.h"
 #include "../obj/signal.h"
 #include "../obj/tunnel.h"
@@ -68,7 +68,6 @@
 /**
  * Pointer to the world of this ground. Static to conserve space.
  * Change to instance variable once more than one world is available.
- * @author Hj. Malthaner
  */
 karte_ptr_t grund_t::welt;
 volatile bool grund_t::show_grid = false;
@@ -84,7 +83,6 @@ uint8 grund_t::underground_mode = ugm_none;
 
 /**
  * Table of ground texts
- * @author Hj. Malthaner
  */
 static inthashtable_tpl<uint64, char*> ground_texts;
 
@@ -228,7 +226,7 @@ void grund_t::rdwr(loadsave_t *file)
 		file->rdwr_str(text);
 		if(text) {
 			set_text(text);
-			guarded_free(const_cast<char *>(text));
+			free(const_cast<char *>(text));
 		}
 	}
 
@@ -264,16 +262,23 @@ void grund_t::rdwr(loadsave_t *file)
 	if(  file->is_loading()  ) {
 		if(  file->is_version_less(112, 7)  ) {
 			// convert slopes from old single height saved game
-			slope = (scorner_sw(slope) + scorner_se(slope) * 3 + scorner_ne(slope) * 9 + scorner_nw(slope) * 27) * env_t::pak_height_conversion_factor;
+			slope = encode_corners(scorner_sw(slope), scorner_se(slope), scorner_ne(slope), scorner_nw(slope)) * env_t::pak_height_conversion_factor;
 		}
 		if(  !ground_desc_t::double_grounds  ) {
 			// truncate double slopes to single slopes
-			slope = min( corner_sw(slope), 1 ) + min( corner_se(slope), 1 ) * 3 + min( corner_ne(slope), 1 ) * 9 + min( corner_nw(slope), 1 ) * 27;
+			slope = encode_corners(min( corner_sw(slope), 1 ), min( corner_se(slope), 1 ), min( corner_ne(slope), 1 ), min( corner_nw(slope), 1 ));
 		}
 	}
 
 	// restore grid
 	if(  file->is_loading()  ) {
+		if( get_typ() == grund_t::boden  ||  get_typ() == grund_t::fundament  ) {
+			/* since those must be on the ground and broken grids occurred in the past 
+			 * (due to incorrect restoration of grid heights on house slopes)
+			 * we simply reset the grid height to our current height
+			 */
+			z = pos.z;
+		}
 		// for south/east map edges we need to restore more than one point
 		if(  pos.x == welt->get_size().x-1  &&  pos.y == welt->get_size().y-1  ) {
 			sint8 z_southeast = z;
@@ -407,7 +412,7 @@ void grund_t::rdwr(loadsave_t *file)
 						// we do not delete them, to keep maintenance costs correct
 					}
 					else {
-						assert((flags&has_way2)==0);	// maximum two ways on one tile ...
+						assert((flags&has_way2)==0); // maximum two ways on one tile ...
 						weg->set_pos(pos);
 						if(owner_n!=-1) {
 							weg->set_owner(welt->get_player(owner_n));
@@ -791,7 +796,7 @@ void grund_t::calc_back_image(const sint8 hgt, const slope_t::type slope_this)
 			const uint8 back_height = min(corner_nw(slope_this),(i==0?corner_sw(slope_this):corner_ne(slope_this)));
 
 			const sint16 left_hgt=gr->get_disp_height()-back_height;
-			const sint8 slope=gr->get_disp_slope();
+			const slope_t::type slope=gr->get_disp_slope();
 
 			const uint8 corner_a = (i==0?corner_sw(slope_this):corner_nw(slope_this))-back_height;
 			const uint8 corner_b = (i==0?corner_nw(slope_this):corner_ne(slope_this))-back_height;
@@ -877,7 +882,7 @@ void grund_t::calc_back_image(const sint8 hgt, const slope_t::type slope_this)
 		for(uint i=0; i<grund_t::BACK_CORNER_COUNT; i++) {
 			if(  const grund_t *gr=welt->lookup_kartenboden(k + testdir[i] - koord(step,step))  ) {
 				sint16 h = gr->get_disp_height()*scale_z_step;
-				sint8 s = gr->get_disp_slope();
+				slope_t::type s = gr->get_disp_slope();
 				// tile should hide anything in tunnel portal behind (tile not in direction of tunnel)
 				if (step == 0  &&  ((i&1)==0)  &&  s  &&  gr->ist_tunnel()) {
 					if ( ribi_t::reverse_single(ribi_type(s)) != ribi_type(testdir[i])) {
@@ -957,7 +962,7 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 			// choose foundation or natural slopes
 			const ground_desc_t *sl_draw = artificial ? ground_desc_t::fundament : ground_desc_t::slopes;
 
-			const sint8 disp_slope = get_disp_slope();
+			const slope_t::type disp_slope = get_disp_slope();
 			// first draw left, then back slopes
 			for(  size_t i=0;  i<grund_t::BACK_WALL_COUNT;  i++  ) {
 				const uint8 back_height = min(i==0?corner_sw(disp_slope):corner_ne(disp_slope),corner_nw(disp_slope));
@@ -972,7 +977,7 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 					grund_t *gr = welt->lookup_kartenboden( k + koord::nsew[(i-1)&3] );
 					if(  gr  ) {
 						// for left we test corners 2 and 3 (east), for back we use 1 and 2 (south)
-						const sint8 gr_slope = gr->get_disp_slope();
+						const slope_t::type gr_slope = gr->get_disp_slope();
 						uint8 corner_a = corner_se(gr_slope);
 						uint8 corner_b = i==0?corner_ne(gr_slope):corner_sw(gr_slope);
 
@@ -1047,7 +1052,7 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 
 					// get transition climate - look for each corner in turn
 					for(  int i = 0;  i < 4;  i++  ) {
-						sint8 corner_height = get_hoehe() + (slope_corner % 3);
+						sint8 corner_height = get_hoehe() + corner_sw(slope_corner);
 
 						climate transition_climate = climate0;
 						climate min_climate = arctic_climate;
@@ -1070,14 +1075,14 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 								uint8 overlay_corners = 1 << i;
 								slope_t::type slope_corner_se = slope_corner;
 								for(  int j = i + 1;  j < 4;  j++  ) {
-									slope_corner_se /= 3;
+									slope_corner_se /= slope_t::southeast;
 
 									// now we check to see if any of remaining corners have same climate transition (also using highest of course)
 									// if so we combine into this overlay layer
 									if(  (climate_corners >> j) & 1  ) {
 										climate compare = climate0;
 										for(  int k = 1;  k < 4;  k++  ) {
-											corner_height = get_hoehe() + (slope_corner_se % 3);
+											corner_height = get_hoehe() + corner_sw(slope_corner_se);
 											if(  corner_height == neighbour_height[(j * 2 + k) & 7][(j + k) & 3]) {
 												climate climatej = neighbour_climate[(j * 2 + k) & 7];
 												climatej > compare ? compare = climatej : 0;
@@ -1094,7 +1099,7 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 								display_alpha( ground_desc_t::get_climate_tile( transition_climate, slope ), ground_desc_t::get_alpha_tile( slope, overlay_corners ), ALPHA_GREEN | ALPHA_BLUE, xpos, ypos, 0, 0, true, dirty CLIP_NUM_PAR );
 							}
 						}
-						slope_corner /= 3;
+						slope_corner /= slope_t::southeast;
 					}
 					// finally overlay any water transition
 					if(  water_corners  ) {
@@ -1280,8 +1285,8 @@ slope_t::type grund_t::get_disp_way_slope() const
 		if (ist_bruecke()) {
 			const slope_t::type slope = get_grund_hang();
 			if(  slope != 0  ) {
-				// for half height slopes we want all corners at 1, for full height all corners at 2
-				return (slope & 7) ? slope_t::raised / 2 : slope_t::raised;
+				// all corners to same height
+				return is_one_high(slope) ? slope_t::all_up_one : slope_t::all_up_two;
 			}
 			else {
 				return get_weg_hang();
@@ -1462,7 +1467,8 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 
 	// display background
 	if (!tunnel_portal  ||  slope == 0) {
-		activate_ribi_clip( (ribi_t::northwest & ribi) | 16 CLIP_NUM_PAR );	}
+		activate_ribi_clip( (ribi_t::northwest & ribi) | 16 CLIP_NUM_PAR );
+	}
 	else {
 		// also clip along the upper edge of the tunnel tile
 		activate_ribi_clip( ribi | 16 CLIP_NUM_PAR );
@@ -1712,7 +1718,6 @@ ribi_t::ribi grund_t::get_weg_ribi_unmasked(waytype_t typ) const
 
 /**
 * If there's a depot here, return this
-* @author Volker Meyer
 */
 depot_t* grund_t::get_depot() const
 {
@@ -1855,7 +1860,7 @@ sint32 grund_t::weg_entfernen(waytype_t wegtyp, bool ribi_rem)
 			}
 		}
 
-		sint32 costs=weg->get_desc()->get_price();	// costs for removal are construction costs
+		sint32 costs=weg->get_desc()->get_price(); // costs for removal are construction costs
 		weg->cleanup( NULL );
 		delete weg;
 
