@@ -1,14 +1,9 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Window with destination information for a stop
- * @author Hj. Malthaner
- */
+#include <algorithm>
 
 #include "halt_info.h"
 #include "components/gui_button_to_chart.h"
@@ -43,7 +38,9 @@
 
 #define CHART_HEIGHT (100)
 
-// class to compute and fill the departure board
+/**
+ * Window with destination information for a stop
+ */
 class gui_departure_board_t : public gui_aligned_container_t
 {
 	// helper class to compute departure board
@@ -145,6 +142,13 @@ private:
 		return strcmp(a.halt->get_name(), b.halt->get_name()) <=0;
 	}
 
+	static bool compare_line (linehandle_t a, linehandle_t b)
+	{
+		return a->get_linetype() == b->get_linetype() ?
+			strcmp(a->get_name(), b->get_name()) <= 0
+			: strcmp(a->get_linetype_name(a->get_linetype()), b->get_linetype_name(b->get_linetype())) <= 0;
+	}
+
 	uint32 cached_line_count;
 	uint32 cached_convoy_count;
 
@@ -159,7 +163,7 @@ private:
 	}
 
 public:
-	uint8 destination_counter;	// last destination counter of the halt; if mismatch to current, then redraw destinations
+	uint8 destination_counter; // last destination counter of the halt; if mismatch to current, then redraw destinations
 
 	gui_halt_detail_t(halthandle_t h) : gui_aligned_container_t()
 	{
@@ -334,7 +338,19 @@ void halt_info_t::init(halthandle_t halt)
 				}
 			}
 			end_table();
-			add_component(&lb_happy);
+			// happy / unhappy / no route
+			add_table(6,1);
+			{
+				add_component(&lb_happy[0]);
+				if (skinverwaltung_t::happy && skinverwaltung_t::unhappy && skinverwaltung_t::no_route) {
+					new_component<gui_image_t>(skinverwaltung_t::happy->get_image_id(0), 0, ALIGN_NONE, true);
+					add_component(&lb_happy[1]);
+					new_component<gui_image_t>(skinverwaltung_t::unhappy->get_image_id(0), 0, ALIGN_NONE, true);
+					add_component(&lb_happy[2]);
+					new_component<gui_image_t>(skinverwaltung_t::no_route->get_image_id(0), 0, ALIGN_NONE, true);
+				}
+			}
+			end_table();
 		}
 		end_table();
 
@@ -356,7 +372,7 @@ void halt_info_t::init(halthandle_t halt)
 	container_freight.add_table(2,1);
 	container_freight.new_component<gui_label_t>("Sort waiting list by");
 
-	// hsiegeln: added sort_button
+	// added sort_button
 	sort_button.init(button_t::roundbox, sort_text[env_t::default_sortmode]);
 	sort_button.set_tooltip("Sort waiting list by");
 	sort_button.add_listener(this);
@@ -398,7 +414,7 @@ void halt_info_t::init(halthandle_t halt)
 	container_chart.end_table();
 
 	update_components();
-	set_resizemode(diagonal_resize);     // 31-May-02	markus weber	added
+	set_resizemode(diagonal_resize);
 	reset_min_windowsize();
 	set_windowsize(get_min_windowsize());
 }
@@ -444,16 +460,29 @@ void halt_info_t::update_components()
 	lb_capacity[2].buf().printf("  %u", halt->get_capacity(2));
 	lb_capacity[2].update();
 
-	if(  has_character( 0x263A )  ) {
-		utf8 happy[4], unhappy[4];
-		happy[ utf16_to_utf8( 0x263A, happy ) ] = 0;
-		unhappy[ utf16_to_utf8( 0x2639, unhappy ) ] = 0;
-		lb_happy.buf().printf(translator::translate("Passengers %d %s, %d %s, %d no route"), halt->get_pax_happy(), happy, halt->get_pax_unhappy(), unhappy, halt->get_pax_no_route());
+	if (skinverwaltung_t::happy && skinverwaltung_t::unhappy && skinverwaltung_t::no_route) {
+		lb_happy[0].buf().printf("%s: %u", translator::translate("Passagiere"), halt->get_pax_happy());
+		lb_happy[0].update();
+		lb_happy[1].buf().printf("  %u", halt->get_pax_unhappy());
+		lb_happy[1].update();
+		lb_happy[2].buf().printf("  %u", halt->get_pax_no_route());
+		lb_happy[2].update();
 	}
 	else {
-		lb_happy.buf().printf(translator::translate("Passengers %d %c, %d %c, %d no route"), halt->get_pax_happy(), 30, halt->get_pax_unhappy(), 31, halt->get_pax_no_route());
+		if(  has_character( 0x263A )  ) {
+			utf8 happy[4], unhappy[4];
+			happy[ utf16_to_utf8( 0x263A, happy ) ] = 0;
+			unhappy[ utf16_to_utf8( 0x2639, unhappy ) ] = 0;
+			lb_happy[0].buf().printf(translator::translate("Passengers %d %s, %d %s, %d no route"), halt->get_pax_happy(), happy, halt->get_pax_unhappy(), unhappy, halt->get_pax_no_route());
+		}
+		else if(  has_character( 0x30 )  ) {
+			lb_happy[0].buf().printf(translator::translate("Passengers %d %c, %d %c, %d no route"), halt->get_pax_happy(), 30, halt->get_pax_unhappy(), 31, halt->get_pax_no_route());
+		}
+		else {
+			lb_happy[0].buf().printf(translator::translate("Passengers %d %c, %d %c, %d no route"), halt->get_pax_happy(), '+', halt->get_pax_unhappy(), '-', halt->get_pax_no_route());
+		}
+		lb_happy[0].update();
 	}
-	lb_happy.update();
 
 	img_enable[0].set_visible(halt->get_pax_enabled());
 	img_enable[1].set_visible(halt->get_mail_enabled());
@@ -482,7 +511,6 @@ void halt_info_t::update_components()
  * Draw new component. The values to be passed refer to the window
  * i.e. It's the screen coordinates of the window where the
  * component is displayed.
- * @author Hj. Malthaner
  */
 void halt_info_t::draw(scr_coord pos, scr_size size)
 {
@@ -519,12 +547,12 @@ void gui_halt_detail_t::update_connections( halthandle_t halt )
 
 	if (!fab_list.empty()) {
 		FOR(slist_tpl<fabrik_t*>, const fab, fab_list) {
-			const koord pos = fab->get_pos().get_2d();
+			const koord3d pos = fab->get_pos();
 
 			// target button ...
 			button_t *pb = new_component<button_t>();
 			pb->init( button_t::posbutton_automatic, NULL);
-			pb->set_targetpos( pos );
+			pb->set_targetpos3d( pos );
 
 			// .. name
 			gui_label_buf_t *lb = new_component<gui_label_buf_t>();
@@ -565,13 +593,27 @@ void gui_halt_detail_t::update_connections( halthandle_t halt )
 	new_component_span<gui_label_t>("Lines serving this stop", 2);
 
 	if(  !halt->registered_lines.empty()  ) {
-		for (unsigned int i = 0; i<halt->registered_lines.get_count(); i++) {
+		simline_t::linetype previous_linetype = simline_t::MAX_LINE_TYPE;
+
+		vector_tpl<linehandle_t> sorted_lines;
+		FOR(vector_tpl<linehandle_t>, l, halt->registered_lines) {
+			if(  l.is_bound()  ) {
+				sorted_lines.insert_unique_ordered( l, gui_halt_detail_t::compare_line );
+			}
+		}
+
+		FOR(vector_tpl<linehandle_t>, line, sorted_lines) {
+
+			// Linetype if it is the first
+			if(  line->get_linetype() != previous_linetype  ) {
+				previous_linetype = line->get_linetype();
+				new_component_span<gui_label_t>(simline_t::get_linetype_name(previous_linetype),2);
+			}
 
-			linehandle_t line = halt->registered_lines[i];
 			new_component<gui_line_button_t>(line);
 
 			// Line labels with color of player
-			gui_label_buf_t *lb = new_component<gui_label_buf_t>(PLAYER_FLAG | color_idx_to_rgb(line->get_owner()->get_player_color1()) );
+			gui_label_buf_t *lb = new_component<gui_label_buf_t>(PLAYER_FLAG | color_idx_to_rgb(line->get_owner()->get_player_color1()+env_t::gui_player_color_dark) );
 			lb->buf().append( line->get_name() );
 			lb->update();
 		}
@@ -581,7 +623,7 @@ void gui_halt_detail_t::update_connections( halthandle_t halt )
 	}
 
 	insert_empty_row();
-	// Knightly : add lineless convoys which serve this stop
+	// add lineless convoys which serve this stop
 	new_component_span<gui_label_t>("Lineless convoys serving this stop", 2);
 	if(  !halt->registered_convoys.empty()  ) {
 		for(  uint32 i=0;  i<halt->registered_convoys.get_count();  ++i  ) {
@@ -591,7 +633,7 @@ void gui_halt_detail_t::update_connections( halthandle_t halt )
 			new_component<gui_convoi_button_t>(cnv);
 
 			// Line labels with color of player
-			gui_label_buf_t *lb = new_component<gui_label_buf_t>(PLAYER_FLAG | color_idx_to_rgb(cnv->get_owner()->get_player_color1()) );
+			gui_label_buf_t *lb = new_component<gui_label_buf_t>(PLAYER_FLAG | color_idx_to_rgb(cnv->get_owner()->get_player_color1()+env_t::gui_player_color_dark) );
 			lb->buf().append( cnv->get_name() );
 			lb->update();
 		}
@@ -610,7 +652,7 @@ void gui_halt_detail_t::update_connections( halthandle_t halt )
 		if(  !connections.empty()  ) {
 
 			gui_label_buf_t *lb = new_component_span<gui_label_buf_t>(2);
-			lb->buf().append(" ");
+			lb->buf().append(" \xC2\xB7");
 			const goods_desc_t* info = goods_manager_t::get_info_catg_index(i);
 			// If it is a special freight, we display the name of the good, otherwise the name of the category.
 			lb->buf().append(translator::translate(info->get_catg()==0 ? info->get_name() : info->get_catg_name() ) );
@@ -634,7 +676,7 @@ void gui_halt_detail_t::update_connections( halthandle_t halt )
 
 				button_t *pb = new_component<button_t>();
 				pb->init( button_t::posbutton_automatic, NULL);
-				pb->set_targetpos( conn.halt->get_basis_pos() );
+				pb->set_targetpos3d( conn.halt->get_basis_pos3d() );
 
 				gui_label_buf_t *lb = new_component<gui_label_buf_t>();
 				lb->buf().printf("%s <%u>", conn.halt->get_name(), conn.weight);
@@ -718,6 +760,9 @@ void gui_departure_board_t::update_departures(halthandle_t halt)
 
 	// iterate over all convoys stopping here
 	FOR(  slist_tpl<convoihandle_t>, cnv, halt->get_loading_convois() ) {
+		if( !cnv.is_bound()) {
+			continue;
+		}
 		halthandle_t next_halt = cnv->get_schedule()->get_next_halt(cnv->get_owner(),halt);
 		if(  next_halt.is_bound()  ) {
 			dest_info_t next( next_halt, 0, cnv );
@@ -863,11 +908,10 @@ void gui_departure_board_t::insert_image(convoihandle_t cnv)
 
 /**
  * This method is called if an action is triggered
- * @author Hj. Malthaner
  */
 bool halt_info_t::action_triggered( gui_action_creator_t *comp,value_t /* */)
 {
-	if (comp == &sort_button) { 	// @author hsiegeln sort button pressed
+	if (comp == &sort_button) {
 		env_t::default_sortmode = ((int)(halt->get_sortby())+1)%4;
 		halt->set_sortby((freight_list_sorter_t::sort_mode_t) env_t::default_sortmode);
 		sort_button.set_text(sort_text[env_t::default_sortmode]);
@@ -913,6 +957,7 @@ void halt_info_t::rdwr(loadsave_t *file)
 		halt = welt->lookup( halt_pos )->get_halt();
 		if (halt.is_bound()) {
 			init(halt);
+			win_set_magic(this, magic_halt_info+halt.get_id());
 			reset_min_windowsize();
 			set_windowsize(size);
 		}
