@@ -1,26 +1,28 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Stations/stops list filter dialog
- * Displays filter settings for the halt list
- * @author V. Meyer
- */
+#ifndef GUI_HALT_LIST_FILTER_FRAME_H
+#define GUI_HALT_LIST_FILTER_FRAME_H
+
 
 #include "gui_frame.h"
+#include "components/action_listener.h"
+#include "components/gui_aligned_container.h"
+#include "components/gui_button.h"
 #include "components/gui_label.h"
 #include "components/gui_scrollpane.h"
-#include "components/action_listener.h"
-#include "components/gui_button.h"
-#include "halt_list_frame.h"
+#include "components/gui_tab_panel.h"
 #include "components/gui_textinput.h"
+#include "halt_list_frame.h"
 
 class player_t;
 
+/**
+ * Stations/stops list filter dialog
+ * Displays filter settings for the halt list
+ */
 class halt_list_filter_frame_t : public gui_frame_t , private action_listener_t
 {
 private:
@@ -42,10 +44,11 @@ private:
 
 		bool infowin_event(event_t const* const ev) OVERRIDE
 		{
-			if(IS_LEFTRELEASE(ev)) {
-				parent->ware_item_triggered(ware_ab, ware_an);
+			bool swallow = button_t::infowin_event( ev );
+			if(  swallow  &&  IS_LEFTRELEASE(ev)  ) {	// only handle, if we are hit!
+				parent->ware_item_triggered( ware_ab, ware_an );
 			}
-			return button_t::infowin_event(ev);
+			return swallow;
 		}
 		void draw(scr_coord offset) OVERRIDE {
 			if(ware_ab) {
@@ -77,6 +80,9 @@ private:
 	 */
 	button_t filter_buttons[FILTER_BUTTONS];
 
+	gui_aligned_container_t name_filter, accepts_filter, sends_filter;
+	gui_tab_panel_t tabs;
+
 	gui_textinput_t name_filter_input;
 
 	button_t typ_filter_enable;
@@ -101,14 +107,12 @@ public:
 
 	/**
 	 * Propagate function from main_frame for ware_item_t
-	 * @author V. Meyer
 	 */
 	bool get_ware_filter_ab(const goods_desc_t *ware) const { return main_frame->get_ware_filter_ab(ware); }
 	bool get_ware_filter_an(const goods_desc_t *ware) const { return main_frame->get_ware_filter_an(ware); }
 
 	/**
 	 * Handler for ware_item_t event.
-	 * @author V. Meyer
 	 */
 	void ware_item_triggered(const goods_desc_t *ware_ab, const goods_desc_t *ware_an);
 
@@ -122,16 +126,16 @@ public:
 	 * Draw new component. The values to be passed refer to the window
 	 * i.e. It's the screen coordinates of the window where the
 	 * component is displayed.
-	 * @author V. Meyer
 	 */
 	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author V. Meyer
 	 */
 	const char * get_help_filename() const OVERRIDE {return "haltlist_filter.txt"; }
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 };
+
+#endif
