@@ -1,17 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- * Written (w) 2001 by Markus Weber
- * filtering added by Volker Meyer
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- */
-
-/*
- * Displays a scrollable list of all stations of a player
- *
- * @author Markus Weber
- * @date 02-Jan-02
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <algorithm>
@@ -23,6 +12,7 @@
 #include "../simhalt.h"
 #include "../simware.h"
 #include "../simfab.h"
+#include "../unicode.h"
 #include "simwin.h"
 #include "../descriptor/skin_desc.h"
 
@@ -73,14 +63,12 @@ public:
 
 /**
  * This variable defines by which column the table is sorted
- * @author Markus Weber
  */
 halt_list_frame_t::sort_mode_t halt_list_frame_t::sortby = nach_name;
 
 /**
  * This variable defines the sort order (ascending or descending)
  * Values: 1 = ascending, 2 = descending)
- * @author Markus Weber
  */
 bool halt_list_frame_t::sortreverse = false;
 
@@ -142,7 +130,7 @@ static bool passes_filter_name(haltestelle_t const& s)
 {
 	if (!halt_list_frame_t::get_filter(halt_list_frame_t::name_filter)) return true;
 
-	return strstr(s.get_name(), halt_list_frame_t::access_name_filter());
+	return utf8caseutf8(s.get_name(), halt_list_frame_t::access_name_filter());
 }
 
 
@@ -196,8 +184,6 @@ static bool passes_filter_out(haltestelle_t const& s)
 	 * - es existiert eine Zugverbindung mit dieser Ware (!ziele[...].empty())
 	 */
 
-	// Hajo: todo: check if there is a destination for the good (?)
-
 	for (uint32 i = 0; i != goods_manager_t::get_count(); ++i) {
 		goods_desc_t const* const ware = goods_manager_t::get_info(i);
 		if (!halt_list_frame_t::get_ware_filter_ab(ware)) continue;
@@ -207,9 +193,9 @@ static bool passes_filter_out(haltestelle_t const& s)
 		} else if (ware == goods_manager_t::mail) {
 			if (s.get_mail_enabled()) return true;
 		} else if (ware != goods_manager_t::none) {
-			// Oh Mann - eine doppelte Schleife und das noch pro Haltestelle
-			// Zum Glck ist die Anzahl der Fabriken und die ihrer Ausgnge
-			// begrenzt (Normal 1-2 Fabriken mit je 0-1 Ausgang) -  V. Meyer
+			// Sigh - a doubly nested loop per halt
+			// Fortunately the number of factories and their number of outputs
+			// is limited (usually 1-2 factories and 0-1 outputs per factory)
 			FOR(slist_tpl<fabrik_t*>, const f, s.get_fab_list()) {
 				FOR(array_tpl<ware_production_t>, const& j, f->get_output()) {
 					if (j.get_typ() == ware) return true;
@@ -231,8 +217,6 @@ static bool passes_filter_in(haltestelle_t const& s)
 	 * - es existiert eine Zugverbindung mit dieser Ware (!ziele[...].empty())
 	 */
 
-	// Hajo: todo: check if there is a destination for the good (?)
-
 	for (uint32 i = 0; i != goods_manager_t::get_count(); ++i) {
 		goods_desc_t const* const ware = goods_manager_t::get_info(i);
 		if (!halt_list_frame_t::get_ware_filter_an(ware)) continue;
@@ -244,9 +228,9 @@ static bool passes_filter_in(haltestelle_t const& s)
 			if (s.get_mail_enabled()) return true;
 		}
 		else if (ware != goods_manager_t::none) {
-			// Oh Mann - eine doppelte Schleife und das noch pro Haltestelle
-			// Zum Glck ist die Anzahl der Fabriken und die ihrer Ausgnge
-			// begrenzt (Normal 1-2 Fabriken mit je 0-1 Ausgang) -  V. Meyer
+			// Sigh - a doubly nested loop per halt
+			// Fortunately the number of factories and their number of outputs
+			// is limited (usually 1-2 factories and 0-1 outputs per factory)
 			FOR(slist_tpl<fabrik_t*>, const f, s.get_fab_list()) {
 				FOR(array_tpl<ware_production_t>, const& j, f->get_input()) {
 					if (j.get_typ() == ware) return true;
@@ -262,7 +246,6 @@ static bool passes_filter_in(haltestelle_t const& s)
 /**
  * Check all filters for one halt.
  * returns true, if it is not filtered away.
- * @author V. Meyer
  */
 static bool passes_filter(haltestelle_t const& s)
 {
@@ -331,11 +314,10 @@ halt_list_frame_t::~halt_list_frame_t()
 
 /**
 * This function refreshes the station-list
-* @author Markus Weber/Volker Meyer
 */
 void halt_list_frame_t::fill_list()
 {
-	last_world_stops = haltestelle_t::get_alle_haltestellen().get_count();				// count of stations
+	last_world_stops = haltestelle_t::get_alle_haltestellen().get_count(); // count of stations
 
 	scrolly->clear_elements();
 	FOR(vector_tpl<halthandle_t>, const halt, haltestelle_t::get_alle_haltestellen()) {
@@ -368,7 +350,6 @@ bool halt_list_frame_t::infowin_event(const event_t *ev)
 
 /**
  * This method is called if an action is triggered
- * @author Markus Weber/Volker Meyer
  */
 bool halt_list_frame_t::action_triggered( gui_action_creator_t *comp,value_t /* */)
 {
