@@ -1,9 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- * Written (w) 2001 Markus Weber
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "halt_list_stats.h"
@@ -31,30 +28,35 @@ static karte_ptr_t welt;
 /**
  * Events werden hiermit an die GUI-Komponenten
  * gemeldet
- * @author Hj. Malthaner
  */
 bool halt_list_stats_t::infowin_event(const event_t *ev)
 {
-	if(halt.is_bound()) {
+	bool swallowed = gui_aligned_container_t::infowin_event(ev);
+	if(  !swallowed  &&  halt.is_bound()  ) {
+
 		if(IS_LEFTRELEASE(ev)) {
-			if (event_get_last_control_shift() != 2) {
+			if(  event_get_last_control_shift() != 2  ) {
 				halt->open_info_window();
 			}
 			return true;
 		}
-		if(IS_RIGHTRELEASE(ev)) {
+		if(  IS_RIGHTRELEASE(ev)  ) {
 			welt->get_viewport()->change_world_position(halt->get_basis_pos3d());
 			return true;
 		}
 	}
-	return false;
+	return swallowed;
 }
 
 
 halt_list_stats_t::halt_list_stats_t(halthandle_t h)
 {
 	halt = h;
-	set_table_layout(2,2);
+	set_table_layout(3,2);
+
+	gotopos.set_typ(button_t::posbutton_automatic);
+	gotopos.set_targetpos3d(halt->get_basis_pos3d());
+	add_component(&gotopos);
 
 	add_component(&indicator);
 	indicator.set_max_size(scr_size(D_INDICATOR_WIDTH,D_INDICATOR_HEIGHT));
@@ -69,6 +71,9 @@ halt_list_stats_t::halt_list_stats_t(halthandle_t h)
 	}
 	end_table();
 
+	// second row, skip posbutton
+	new_component<gui_empty_t>();
+
 	gui_aligned_container_t *table = add_table(3,1);
 	{
 		add_component(&img_enabled[0]);
@@ -98,7 +103,6 @@ const char* halt_list_stats_t::get_text() const
 
 /**
  * Draw the component
- * @author Markus Weber
  */
 void halt_list_stats_t::draw(scr_coord offset)
 {
