@@ -1,27 +1,25 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- * Written (w) 2001 Markus Weber
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef halt_list_stats_h
-#define halt_list_stats_h
+#ifndef GUI_HALT_LIST_STATS_H
+#define GUI_HALT_LIST_STATS_H
+
 
 #include "components/gui_component.h"
 
 #include "components/gui_aligned_container.h"
 #include "components/gui_colorbox.h"
+#include "components/gui_button.h"
 #include "components/gui_image.h"
 #include "components/gui_label.h"
 #include "components/gui_scrolled_list.h"
 #include "../halthandle_t.h"
 
 class gui_halt_type_images_t;
-/**
- * @author Hj. Malthaner
- */
+
+
 class halt_list_stats_t : public gui_aligned_container_t, public gui_scrolled_list_t::scrollitem_t
 {
 private:
@@ -32,6 +30,7 @@ public:
 	gui_image_t img_enabled[3];
 	gui_halt_type_images_t *img_types;
 	gui_colorbox_t indicator;
+	button_t gotopos;
 
 public:
 	halt_list_stats_t(halthandle_t halt_);
@@ -40,7 +39,6 @@ public:
 
 	/**
 	 * Draw the component
-	 * @author Hj. Malthaner
 	 */
 	void draw(scr_coord offset) OVERRIDE;
 
