@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include "koord.h"
 #include "loadsave.h"
 #include "../display/scr_coord.h"
@@ -12,6 +17,7 @@ uint32 koord::locality_factor = 10000;
 const scr_coord scr_coord::invalid(-1, -1);
 
 const scr_size scr_size::invalid(-1, -1);
+const scr_size scr_size::inf(0x7fffffff, 0x7fffffff);
 
 const koord koord::invalid(-1, -1);
 const koord koord::north(    0, -1);
@@ -38,20 +44,20 @@ const koord koord::neighbours[] = {
 
 const koord koord::from_ribi[] = {
 	koord( 0,  0), // none
-	koord( 0, -1), // north				(1)
-	koord( 1,  0), // east				(2)
-	koord( 1, -1), // north-east		(3)
-	koord( 0,  1), // south				(4)
-	koord( 0,  0), // north-south		(5)
-	koord( 1,  1), // south-east		(6)
-	koord( 1,  0), // north-south-east	(7)
-	koord(-1,  0), // west				(8)
-	koord(-1, -1), // north-west		(9)
-	koord( 0,  0), // east-west			(10)
-	koord( 0, -1), // north-east-west	(11)
-	koord(-1,  1), // south-west		(12)
-	koord(-1,  0), // north-south-west	(13)
-	koord( 0,  1), // south-east-west	(14)
+	koord( 0, -1), // north             (1)
+	koord( 1,  0), // east              (2)
+	koord( 1, -1), // north-east        (3)
+	koord( 0,  1), // south             (4)
+	koord( 0,  0), // north-south       (5)
+	koord( 1,  1), // south-east        (6)
+	koord( 1,  0), // north-south-east  (7)
+	koord(-1,  0), // west              (8)
+	koord(-1, -1), // north-west        (9)
+	koord( 0,  0), // east-west         (10)
+	koord( 0, -1), // north-east-west   (11)
+	koord(-1,  1), // south-west        (12)
+	koord(-1,  0), // north-south-west  (13)
+	koord( 0,  1), // south-east-west   (14)
 	koord( 0,  0)  // all
 };
 
