@@ -1,5 +1,11 @@
-#ifndef KOORD_H
-#define KOORD_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DATAOBJ_KOORD_H
+#define DATAOBJ_KOORD_H
+
 
 #include "ribi.h"
 #include "../simtypes.h"
@@ -22,7 +28,7 @@ public:
 
 	koord() : x(0), y(0) {}
 
-	koord(short xp, short yp) : x(xp), y(yp) {}
+	koord(sint16 xp, sint16 yp) : x(xp), y(yp) {}
 	koord(ribi_t::ribi ribi) { *this = from_ribi[ribi]; }
 	koord(slope_t::type slope) { *this = from_hang[slope]; }
 
@@ -33,7 +39,7 @@ public:
 	void rdwr(loadsave_t *file);
 
 	const char *get_str() const;
-	const char *get_fullstr() const;	// including brackets
+	const char *get_fullstr() const; // including brackets
 
 	const koord& operator += (const koord & k)
 	{
@@ -101,7 +107,7 @@ static inline uint32 koord_distance(const koord &a, const koord &b)
 	return abs(a.x - b.x) + abs(a.y - b.y);
 }
 
-// Knightly : shortest distance in cardinal (N, E, S, W) and ordinal (NE, SE, SW, NW) directions
+// shortest distance in cardinal (N, E, S, W) and ordinal (NE, SE, SW, NW) directions
 static inline uint32 shortest_distance(const koord &a, const koord &b)
 {
 	const uint32 x_offset = abs(a.x - b.x);
@@ -115,7 +121,7 @@ static inline uint32 shortest_distance(const koord &a, const koord &b)
 	}
 }
 
-// Knightly : multiply the value by the distance weight
+// multiply the value by the distance weight
 static inline uint32 weight_by_distance(const sint32 value, const uint32 distance)
 {
 	return value<=0 ? 0 : 1+(uint32)( ( ((sint64)value<<8) * koord::locality_factor ) / (sint64)( koord::locality_factor + (distance < 4u ? 4u : distance) ) );
