@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -172,7 +170,6 @@ void leitung_t::cleanup(player_t *player)
 
 /**
  * called during map rotation
- * @author prissi
  */
 void leitung_t::rotate90()
 {
@@ -181,9 +178,9 @@ void leitung_t::rotate90()
 }
 
 
-/* replace networks connection
+/**
+ * replace networks connection
  * non-trivial to handle transformers correctly
- * @author prissi
  */
 void leitung_t::replace(powernet_t* new_net)
 {
@@ -207,7 +204,6 @@ void leitung_t::replace(powernet_t* new_net)
 /**
  * Connect this piece of powerline to its neighbours
  * -> this can merge power networks
- * @author Hj. Malthaner
  */
 void leitung_t::verbinde()
 {
@@ -250,7 +246,6 @@ void leitung_t::verbinde()
 }
 
 
-/* extended by prissi */
 void leitung_t::calc_image()
 {
 	is_crossing = false;
@@ -309,8 +304,6 @@ void leitung_t::calc_image()
 /**
  * Recalculates the images of all neighbouring
  * powerlines and the powerline itself
- *
- * @author Hj. Malthaner
  */
 void leitung_t::calc_neighbourhood()
 {
@@ -330,11 +323,6 @@ void leitung_t::calc_neighbourhood()
 }
 
 
-/**
- * @return Einen Beschreibungsstring fr das Objekt, der z.B. in einem
- * Beobachtungsfenster angezeigt wird.
- * @author Hj. Malthaner
- */
 void leitung_t::info(cbuffer_t & buf) const
 {
 	obj_t::info(buf);
@@ -352,28 +340,21 @@ void leitung_t::info(cbuffer_t & buf) const
 	buf.printf(translator::translate("Usage: %.0f %%"), (double)((100 * net->get_normal_demand()) >> powernet_t::FRACTION_PRECISION));
 }
 
-/**
- * Wird nach dem Laden der Welt aufgerufen - blicherweise benutzt
- * um das Aussehen des Dings an Boden und Umgebung anzupassen
- *
- * @author Hj. Malthaner
- */
+
 void leitung_t::finish_rd()
 {
 #ifdef MULTI_THREAD
 	pthread_mutex_lock( &verbinde_mutex );
-#endif
 	verbinde();
-#ifdef MULTI_THREAD
 	pthread_mutex_unlock( &verbinde_mutex );
-#endif
-#ifdef MULTI_THREAD
 	pthread_mutex_lock( &calc_image_mutex );
-#endif
 	calc_neighbourhood();
-#ifdef MULTI_THREAD
 	pthread_mutex_unlock( &calc_image_mutex );
+#else
+	verbinde();
+	calc_neighbourhood();
 #endif
+
 	grund_t *gr = welt->lookup(get_pos());
 	assert(gr); (void)gr;
 
@@ -706,7 +687,7 @@ void senke_t::step(uint32 delta_t)
 void senke_t::pay_revenue()
 {
 	// megajoules (megawatt seconds) per cent
-	const uint64 mjpc = (1 << POWER_TO_MW) / 2; // should be tied to game setting
+	const uint64 mjpc = (1 << POWER_TO_MW) / CREDIT_PER_MWS; // should be tied to game setting
 
 	// calculate payment in cent
 	const sint64 payment = (sint64)(energy_acc / mjpc);
