@@ -1,5 +1,11 @@
-#ifndef line_scrollitem_h
-#define line_scrollitem_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef GUI_LINE_ITEM_H
+#define GUI_LINE_ITEM_H
+
 
 #include "components/gui_scrolled_list.h"
 #include "../linehandle_t.h"
@@ -21,7 +27,7 @@ public:
 	linehandle_t get_line() const { return line; }
 	char const* get_text() const OVERRIDE;
 	void set_text(char const*) OVERRIDE;
-	bool is_valid() const OVERRIDE { return line.is_bound(); }	//  can be used to indicate invalid entries
+	bool is_valid() const OVERRIDE { return line.is_bound(); } //  can be used to indicate invalid entries
 	bool is_editable() const OVERRIDE { return true; }
 	static bool compare(const gui_component_t *a, const gui_component_t *b );
 };
