@@ -1,9 +1,12 @@
 /*
- * part of the Simutrans project
- * @author hsiegeln
- * 01/12/2003
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
+#ifndef GUI_LINE_MANAGEMENT_GUI_H
+#define GUI_LINE_MANAGEMENT_GUI_H
+
+
 #include "schedule_gui.h"
 
 #include "../linehandle_t.h"
@@ -27,3 +30,5 @@ public:
 private:
 	linehandle_t line;
 };
+
+#endif
