@@ -1,8 +1,6 @@
-﻿/*
- * Copyright (c) 1997 - 2001 Hansjörg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "../simdebug.h"
@@ -13,7 +11,7 @@
 
 #include "loadfont_frame.h"
 
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../simworld.h"
 #include "../simversion.h"
 #include "../pathes.h"
@@ -35,7 +33,6 @@ bool loadfont_frame_t::use_unicode=false;
 
 /**
  * Action that's started with a button click
- * @author Hansjörg Malthaner
  */
 bool loadfont_frame_t::item_action(const char *filename)
 {
