@@ -1,7 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdlib.h>
@@ -17,7 +16,7 @@
 
 #include "log.h"
 #include "../simdebug.h"
-#include "../simsys.h"
+#include "../sys/simsys.h"
 
 
 #ifdef MAKEOBJ
@@ -42,7 +41,6 @@
 
 /**
  * writes a debug message into the log.
- * @author Hj. Malthaner
  */
 void log_t::debug(const char *who, const char *format, ...)
 {
@@ -85,7 +83,6 @@ void log_t::debug(const char *who, const char *format, ...)
 
 /**
  * writes a message into the log.
- * @author Hj. Malthaner
  */
 void log_t::message(const char *who, const char *format, ...)
 {
@@ -128,7 +125,6 @@ void log_t::message(const char *who, const char *format, ...)
 
 /**
  * writes a warning into the log.
- * @author Hj. Malthaner
  */
 void log_t::warning(const char *who, const char *format, ...)
 {
@@ -171,7 +167,6 @@ void log_t::warning(const char *who, const char *format, ...)
 
 /**
  * writes an error into the log.
- * @author Hj. Malthaner
  */
 void log_t::error(const char *who, const char *format, ...)
 {
@@ -222,7 +217,6 @@ void log_t::error(const char *who, const char *format, ...)
 
 /**
  * writes a warning into the log.
- * @author Hj. Malthaner
  */
 void log_t::doubled(const char *what, const char *name )
 {
@@ -252,7 +246,6 @@ void log_t::doubled(const char *what, const char *name )
 
 /**
  * writes an error into the log, aborts the program.
- * @author Hj. Malthaner
  */
 void log_t::fatal(const char *who, const char *format, ...)
 {
@@ -297,7 +290,7 @@ void log_t::fatal(const char *who, const char *format, ...)
 #  ifdef MSG_LEVEL
 	int old_level = env_t::verbose_debug;
 #  endif
-	env_t::verbose_debug = 0;	// no more window concerning messages
+	env_t::verbose_debug = 0; // no more window concerning messages
 	if(is_display_init()) {
 		// show notification
 		destroy_all_win( true );
