@@ -1,6 +1,12 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #ifndef MACROS_H
 #define MACROS_H
 
+
 #include "simtypes.h"
 
 // XXX Workaround: Old GCCs choke on type check.
@@ -21,15 +27,9 @@ template <typename T, unsigned N> static inline void lengthof_check(T (&)[N]) {}
 #define MEMZERO(obj)     MEMZERON(&(obj), 1)
 
 // make sure, a value in within the borders
-static inline int clamp(int x, int min, int max)
+template<typename T> static inline T clamp(T v, T l, T u)
 {
-	if (x <= min) {
-		return min;
-	}
-	if (x >= max) {
-		return max;
-	}
-	return x;
+	return v < l ? l : (v > u ? u :v);
 }
 
 
