@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef message_frame_h
-#define message_frame_h
+#ifndef GUI_MESSAGE_FRAME_T_H
+#define GUI_MESSAGE_FRAME_T_H
+
 
 #include "simwin.h"
 
@@ -23,17 +22,16 @@
 
 /**
  * All messages since the start of the program
- * @author prissi
  */
 class message_frame_t : public gui_frame_t, private action_listener_t
 {
 private:
 	char ibuf[256];
-	message_stats_t	stats;
+	message_stats_t stats;
 	gui_scrollpane_t scrolly;
-	gui_tab_panel_t tabs;		// Knightly : tab panel for filtering messages
+	gui_tab_panel_t tabs;     // tab panel for filtering messages
 	gui_textinput_t input;
-	button_t option_bt, send_bt;
+	button_t option_bt, copy_bt;
 	vector_tpl<sint32> tab_categories;
 
 public:
@@ -42,7 +40,6 @@ public:
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char * get_help_filename() const OVERRIDE {return "mailbox.txt";}
 
