@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef message_stats_t_h
-#define message_stats_t_h
+#ifndef GUI_MESSAGE_STATS_T_H
+#define GUI_MESSAGE_STATS_T_H
+
 
 #include "components/gui_component.h"
 #include "../simmesg.h"
@@ -15,19 +14,19 @@
 
 /**
  * City list stats display
- * @author Hj. Malthaner
  */
 class message_stats_t : public gui_world_component_t
 {
 private:
 	message_t *msg;
-	sint32 message_type;								// Knightly : message type for filtering; -1 indicates no filtering
+	sint32 message_type;                              // message type for filtering; -1 indicates no filtering
 	uint32 last_count;
 	sint32 message_selected;
-	const slist_tpl<message_t::node *> *message_list;	// Knightly : points to the active message list (original or filtered)
-	slist_tpl<message_t::node *> filtered_messages;		// Knightly : cache the list of messages belonging to a certain type
+	const slist_tpl<message_t::node *> *message_list; // points to the active message list (original or filtered)
+	slist_tpl<message_t::node *> filtered_messages;   // cache the list of messages belonging to a certain type
 
 	scr_size min_size;
+
 public:
 	message_stats_t();
 	~message_stats_t() { filtered_messages.clear(); }
@@ -35,7 +34,6 @@ public:
 	/**
 	 * Filter messages by type
 	 * @return whether there is a change in message filtering
-	 * @author Knightly
 	 */
 	bool filter_messages(const sint32 msg_type);
 
@@ -48,11 +46,9 @@ public:
 
 	/**
 	 * Draw the component
-	 * @author Hj. Malthaner
 	 */
 	void draw(scr_coord offset) OVERRIDE;
 
-
 	scr_size get_max_size() const OVERRIDE {
 		return get_min_size();
 	}
@@ -60,7 +56,6 @@ public:
 	scr_size get_min_size() const OVERRIDE {
 		return min_size;
 	}
-
 };
 
 #endif
