@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string.h>
@@ -33,7 +31,6 @@ static vector_tpl<sint32> bFilterStates;
 
 #define BUTTONSPACE max(D_BUTTON_HEIGHT, LINESPACE)
 
-// @author hsiegeln
 static const char *cost_type_name[MAX_PLAYER_COST_BUTTON] =
 {
 	"Transported",
@@ -79,7 +76,7 @@ static const uint8 cost_type[3*MAX_PLAYER_COST_BUTTON] =
 	ATV_WAY_TOLL,                   TT_ALL, MONEY,
 	ATV_OPERATING_PROFIT,           TT_ALL, MONEY,
 	ATV_NEW_VEHICLE,                TT_ALL, MONEY,   // New vehicles
-	ATV_CONSTRUCTION_COST,	        TT_ALL, MONEY,   // Construction
+	ATV_CONSTRUCTION_COST,          TT_ALL, MONEY,   // Construction
 	ATV_PROFIT,                     TT_ALL, MONEY,
 	ATC_CASH,                       TT_MAX, MONEY,   // Cash
 	ATV_NON_FINANCIAL_ASSETS,       TT_ALL, MONEY,   // value of all vehicles and buildings
@@ -89,15 +86,15 @@ static const uint8 cost_type[3*MAX_PLAYER_COST_BUTTON] =
 
 static const sint8 cell_to_buttons[] =
 {
-	0,		-1,		-1,		-1,		-1,
-	1,		-1,		-1,		-1,		-1,
-	2,		-1,		-1,		-1,		-1,
-	3,		-1,		-1,		-1,		-1,
-	4,		-1,		-1,		-1,		-1,
-	5,		-1,		-1,		 9,		-1,
-	6,		-1,		-1,		10,		-1,
-	7,		-1,		-1,		11,		-1,
-	8,		-1,		-1,		12,		-1
+	0,  -1,  -1,  -1,  -1,
+	1,  -1,  -1,  -1,  -1,
+	2,  -1,  -1,  -1,  -1,
+	3,  -1,  -1,  -1,  -1,
+	4,  -1,  -1,  -1,  -1,
+	5,  -1,  -1,   9,  -1,
+	6,  -1,  -1,  10,  -1,
+	7,  -1,  -1,  11,  -1,
+	8,  -1,  -1,  12,  -1
 };
 
 
@@ -130,15 +127,15 @@ static const uint16 label_type[] =
 
 static const sint8 cell_to_moneylabel[] =
 {
-	-1, 	 0,		 1,		-1,		-1,
-	-1, 	 2,		 3,		-1,		-1,
-	-1, 	 4,		 5,		-1,		-1,
-	-1, 	 6,		 7,		-1,		-1,
-	-1, 	 8,		 9,		-1,		-1,
-	-1, 	10,		11,		-1,		18,
-	-1, 	12,		13,		-1,		19,
-	-1, 	14,		15,		-1,		20,
-	-1, 	16,		17,		-1,		21,
+	-1,   0,   1,  -1,  -1,
+	-1,   2,   3,  -1,  -1,
+	-1,   4,   5,  -1,  -1,
+	-1,   6,   7,  -1,  -1,
+	-1,   8,   9,  -1,  -1,
+	-1,  10,  11,  -1,  18,
+	-1,  12,  13,  -1,  19,
+	-1,  14,  15,  -1,  20,
+	-1,  16,  17,  -1,  21,
 };
 
 /* order has to be same as in enum transport_type in file finance.h */
@@ -257,13 +254,13 @@ bool money_frame_t::is_chart_table_zero(int ttoption)
 }
 
 
-money_frame_t::money_frame_t(player_t *player)
-  : gui_frame_t( translator::translate("Finanzen"), player),
-		maintenance_money(MONEY_PLUS, gui_label_t::money_right),
-		scenario_desc(SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left),
-		scenario_completion(SYSCOL_TEXT, gui_label_t::left),
-		warn(SYSCOL_TEXT_STRONG, gui_label_t::left),
-		transport_type_option(0)
+money_frame_t::money_frame_t(player_t *player) :
+	gui_frame_t( translator::translate("Finanzen"), player),
+	maintenance_money(MONEY_PLUS, gui_label_t::money_right),
+	scenario_desc(SYSCOL_TEXT_HIGHLIGHT, gui_label_t::left),
+	scenario_completion(SYSCOL_TEXT, gui_label_t::left),
+	warn(SYSCOL_TEXT_STRONG, gui_label_t::left),
+	transport_type_option(0)
 {
 	if(welt->get_player(0)!=player) {
 		money_frame_title.printf(translator::translate("Finances of %s"), translator::translate(player->get_name()) );
@@ -373,7 +370,7 @@ money_frame_t::money_frame_t(player_t *player)
 					button_to_chart.append(b, current_chart, curve);
 				}
 				else if (l >= 0) {
-					//	money_frame_label_t(uint8 tt, uint8 t, uint8 lt, uint8 i, bool mon)
+					// money_frame_label_t(uint8 tt, uint8 t, uint8 lt, uint8 i, bool mon)
 					money_labels.append( current->new_component<money_frame_label_t>(label_type[4*l], label_type[4*l+1], label_type[4*l+3], label_type[4*l+2], i==1) );
 				}
 				else {
@@ -538,7 +535,7 @@ void money_frame_t::draw(scr_coord pos, scr_size size)
 	fill_chart_tables();
 	update_labels();
 
-	// Hajo: update chart seed
+	// update chart seed
 	chart.set_seed(welt->get_last_year());
 
 	gui_frame_t::draw(pos, size);
