@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef vehicle_movingobj_h
-#define vehicle_movingobj_h
+#ifndef VEHICLE_MOVINGOBJ_H
+#define VEHICLE_MOVINGOBJ_H
+
 
 #include "../tpl/stringhashtable_tpl.h"
 #include "../tpl/vector_tpl.h"
@@ -18,8 +17,7 @@
 
 
 /**
- * moving stuff like sheeps or birds
- * @author prissi
+ * moving stuff like sheep or birds
  */
 class movingobj_t : public vehicle_base_t, public sync_steppable
 {
@@ -58,7 +56,7 @@ public:
 
 	sync_result sync_step(uint32 delta_t) OVERRIDE;
 
-	// prissi: always free
+	// always free
 	virtual bool check_next_tile(const grund_t *) const;
 	virtual bool ist_weg_frei() { return 1; }
 	grund_t* hop_check() OVERRIDE;
