@@ -1,5 +1,11 @@
-#ifndef MUSIC_H
-#define MUSIC_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef MUSIC_MUSIC_H
+#define MUSIC_MUSIC_H
+
 
 #include "../simtypes.h"
 
@@ -16,42 +22,36 @@ bool dr_init_midi();
 /**
  * sets midi playback volume
  * @param vol volume in range 0..255
- * @author Hj. Malthaner
  */
 void dr_set_midi_volume(int vol);
 
 
 /**
  * Loads a MIDI file
- * @author Owen Rudge
  */
 int dr_load_midi(const char* filename);
 
 
 /**
  * Plays a MIDI file
- * @author Owen Rudge
  */
 void dr_play_midi(int key);
 
 
 /**
  * Stops playing MIDI file
- * @author Owen Rudge
  */
 void dr_stop_midi();
 
 
 /**
  * @return -1 if current track has finished, 0 otherwise.
- * @author Owen Rudge
  */
 sint32 dr_midi_pos();
 
 
 /**
  * Midi shutdown/cleanup
- * @author Owen Rudge
  */
 void dr_destroy_midi();
 
