@@ -1,5 +1,11 @@
-#ifndef _NETWORK_SOCKET_LIST_H_
-#define _NETWORK_SOCKET_LIST_H_
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef NETWORK_NETWORK_SOCKET_LIST_H
+#define NETWORK_NETWORK_SOCKET_LIST_H
+
 
 #include "network.h"
 #include "network_address.h"
