@@ -1,12 +1,10 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef blockmanager_h
-#define blockmanager_h
+#ifndef OLD_BLOCKMANAGER_H
+#define OLD_BLOCKMANAGER_H
 
 
 class karte_t;
