@@ -1,9 +1,11 @@
 /*
- * selection of paks at the start time
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef pakselector_h
-#define pakselector_h
+#ifndef GUI_PAKSELECTOR_H
+#define GUI_PAKSELECTOR_H
+
 
 #include "savegame_frame.h"
 #include "components/gui_textarea.h"
