@@ -1,14 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
- *
- * Author: V. Meyer
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __PLACEFINDER_H
-#define __PLACEFINDER_H
+#ifndef FINDER_PLACEFINDER_H
+#define FINDER_PLACEFINDER_H
+
 
 #include "../dataobj/koord.h"
 class karte_t;
@@ -19,8 +16,6 @@ class karte_t;
  * Provides a list of all coordinates from (0, 0) sorted by distance in increasing
  * order with x and y in range [-max_xy; max_xy] except for (0, 0) itself.
  * (0, 0) is used as the end marker.
- *
- * @author V. Meyer
  */
 class pos_list_t {
 	sint16 max_radius;
@@ -34,8 +29,6 @@ class pos_list_t {
 public:
 	/**
 	* @param max_xy (Maximum value for x and y position)
-	*
-	* @author V. Meyer
 	*/
 	pos_list_t(sint16 max_xy);
 	virtual ~pos_list_t();
@@ -52,8 +45,6 @@ public:
  * Extended version of pos_list_t. Provides surrounding positions
  * for a range of size h by w.
  * (0, 0) is used as the end marker again.
- *
- * @author V. Meyer
  */
 class pos_list_wh_t : public pos_list_t {
 	sint16 w;
@@ -70,9 +61,7 @@ public:
 	bool get_next_pos(koord &k) OVERRIDE;
 };
 
-/**
- * @author V. Meyer
- */
+
 class placefinder_t {
 protected:
 	karte_t *welt;
