@@ -1,5 +1,11 @@
-#ifndef PLAINSTRING_H
-#define PLAINSTRING_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef UTILS_PLAINSTRING_H
+#define UTILS_PLAINSTRING_H
+
 
 #include <cstring>
 
