@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include <stdio.h>
 #include <string.h>
 #include "../../bauer/hausbauer.h"
@@ -15,7 +20,6 @@ struct old_btyp
 {
 	/**
 	 * From type "unknown" also come special buildings e.q. Townhall
-	 * @author Hj. Malthaner
 	 */
 	enum typ {wohnung, gewerbe, industrie, unknown};
 };
@@ -26,12 +30,12 @@ obj_desc_t * tile_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 
 	building_tile_desc_t *desc = new building_tile_desc_t();
 
-	// Hajo: Read data
+	// Read data
 	fread(desc_buf, node.size, 1, fp);
 
 	char * p = desc_buf;
 
-	// Hajo: old versions of PAK files have no version stamp.
+	// old versions of PAK files have no version stamp.
 	// But we know, the highest bit was always cleared.
 	const uint16 v = decode_uint16(p);
 	const int version = (v & 0x8000)!=0 ? v&0x7FFF : 0;
@@ -53,6 +57,9 @@ obj_desc_t * tile_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->building = NULL;
 	}
 	else {
+		if( version ) {
+			dbg->fatal( "tile_reader_t::read_node()", "Cannot handle too new node version %i", version );
+		}
 		// skip the pointer ...
 		p += 2;
 		desc->phases = (uint8)decode_uint16(p);
@@ -210,18 +217,40 @@ obj_desc_t * building_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 
 	building_desc_t *desc = new building_desc_t();
 
-	// Hajo: Read data
+	// Read data
 	fread(desc_buf, node.size, 1, fp);
 
 	char * p = desc_buf;
-	// Hajo: old versions of PAK files have no version stamp.
+	// old versions of PAK files have no version stamp.
 	// But we know, the highest bit was always cleared.
 	const uint16 v = decode_uint16(p);
 	const int version = (v & 0x8000)!=0 ? v&0x7FFF : 0;
 
 	old_btyp::typ btyp;
 
-	if(version == 8  ||  version == 9) {
+	if(version == 10) {
+		// preservation date added
+		btyp = (old_btyp::typ)decode_uint8(p);
+		desc->type = (building_desc_t::btype)decode_uint8(p);
+		desc->level = decode_uint16(p);
+		desc->extra_data = decode_uint32(p);
+		desc->size.x = decode_uint16(p);
+		desc->size.y = decode_uint16(p);
+		desc->layouts = decode_uint8(p);
+		desc->allowed_climates = (climate_bits)decode_uint16(p);
+		desc->enables = decode_uint8(p);
+		desc->flags = (building_desc_t::flag_t)decode_uint8(p);
+		desc->distribution_weight = decode_uint8(p);
+		desc->intro_date = decode_uint16(p);
+		desc->retire_date = decode_uint16(p);
+		desc->animation_time = decode_uint16(p);
+		desc->capacity = decode_uint16(p);
+		desc->maintenance = decode_sint32(p);
+		desc->price = decode_sint32(p);
+		desc->allow_underground = decode_uint8(p);
+		desc->preservation_year_month = decode_uint16(p);
+	}
+	else if(version == 8  ||  version == 9) {
 		// Versioned node, version 8
 		// station price, maintenance and capacity added
 		btyp = (old_btyp::typ)decode_uint8(p);
@@ -351,6 +380,9 @@ obj_desc_t * building_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->animation_time = 300;
 	}
 	else {
+		if( version ) {
+			dbg->fatal( "building_reader_t::read_node()", "Cannot handle too new node version %i", version );
+		}
 		// old node, version 0
 		btyp = (old_btyp::typ)v;
 		decode_uint16(p);
@@ -397,7 +429,7 @@ obj_desc_t * building_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 	}
 
 	if (desc->level == 65535) {
-		desc->level = 0;	// apparently wrong level
+		desc->level = 0; // apparently wrong level
 		dbg->warning("building_reader_t::read_node()","level was 65535, intended was probably 0 => changed." );
 	}
 
@@ -410,6 +442,11 @@ obj_desc_t * building_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		}
 	}
 
+	if( version < 10 ) {
+		// can always replace
+		desc->preservation_year_month = DEFAULT_RETIRE_DATE*12;
+	}
+
 	DBG_DEBUG("building_reader_t::read_node()",
 		"version=%d,"
 		" btyp=%d,"
