@@ -1,5 +1,11 @@
-#ifndef __GOODS_READER_H
-#define __GOODS_READER_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_READER_GOOD_READER_H
+#define DESCRIPTOR_READER_GOOD_READER_H
+
 
 #include "obj_reader.h"
 
@@ -20,7 +26,6 @@ public:
 	/**
 	 * Read a goods info node. Does version check and
 	 * compatibility transformations.
-	 * @author Hj. Malthaner
 	 */
 	obj_desc_t* read_node(FILE*, obj_node_info_t&) OVERRIDE;
 };
