@@ -1,7 +1,6 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -14,10 +13,7 @@
 #include "pedestrian_reader.h"
 #include "../../network/pakset_info.h"
 
-/*
- *  Author:
- *      Volker Meyer
- */
+
 void pedestrian_reader_t::register_obj(obj_desc_t *&data)
 {
 	pedestrian_desc_t *desc = static_cast<pedestrian_desc_t  *>(data);
@@ -30,18 +26,15 @@ void pedestrian_reader_t::register_obj(obj_desc_t *&data)
 }
 
 
-
 bool pedestrian_reader_t::successfully_loaded() const
 {
 	return pedestrian_t::successfully_loaded();
 }
 
 
-
 /**
  * Read a pedestrian info node. Does version check and
  * compatibility transformations.
- * @author Hj. Malthaner
  */
 obj_desc_t * pedestrian_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 {
@@ -49,11 +42,11 @@ obj_desc_t * pedestrian_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 
 	pedestrian_desc_t *desc = new pedestrian_desc_t();
 
-	// Hajo: Read data
+	// Read data
 	fread(desc_buf, node.size, 1, fp);
 	char * p = desc_buf;
 
-	// Hajo: old versions of PAK files have no version stamp.
+	// old versions of PAK files have no version stamp.
 	// But we know, the higher most bit was always cleared.
 
 	const uint16 v = decode_uint16(p);
@@ -65,12 +58,8 @@ obj_desc_t * pedestrian_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 	// always there and never retire
 	desc->intro_date = 1;
 	desc->retire_date = 0xFFFEu;
-	
-	if(version == 0) {
-		// old, nonversion node
-		desc->distribution_weight = v;
-	}
-	else if (version == 1) {
+
+	if (version == 1) {
 		desc->distribution_weight = decode_uint16(p);
 		desc->steps_per_frame     = decode_uint16(p);
 		desc->offset              = decode_uint16(p);
@@ -82,6 +71,14 @@ obj_desc_t * pedestrian_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->intro_date          = decode_uint16(p);
 		desc->retire_date         = decode_uint16(p);
 	}
-		DBG_DEBUG("pedestrian_reader_t::read_node()", "version=%i, chance=%i", version, desc->distribution_weight);
+	else {
+		if( version ) {
+			dbg->fatal( "pedestrian_reader_t::read_node()", "Cannot handle too new node version %i", version );
+		}
+		// old, nonversion node
+		desc->distribution_weight = v;
+	}
+
+	DBG_DEBUG("pedestrian_reader_t::read_node()", "version=%i, chance=%i", version, desc->distribution_weight);
 	return desc;
 }
