@@ -1,19 +1,15 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __PEDESTRIAN_READER_H
-#define __PEDESTRIAN_READER_H
+#ifndef DESCRIPTOR_READER_PEDESTRIAN_READER_H
+#define DESCRIPTOR_READER_PEDESTRIAN_READER_H
+
 
 #include "obj_reader.h"
 
 
-/*
- *  Author:
- *      Volker Meyer
- */
 class pedestrian_reader_t : public obj_reader_t {
 	static pedestrian_reader_t the_instance;
 
