@@ -1,11 +1,11 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __ROADSIGN_READER_H
-#define __ROADSIGN_READER_H
+#ifndef DESCRIPTOR_READER_ROADSIGN_READER_H
+#define DESCRIPTOR_READER_ROADSIGN_READER_H
+
 
 #include "obj_reader.h"
 
