@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include <stdio.h>
 
 #include "../../simobj.h"
@@ -12,10 +17,9 @@
 
 void tree_reader_t::register_obj(obj_desc_t *&data)
 {
-    tree_desc_t *desc = static_cast<tree_desc_t *>(data);
+	tree_desc_t *desc = static_cast<tree_desc_t *>(data);
 
-    baum_t::register_desc(desc);
-//    printf("...Tree %s loaded\n", desc->get_name());
+	baum_t::register_desc(desc);
 	checksum_t *chk = new checksum_t();
 	desc->calc_checksum(chk);
 	pakset_info_t::append(desc->get_name(), get_type(), chk);
@@ -24,7 +28,7 @@ void tree_reader_t::register_obj(obj_desc_t *&data)
 
 bool tree_reader_t::successfully_loaded() const
 {
-    return baum_t::successfully_loaded();
+	return baum_t::successfully_loaded();
 }
 
 
@@ -34,12 +38,12 @@ obj_desc_t * tree_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 
 	tree_desc_t *desc = new tree_desc_t();
 
-	// Hajo: Read data
+	// Read data
 	fread(desc_buf, node.size, 1, fp);
 
 	char * p = desc_buf;
 
-	// Hajo: old versions of PAK files have no version stamp.
+	// old versions of PAK files have no version stamp.
 	// But we know, the highest bit was always cleared.
 	const uint16 v = decode_uint16(p);
 	const int version = v & 0x8000 ? v & 0x7FFF : 0;
@@ -48,13 +52,18 @@ obj_desc_t * tree_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->allowed_climates = (climate_bits)decode_uint16(p);
 		desc->distribution_weight = (uint8)decode_uint8(p);
 		desc->number_of_seasons = (uint8)decode_uint8(p);
-	} else if(version == 1) {
+	}
+	else if(version == 1) {
 		// Versioned node, version 1
 		desc->allowed_climates = all_but_arctic_climate;
 		desc->number_of_seasons = 0;
-		decode_uint8(p);	// ignore hoehenlage
+		decode_uint8(p); // ignore hoehenlage
 		desc->distribution_weight = (uint8)decode_uint8(p);
-	} else {
+	}
+	else {
+		if( version ) {
+			dbg->fatal( "tree_reader_t::read_node()", "Cannot handle too new node version %i", version );
+		}
 		// old node, version 0
 		desc->number_of_seasons = 0;
 		desc->allowed_climates = all_but_arctic_climate;
