@@ -1,5 +1,11 @@
-#ifndef __TREE_READER_H
-#define __TREE_READER_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_READER_TREE_READER_H
+#define DESCRIPTOR_READER_TREE_READER_H
+
 
 #include "obj_reader.h"
 
