@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include <stdio.h>
 #include "../../simdebug.h"
 #include "../../simconst.h"
@@ -36,11 +41,11 @@ obj_desc_t *vehicle_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 
 	vehicle_desc_t *desc = new vehicle_desc_t();
 
-	// Hajo: Read data
+	// Read data
 	fread(desc_buf, node.size, 1, fp);
 	char * p = desc_buf;
 
-	// Hajo: old versions of PAK files have no version stamp.
+	// old versions of PAK files have no version stamp.
 	// But we know, the higher most bit was always cleared.
 
 	const uint16 v = decode_uint16(p);
@@ -181,7 +186,7 @@ obj_desc_t *vehicle_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->axle_load = decode_uint16(p);
 		desc->power = decode_uint32(p);
 		desc->running_cost = decode_uint16(p);
-		desc->fixed_cost = decode_uint16(p);
+		desc->maintenance = decode_uint16(p);
 
 		desc->intro_date = decode_uint16(p);
 		desc->retire_date = decode_uint16(p);
@@ -205,7 +210,7 @@ obj_desc_t *vehicle_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->axle_load = decode_uint16(p);
 		desc->power = decode_uint32(p);
 		desc->running_cost = decode_uint16(p);
-		desc->fixed_cost = decode_uint16(p);
+		desc->maintenance = decode_uint16(p);
 
 		desc->intro_date = decode_uint16(p);
 		desc->retire_date = decode_uint16(p);
@@ -229,7 +234,7 @@ obj_desc_t *vehicle_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->axle_load = decode_uint16(p);
 		desc->power = decode_uint32(p);
 		desc->running_cost = decode_uint16(p);
-		desc->fixed_cost = decode_uint32(p);
+		desc->maintenance = decode_uint32(p);
 
 		desc->intro_date = decode_uint16(p);
 		desc->retire_date = decode_uint16(p);
@@ -244,11 +249,11 @@ obj_desc_t *vehicle_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 		desc->freight_image_type = decode_uint8(p);
 	}
 	else {
-		if(  version!=0  ) {
-			dbg->fatal( "vehicle_reader_t::read_node()","Do not know how to handle version=%i", version );
+		if( version ) {
+			dbg->fatal( "vehicle_reader_t::read_node()", "Cannot handle too new node version %i", version );
 		}
-		// old node, version 0
 
+		// old node, version 0
 		desc->wtyp = (sint8)v;
 		desc->capacity = decode_uint16(p);
 		desc->price = decode_uint32(p);
@@ -305,7 +310,7 @@ obj_desc_t *vehicle_reader_t::read_node(FILE *fp, obj_node_info_t &node)
 	}
 
 	if(version<9) {
-		desc->fixed_cost = 0;
+		desc->maintenance = 0;
 		desc->axle_load = 0;
 		desc->loading_time = 1000;
 	}
@@ -345,7 +350,7 @@ DBG_MESSAGE("vehicle_reader_t::register_obj()","old sound %i to %i",old_id,desc-
 		desc->axle_load,
 		desc->power,
 		desc->running_cost,
-		desc->fixed_cost,
+		desc->maintenance,
 		desc->sound,
 		desc->leader_count,
 		desc->trailer_count,
