@@ -1,5 +1,11 @@
-#ifndef __WAY_READER_H
-#define __WAY_READER_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_READER_WAY_READER_H
+#define DESCRIPTOR_READER_WAY_READER_H
+
 
 #include "obj_reader.h"
 
@@ -18,7 +24,6 @@ public:
 	/**
 	 * Read a way info node. Does version check and
 	 * compatibility transformations.
-	 * @author Hj. Malthaner
 	 */
 	obj_desc_t* read_node(FILE*, obj_node_info_t&) OVERRIDE;
 
