@@ -1,3 +1,12 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_READER_XREF_READER_H
+#define DESCRIPTOR_READER_XREF_READER_H
+
+
 #include "obj_reader.h"
 
 class xref_reader_t : public obj_reader_t {
@@ -16,3 +25,5 @@ public:
 
 	obj_desc_t* read_node(FILE*, obj_node_info_t&) OVERRIDE;
 };
+
+#endif
