@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -34,7 +32,7 @@
 
 
 #ifdef DEBUG_ROUTES
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #endif
 
 
@@ -72,7 +70,6 @@ void route_t::remove_koord_from(uint32 i) {
 /**
  * Appends a straight line from the last koord3d in route to the desired target.
  * Will return false if failed
- * @author prissi
  */
 bool route_t::append_straight_route(karte_t *welt, koord3d dest )
 {
@@ -113,8 +110,8 @@ uint32 route_t::MAX_STEP=0;
 bool route_t::node_in_use=false;
 #endif
 
-/* find the route to an unknown location
- * @author prissi
+/**
+ * find the route to an unknown location
  */
 bool route_t::find_route(karte_t *welt, const koord3d start, test_driver_t *tdriver, const uint32 max_khm, uint8 start_dir, uint32 max_depth )
 {
@@ -176,7 +173,7 @@ bool route_t::find_route(karte_t *welt, const koord3d start, test_driver_t *tdri
 
 	bool target_reached = false;
 	do {
-		// Hajo: this is too expensive to be called each step
+		// this is too expensive to be called each step
 		if((step & 4095) == 0) {
 			INT_CHECK("route 161");
 		}
@@ -205,10 +202,10 @@ bool route_t::find_route(karte_t *welt, const koord3d start, test_driver_t *tdri
 			// a way goes here, and it is not marked (i.e. in the closed list)
 			grund_t* to;
 			if(  (ribi & ribi_t::nsew[r] )!=0 // do not go backwards
-				&& koord_distance(start, gr->get_pos() + koord::nsew[r])<max_depth	// not too far away
-				&& gr->get_neighbour(to, wegtyp, ribi_t::nsew[r])  // is connected
-				&& !marker.is_marked(to) // not already tested
-				&& tdriver->check_next_tile(to)	// can be driven on
+			    && koord_distance(start, gr->get_pos() + koord::nsew[r])<max_depth // not too far away
+			    && gr->get_neighbour(to, wegtyp, ribi_t::nsew[r])  // is connected
+			    && !marker.is_marked(to) // not already tested
+			    && tdriver->check_next_tile(to) // can be driven on
 			) {
 				// not in there or taken out => add new
 				ANode* k = &nodes[step++];
@@ -226,7 +223,7 @@ bool route_t::find_route(karte_t *welt, const koord3d start, test_driver_t *tdri
 					if(tmp->dir!=current_dir) {
 						k->g += 3;
 						if(tmp->parent->dir!=tmp->dir  &&  tmp->parent->parent!=NULL) {
-							// discourage 90 turns
+							// discourage 90 degree turns
 							k->g += 10;
 						}
 						else if(ribi_t::is_perpendicular(tmp->dir,current_dir)) {
@@ -362,7 +359,7 @@ bool route_t::intern_calc_route(karte_t *welt, const koord3d ziel, const koord3d
 
 	uint32 beat=1;
 	do {
-		// Hajo: this is too expensive to be called each step
+		// this is too expensive to be called each step
 		if((beat++ & 4095) == 0) {
 			INT_CHECK("route 161");
 		}
@@ -433,7 +430,7 @@ bool route_t::intern_calc_route(karte_t *welt, const koord3d ziel, const koord3d
 					if(tmp->dir!=current_dir) {
 						new_g += 3;
 						if(tmp->parent->dir!=tmp->dir  &&  tmp->parent->parent!=NULL) {
-							// discourage 90 turns
+							// discourage 90 degree turns
 							new_g += 10;
 						}
 						else if(ribi_t::is_perpendicular(tmp->dir,current_dir)) {
@@ -522,7 +519,7 @@ bool route_t::intern_calc_route(karte_t *welt, const koord3d ziel, const koord3d
 
 #ifdef DEBUG_ROUTES
 	// display marked route
-	//reliefkarte_t::get_karte()->calc_map();
+	// minimap_t::get_instance()->calc_map();
 	DBG_DEBUG("route_t::intern_calc_route()","steps=%i  (max %i) in route, open %i, cost %u (max %u)",step,MAX_STEP,queue.get_count(),tmp->g,max_cost);
 #endif
 
@@ -534,7 +531,9 @@ bool route_t::intern_calc_route(karte_t *welt, const koord3d ziel, const koord3d
 		}
 	}
 	else {
+#ifdef DEBUG
 		uint32 best = tmp->g;
+#endif
 		// reached => construct route
 		route.store_at( tmp->count, tmp->gr->get_pos() );
 		while(tmp != NULL) {
@@ -667,10 +666,9 @@ void route_t::postprocess_water_route(karte_t *welt)
 
 
 
-/* searches route, uses intern_calc_route() for distance between stations
+/**
+ * searches route, uses intern_calc_route() for distance between stations
  * handles only driving in stations by itself
- * corrected 12/2005 for station search
- * @author Hansjrg Malthaner, prissi
  */
 route_t::route_result_t route_t::calc_route(karte_t *welt, const koord3d ziel, const koord3d start, test_driver_t *tdriver, const sint32 max_khm, sint32 max_len )
 {
@@ -678,9 +676,14 @@ route_t::route_result_t route_t::calc_route(karte_t *welt, const koord3d ziel, c
 
 	INT_CHECK("route 336");
 
+#ifdef DEBUG_ROUTES
+	const uint32 ms = dr_time();
+#endif
 	bool ok = intern_calc_route(welt, start, ziel, tdriver, max_khm, 0xFFFFFFFFul );
 #ifdef DEBUG_ROUTES
-	if(tdriver->get_waytype()==water_wt) {DBG_DEBUG("route_t::calc_route()","route from %d,%d to %d,%d with %i steps in %u ms found.",start.x, start.y, ziel.x, ziel.y, route.get_count()-1, dr_time()-ms );}
+	if(tdriver->get_waytype()==water_wt) {
+		DBG_DEBUG("route_t::calc_route()", "route from %d,%d to %d,%d with %i steps in %u ms found.", start.x, start.y, ziel.x, ziel.y, route.get_count()-1, dr_time()-ms );
+	}
 #endif
 
 	INT_CHECK("route 343");
