@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjörg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string>
@@ -11,7 +9,7 @@
 
 #include "savegame_frame.h"
 #include "../pathes.h"
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../simdebug.h"
 #include "simwin.h"
 #include "../utils/simstring.h"
@@ -34,10 +32,6 @@ public:
 };
 
 /**
- * SAVE GAME FRAME CONSTRUCTOR
- * @author Hj. Malthaner
- * @author Max Kielland
- *
  * @param suffix            Optional file pattern to populate the file list.
  *                          Example ".sve" or "sve"
  *                          Default value is NULL to disregard extension.
@@ -120,9 +114,7 @@ savegame_frame_t::savegame_frame_t(const char *suffix, bool only_directories, co
 
 
 /**
- * SAVE GAME FRAME DESTRUCTOR
  * Free all list items.
- * @author Hj. Malthaner
  */
 savegame_frame_t::~savegame_frame_t()
 {
@@ -147,7 +139,6 @@ savegame_frame_t::~savegame_frame_t()
 
 
 /**
- * ADD SECTION
  * Adds a section entry to the list...
  *
  * @param name  Section name?!?
@@ -164,9 +155,9 @@ void savegame_frame_t::add_section(std::string &name){
 
 	size_t program_dir_len = strlen(env_t::program_dir);
 
-	if (strncmp(name.c_str(),env_t::program_dir,program_dir_len) == 0) {
-		// starts with program_dir
-		strncpy(path_expanded, name.c_str(), FILENAME_MAX);
+	if(  name[0]=='/'  ||  name[0]=='\\'  ||  name[1]==':'  ||  strncmp(name.c_str(),env_t::program_dir,program_dir_len) == 0  ) {
+		// starts with program_dir or an absolute path
+		tstrncpy(path_expanded, name.c_str(), FILENAME_MAX);
 	}
 	else {
 		// user_dir path
@@ -201,7 +192,6 @@ void savegame_frame_t::add_section(std::string &name){
 
 
 /**
- * ADD PATH
  * Adds a path to the list of path included in the file search.
  * Several paths can be added one at a time. All added paths will
  * be searched by fill_list().
@@ -220,7 +210,6 @@ void savegame_frame_t::add_path(const char * path){
 
 
 /**
- * FILL LIST
  * Populates the item list with matching file names. Each matching file
  * is first checked (check_file) and then added (add_file).
  */
@@ -241,8 +230,8 @@ void savegame_frame_t::fill_list( void )
 	// for each path, we search.
 	FOR(vector_tpl<std::string>, &path, paths){
 
-		const char		*path_c = path.c_str();
-		const size_t	path_c_len = strlen(path_c);
+		const char *path_c      = path.c_str();
+		const size_t path_c_len = strlen(path_c);
 
 		sf.search(path, std::string(suffixnodot), this->only_directories, false);
 
@@ -273,19 +262,17 @@ void savegame_frame_t::fill_list( void )
 
 
 /**
- * LIST FILLED
  * All items has been inserted in the list.
  * On return resize() is called and all item's GYU members are positioned and resized.
  * Therefore it is no use to set the button's and label's width or any items y position.
  * The only control keeping its size is the delete button.
- * @author Unknown
- * @author Max Kielland
  */
 void savegame_frame_t::list_filled( void )
 {
 	uint cols = (delete_enabled ? 1 : 0) + 1 + (label_enabled ? 1 : 0);
 	button_frame.set_table_layout(1,0);
 	button_frame.add_table(cols,0);
+	button_frame.add_table(cols,0)->set_spacing(scr_size(D_H_SPACE,D_FILELIST_V_SPACE)); // change space between entries to zero to see more on screen
 
 	FOR(slist_tpl<dir_entry_t>, const& i, entries) {
 		button_t*    const delete_button = i.del;
@@ -335,8 +322,7 @@ void savegame_frame_t::list_filled( void )
 
 
 /**
- * CHECK FILE
- * Check if a file name qualifies to be added tot he item list.
+ * Check if a file name qualifies to be added to he item list.
  *
  * @param filename  The found file name
  * @param suffix    Suffix pattern to match. If this is NULL
@@ -354,7 +340,6 @@ bool savegame_frame_t::check_file(const char *filename, const char *suffix)
 
 
 /**
- * ADD FILE
  * Create and add a list item from the given parameters. The button is set
  * to the filename, the label to the string returned by get_info().
  *
@@ -441,7 +426,6 @@ void savegame_frame_t::add_file(const char *fullpath, const char *filename, cons
 
 
 /**
- * INFO WIN EVENT
  * This dialogue's message event handler. The enter key is dispateched as
  * an action button click event. The WIN_OPEN event starts to fill the file
  * list if it is empty.
@@ -470,12 +454,9 @@ bool savegame_frame_t::infowin_event(const event_t *event)
 
 
 /**
- * ACTION TRIGGERED
  * Click event handler and dispatcher. This function is called
  * every time a button is clicked and the corresponding handler
  * is called from here.
- * @author Hj. Malthaner
- * @author Max Kielland
  *
  * @param component  The component that was clicked.
  *
@@ -505,14 +486,14 @@ bool savegame_frame_t::action_triggered(gui_action_creator_t *component, value_t
 			}
 		}
 		ok_action(buf);
-		destroy_win(this);      //29-Oct-2001         Markus Weber    Close window
+		destroy_win(this);
 
 	}
 	else if(component == &cancelbutton) {
 		// Cancel-button pressed
 		//----------------------------
 		cancel_action(buf);
-		destroy_win(this);      //29-Oct-2001         Markus Weber    Added   savebutton case
+		destroy_win(this);
 	}
 	else {
 		// File in list selected
@@ -555,12 +536,10 @@ bool savegame_frame_t::action_triggered(gui_action_creator_t *component, value_t
 
 
 /**
- * DELETE ACTION
  * Generic delete button click handler. This will delete the
  * item from the storage media. If the system supports a
  * trash bin, the file is moved over there instead of being deleted.
  * A shift + Delete always deletes the file imediatly
- * @author Hansjörg Malthaner
  *
  * @param fullpath  Full path to the file being deleted.
  *
@@ -581,7 +560,6 @@ bool savegame_frame_t::del_action(const char *fullpath)
 
 
 /**
- * SET FILE NAME
  * Sets the current filename in the input box
  *
  * @param file_name  A nul terminated string to assign the edit control.
@@ -603,7 +581,7 @@ void savegame_frame_t::set_filename(const char *file_name)
 
 
 /**
- * CLEAN UP PATH - ONLY WIN32
+ * ONLY WIN32
  * Translates all / into \ in a given path string. If a drive
  * letter is present it is translated to upper case
  *
@@ -635,7 +613,6 @@ void savegame_frame_t::cleanup_path(char *path)
 
 
 /**
- * SHORTEN PATH
  * Outputs a truncated path by replacing the middle portion with "..."
  *
  * @param dest      Destination string.
@@ -665,7 +642,6 @@ void savegame_frame_t::shorten_path(char *dest,const char *source,const size_t m
 
 
 /**
- * GET BASE NAME
  * Returns the path portion of a qualified filename including path.
  *
  * @param fullpath  A null terminated string with a full qualified file name.
@@ -683,7 +659,6 @@ std::string savegame_frame_t::get_basename(const char *fullpath)
 
 
 /**
- * GET FILE NAME
  * Returns the file name without extension (optional) of a qualified filename
  * including path.
  *
