@@ -1,11 +1,16 @@
-#ifndef schedule_entry_t_h
-#define schedule_entry_t_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DATAOBJ_SCHEDULE_ENTRY_H
+#define DATAOBJ_SCHEDULE_ENTRY_H
+
 
 #include "koord3d.h"
 
 /**
  * A schedule entry.
- * @author Hj. Malthaner
  */
 struct schedule_entry_t
 {
@@ -20,21 +25,18 @@ public:
 
 	/**
 	 * target position
-	 * @author Hj. Malthaner
 	 */
 	koord3d pos;
 
 	/**
 	 * Wait for % load at this stops
 	 * (ignored on waypoints)
-	 * @author Hj. Malthaner
 	 */
 	uint8 minimum_loading;
 
 	/**
 	 * maximum waiting time in 1/2^(16-n) parts of a month
 	 * (only active if minimum_loading!=0)
-	 * @author prissi
 	 */
 	sint8 waiting_time_shift;
 };
