@@ -1,10 +1,6 @@
 /*
- * Copyright (c) 1997 - 2004 Hj. Malthaner
- *
- * Line management
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -44,8 +40,10 @@
 #include "../boden/wege/schiene.h"
 #include "../boden/wege/strasse.h"
 
+#include "../unicode.h"
 
-#include "karte.h"
+
+#include "minimap.h"
 
 
 static const char *cost_type[MAX_LINE_COST] =
@@ -116,12 +114,10 @@ linehandle_t schedule_list_gui_t::selected_line[MAX_PLAYER_COUNT][simline_t::MAX
 schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	gui_frame_t( translator::translate("Line Management"), player_),
 	player(player_),
-	scrolly_convois(&cont),
-	scrolly_haltestellen(&cont_haltestellen),
-	scl(gui_scrolled_list_t::listskin),
-	lbl_filter("Line Filter"),
-	convoy_infos(),
-	stop_infos()
+	scl(gui_scrolled_list_t::listskin, line_scrollitem_t::compare),
+	scrolly_convois(gui_scrolled_list_t::windowskin),
+	scrolly_haltestellen(gui_scrolled_list_t::windowskin),
+	lbl_filter("Line Filter")
 {
 	capacity = load = 0;
 	selection = -1;
@@ -129,6 +125,7 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	schedule_filter[0] = 0;
 	old_schedule_filter[0] = 0;
 	last_schedule = NULL;
+	old_player = NULL;
 
 	// add components
 	// first column: scrolled list of all lines
@@ -136,7 +133,6 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	// init scrolled list
 	scl.set_pos(scr_coord(D_MARGIN_LEFT, D_MARGIN_TOP));
 	scl.set_size(scr_size(3*D_BUTTON_WIDTH+2*D_H_SPACE, SCL_HEIGHT));
-	scl.set_highlight_color(color_idx_to_rgb(player->get_player_color1()+1));
 	scl.add_listener(this);
 
 	// tab panel
@@ -195,15 +191,47 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 
 	sint16 bt_y = D_MARGIN_TOP+SCL_HEIGHT+D_V_SPACE+D_EDIT_HEIGHT+D_V_SPACE ;
 
+	// freight type filter
+	viewable_freight_types.append(NULL);
+	freight_type_c.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( translator::translate("All"), SYSCOL_TEXT) ;
+	viewable_freight_types.append(goods_manager_t::passengers);
+	freight_type_c.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( translator::translate("Passagiere"), SYSCOL_TEXT) ;
+	viewable_freight_types.append(goods_manager_t::mail);
+	freight_type_c.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( translator::translate("Post"), SYSCOL_TEXT) ;
+	viewable_freight_types.append(goods_manager_t::none); // for all freight ...
+	freight_type_c.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( translator::translate("Fracht"), SYSCOL_TEXT) ;
+	for(  int i = 0;  i < goods_manager_t::get_max_catg_index();  i++  ) {
+		const goods_desc_t *freight_type = goods_manager_t::get_info_catg(i);
+		const int index = freight_type->get_catg_index();
+		if(  index == goods_manager_t::INDEX_NONE  ||  freight_type->get_catg()==0  ) {
+			continue;
+		}
+		freight_type_c.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate(freight_type->get_catg_name()), SYSCOL_TEXT);
+		viewable_freight_types.append(freight_type);
+	}
+	for(  int i=0;  i < goods_manager_t::get_count();  i++  ) {
+		const goods_desc_t *ware = goods_manager_t::get_info(i);
+		if(  ware->get_catg() == 0  &&  ware->get_index() > 2  ) {
+			// Special freight: Each good is special
+			viewable_freight_types.append(ware);
+			freight_type_c.new_component<gui_scrolled_list_t::const_text_scrollitem_t>( translator::translate(ware->get_name()), SYSCOL_TEXT) ;
+		}
+	}
+	freight_type_c.set_selection(0);
+	freight_type_c.set_focusable( true );
+	freight_type_c.add_listener( this );
+	freight_type_c.init( scr_coord( D_MARGIN_LEFT+D_BUTTON_WIDTH+D_H_SPACE, bt_y ), scr_size( D_BUTTON_WIDTH*2+D_H_SPACE, D_BUTTON_HEIGHT ) );
+	add_component(&freight_type_c);
+
 	// normal buttons edit new remove
 	bt_new_line.init(button_t::roundbox, "New Line",
-		scr_coord(D_MARGIN_LEFT, bt_y),
+		scr_coord(D_MARGIN_LEFT, bt_y+D_BUTTON_HEIGHT+D_V_SPACE),
 		scr_size(D_BUTTON_WIDTH, D_BUTTON_HEIGHT));
 	bt_new_line.add_listener(this);
 	add_component(&bt_new_line);
 
 	bt_edit_line.init(button_t::roundbox, "Update Line",
-		scr_coord(D_MARGIN_LEFT+D_BUTTON_WIDTH+D_H_SPACE, bt_y),
+		scr_coord(D_MARGIN_LEFT+D_BUTTON_WIDTH+D_H_SPACE, bt_y+D_BUTTON_HEIGHT+D_V_SPACE),
 		scr_size(D_BUTTON_WIDTH, D_BUTTON_HEIGHT));
 	bt_edit_line.set_tooltip("Modify the selected line");
 	bt_edit_line.add_listener(this);
@@ -211,7 +239,7 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	add_component(&bt_edit_line);
 
 	bt_delete_line.init(button_t::roundbox, "Delete Line",
-		scr_coord(D_MARGIN_LEFT+2*(D_BUTTON_WIDTH+D_H_SPACE), bt_y),
+		scr_coord(D_MARGIN_LEFT+2*(D_BUTTON_WIDTH+D_H_SPACE), bt_y+D_BUTTON_HEIGHT+D_V_SPACE),
 		scr_size(D_BUTTON_WIDTH, D_BUTTON_HEIGHT));
 	bt_delete_line.set_tooltip("Delete the selected line (if without associated convois).");
 	bt_delete_line.add_listener(this);
@@ -219,8 +247,7 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	add_component(&bt_delete_line);
 
 	// lower left corner: halt list of selected line
-	cont_haltestellen.set_size(scr_size(3*D_BUTTON_WIDTH+2*D_H_SPACE, 28));
-	scrolly_haltestellen.set_pos(scr_coord(D_MARGIN_LEFT, bt_y + D_BUTTON_HEIGHT+ D_V_SPACE));
+	scrolly_haltestellen.set_pos(scr_coord(0, bt_y + D_BUTTON_HEIGHT*2+ D_V_SPACE*2));
 	scrolly_haltestellen.set_show_scroll_x(true);
 	scrolly_haltestellen.set_scroll_amount_y(28);
 	scrolly_haltestellen.set_visible(false);
@@ -240,8 +267,7 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	add_component(&filled_bar);
 
 	// convoi list
-	cont.set_size(scr_size(200, 40));
-	scrolly_convois.set_pos(scr_coord(RIGHT_COLUMN_OFFSET, bt_y + D_BUTTON_HEIGHT+ D_V_SPACE + 2*LINESPACE));
+	scrolly_convois.set_pos(scr_coord(RIGHT_COLUMN_OFFSET-D_H_SPACE, bt_y + D_BUTTON_HEIGHT+ D_V_SPACE + 2*LINESPACE));
 	scrolly_convois.set_show_scroll_x(true);
 	scrolly_convois.set_scroll_amount_y(40);
 	scrolly_convois.set_visible(false);
@@ -274,6 +300,10 @@ schedule_list_gui_t::schedule_list_gui_t(player_t *player_) :
 	for(  uint i=0;  i<max_idx;  i++  ) {
 		if(  tabs_to_lineindex[i] == selected_tab[player->get_player_nr()]  ) {
 			line = selected_line[player->get_player_nr()][selected_tab[player->get_player_nr()]];
+			// check owner here: selected_line[][] is not reset between games, so line could have another player as owner
+			if (line.is_bound()  &&  line->get_owner() != player) {
+				line = linehandle_t();
+			}
 			index = i;
 			break;
 		}
@@ -303,16 +333,6 @@ schedule_list_gui_t::~schedule_list_gui_t()
 	delete last_schedule;
 	// change line name if necessary
 	rename_line();
-
-	// delete all convoy info objects
-	while(  !convoy_infos.empty()  ) {
-		delete convoy_infos.pop_back();
-	}
-
-	// delete all stop info objects
-	while(  !stop_infos.empty()  ) {
-		delete stop_infos.pop_back();
-	}
 }
 
 
@@ -324,16 +344,16 @@ bool schedule_list_gui_t::infowin_event(const event_t *ev)
 	if(  ev->ev_class == INFOWIN  ) {
 		if(  ev->ev_code == WIN_CLOSE  ) {
 			// hide schedule on minimap (may not current, but for safe)
-			reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
+			minimap_t::get_instance()->set_selected_cnv( convoihandle_t() );
 		}
 		else if(  (ev->ev_code==WIN_OPEN  ||  ev->ev_code==WIN_TOP)  &&  line.is_bound() ) {
 			if(  line->count_convoys()>0  ) {
 				// set this schedule as current to show on minimap if possible
-				reliefkarte_t::get_karte()->set_current_cnv( line->get_convoy(0) );
+				minimap_t::get_instance()->set_selected_cnv( line->get_convoy(0) );
 			}
 			else {
 				// set this schedule as current to show on minimap if possible
-				reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
+				minimap_t::get_instance()->set_selected_cnv( convoihandle_t() );
 			}
 		}
 	}
@@ -341,14 +361,14 @@ bool schedule_list_gui_t::infowin_event(const event_t *ev)
 }
 
 
-bool schedule_list_gui_t::action_triggered( gui_action_creator_t *komp, value_t v )           // 28-Dec-01    Markus Weber    Added
+bool schedule_list_gui_t::action_triggered( gui_action_creator_t *comp, value_t v )
 {
-	if(  komp == &bt_edit_line  ) {
+	if(  comp == &bt_edit_line  ) {
 		if(  line.is_bound()  ) {
 			create_win( new line_management_gui_t(line, player), w_info, (ptrdiff_t)line.get_rep() );
 		}
 	}
-	else if(  komp == &bt_new_line  ) {
+	else if(  comp == &bt_new_line  ) {
 		// create typed line
 		assert(  tabs.get_active_tab_index() > 0  &&  tabs.get_active_tab_index()<max_idx  );
 		// update line schedule via tool!
@@ -362,7 +382,7 @@ bool schedule_list_gui_t::action_triggered( gui_action_creator_t *komp, value_t
 		delete tmp_tool;
 		depot_t::update_all_win();
 	}
-	else if(  komp == &bt_delete_line  ) {
+	else if(  comp == &bt_delete_line  ) {
 		if(  line.is_bound()  ) {
 			tool_t *tmp_tool = create_tool( TOOL_CHANGE_LINE | SIMPLE_TOOL );
 			cbuffer_t buf;
@@ -374,7 +394,7 @@ bool schedule_list_gui_t::action_triggered( gui_action_creator_t *komp, value_t
 			depot_t::update_all_win();
 		}
 	}
-	else if(  komp == &bt_withdraw_line  ) {
+	else if(  comp == &bt_withdraw_line  ) {
 		bt_withdraw_line.pressed ^= 1;
 		if (  line.is_bound()  ) {
 			tool_t *tmp_tool = create_tool( TOOL_CHANGE_LINE | SIMPLE_TOOL );
@@ -386,7 +406,7 @@ bool schedule_list_gui_t::action_triggered( gui_action_creator_t *komp, value_t
 			delete tmp_tool;
 		}
 	}
-	else if(  komp == &tabs  ) {
+	else if(  comp == &tabs  ) {
 		int const tab = tabs.get_active_tab_index();
 		uint8 old_selected_tab = selected_tab[player->get_player_nr()];
 		selected_tab[player->get_player_nr()] = tabs_to_lineindex[tab];
@@ -404,7 +424,7 @@ bool schedule_list_gui_t::action_triggered( gui_action_creator_t *komp, value_t
 			bt_new_line.disable();
 		}
 	}
-	else if(  komp == &scl  ) {
+	else if(  comp == &scl  ) {
 		if(  line_scrollitem_t *li=(line_scrollitem_t *)scl.get_element(v.i)  ) {
 			update_lineinfo( li->get_line() );
 		}
@@ -415,19 +435,22 @@ bool schedule_list_gui_t::action_triggered( gui_action_creator_t *komp, value_t
 		selected_line[player->get_player_nr()][selected_tab[player->get_player_nr()]] = line;
 		selected_line[player->get_player_nr()][0] = line; // keep these the same in overview
 	}
-	else if(  komp == &inp_filter  ) {
+	else if(  comp == &inp_filter  ) {
 		if(  strcmp(old_schedule_filter,schedule_filter)  ) {
 			build_line_list(tabs.get_active_tab_index());
 			strcpy(old_schedule_filter,schedule_filter);
 		}
 	}
-	else if(  komp == &inp_name  ) {
+	else if(  comp == &freight_type_c  ) {
+		build_line_list(tabs.get_active_tab_index());
+	}
+	else if(  comp == &inp_name  ) {
 		rename_line();
 	}
 	else {
 		if(  line.is_bound()  ) {
 			for(  int i=0;  i<MAX_LINE_COST;  i++  ) {
-				if(  komp == &filterButtons[i]  ) {
+				if(  comp == &filterButtons[i]  ) {
 					filterButtons[i].pressed ^= 1;
 					if(  filterButtons[i].pressed  ) {
 						chart.show_curve(i);
@@ -483,6 +506,17 @@ void schedule_list_gui_t::draw(scr_coord pos, scr_size size)
 	if(  old_line_count != player->simlinemgmt.get_line_count()  ) {
 		show_lineinfo( line );
 	}
+
+	if(  old_player != welt->get_active_player()  ) {
+		// deativate buttons, if not curretn player
+		old_player = welt->get_active_player();
+		const bool activate = old_player == player || old_player == welt->get_player( 1 );
+		bt_delete_line.enable( activate );
+		bt_edit_line.enable( activate );
+		bt_new_line.enable( activate   &&  tabs.get_active_tab_index() > 0);
+		bt_withdraw_line.enable( activate );
+	}
+
 	// if search string changed, update line selection
 	if(  strcmp( old_schedule_filter, schedule_filter )  ) {
 		build_line_list(tabs.get_active_tab_index());
@@ -574,8 +608,8 @@ void schedule_list_gui_t::set_windowsize(scr_size size)
 	int button_per_row = max(1, (rest_width+D_H_SPACE)/(D_BUTTON_WIDTH+D_H_SPACE));
 	int button_rows = MAX_LINE_COST/button_per_row + ((MAX_LINE_COST%button_per_row)!=0);
 
-	scrolly_convois.set_size( scr_size(rest_width, get_client_windowsize().h-scrolly_convois.get_pos().y) );
-	scrolly_haltestellen.set_size( scr_size(RIGHT_COLUMN_OFFSET-2*D_V_SPACE, get_client_windowsize().h-scrolly_haltestellen.get_pos().y) );
+	scrolly_convois.set_size( scr_size(rest_width+D_MARGIN_RIGHT, get_client_windowsize().h-scrolly_convois.get_pos().y) );
+	scrolly_haltestellen.set_size( scr_size(RIGHT_COLUMN_OFFSET, get_client_windowsize().h-scrolly_haltestellen.get_pos().y) );
 
 	chart.set_size( scr_size( rest_width, SCL_HEIGHT-D_MARGIN_TOP-(button_rows*(D_BUTTON_HEIGHT+D_H_SPACE)) ) );
 	inp_name.set_size(scr_size(rest_width, D_EDIT_HEIGHT));
@@ -593,25 +627,24 @@ void schedule_list_gui_t::build_line_list(int filter)
 	sint32 sel = -1;
 	scl.clear_elements();
 	player->simlinemgmt.get_lines(tabs_to_lineindex[filter], &lines);
-	vector_tpl<line_scrollitem_t *>selected_lines;
 
 	FOR(vector_tpl<linehandle_t>, const l, lines) {
 		// search name
-		if(  strstr(l->get_name(), schedule_filter)  ) {
-			selected_lines.append(new line_scrollitem_t(l));
-		}
-	}
-
-	FOR(vector_tpl<line_scrollitem_t*>, const i, selected_lines) {
-		scl.append_element(i);
-		if(  line == i->get_line()  ) {
-			sel = scl.get_count() - 1;
+		if(  utf8caseutf8(l->get_name(), schedule_filter)  ) {
+			// match good category
+			if(  is_matching_freight_catg( l->get_goods_catg_index() )  ) {
+				scl.new_component<line_scrollitem_t>(l);
+			}
+			if(  line == l  ) {
+				sel = scl.get_count() - 1;
+			}
 		}
 	}
 
 	scl.set_selection( sel );
 	line_scrollitem_t::sort_mode = (line_scrollitem_t::sort_modes_t)current_sort_mode;
-	scl.sort( 0, NULL );
+	scl.sort( 0 );
+	scl.set_size(scl.get_size());
 
 	old_line_count = player->simlinemgmt.get_line_count();
 }
@@ -637,21 +670,11 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 		uint32 icnv = 0;
 		icnv = new_line->count_convoys();
 		// display convoys of line
-		cont.remove_all();
-		while(  !convoy_infos.empty()  ) {
-			delete convoy_infos.pop_back();
-		}
-		convoy_infos.resize(icnv);
-		scr_coord_val ypos = 0;
+		scrolly_convois.clear_elements();
 		for(  uint32 i=0;  i<icnv;  i++  ) {
-			gui_convoiinfo_t* const cinfo = new gui_convoiinfo_t(new_line->get_convoy(i));
-			cinfo->set_pos(scr_coord(0, ypos));
-			cinfo->set_size(scr_size(400, 40));
-			convoy_infos.append(cinfo);
-			cont.add_component(cinfo);
-			ypos += 40;
+			scrolly_convois.new_component<gui_convoiinfo_t>(new_line->get_convoy(i));
 		}
-		cont.set_size(scr_size(500, ypos));
+		scrolly_convois.set_size(scrolly_convois.get_size());
 
 		bt_delete_line.disable();
 		add_component(&bt_withdraw_line);
@@ -667,24 +690,14 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 		bt_withdraw_line.pressed = new_line->get_withdraw();
 
 		// fill haltestellen container with info of stops of the line
-		cont_haltestellen.remove_all();
-		while(  !stop_infos.empty()  ) {
-			delete stop_infos.pop_back();
-		}
-		stop_infos.resize(new_line->get_schedule()->entries.get_count());
-		ypos = 0;
+		scrolly_haltestellen.clear_elements();
 		FOR(minivec_tpl<schedule_entry_t>, const& i, new_line->get_schedule()->entries) {
 			halthandle_t const halt = haltestelle_t::get_halt(i.pos, player);
 			if(  halt.is_bound()  ) {
-				halt_list_stats_t* cinfo = new halt_list_stats_t(halt);
-				cinfo->set_pos(scr_coord(0, ypos));
-				cinfo->set_size(scr_size(500, 28));
-				stop_infos.append(cinfo);
-				cont_haltestellen.add_component(cinfo);
-				ypos += 28;
+				scrolly_haltestellen.new_component<halt_list_stats_t>(halt);
 			}
 		}
-		cont_haltestellen.set_size(scr_size(500, ypos));
+		scrolly_haltestellen.set_size(scrolly_haltestellen.get_size());
 
 		// chart
 		chart.remove_curves();
@@ -699,10 +712,10 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 		// has this line a single running convoy?
 		if(  new_line.is_bound()  &&  new_line->count_convoys()>0  ) {
 			// set this schedule as current to show on minimap if possible
-			reliefkarte_t::get_karte()->set_current_cnv( new_line->get_convoy(0) );
+			minimap_t::get_instance()->set_selected_cnv( new_line->get_convoy(0) );
 		}
 		else {
-			reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
+			minimap_t::get_instance()->set_selected_cnv( convoihandle_t() );
 		}
 
 		delete last_schedule;
@@ -712,7 +725,6 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 	else if(  inp_name.is_visible()  ) {
 		// previously a line was visible
 		// thus the need to hide everything
-		cont.remove_all();
 		inp_name.set_visible(false);
 		filled_bar.set_visible(false);
 		scrolly_convois.set_visible(false);
@@ -728,7 +740,7 @@ void schedule_list_gui_t::update_lineinfo(linehandle_t new_line)
 		chart.set_visible(true);
 
 		// hide schedule on minimap (may not current, but for safe)
-		reliefkarte_t::get_karte()->set_current_cnv( convoihandle_t() );
+		minimap_t::get_instance()->set_selected_cnv( convoihandle_t() );
 
 		delete last_schedule;
 		last_schedule = NULL;
@@ -800,7 +812,7 @@ void schedule_list_gui_t::rdwr( loadsave_t *file )
 	size.rdwr( file );
 	simline_t::rdwr_linehandle_t(file, line);
 
-	uint8 num_buttons = file->get_version()<112008 ? 8 : MAX_LINE_COST;
+	uint8 num_buttons = file->is_version_atleast(112, 8) ? MAX_LINE_COST : 8;
 	for(  int i=0;  i<num_buttons;  i++  ) {
 		bool b = filterButtons[i].pressed;
 		file->rdwr_bool( b );
@@ -820,3 +832,36 @@ void schedule_list_gui_t::rdwr( loadsave_t *file )
 		scrolly_haltestellen.set_scroll_position( halt_xoff, halt_yoff );
 	}
 }
+
+
+// borrowed code from minimap
+bool schedule_list_gui_t::is_matching_freight_catg(const minivec_tpl<uint8> &goods_catg_index)
+{
+	const goods_desc_t *line_freight_type_group_index = viewable_freight_types[ freight_type_c.get_selection() ];
+	// does this line/convoi has a matching freight
+	if(  line_freight_type_group_index == goods_manager_t::passengers  ) {
+		return goods_catg_index.is_contained(goods_manager_t::INDEX_PAS);
+	}
+	else if(  line_freight_type_group_index == goods_manager_t::mail  ) {
+		return goods_catg_index.is_contained(goods_manager_t::INDEX_MAIL);
+	}
+	else if(  line_freight_type_group_index == goods_manager_t::none  ) {
+		// all freights but not pax or mail
+		for(  uint8 i = 0;  i < goods_catg_index.get_count();  i++  ) {
+			if(  goods_catg_index[i] > goods_manager_t::INDEX_NONE  ) {
+				return true;
+			}
+		}
+		return false;
+	}
+	else if(  line_freight_type_group_index != NULL  ) {
+		for(  uint8 i = 0;  i < goods_catg_index.get_count();  i++  ) {
+			if(  goods_catg_index[i] == line_freight_type_group_index->get_catg_index()  ) {
+				return true;
+			}
+		}
+		return false;
+	}
+	// all true
+	return true;
+}
