@@ -1,9 +1,9 @@
 /*
- * sdl-sound without SDL_mixer.dll
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
+/// sdl-sound without SDL_mixer.dll
 
 #include <SDL.h>
 #include <string.h>
@@ -13,7 +13,7 @@
 #include <stdio.h>
 
 /*
- * Hajo: flag if sound module should be used
+ * flag if sound module should be used
  */
 static int use_sound = 0;
 
@@ -27,12 +27,12 @@ static int use_sound = 0;
  * this structure contains the data for one sample
  */
 struct sample {
-    /* the buffer containing the data for the sample, the format
-     * must always be identical to the one of the system output
-     * format */
-    Uint8 *audio_data;
+	/* the buffer containing the data for the sample, the format
+	 * must always be identical to the one of the system output
+	 * format */
+	Uint8 *audio_data;
 
-    Uint32 audio_len;		    /* number of samples in the audio data */
+	Uint32 audio_len; /* number of samples in the audio data */
 };
 
 
@@ -48,14 +48,13 @@ static int samplenumber = 0;
 /* this structure contains the information about one channel
  */
 struct channel {
-    Uint32 sample_pos; /* the current position inside this sample */
-    Uint8 sample;		/* which sample is played, 255 for no sample */
-    Uint8 volume;		/* the volume this channel should be played */
+	Uint32 sample_pos; /* the current position inside this sample */
+	Uint8 sample;      /* which sample is played, 255 for no sample */
+	Uint8 volume;      /* the volume this channel should be played */
 };
 
 
-/* this array contains all the information of the currently played samples
- */
+/* this array contains all the information of the currently played samples */
 static channel channels[CHANNELS];
 
 
@@ -102,7 +101,7 @@ bool dr_init_sound()
 {
 	int sound_ok = 0;
 	if(use_sound!=0) {
-		return use_sound;	// avoid init twice
+		return use_sound; // avoid init twice
 	}
 	use_sound = 1;
 
@@ -136,20 +135,22 @@ bool dr_init_sound()
 				// start playing sounds
 				SDL_PauseAudio(0);
 
-			} else {
-				dbg->important("dr_init_sound", "Open audio channel doesn't meet requirements. Muting");
+			}
+			else {
+				dbg->error("dr_init_sound()", "Open audio channel doesn't meet requirements. Muting");
 				SDL_CloseAudio();
 				SDL_QuitSubSystem(SDL_INIT_AUDIO);
 			}
 
 
-		} else {
-			dbg->important("dr_init_sound", "Could not open required audio channel. Muting");
+		}
+		else {
+			dbg->error("dr_init_sound()", "Could not open required audio channel. Muting");
 			SDL_QuitSubSystem(SDL_INIT_AUDIO);
 		}
 	}
 	else {
-		dbg->important("dr_init_sound", "Could not initialize sound system. Muting");
+		dbg->error("dr_init_sound()", "Could not initialize sound system. Muting");
 	}
 
 	use_sound = sound_ok ? 1: -1;
@@ -160,7 +161,6 @@ bool dr_init_sound()
 /**
  * loads a sample
  * @return a handle for that sample or -1 on failure
- * @author Hj. Malthaner
  */
 int dr_load_sample(const char *filename)
 {
@@ -215,7 +215,6 @@ int dr_load_sample(const char *filename)
 /**
  * plays a sample
  * @param key the key for the sample to be played
- * @author Hj. Malthaner
  */
 void dr_play_sample(int sample_number, int volume)
 {
