@@ -1,5 +1,11 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include <string>
 #include <string.h>
+#include <stdlib.h>
 
 #ifndef _WIN32
 #	include <dirent.h>
@@ -13,6 +19,7 @@
 
 #include "../simdebug.h"
 #include "../simmem.h"
+#include "../simtypes.h"
 #include "simstring.h"
 #include "searchfolder.h"
 
@@ -24,14 +31,10 @@
  *      If filepath does not end with a slash and it also doesn't contain
  *      a dot after the last slash, then append extension to filepath and
  *      search for it.
- *	Otherwise searches directly for filepath.
+ * Otherwise searches directly for filepath.
  *
- *	No wildcards please!
- *
- *  Return type:
- *      int			number of matching files.
-*/
-
+ * No wildcards please!
+ */
 void searchfolder_t::add_entry(const std::string &path, const char *entry, const bool prepend)
 {
 	const size_t entry_len = strlen(entry);
@@ -50,7 +53,7 @@ void searchfolder_t::add_entry(const std::string &path, const char *entry, const
 void searchfolder_t::clear_list()
 {
 	FOR(vector_tpl<char*>, const i, files) {
-		guarded_free(i);
+		free(i);
 	}
 	files.clear();
 }
@@ -196,7 +199,7 @@ std::string searchfolder_t::complete(const std::string &filepath, const std::str
 searchfolder_t::~searchfolder_t()
 {
 	FOR(vector_tpl<char*>, const i, files) {
-		guarded_free(i);
+		free(i);
 	}
 	files.clear();
 }
