@@ -1,13 +1,10 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- *
- *  Functionality:
- *      Searches a disk folder for files matching certain restrictions.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
-#ifndef __SEARCHFOLDER_H
-#define __SEARCHFOLDER_H
+
+#ifndef UTILS_SEARCHFOLDER_H
+#define UTILS_SEARCHFOLDER_H
 
 
 #include <string>
@@ -15,8 +12,7 @@
 
 
 /**
- * @author Volker Meyer
- * @author Markohs
+ * Searches a disk folder for files matching certain restrictions.
  */
 class searchfolder_t {
 public:
