@@ -1,11 +1,11 @@
-/**
- * server_frame.h
- *
- * Server game listing and current game information window
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef gui_serverframe_h
-#define gui_serverframe_h
+#ifndef GUI_SERVER_FRAME_H
+#define GUI_SERVER_FRAME_H
+
 
 #include "gui_frame.h"
 #include "components/gui_button.h"
@@ -21,7 +21,6 @@ class gui_minimap_t;
 /**
  * When connected to a network server, this dialog shows game information
  * When not connected, it provides the mechanism for joining a remote game
- * @author Hj. Malthaner
  */
 class server_frame_t : public gui_frame_t, private action_listener_t
 {
@@ -49,7 +48,6 @@ private:
 	 * Stores dnsname (for connection) and servername (for display in list)
 	 * Also stores online/offline status of the server for filtering
 	 * Adds get_dns() method to retrieve dnsname
-	 * @author Timothy Baldock <tb@entropy.me.uk>
 	 */
 	class server_scrollitem_t : public gui_scrolled_list_t::const_text_scrollitem_t {
 	private:
@@ -67,11 +65,10 @@ private:
 	/**
 	 * Update UI fields with data from the current state of gameinfo_t gi
 	 */
-	void update_info();
+	PIXVAL update_info();
 
 	/**
 	 * Update UI fields to show connection errors
-	 * @author Timothy Baldock <tb@entropy.me.uk>
 	 */
 	void update_error ( const char* );
 
@@ -79,7 +76,6 @@ private:
 	 * Update server listing (retrieve from listings server)
 	 * Display depends on the state of the show_mismatched and
 	 * show_offline checkboxes
-	 * @author Timothy Baldock <tb@entropy.me.uk>
 	 */
 	bool update_serverlist ();
 
@@ -91,7 +87,6 @@ public:
 	/**
 	 * Return name of file which contains associated help text for this window
 	 * @return Help file name, nor NULL if no help file exists
-	 * @author Hj. Malthaner
 	 */
 	const char *get_help_filename() const OVERRIDE {return "server.txt";}
 
