@@ -1,12 +1,10 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef settings_frame_h
-#define settings_frame_h
+#ifndef GUI_SETTINGS_FRAME_H
+#define GUI_SETTINGS_FRAME_H
 
 
 #include "gui_frame.h"
@@ -22,26 +20,25 @@ class settings_t;
 
 /**
  * All messages since the start of the program
- * @author prissi
  */
 class settings_frame_t : public gui_frame_t, action_listener_t
 {
 private:
 	settings_t* sets;
-	gui_tab_panel_t	tabs;
+	gui_tab_panel_t tabs;
 
-	settings_general_stats_t	general;
-	gui_scrollpane_t scrolly_general;
-	settings_display_stats_t	display;
-	gui_scrollpane_t scrolly_display;
-	settings_economy_stats_t	economy;
-	gui_scrollpane_t scrolly_economy;
-	settings_routing_stats_t	routing;
-	gui_scrollpane_t scrolly_routing;
-	settings_costs_stats_t	costs;
-	gui_scrollpane_t scrolly_costs;
-	settings_climates_stats_t	climates;
-	gui_scrollpane_t scrolly_climates;
+	settings_general_stats_t  general;
+	gui_scrollpane_t          scrolly_general;
+	settings_display_stats_t  display;
+	gui_scrollpane_t          scrolly_display;
+	settings_economy_stats_t  economy;
+	gui_scrollpane_t          scrolly_economy;
+	settings_routing_stats_t  routing;
+	gui_scrollpane_t          scrolly_routing;
+	settings_costs_stats_t    costs;
+	gui_scrollpane_t          scrolly_costs;
+	settings_climates_stats_t climates;
+	gui_scrollpane_t          scrolly_climates;
 
 	button_t revert_to_default, revert_to_last_save;
 
@@ -51,7 +48,6 @@ public:
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
 	 */
 	const char *get_help_filename() const OVERRIDE {return "settings.txt";}
 
