@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2002 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef obj_signal_h
-#define obj_signal_h
+#ifndef OBJ_SIGNAL_H
+#define OBJ_SIGNAL_H
+
 
 #include "roadsign.h"
 
@@ -18,7 +17,6 @@
  *
  * @see blockstrecke_t
  * @see blockmanager
- * @author Hj. Malthaner
  */
 class signal_t : public roadsign_t
 {
@@ -26,11 +24,7 @@ public:
 	signal_t(loadsave_t *file);
 	signal_t(player_t *player, koord3d pos, ribi_t::ribi dir,const roadsign_desc_t *desc, bool preview = false) : roadsign_t(player,pos,dir,desc,preview) { state = rot;}
 
-	/**
-	* @return Einen Beschreibungsstring fr das Objekt, der z.B. in einem
-	* Beobachtungsfenster angezeigt wird.
-	* @author Hj. Malthaner
-	*/
+	/// @copydoc obj_t::info
 	void info(cbuffer_t & buf) const OVERRIDE;
 
 	typ get_typ() const OVERRIDE { return obj_t::signal; }
