@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef simcity_h
-#define simcity_h
+#ifndef SIMCITY_H
+#define SIMCITY_H
+
 
 #include "simobj.h"
 #include "obj/gebaeude.h"
@@ -30,20 +29,20 @@ class rule_t;
 #define PAX_DESTINATIONS_SIZE (256) // size of the minimap (sparse array)
 
 enum city_cost {
-	HIST_CITICENS=0,// total people
-	HIST_GROWTH,	// growth (just for convenience)
-	HIST_BUILDING,	// number of buildings
-	HIST_CITYCARS,	// number of citycars generated
-	HIST_PAS_TRANSPORTED, // number of passengers who could start their journey
-	HIST_PAS_WALKED,    // direct transfer
-	HIST_PAS_GENERATED,	// total number generated
-	HIST_MAIL_TRANSPORTED,	// letters that could be sent
-	HIST_MAIL_WALKED,       // direct handover
-	HIST_MAIL_GENERATED,	// all letters generated
-	HIST_GOODS_RECEIVED,	// times all storages were not empty
-	HIST_GOODS_NEEDED,	// times storages checked
-	HIST_POWER_RECEIVED,	// power consumption (not used at the moment!)
-	MAX_CITY_HISTORY	// Total number of items in array
+	HIST_CITICENS=0,       // total people
+	HIST_GROWTH,           // growth (just for convenience)
+	HIST_BUILDING,         // number of buildings
+	HIST_CITYCARS,         // number of citycars generated
+	HIST_PAS_TRANSPORTED,  // number of passengers who could start their journey
+	HIST_PAS_WALKED,       // direct transfer
+	HIST_PAS_GENERATED,    // total number generated
+	HIST_MAIL_TRANSPORTED, // letters that could be sent
+	HIST_MAIL_WALKED,      // direct handover
+	HIST_MAIL_GENERATED,   // all letters generated
+	HIST_GOODS_RECEIVED,   // times all storages were not empty
+	HIST_GOODS_NEEDED,     // times storages checked
+	HIST_POWER_RECEIVED,   // power consumption (not used at the moment!)
+	MAX_CITY_HISTORY       // Total number of items in array
 };
 
 // The base offset for passenger statistics.
@@ -76,16 +75,11 @@ static const uint32 GENERATE_RATIO_MAIL = 1;
 /**
  * Die Objecte der Klasse stadt_t bilden die Staedte in Simu. Sie
  * wachsen automatisch.
- * @author Hj. Malthaner
  */
 class stadt_t
 {
 	/**
-	* best_t:
-	*
 	* Kleine Hilfsklasse - speichert die beste Bewertung einer Position.
-	*
-	* @author V. Meyer
 	*/
 	class best_t {
 		sint32 best_wert;
@@ -109,14 +103,12 @@ class stadt_t
 public:
 	/**
 	 * Reads city configuration data from config/cityrules.tab
-	 * @author Hj. Malthaner
 	 */
 	static bool cityrules_init(const std::string &objpathname);
 	/**
 	 * Reads/writes city configuration data from/to a savegame
 	 * called from settings_t::rdwr
 	 * only written for networkgames
-	 * @author Dwachs
 	 */
 	static void cityrules_rdwr(loadsave_t *file);
 
@@ -140,13 +132,13 @@ private:
 	// this counter will increment by one for every change => dialogs can question, if they need to update map
 	uint32 pax_destinations_new_change;
 
-	koord pos;			// Gruendungsplanquadrat der City
-	koord townhall_road; // road in front of townhall
-	koord lo, ur;		// max size of housing area
+	koord pos;             // Gruendungsplanquadrat der City
+	koord townhall_road;   // road in front of townhall
+	koord lo, ur;          // max size of housing area
 	koord last_center;
-	bool  has_low_density;	// in this case extend borders by two
+	bool  has_low_density; // in this case extend borders by two
 
-	bool allow_citygrowth;	// town can be static and will grow (true by default)
+	bool allow_citygrowth; // town can be static and will grow (true by default)
 
 	bool has_townhall;
 	// this counter indicate which building will be processed next
@@ -155,13 +147,11 @@ private:
 	/**
 	 * step so every house is asked once per month
 	 * i.e. 262144/(number of houses) per step
-	 * @author Hj. Malthaner
 	 */
 	uint32 step_interval;
 
 	/**
 	 * next passenger generation timer
-	 * @author Hj. Malthaner
 	 */
 	uint32 next_step;
 
@@ -172,41 +162,36 @@ private:
 
 	/**
 	 * When to do growth next
-	 * @author Hj. Malthaner
 	 */
 	uint32 next_growth_step;
 
 	static uint32 cluster_factor;
 
 	// attribute for the population (Bevoelkerung)
-	sint32 bev;	// total population (bevoelkerung)
-	sint32 arb;	// with a job (arbeit)
-	sint32 won;	// with a residence (wohnung)
+	sint32 bev; // total population (bevoelkerung)
+	sint32 arb; // with a job (arbeit)
+	sint32 won; // with a residence (wohnung)
 
 	/**
 	 * Un-supplied city growth needs
 	 * A value of 2^32 means 1 new resident
-	 * @author Nathanael Nerode (neroden)
 	 */
 	sint64 unsupplied_city_growth;
 
 	/**
 	* City history
 	* Current month stats are not appropiate to determine satisfaction for growth.
-	* @author prissi
 	*/
 	sint64 city_history_year[MAX_CITY_HISTORY_YEARS][MAX_CITY_HISTORY];
 	sint64 city_history_month[MAX_CITY_HISTORY_MONTHS][MAX_CITY_HISTORY];
 
 	/* updates the city history
-	* @author prissi
 	*/
 	void roll_history();
 
 	/* Members used to determine satisfaction for growth rate.
 	 * Satisfaction of this month cannot be used as it is an averaging filter for the entire month up to the present.
 	 * Instead the average over a number of growth ticks is used, defaulting to last month average if nothing is available.
-	 * @author DrSuperGood
 	 */
 private:
 	// The growth factor type in form of the amount demanded and what was received.
@@ -245,7 +230,6 @@ private:
 public:
 	/**
 	 * Returns pointer to history for city
-	 * @author hsiegeln
 	 */
 	sint64* get_city_history_year() { return *city_history_year; }
 	sint64* get_city_history_month() { return *city_history_month; }
@@ -263,7 +247,6 @@ private:
 public:
 	/**
 	 * Classes for storing and manipulating target factories and their data
-	 * @author Knightly
 	 */
 	struct factory_entry_t
 	{
@@ -276,9 +259,9 @@ public:
 				sint16 factory_pos_y;
 			};
 		};
-		sint32 demand;		// amount demanded by the factory; shifted by DEMAND_BITS
-		sint32 supply;		// amount that the city can supply
-		sint32 remaining;	// portion of supply which has not realised yet; remaining <= supply
+		sint32 demand;    // amount demanded by the factory; shifted by DEMAND_BITS
+		sint32 supply;    // amount that the city can supply
+		sint32 remaining; // portion of supply which has not realised yet; remaining <= supply
 
 		factory_entry_t() : factory(NULL), demand(0), supply(0), remaining(0) { }
 		factory_entry_t(fabrik_t *_factory) : factory(_factory), demand(0), supply(0), remaining(0) { }
@@ -293,7 +276,7 @@ public:
 	struct factory_set_t
 	{
 		vector_tpl<factory_entry_t> entries;
-		sint32 total_demand;		// shifted by DEMAND_BITS
+		sint32 total_demand;    // shifted by DEMAND_BITS
 		sint32 total_remaining;
 		sint32 total_generated;
 		uint32 generation_ratio;
@@ -315,14 +298,12 @@ public:
 private:
 	/**
 	 * Data of target factories for pax/mail
-	 * @author Knightly
 	 */
 	factory_set_t target_factories_pax;
 	factory_set_t target_factories_mail;
 
 	/**
 	 * Initialization of pax_destinations_old/new
-	 * @author Hj. Malthaner
 	 */
 	void init_pax_destinations();
 
@@ -337,7 +318,6 @@ private:
 
 	/**
 	 * Build new buildings when growing city
-	 * @author Hj. Malthaner
 	 */
 	void step_grow_city(bool new_town = false);
 
@@ -345,31 +325,26 @@ private:
 
 	/**
 	 * verteilt die Passagiere auf die Haltestellen
-	 * @author Hj. Malthaner
 	 */
 	void step_passagiere();
 
 	/**
 	 * ein Passagierziel in die Zielkarte eintragen
-	 * @author Hj. Malthaner
 	 */
 	void merke_passagier_ziel(koord ziel, PIXVAL color);
 
 	/**
 	 * baut Spezialgebaeude, z.B Stadion
-	 * @author Hj. Malthaner
 	 */
 	void check_bau_spezial(bool);
 
 	/**
 	 * baut ein angemessenes Rathaus
-	 * @author V. Meyer
 	 */
 	void check_bau_townhall(bool);
 
 	/**
 	 * constructs a new consumer
-	 * @author prissi
 	 */
 	void check_bau_factory(bool);
 
@@ -384,32 +359,29 @@ private:
 	void renovate_city_building(gebaeude_t *gb);
 
 #ifdef DESTINATION_CITYCARS
-	sint16	number_of_cars; // allowed number of cars to spawn per month
+	sint16 number_of_cars; // allowed number of cars to spawn per month
 	void generate_private_cars(koord pos, koord target);
 #endif
 
+protected:
 	/**
 	 * baut ein Stueck Strasse
-	 *
-	 * @param k         Bauposition
-	 *
-	 * @author Hj. Malthaner, V. Meyer
+	 * @param k Bauposition
 	 */
 	bool build_road(const koord k, player_t *player_, bool forced);
 
+private:
 	void build();
 
 	/**
 	 * @param pos position to check
 	 * @param regel the rule to evaluate
 	 * @return true on match, false otherwise
-	 * @author Hj. Malthaner
 	 */
 	static bool bewerte_loc(koord pos, const rule_t &regel, int rotation);
 
 	/**
 	 * Check rule in all transformations at given position
-	 * @author Hj. Malthaner
 	 */
 	static sint32 bewerte_pos(koord pos, const rule_t &regel);
 
@@ -423,15 +395,13 @@ private:
 	void pruefe_grenzen(koord pos);
 
 public:
-	/**
-	 * sucht arbeitspltze fr die Einwohner
-	 * @author Hj. Malthaner
-	 */
+	bool is_within_players_network( const player_t* player ) const;
+
+	/// Connects factories to this city.
 	void verbinde_fabriken();
 
 	/**
 	 * Returns the data set associated with the pax/mail target factories
-	 * @author: prissi
 	 */
 	const factory_set_t& get_target_factories_for_pax() const { return target_factories_pax; }
 	const factory_set_t& get_target_factories_for_mail() const { return target_factories_mail; }
@@ -456,7 +426,6 @@ public:
 
 	/**
 	* Returns the finance history for cities
-	* @author hsiegeln
 	*/
 	sint64 get_finance_history_year(int year, int type) { return city_history_year[year][type]; }
 	sint64 get_finance_history_month(int month, int type) { return city_history_month[month][type]; }
@@ -466,7 +435,6 @@ public:
 
 	/**
 	 * ermittelt die Einwohnerzahl der City
-	 * @author Hj. Malthaner
 	 */
 	sint32 get_einwohner() const {return (buildings.get_sum_weight()*6)+((2*bev-arb-won)>>1);}
 
@@ -474,40 +442,20 @@ public:
 	sint32 get_unemployed() const { return bev - arb; }
 	sint32 get_homeless()   const { return bev - won; }
 
-	/**
-	 * Return the city name.
-	 * @author Hj. Malthaner
-	 */
 	const char *get_name() const { return name; }
-
-	/**
-	 * Ermglicht Zugriff auf Namesnarray
-	 * @author Hj. Malthaner
-	 */
 	void set_name( const char *name );
 
-	/**
-	 * gibt einen zufllingen gleichverteilten Punkt innerhalb der
-	 * Citygrenzen zurck
-	 * @author Hj. Malthaner
-	 */
+	/// @returns a random point within city borders.
 	koord get_zufallspunkt() const;
 
-	/**
-	 * gibt das pax-statistik-array fr letzten monat zurck
-	 * @author Hj. Malthaner
-	 */
+	/// @returns passenger destination statistics for the last month
 	const sparse_tpl<PIXVAL>* get_pax_destinations_old() const { return &pax_destinations_old; }
 
-	/**
-	 * gibt das pax-statistik-array fr den aktuellen monat zurck
-	 * @author Hj. Malthaner
-	 */
+	/// @returns passenger destination statistics for the current month
 	const sparse_tpl<PIXVAL>* get_pax_destinations_new() const { return &pax_destinations_new; }
 
 	/* this counter will increment by one for every change
 	 * => dialogs can question, if they need to update map
-	 * @author prissi
 	 */
 	uint32 get_pax_destinations_new_change() const { return pax_destinations_new_change; }
 
@@ -518,7 +466,6 @@ public:
 	 * @param x x-Planquadratkoordinate
 	 * @param y y-Planquadratkoordinate
 	 * @param number of citizens
-	 * @author Hj. Malthaner
 	 */
 	stadt_t(player_t* player, koord pos, sint32 citizens);
 
@@ -527,7 +474,6 @@ public:
 	 * @param welt Die Karte zu der die City gehoeren soll.
 	 * @param file Zeiger auf die Datei mit den Citybaudaten.
 	 * @see stadt_t::speichern()
-	 * @author Hj. Malthaner
 	 */
 	stadt_t(loadsave_t *file);
 
@@ -541,7 +487,6 @@ public:
 	 * Planquadraten auf denen sie stehen.
 	 * @see stadt_t::stadt_t()
 	 * @see planquadrat_t
-	 * @author Hj. Malthaner
 	 */
 	void rdwr(loadsave_t *file);
 
@@ -552,8 +497,7 @@ public:
 
 	void rotate90( const sint16 y_size );
 
-	/* change size of city
-	* @author prissi */
+	/* change size of city */
 	void change_size( sint64 delta_citizens, bool new_town = false );
 
 	// when ng is false, no town growth any more
@@ -567,20 +511,17 @@ public:
 private:
 	/**
 	 * List of target cities weighted by both city size and distance
-	 * @author Knightly
 	 */
 	weighted_vector_tpl<stadt_t *> target_cities;
 
 	/**
 	 * List of target attractions weighted by both passenger level and distance
-	 * @author Knightly
 	 */
 	weighted_vector_tpl<gebaeude_t *> target_attractions;
 
 public:
 	/**
 	 * Functions for manipulating the list of target cities
-	 * @author Knightly
 	 */
 	void add_target_city(stadt_t *const city);
 	void remove_target_city(stadt_t *const city) { target_cities.remove( city ); }
@@ -588,7 +529,6 @@ public:
 
 	/**
 	 * Functions for manipulating the list of target attractions
-	 * @author Knightly
 	 */
 	void add_target_attraction(gebaeude_t *const attraction);
 	void remove_target_attraction(gebaeude_t *const attraction) { target_attractions.remove( attraction ); }
@@ -601,14 +541,12 @@ public:
 	 * @param will_return set to the jounrey return type on return.
 	 * @param factory_entry set to the destination factory, if any.
 	 * @param dest_city set to the destination city for return flow use.
-	 * @author Hj. Malthaner
 	 */
 	koord find_destination(factory_set_t &target_factories, const sint64 generated, pax_return_type* will_return, factory_entry_t* &factory_entry, stadt_t* &dest_city);
 
 	/**
 	 * Gibt die Gruendungsposition der City zurueck.
 	 * @return die Koordinaten des Gruendungsplanquadrates
-	 * @author Hj. Malthaner
 	 */
 	inline koord get_pos() const {return pos;}
 	inline koord get_townhall_road() const {return townhall_road;}
@@ -623,9 +561,7 @@ public:
 	 * die fuer eine Citygruendung geeignet sind.
 	 * @param wl Die Karte auf der die City gegruendet werden soll.
 	 * @param count die Anzahl der zu liefernden Koordinaten
-	 * @author Hj. Malthaner
 	 * @param old_x, old_y: Generate no cities in (0,0) - (old_x, old_y)
-	 * @author Gerd Wachsmuth
 	 */
 	static vector_tpl<koord> *random_place(sint32 count, sint16 old_x, sint16 old_y);
 	// geeigneten platz zur Citygruendung durch Zufall ermitteln
