@@ -1,9 +1,16 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef SIMCONST_H
+#define SIMCONST_H
+
+
 /*
  * all defines that can change the compiling
  */
 
-#ifndef simconst_h
-#define simconst_h
 
 // color depth (default assumes RGB565), undefine only for rgb555 builds!
 //#define RGB555
