@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdlib.h>
@@ -53,7 +51,7 @@ depot_t::depot_t(loadsave_t *file) : gebaeude_t()
 
 
 depot_t::depot_t(koord3d pos, player_t *player, const building_tile_desc_t *t) :
-    gebaeude_t(pos, player, t)
+	gebaeude_t(pos, player, t)
 {
 	all_depots.append(this);
 	selected_filter = VEHICLE_FILTER_RELEVANT;
@@ -144,7 +142,7 @@ void depot_t::convoi_arrived(convoihandle_t acnv, bool schedule_adjust)
 
 		for(unsigned i=0; i<acnv->get_vehicle_count(); i++) {
 			vehicle_t *v = acnv->get_vehikel(i);
-			// Hajo: reset vehikel data
+			// reset vehikel data
 			v->discard_cargo();
 			v->set_pos( koord3d::invalid );
 			v->set_leading( i==0 );
@@ -535,7 +533,7 @@ void depot_t::rdwr_vehikel(slist_tpl<vehicle_t *> &list, loadsave_t *file)
 			}
 			if(v->get_desc()) {
 				DBG_MESSAGE("depot_t::vehikel_laden()","loaded %s", v->get_desc()->get_name());
-				list.insert( v );
+				list.append( v );
 			}
 			else {
 				dbg->error("depot_t::vehikel_laden()","vehicle has no desc => ignored");
@@ -553,7 +551,6 @@ void depot_t::rdwr_vehikel(slist_tpl<vehicle_t *> &list, loadsave_t *file)
 
 /**
  * @return NULL when OK, otherwise an error message
- * @author Hj. Malthaner
  */
 const char * depot_t::is_deletable(const player_t *player)
 {
