@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef _simdepot_h
-#define _simdepot_h
+#ifndef SIMDEPOT_H
+#define SIMDEPOT_H
+
 
 #include "tpl/slist_tpl.h"
 #include "obj/gebaeude.h"
@@ -26,7 +25,6 @@ class vehicle_desc_t;
 
 /**
  * In Depots werden Fahrzeuge gekauft, gewartet, verkauft und gelagert.
- * @author Hj. Malthaner
  */
 class depot_t : public gebaeude_t
 {
@@ -40,9 +38,6 @@ protected:
 	 * automatically created, when necessary.
 	 * Convois are numbered 0...(n-1).
 	 * Vehicles are accessed by type.
-	 *
-	 * @author Volker Meyer
-	 * @date  30.05.2003
 	 */
 	slist_tpl<vehicle_t *> vehicles;
 	slist_tpl<convoihandle_t> convois;
@@ -83,8 +78,6 @@ public:
 
 	/**
 	 * Access to convoi list.
-	 * @author Volker Meyer
-	 * @date  30.05.2003
 	 */
 	unsigned convoi_count() const { return convois.get_count(); }
 
@@ -99,7 +92,6 @@ public:
 
 	/**
 	 * copies convoi and its schedule or line
-	 * @author hsiegeln
 	 */
 	convoihandle_t copy_convoi(convoihandle_t old_cnv, bool local_execution);
 
@@ -107,8 +99,6 @@ public:
 	 * Let convoi leave the depot.
 	 * If not possible, a message is displayed and the function returns false.
 	 * @param if local_execution is true, this method creates pop-ups in case of errors
-	 * @author Volker Meyer, Dwachs
-	 * @date  09.06.2003 / 27.04.2010
 	 */
 	bool start_convoi(convoihandle_t cnv, bool local_execution);
 
@@ -117,8 +107,6 @@ public:
 	/**
 	 * Destroy the convoi and put the vehicles in the vehicles list (sell==false),
 	 * or sell all immediately (sell==true).
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	bool disassemble_convoi(convoihandle_t cnv, bool sell);
 
@@ -131,16 +119,12 @@ public:
 	/**
 	 * Remove vehicle from vehicle list and add it to the convoi. Two positions
 	 * are possible - in front or at the rear.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	void append_vehicle(convoihandle_t cnv, vehicle_t* veh, bool infront, bool local_execution);
 
 	/**
 	 * Remove the vehicle at given position from the convoi and put it in the
 	 * vehicle list.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	void remove_vehicle(convoihandle_t cnv, int ipos);
 	void remove_vehicles_to_end(convoihandle_t cnv, int ipos);
@@ -148,44 +132,33 @@ public:
 	/**
 	 * Access to vehicles not bound to a convoi. They are not ordered
 	 * in any way.
-	 * @author Volker Meyer
-	 * @date  30.05.2003
 	 */
 	slist_tpl<vehicle_t*> const& get_vehicle_list() { return vehicles; }
 
 	/**
 	 * A new vehicle is bought and added to the vehicle list.
 	 * The new vehicle in the list is returned.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	vehicle_t* buy_vehicle(const vehicle_desc_t* info);
 
 	/**
 	 * Sell a vehicle from the vehicle list.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	void sell_vehicle(vehicle_t* veh);
 
 	/**
 	 * Access to vehicle types which can be bought in the depot.
-	 * @author Volker Meyer
 	 */
 	slist_tpl<vehicle_desc_t const*> const& get_vehicle_type(uint8 sortkey = SORT_BY_DEFAULT) const;
 
 	/**
 	 * A convoi arrived at the depot and is added to the convoi list.
 	 * If schedule_adjust is true, the current depot is removed from schedule.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	void convoi_arrived(convoihandle_t cnv, bool schedule_adjust);
 
 	/**
 	 * Parameters to determine layout and behaviour of the depot_frame_t.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	virtual int get_x_grid() const = 0;
 	virtual int get_y_grid() const = 0;
@@ -195,22 +168,18 @@ public:
 
 	/**
 	 * Opens a new info window for that object.
-	 *
-	 * @author Hj. Malthaner
 	 */
 	void show_info() OVERRIDE;
 
 	/**
 	 * Can object be removed?
 	 * @return NULL when OK, otherwise an error message
-	 * @author Hj. Malthaner
 	 */
 	const char * is_deletable(const player_t *player) OVERRIDE;
 
 	/**
 	 * identifies the oldest vehicle of a certain type
 	 * @return NULL if no vehicle is found
-	 * @author hsiegeln (stolen from Hajo)
 	 */
 	vehicle_t* get_oldest_vehicle(const vehicle_desc_t* desc);
 
@@ -250,8 +219,6 @@ public:
 
 /**
  * Depots for train vehicles.
- *
- * @author Hj. Malthaner
  * @see depot_t
  * @see gebaeude_t
  */
@@ -267,8 +234,6 @@ public:
 
 	/**
 	 * Parameters to determine layout and behaviour of the depot_frame_t.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	int get_x_placement() const OVERRIDE {return -25; }
 	int get_y_placement() const OVERRIDE {return -28; }
@@ -331,8 +296,6 @@ public:
 
 /**
  * Depots for street vehicles
- *
- * @author Hj. Malthaner
  * @see depot_t
  * @see gebaeude_t
  */
@@ -352,8 +315,6 @@ public:
 
 	/**
 	 * Parameters to determine layout and behaviour of the depot_frame_t.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	int get_x_placement() const OVERRIDE { return -20; }
 	int get_y_placement() const OVERRIDE { return -25; }
@@ -368,8 +329,6 @@ public:
 
 /**
  * Depots for ships
- *
- * @author Hj. Malthaner
  * @see depot_t
  * @see gebaeude_t
  */
@@ -388,8 +347,6 @@ public:
 
 	/**
 	 * Parameters to determine layout and behaviour of the depot_frame_t.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	int get_x_placement() const OVERRIDE { return -1; }
 	int get_y_placement() const OVERRIDE { return -11; }
@@ -419,8 +376,6 @@ public:
 
 	/**
 	 * Parameters to determine layout and behaviour of the depot_frame_t.
-	 * @author Volker Meyer
-	 * @date  09.06.2003
 	 */
 	int get_x_placement() const OVERRIDE {return -10; }
 	int get_y_placement() const OVERRIDE {return -23; }
