@@ -1,17 +1,18 @@
 /*
- * system-independent event handling routines
- * Hj. Malthaner, Jan. 2001
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "simevent.h"
-#include "simsys.h"
+#include "sys/simsys.h"
 #include "tpl/slist_tpl.h"
 
+// system-independent event handling routines
 
 static int cx = -1; // coordinates of last mouse click event
 static int cy = -1; // initialised to "nowhere"
-static int control_shift_state = 0;	// none pressed
-static event_t meta_event(EVENT_NONE);	// Knightly : for storing meta-events like double-clicks and triple-clicks
+static int control_shift_state = 0; // none pressed
+static event_t meta_event(EVENT_NONE); // for storing meta-events like double-clicks and triple-clicks
 static unsigned int last_meta_class = EVENT_NONE;
 static slist_tpl<event_t *> queued_events;
 
@@ -44,15 +45,14 @@ void change_drag_start(int x, int y)
 
 static void fill_event(event_t* const ev)
 {
-	// Knightly : variables for detecting double-clicks and triple-clicks
+	// variables for detecting double-clicks and triple-clicks
 	const  uint32        interval = 400;
 	static unsigned int  prev_ev_class = EVENT_NONE;
 	static unsigned int  prev_ev_code = 0;
 	static uint32        prev_ev_time = 0;
-	static unsigned char repeat_count = 0;	// number of consecutive sequences of click-release
+	static unsigned char repeat_count = 0; // number of consecutive sequences of click-release
 
 	// for autorepeat buttons we track button state, press time and a repeat time
-	// code by Niels Roest and Hj. Maltahner
 
 	static int  pressed_buttons = 0; // assume: at startup no button pressed (needed for some backends)
 	static uint32 lb_time = 0;
@@ -161,7 +161,7 @@ static void fill_event(event_t* const ev)
 			break;
 	}
 
-	// Knightly : check for double-clicks and triple-clicks
+	// check for double-clicks and triple-clicks
 	const uint32 curr_time = dr_time();
 	if(  ev->ev_class==EVENT_CLICK  ) {
 		if(  prev_ev_class==EVENT_RELEASE  &&  prev_ev_code==ev->ev_code  &&  curr_time-prev_ev_time<=interval  ) {
@@ -193,7 +193,7 @@ static void fill_event(event_t* const ev)
 			// case : triple-click
 			meta_event = *ev;
 			meta_event.ev_class = EVENT_TRIPLE_CLICK;
-			repeat_count = 0;	// reset -> start over again
+			repeat_count = 0; // reset -> start over again
 		}
 	}
 	else if(  ev->ev_class!=EVENT_NONE  &&  prev_ev_class!=EVENT_NONE  ) {
@@ -213,7 +213,7 @@ static void fill_event(event_t* const ev)
 		lb_time = 0;
 	}
 	else { // the else is to prevent race conditions
-		/* Hajo: this would transform non-left button presses always
+		/* this would transform non-left button presses always
 		 * to repeat events. I need right button clicks.
 		 * I have no idea how this can be done cleanly, currently just
 		 * disabling the repeat feature for non-left buttons
@@ -241,7 +241,7 @@ void display_poll_event(event_t* const ev)
 		delete elem;
 		return ;
 	}
-	// Knightly : if there is any pending meta-event, consume it instead of fetching a new event from the system
+	// if there is any pending meta-event, consume it instead of fetching a new event from the system
 	if(  meta_event.ev_class!=EVENT_NONE  ) {
 		*ev = meta_event;
 		last_meta_class = meta_event.ev_class;
@@ -267,7 +267,7 @@ void display_get_event(event_t* const ev)
 		delete elem;
 		return ;
 	}
-	// Knightly : if there is any pending meta-event, consume it instead of fetching a new event from the system
+	// if there is any pending meta-event, consume it instead of fetching a new event from the system
 	if(  meta_event.ev_class!=EVENT_NONE  ) {
 		*ev = meta_event;
 		meta_event.ev_class = EVENT_NONE;
