@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef simfab_h
-#define simfab_h
+#ifndef SIMFAB_H
+#define SIMFAB_H
+
 
 #include "dataobj/koord3d.h"
 #include "dataobj/translator.h"
@@ -28,7 +27,6 @@ class leitung_t;
 
 /**
  * Factory statistics
- * @author Knightly
  */
 #define MAX_MONTH                  (12)
 #define FAB_PRODUCTION              (0)
@@ -113,7 +111,7 @@ class ware_production_t
 {
 private:
 	const goods_desc_t *type;
-	// Knightly : statistics for each goods
+	// statistics for each goods
 	sint64 statistics[MAX_MONTH][MAX_FAB_GOODS_STAT];
 	sint64 weighted_sum_storage;
 
@@ -132,7 +130,7 @@ public:
 	const goods_desc_t* get_typ() const { return type; }
 	void set_typ(const goods_desc_t *t) { type=t; }
 
-	// Knightly : functions for manipulating goods statistics
+	// functions for manipulating goods statistics
 	void roll_stats(uint32 factor, sint64 aggregate_weight);
 	void rdwr(loadsave_t *file);
 	const sint64* get_stats() const { return *statistics; }
@@ -153,7 +151,7 @@ public:
 	}
 	void book_weighted_sum_storage(uint32 factor, sint64 delta_time);
 
-	sint32 menge;	// in internal units shifted by precision_bits (see step)
+	sint32 menge; // in internal units shifted by precision_bits (see step)
 	sint32 max;
 	/// Cargo currently in transit from/to this slot. Equivalent to statistics[0][FAB_GOODS_TRANSIT].
 	sint32 get_in_transit() const { return (sint32)statistics[0][FAB_GOODS_TRANSIT]; }
@@ -174,7 +172,7 @@ public:
 	bool placing_orders;
 
 #ifdef TRANSIT_DISTANCE
-	sint32 count_suppliers;	// only needed for averaging
+	sint32 count_suppliers; // only needed for averaging
 #endif
 	uint32 index_offset; // used for haltlist and lieferziele searches in verteile_waren to produce round robin results
 
@@ -187,26 +185,20 @@ public:
 
 
 /**
- * Eine Klasse fr Fabriken in Simutrans. Fabriken produzieren und
- * verbrauchen Waren und beliefern nahe Haltestellen.
- *
- * @date 1998
+ * Factories produce and consume goods (ware_t) and supply nearby halts.
  * @see haltestelle_t
- * @author Hj. Malthaner
  */
 class fabrik_t
 {
 public:
 	/**
 	 * Constants
-	 * @author Hj. Malthaner
 	 */
 	enum { precision_bits = 10, old_precision_bits = 10, precision_mask = 1023 };
 
 private:
 	/**
 	 * Factory statistics
-	 * @author Knightly
 	 */
 	sint64 statistics[MAX_MONTH][MAX_FAB_STAT];
 	sint64 weighted_sum_production;
@@ -249,29 +241,24 @@ private:
 		BL_CLASSIC, // Production boosted in classic way.
 	} boost_type;
 
-	// Knightly : Functions for manipulating factory statistics
+	// Functions for manipulating factory statistics
 	void init_stats();
 	void set_stat(sint64 value, int stat_type) { assert(stat_type<MAX_FAB_STAT); statistics[0][stat_type] = value; }
 
-	// Knightly : For accumulating weighted sums for average statistics
+	// For accumulating weighted sums for average statistics
 	void book_weighted_sums(sint64 delta_time);
 
-	/**
-	 * Die mglichen Lieferziele
-	 * @author Hj. Malthaner
-	 */
+	/// Possible destinations for produced goods
 	vector_tpl <koord> lieferziele;
 	uint32 lieferziele_active_last_month;
 
 	/**
 	 * suppliers to this factory
-	 * @author hsiegeln
 	 */
 	vector_tpl <koord> suppliers;
 
 	/**
 	 * fields of this factory (only for farms etc.)
-	 * @author prissi/Knightly
 	 */
 	struct field_data_t
 	{
@@ -288,7 +275,6 @@ private:
 
 	/**
 	 * Distribute products to connected stops
-	 * @author Hj. Malthaner
 	 */
 	void verteile_waren(const uint32 product);
 
@@ -302,19 +288,16 @@ private:
 
 	/**
 	 * Is construction site rotated?
-	 * @author V.Meyer
 	 */
 	uint8 rotate;
 
 	/**
 	 * production base amount
-	 * @author Hj. Malthaner
 	 */
 	sint32 prodbase;
 
 	/**
 	 * multipliers for the production base amount
-	 * @author Hj. Malthaner
 	 */
 	sint32 prodfactor_electric;
 	sint32 prodfactor_pax;
@@ -323,17 +306,14 @@ private:
 	array_tpl<ware_production_t> input;  ///< array for input/consumed goods
 	array_tpl<ware_production_t> output; ///< array for output/produced goods
 
-	/**
-	 * Zeitakkumulator fr Produktion
-	 * @author Hj. Malthaner
-	 */
+	/// Accumulated time since last production
 	sint32 delta_sum;
 	uint32 delta_menge;
 
 	// production remainder when scaled to PRODUCTION_DELTA_T. added back next step to eliminate cumulative error
 	uint32 menge_remainder;
 
-	// Knightly : number of rounds where there is active production or consumption
+	// number of rounds where there is active production or consumption
 	uint8 activity_count;
 
 	// The adjacent connected transformer, if any.
@@ -363,68 +343,60 @@ private:
 	/**
 	 * Number of times the factory has expanded so far
 	 * Only for factories without fields
-	 * @author Knightly
 	 */
 	uint16 times_expanded;
 
 	/**
 	 * Electricity amount scaled with prodbase
-	 * @author TurfIt
 	 */
 	uint32 scaled_electric_demand;
 
 	/**
 	 * Pax/mail demand scaled with prodbase and month length
-	 * @author Knightly
 	 */
 	uint32 scaled_pax_demand;
 	uint32 scaled_mail_demand;
 
 	/**
 	 * Update scaled electricity amount
-	 * @author TurfIt
 	 */
 	void update_scaled_electric_demand();
 
 	/**
 	 * Update scaled pax/mail demand
-	 * @author Knightly
 	 */
 	void update_scaled_pax_demand();
 	void update_scaled_mail_demand();
 
 	/**
 	 * Update production multipliers for pax and mail
-	 * @author Knightly
 	 */
 	void update_prodfactor_pax();
 	void update_prodfactor_mail();
 
 	/**
 	 * Re-calculate the pax/mail demands of factory at target cities
-	 * @author Knightly
 	 */
 	void recalc_demands_at_target_cities();
 
 	/**
 	 * Recalculate storage capacities based on prodbase or capacities contributed by fields
-	 * @author Knightly
 	 */
 	void recalc_storage_capacities();
 
 	/**
 	 * Class for collecting arrival data and calculating pax/mail boost with fixed period length
-	 * @author Knightly
 	 */
-	#define PERIOD_BITS   (18)				// determines period length on which boost calculation is based
-	#define SLOT_BITS     (6)				// determines the number of time slots available
-	#define SLOT_COUNT    (1<<SLOT_BITS)	// number of time slots for accumulating arrived pax/mail
+	#define PERIOD_BITS   (18)              // determines period length on which boost calculation is based
+	#define SLOT_BITS     (6)               // determines the number of time slots available
+	#define SLOT_COUNT    (1<<SLOT_BITS)    // number of time slots for accumulating arrived pax/mail
+
 	class arrival_statistics_t
 	{
 	private:
 		uint16 slots[SLOT_COUNT];
 		uint16 current_slot;
-		uint16 active_slots;		// number of slots covered since aggregate arrival last increased from 0 to +ve
+		uint16 active_slots;      // number of slots covered since aggregate arrival last increased from 0 to +ve
 		uint32 aggregate_arrival;
 		uint32 scaled_demand;
 	public:
@@ -444,7 +416,6 @@ private:
 
 	/**
 	 * Arrival data for calculating pax/mail boost
-	 * @author Knightly
 	 */
 	arrival_statistics_t arrival_stats_pax;
 	arrival_statistics_t arrival_stats_mail;
@@ -453,14 +424,13 @@ private:
 
 	/**
 	 * For advancement of slots for boost calculation
-	 * @author Knightly
 	 */
 	sint32 delta_slot;
 
 	void recalc_factory_status();
 
 	// create some smoke on the map
-	void smoke() const;
+	void smoke();
 
 	// scales the amount of production based on the amount already in storage
 	uint32 scale_output_production(const uint32 product, uint32 menge) const;
@@ -507,7 +477,6 @@ public:
 
 	/**
 	 * Return/book statistics
-	 * @author Knightly
 	 */
 	const sint64* get_stats() const { return *statistics; }
 	sint64 get_stat(int month, int stat_type) const { assert(stat_type<MAX_FAB_STAT); return statistics[month][stat_type]; }
@@ -543,7 +512,6 @@ public:
 
 	/**
 	 * @return vehicle description object
-	 * @author Hj. Malthaner
 	 */
 	const factory_desc_t *get_desc() const {return desc; }
 
@@ -557,6 +525,8 @@ public:
 	void link_halt(halthandle_t halt);
 	void unlink_halt(halthandle_t halt);
 
+	bool is_within_players_network( const player_t* player ) const;
+
 	const vector_tpl<koord>& get_lieferziele() const { return lieferziele; }
 	bool is_active_lieferziel( koord k ) const;
 
@@ -564,23 +534,17 @@ public:
 
 	/**
 	 * Functions for manipulating the list of connected cities
-	 * @author Hj. Malthaner/prissi/Knightly
 	 */
 	void add_target_city(stadt_t *const city);
 	void remove_target_city(stadt_t *const city);
 	void clear_target_cities();
 	const vector_tpl<stadt_t *>& get_target_cities() const { return target_cities; }
 
-	/**
-	 * Fgt ein neues Lieferziel hinzu
-	 * @author Hj. Malthaner
-	 */
 	void  add_lieferziel(koord ziel);
 	void  rem_lieferziel(koord pos);
 
 	/**
 	 * adds a supplier
-	 * @author Hj. Malthaner
 	 */
 	void  add_supplier(koord pos);
 	void  rem_supplier(koord pos);
@@ -601,6 +565,8 @@ public:
 	 */
 	bool is_transformer_connected() const { return transformer != NULL; }
 
+	leitung_t* get_transformer() { return transformer; }
+
 	/**
 	 * Connect transformer to this factory.
 	 */
@@ -649,28 +615,18 @@ public:
 	 */
 	void get_tile_list( vector_tpl<koord> &tile_list ) const;
 
-	/**
-	 * gibt eine NULL-Terminierte Liste von Fabrikpointern zurck
-	 *
-	 * @author Hj. Malthaner
-	 */
+	/// @returns a vector of factories within a rectangle
 	static vector_tpl<fabrik_t *> & sind_da_welche(koord min, koord max);
 
-
 	// hier die methoden zum parametrisieren der Fabrik
 
-	/**
-	 * Baut die Gebude fr die Fabrik
-	 *
-	 * @author Hj. Malthaner, V. Meyer
-	 */
+	/// Builds buildings (gebaeude_t) for the factory.
 	void build(sint32 rotate, bool build_fields, bool force_initial_prodbase);
 
 	sint16 get_rotate() const { return rotate; }
 
 	/* field generation code
 	 * spawns a field for sure if probability>=1000
-	 * @author Kieron Green
 	 */
 	bool add_random_field(uint16 probability);
 
@@ -678,16 +634,20 @@ public:
 
 	uint32 get_field_count() const { return fields.get_count(); }
 
+	uint32 get_min_field_count() const
+	{
+		const field_group_desc_t *fg = get_desc()->get_field_group();
+		return fg ?  fg->get_min_fields() : 0;
+	}
+
 	/**
 	 * total and current procduction/storage values
-	 * @author Hj. Malthaner
 	 */
 	const array_tpl<ware_production_t>& get_input() const { return input; }
 	const array_tpl<ware_production_t>& get_output() const { return output; }
 
 	/**
 	 * Production multipliers
-	 * @author Hj. Malthaner
 	 */
 	sint32 get_prodfactor_electric() const { return prodfactor_electric; }
 	sint32 get_prodfactor_pax() const { return prodfactor_pax; }
@@ -700,7 +660,7 @@ public:
 
 	sint32 get_current_production() const { return (sint32)welt->scale_with_month_length( ((sint64)prodbase * (sint64)get_prodfactor())>>8 ); }
 
-	/* prissi: returns the status of the current factory, as well as output */
+	/* returns the status of the current factory, as well as output */
 	enum { bad, medium, good, inactive, nothing };
 	static uint8 status_to_color[5];
 
@@ -711,7 +671,6 @@ public:
 
 	/**
 	 * Crossconnects all factories
-	 * @author prissi
 	 */
 	void add_all_suppliers();
 
@@ -722,7 +681,6 @@ public:
 
 	/**
 	 * Return the scaled electricity amount and pax/mail demand
-	 * @author Knightly
 	 */
 	uint32 get_scaled_electric_demand() const { return scaled_electric_demand; }
 	uint32 get_scaled_pax_demand() const { return scaled_pax_demand; }
