@@ -1,18 +1,11 @@
 /*
- * Copyright (c) 2001 Hansjörg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Attempt of graphics for the Simulation game
- * Hj. Malthaner, Aug. 1997
- *
- *
- * 3D, isometric representation
- */
-#ifndef simgraph_h
-#define simgraph_h
+#ifndef DISPLAY_SIMGRAPH_H
+#define DISPLAY_SIMGRAPH_H
+
 
 #include "../simcolor.h"
 #include "../unicode.h"
@@ -22,18 +15,24 @@
 #include "scr_coord.h"
 
 
-extern int large_font_ascent;
-extern int large_font_total_height;
+#if COLOUR_DEPTH != 0
+
+extern int default_font_ascent;
+extern int default_font_linespace;
+
+#  define LINEASCENT (default_font_ascent)
+#  define LINESPACE  (default_font_linespace)
+#else
+#  define LINEASCENT 0
+// a font height of zero could cause division by zero errors, even though it should not be used in a server
+#  define LINESPACE  1
+#endif
 
-#define LINEASCENT (large_font_ascent)
-#define LINESPACE (large_font_total_height)
 
 /**
 * Alignment enum to align controls against each other
 * Vertical and horizontal alignment can be masked together
 * Unused bits are reserved for future use, set to 0.
-*
-* @author Max Kielland
 */
 enum control_alignments_t {
 
@@ -107,7 +106,6 @@ void env_t_rgb_to_system_colors();
 
 /**
  * Helper functions for clipping along tile borders.
- * @author Dwachs
  */
 void add_poly_clip(int x0_,int y0_, int x1, int y1, int ribi  CLIP_NUM_DEF);
 void clear_all_poly_clip(CLIP_NUM_DEF0);
@@ -115,7 +113,6 @@ void activate_ribi_clip(int ribi  CLIP_NUM_DEF);
 
 /* Do no access directly, use the get_tile_raster_width()
  * macro instead.
- * @author Hj. Malthaner
  */
 #define get_tile_raster_width()    (tile_raster_width)
 extern KOORD_VAL tile_raster_width;
@@ -133,19 +130,18 @@ int zoom_factor_down();
 
 /**
  * Initialises the graphics module
- * @author Hj. Malthaner
  */
 void simgraph_init(KOORD_VAL width, KOORD_VAL height, int fullscreen);
 int is_display_init();
 void simgraph_exit();
 void simgraph_resize(KOORD_VAL w, KOORD_VAL h);
-void reset_textur(void *new_textur);
+
 
 /**
  * Loads the font, returns the number of characters in it
  * @param reload if true forces reload
  */
-uint16 display_load_font(const char* fname, bool reload = false);
+bool display_load_font(const char *fname, bool reload = false);
 
 image_id get_image_count();
 void register_image(class image_t *);
@@ -187,7 +183,6 @@ void display_img_aux(const image_id n, KOORD_VAL xp, KOORD_VAL yp, const signed
 
 /**
  * draws the images with alpha, either blended or as outline
- * @author kierongreen
  */
 void display_rezoomed_img_blend(const image_id n, KOORD_VAL xp, KOORD_VAL yp, const signed char player_nr, const FLAGGED_PIXVAL color_index, const int daynight, const int dirty  CLIP_NUM_DEF);
 #define display_img_blend( n, x, y, c, dn, d ) display_rezoomed_img_blend( (n), (x), (y), 0, (c), (dn), (d)  CLIP_NUM_DEFAULT)
@@ -213,26 +208,26 @@ void display_img_stretch( const stretch_map_t &imag, scr_rect area );
 // this displays a 3x3 array of images to fit the scr_rect like above, but blend the color
 void display_img_stretch_blend( const stretch_map_t &imag, scr_rect area, FLAGGED_PIXVAL color );
 
-// Knightly : display unzoomed image with alpha, either blended or as outline
+// display unzoomed image with alpha, either blended or as outline
 void display_base_img_blend(const image_id n, KOORD_VAL xp, KOORD_VAL yp, const signed char player_nr, const FLAGGED_PIXVAL color_index, const int daynight, const int dirty  CLIP_NUM_DEF CLIP_NUM_DEFAULT_ZERO);
 void display_base_img_alpha(const image_id n, const image_id alpha_n, const unsigned alpha_flags, KOORD_VAL xp, KOORD_VAL yp, const signed char player_nr, const FLAGGED_PIXVAL color_index, const int daynight, const int dirty  CLIP_NUM_DEF CLIP_NUM_DEFAULT_ZERO);
 
-// Knightly : pointer to image display procedures
+// pointer to image display procedures
 typedef void (*display_image_proc)(const image_id n, KOORD_VAL xp, KOORD_VAL yp, const signed char player_nr, const int daynight, const int dirty  CLIP_NUM_DEF);
 typedef void (*display_blend_proc)(const image_id n, KOORD_VAL xp, KOORD_VAL yp, const signed char player_nr, const FLAGGED_PIXVAL color_index, const int daynight, const int dirty  CLIP_NUM_DEF);
 typedef void (*display_alpha_proc)(const image_id n, const image_id alpha_n, const unsigned alpha_flags, KOORD_VAL xp, KOORD_VAL yp, const signed char player_nr, const FLAGGED_PIXVAL color_index, const int daynight, const int dirty  CLIP_NUM_DEF);
 
-// Knightly : variables for storing currently used image procedure set and tile raster width
+// variables for storing currently used image procedure set and tile raster width
 extern display_image_proc display_normal;
 extern display_image_proc display_color;
 extern display_blend_proc display_blend;
 extern display_alpha_proc display_alpha;
 extern signed short current_tile_raster_width;
 
-// Knightly : call this instead of referring to current_tile_raster_width directly
+// call this instead of referring to current_tile_raster_width directly
 #define get_current_tile_raster_width() (current_tile_raster_width)
 
-// Knightly : for switching between image procedure sets and setting current tile raster width
+// for switching between image procedure sets and setting current tile raster width
 inline void display_set_image_proc( bool is_global )
 {
 	if(  is_global  ) {
@@ -295,7 +290,6 @@ bool has_character( utf16 char_code );
  * @param text  pointer to a string of characters to evaluate.
  * @param len   length of text buffer to evaluate. If set to 0,
  *              evaluate until null termination.
- * @author      Max Kielland
  */
 KOORD_VAL display_get_char_max_width(const char* text, size_t len=0);
 
@@ -303,7 +297,6 @@ KOORD_VAL display_get_char_max_width(const char* text, size_t len=0);
  * For the next logical character in the text, returns the character code
  * as well as retrieves the char byte count and the screen pixel width
  * CAUTION : The text pointer advances to point to the next logical character
- * @author Knightly
  */
 utf32 get_next_char_with_metrics(const char* &text, unsigned char &byte_length, unsigned char &pixel_width);
 
@@ -311,7 +304,6 @@ utf32 get_next_char_with_metrics(const char* &text, unsigned char &byte_length,
  * For the previous logical character in the text, returns the character code
  * as well as retrieves the char byte count and the screen pixel width
  * CAUTION : The text pointer recedes to point to the previous logical character
- * @author Knightly
  */
 utf32 get_prev_char_with_metrics(const char* &text, const char *const text_start, unsigned char &byte_length, unsigned char &pixel_width);
 
@@ -325,14 +317,16 @@ size_t display_fit_proportional( const char *text, scr_coord_val max_width, scr_
 /* routines for string len (macros for compatibility with old calls) */
 #define proportional_string_width(text)          display_calc_proportional_string_len_width(text, 0x7FFF)
 #define proportional_string_len_width(text, len) display_calc_proportional_string_len_width(text, len)
+
 // length of a string in pixel
 int display_calc_proportional_string_len_width(const char* text, size_t len);
 
+// box which will contain the multi (or single) line of text
+void display_calc_proportional_multiline_string_len_width( int &xw, int &yh, const char *text, size_t len );
+
 /*
  * len parameter added - use -1 for previous behaviour.
  * completely renovated for unicode and 10 bit width and variable height
- * @author Volker Meyer, prissi
- * @date  15.06.2003, 2.1.2005
  */
 
 // #ifdef MULTI_THREAD
@@ -377,3 +371,4 @@ extern uint8 display_night_lights[LIGHT_COUNT * 3];
 #endif
 
 #endif
+void display_right_triangle_rgb(KOORD_VAL x, KOORD_VAL y, KOORD_VAL height, const PIXVAL colval, const bool dirty);
