@@ -1,17 +1,14 @@
 /*
- * Copyright 2010 Simutrans contributors
- * Available under the Artistic License (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "../simconst.h"
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../descriptor/image.h"
 
 #include "simgraph.h"
 
-int large_font_height = 10;
-int large_font_total_height = 11;
-int large_font_ascent = 9;
 
 KOORD_VAL tile_raster_width = 16; // zoomed
 KOORD_VAL base_tile_raster_width = 16; // original
@@ -72,9 +69,9 @@ void display_mark_img_dirty(image_id, KOORD_VAL, KOORD_VAL)
 {
 }
 
-uint16 display_load_font(const char*, bool)
+bool display_load_font(const char*, bool)
 {
-	return 1;
+	return true;
 }
 
 sint16 display_get_width()
@@ -166,14 +163,6 @@ void display_scroll_band(const KOORD_VAL, const KOORD_VAL, const KOORD_VAL)
 {
 }
 
-static inline void pixcopy(PIXVAL *, const PIXVAL *, const unsigned int)
-{
-}
-
-static inline void colorpixcopy(PIXVAL *, const PIXVAL *, const PIXVAL * const)
-{
-}
-
 void display_img_aux(const image_id, KOORD_VAL, KOORD_VAL, const signed char, const int, const int  CLIP_NUM_DEF_NOUSE)
 {
 }
@@ -214,7 +203,7 @@ void display_base_img_alpha(const image_id, const image_id, const unsigned, KOOR
 {
 }
 
-// Knightly : variables for storing currently used image procedure set and tile raster width
+// variables for storing currently used image procedure set and tile raster width
 display_image_proc display_normal = display_base_img;
 display_image_proc display_color = display_base_img;
 display_blend_proc display_blend = display_base_img_blend;
@@ -299,6 +288,12 @@ int display_calc_proportional_string_len_width(const char*, size_t)
 }
 
 
+void display_calc_proportional_multiline_string_len_width( int &xw, int &yh, const char *, size_t )
+{
+	xw = yh = 0;;
+}
+
+
 int display_text_proportional_len_clip_rgb(KOORD_VAL, KOORD_VAL, const char*, control_alignment_t , const PIXVAL, bool, sint32  CLIP_NUM_DEF_NOUSE)
 {
 	return 0;
@@ -367,10 +362,6 @@ void simgraph_resize(KOORD_VAL, KOORD_VAL)
 {
 }
 
-void reset_textur(void *)
-{
-}
-
 void display_snapshot()
 {
 }
@@ -395,6 +386,10 @@ void draw_bezier_rgb(KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, KOOR
 {
 }
 
+void display_right_triangle_rgb(KOORD_VAL, KOORD_VAL, KOORD_VAL, const PIXVAL, const bool)
+{
+}
+
 void display_set_progress_text(const char *)
 {
 }
