@@ -1,15 +1,13 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
 #include <string.h>
 
 #include "simdebug.h"
-#include "simsys.h"
+#include "sys/simsys.h"
 #include "simintr.h"
 #include "gui/simwin.h"
 #include "player/simplay.h"
@@ -37,39 +35,45 @@ static uint32 frame_time = 36*FRAME_TIME_MULTI;
 
 bool reduce_frame_time()
 {
-	if(frame_time > 10*FRAME_TIME_MULTI) {
+	if(  frame_time > 150*FRAME_TIME_MULTI  ) { // < ~6.6fps
+		frame_time -= 8;
+		return true;
+	}
+	else if(frame_time > (FRAME_TIME_MULTI*1000)/env_t::max_fps) {
 		frame_time -= 1;
-		if(  frame_time>150*FRAME_TIME_MULTI  ) {
-			frame_time -= 8;
-		}
 		return true;
 	}
 	else {
-		frame_time = 10*FRAME_TIME_MULTI;
+		frame_time = (FRAME_TIME_MULTI*1000)/env_t::max_fps;
 		return false;
 	}
 }
 
+
 bool increase_frame_time()
 {
-	if(frame_time < 255*FRAME_TIME_MULTI) {
-		frame_time ++;
-		return true;
-	} else {
+	if(frame_time > (FRAME_TIME_MULTI*1000)/5) { // < 5 fps
 		return false;
 	}
+	else {
+		frame_time ++;
+		return true;
+	}
 }
 
+
 uint32 get_frame_time()
 {
 	return frame_time/FRAME_TIME_MULTI;
 }
 
+
 void set_frame_time(uint32 time)
 {
-	frame_time = clamp( time, 10, 250 )*FRAME_TIME_MULTI;
+	frame_time = clamp( time, 1000/env_t::max_fps, 1000/env_t::min_fps )*FRAME_TIME_MULTI;
 }
 
+
 void intr_refresh_display(bool dirty)
 {
 	wasser_t::prepare_for_refresh();
@@ -90,24 +94,28 @@ void intr_refresh_display(bool dirty)
 void interrupt_check(const char* caller_info)
 {
 	DBG_DEBUG4("interrupt_check", "called from (%s)", caller_info);
-	if(enabled) {
-		static uint32 last_ms = 0;
-		if(  !welt_modell->is_fast_forward()  ||  welt_modell->get_ticks() != last_ms  ) {
-			const uint32 now = dr_time();
-			if((now-last_time)*FRAME_TIME_MULTI < frame_time) {
-				return;
-			}
-			const sint32 diff = (( (sint32)now - (sint32)last_time)*welt_modell->get_time_multiplier())/16;
-			if(  diff>0  ) {
-				enabled = false;
-				last_time = now;
-				welt_modell->sync_step( diff, !welt_modell->is_fast_forward(), true );
-				enabled = true;
-			}
-		}
-		last_ms = welt_modell->get_ticks();
-	}
 	(void)caller_info;
+
+	if(  !enabled  ) {
+		return;
+	}
+
+	static uint32 last_ms = 0;
+	if(  !welt_modell->is_fast_forward()  ||  welt_modell->get_ticks() != last_ms  ) {
+		const uint32 now = dr_time();
+		if((now-last_time)*FRAME_TIME_MULTI < frame_time) {
+			return;
+		}
+
+		const sint32 diff = (( (sint32)now - (sint32)last_time)*welt_modell->get_time_multiplier())/16;
+		if(  diff>0  ) {
+			enabled = false;
+			last_time = now;
+			welt_modell->sync_step( diff, !welt_modell->is_fast_forward(), true );
+			enabled = true;
+		}
+	}
+	last_ms = welt_modell->get_ticks();
 }
 
 
@@ -119,24 +127,25 @@ void intr_set(karte_t *welt, main_view_t *view)
 	enabled = true;
 }
 
-/**
- * @author Hj. Malthaner
- */
+
 void intr_set_last_time(uint32 time)
 {
 	last_time = time;
 }
 
+
 void intr_disable()
 {
 	enabled = false;
 }
 
+
 void intr_enable()
 {
 	enabled = true;
 }
 
+
 char const *tick_to_string( sint32 ticks, bool show_full )
 {
 	static sint32 tage_per_month[12]={31,28,31,30,31,30,31,31,30,31,30,31};
@@ -181,8 +190,6 @@ char const *tick_to_string( sint32 ticks, bool show_full )
 	if(  show_full  ||  env_t::show_month == env_t::DATE_FMT_SEASON  ) {
 
 		//DBG_MESSAGE("env_t::show_month","%d",env_t::show_month);
-		// @author hsiegeln - updated to show month
-		// @author prissi - also show date if desired
 		// since seasons 0 is always summer for backward compatibility
 		char const* const date = translator::get_date(year, month, tage, translator::translate(seasons[welt_modell->get_season()]));
 		switch (env_t::show_month) {
