@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef simintr_h
-#define simintr_h
+#ifndef SIMINTR_H
+#define SIMINTR_H
+
 
 #include "macros.h"
 
@@ -14,10 +13,14 @@ class karte_t;
 class main_view_t;
 
 
+/// Try to increase fps
 bool reduce_frame_time();
+
+/// Try to decrease fps
 bool increase_frame_time();
+
 uint32 get_frame_time();
-void set_frame_time(uint32 time);
+void set_frame_time(uint32 ms);
 
 
 void intr_refresh_display(bool dirty);
@@ -48,9 +51,9 @@ void interrupt_check(const char* caller_info = "0");
 		#define INT_CHECK(info) interrupt_check( __FILE__ ":" QUOTEME(__LINE__) );
 	#endif
 #endif
-#endif
-
 
 // returns a time string in the desired format
 // Returns an empty string if called before the world model defining time is initalized.
 char const *tick_to_string( sint32 ticks, bool show_full );
+
+#endif
