@@ -1,12 +1,16 @@
 /*
- * Ein-/Ausgaberoutinen fuer Simutrans
- * von Hj. Malthaner, 2000
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
+#ifndef SIMIO_H
+#define SIMIO_H
+
+
 /**
  * Reads a line from a file. Skips lines starting with #
- *
  * @see fgets
- * @author Hj. Malthaner
  */
 char *read_line(char *s, int size, FILE *stream);
+
+#endif
