@@ -1,10 +1,11 @@
 /*
- * part of the Simutrans project
- * @author hsiegeln
- * 01/12/2003
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
-#ifndef simline_h
-#define simline_h
+
+#ifndef SIMLINE_H
+#define SIMLINE_H
+
 
 #include "simtypes.h"
 #include "simcolor.h"
@@ -17,16 +18,16 @@
 
 #define MAX_MONTHS     12 // Max history
 
-#define LINE_CAPACITY   0 // the amount of ware that could be transported, theoretically
+#define LINE_CAPACITY          0 // the amount of ware that could be transported, theoretically
 #define LINE_TRANSPORTED_GOODS 1 // the amount of ware that has been transported
-#define LINE_CONVOIS		2 // number of convois for this line
-#define LINE_REVENUE		3 // the income this line generated
-#define LINE_OPERATIONS     4 // the cost of operations this line generated
-#define LINE_PROFIT         5 // total profit of line
-#define LINE_DISTANCE       6 // distance covered by all convois
-#define LINE_MAXSPEED       7 // maximum speed for bonus calculation of all convois
-#define LINE_WAYTOLL        8 // way toll paid by vehicles of line
-#define MAX_LINE_COST   9 // Total number of cost items
+#define LINE_CONVOIS           2 // number of convois for this line
+#define LINE_REVENUE           3 // the income this line generated
+#define LINE_OPERATIONS        4 // the cost of operations this line generated
+#define LINE_PROFIT            5 // total profit of line
+#define LINE_DISTANCE          6 // distance covered by all convois
+#define LINE_MAXSPEED          7 // maximum speed for bonus calculation of all convois
+#define LINE_WAYTOLL           8 // way toll paid by vehicles of line
+#define MAX_LINE_COST          9 // Total number of cost items
 
 class karte_ptr_t;
 class loadsave_t;
@@ -52,30 +53,27 @@ private:
 	/**
 	 * Handle for ourselves. Can be used like the 'this' pointer
 	 * Initialized by constructors
-	 * @author Hj. Malthaner
 	 */
 	linehandle_t self;
 
-	/*
+	/**
 	 * the current state saved as color
 	 * Meanings are BLACK (ok), WHITE (no convois), YELLOW (no vehicle moved), RED (last month income minus), BLUE (at least one convoi vehicle is obsolete)
 	 */
 	PIXVAL state_color;
 
-	/*
+	/**
 	 * a list of all convoys assigned to this line
-	 * @author hsiegeln
 	 */
 	vector_tpl<convoihandle_t> line_managed_convoys;
 
-	/*
+	/**
 	 * a list of all catg_index, which can be transported by this line.
 	 */
 	minivec_tpl<uint8> goods_catg_index;
 
-	/*
+	/**
 	 * struct holds new financial history for line
-	 * @author hsiegeln
 	 */
 	sint64 financial_history[MAX_MONTHS][MAX_LINE_COST];
 
@@ -96,49 +94,42 @@ public:
 
 	linehandle_t get_handle() const { return self; }
 
-	/*
+	/**
 	 * add convoy to route
-	 * @author hsiegeln
 	 */
 	void add_convoy(convoihandle_t cnv);
 
-	/*
+	/**
 	 * remove convoy from route
-	 * @author hsiegeln
 	 */
 	void remove_convoy(convoihandle_t cnv);
 
-	/*
+	/**
 	 * get convoy
-	 * @author hsiegeln
 	 */
 	convoihandle_t get_convoy(int i) const { return line_managed_convoys[i]; }
 
-	/*
+	/**
 	 * return number of manages convoys in this line
-	 * @author hsiegeln
 	 */
 	uint32 count_convoys() const { return line_managed_convoys.get_count(); }
 
 	vector_tpl<convoihandle_t> const& get_convoys() const { return line_managed_convoys; }
 
-	/*
+	/**
 	 * returns the state of the line
-	 * @author prissi
 	 */
 	PIXVAL get_state_color() const { return state_color; }
 
-	/*
+	/**
 	 * return the schedule of the line
-	 * @author hsiegeln
 	 */
 	schedule_t * get_schedule() const { return schedule; }
 
 	void set_schedule(schedule_t* schedule);
 
-	/*
+	/**
 	 * get name of line
-	 * @author hsiegeln
 	 */
 	char const* get_name() const { return name; }
 	void set_name(const char *str) { name = str; }
