@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #if defined(_M_X64)  ||  defined(__x86_64__)
 #if   __GNUC__
 #warning "Simutrans is preferably compiled as 32 bit binary!"
@@ -34,7 +39,7 @@
 #include "simmenu.h"
 #include "siminteraction.h"
 
-#include "simsys.h"
+#include "sys/simsys.h"
 #include "display/simgraph.h"
 #include "simevent.h"
 
@@ -52,11 +57,12 @@
 #include "gui/scenario_frame.h"
 
 #include "obj/baum.h"
+#include "obj/wolke.h"
 
 #include "utils/simstring.h"
 #include "utils/searchfolder.h"
 
-#include "network/network.h"	// must be before any "windows.h" is included via bzlib2.h ...
+#include "network/network.h" // must be before any "windows.h" is included via bzlib2.h ...
 #include "dataobj/loadsave.h"
 #include "dataobj/environment.h"
 #include "dataobj/tabfile.h"
@@ -75,6 +81,7 @@
 #include "utils/simrandom.h"
 
 #include "bauer/vehikelbauer.h"
+#include "script/script_tool_manager.h"
 
 #include "vehicle/simvehicle.h"
 #include "vehicle/simroadtraffic.h"
@@ -96,6 +103,7 @@ static void show_sizes()
 	DBG_MESSAGE("sizes", "obj_t: %d", sizeof(obj_t));
 	DBG_MESSAGE("sizes", "gebaeude_t: %d", sizeof(gebaeude_t));
 	DBG_MESSAGE("sizes", "baum_t: %d", sizeof(baum_t));
+	DBG_MESSAGE("sizes", "wolke_t: %d", sizeof(wolke_t));
 	DBG_MESSAGE("sizes", "weg_t: %d", sizeof(weg_t));
 	DBG_MESSAGE("sizes", "private_car_t: %d\n", sizeof(private_car_t));
 
@@ -117,12 +125,12 @@ static void show_sizes()
 // render tests ...
 static void show_times(karte_t *welt, main_view_t *view)
 {
- 	intr_set(welt, view);
+	intr_set(welt, view);
 	welt->set_fast_forward(true);
 	intr_disable();
 
 	dbg->message( "show_times()", "simple profiling of drawing routines" );
- 	int i;
+	int i;
 
 	image_id img = ground_desc_t::outside->get_image(0,0);
 
@@ -133,53 +141,53 @@ static void show_times(karte_t *welt, main_view_t *view)
 	dbg->message( "display_img()", "%i iterations took %li ms", i, dr_time() - ms );
 
 	image_id player_img = skinverwaltung_t::color_options->get_image_id(0);
- 	ms = dr_time();
+	ms = dr_time();
 	for (i = 0;  i < 1000000;  i++) {
- 		display_color_img( player_img, 120, 100, i%15, 0, 1);
+		display_color_img( player_img, 120, 100, i%15, 0, 1);
 	}
 	dbg->message( "display_color_img() with recolor", "%i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
+	ms = dr_time();
 	for (i = 0;  i < 1000000;  i++) {
 		display_color_img( img, 120, 100, 0, 1, 1);
- 		display_color_img( player_img, 160, 150, 16, 1, 1);
+		display_color_img( player_img, 160, 150, 16, 1, 1);
 	}
 	dbg->message( "display_color_img()", "3x %i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
+	ms = dr_time();
 	for (i = 0;  i < 600000;  i++) {
 		dr_prepare_flush();
- 		dr_flush();
+		dr_flush();
 	}
 	dbg->message( "display_flush_buffer()", "%i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
+	ms = dr_time();
 	for (i = 0;  i < 300000;  i++) {
- 		display_text_proportional_len_clip_rgb(100, 120, "Dies ist ein kurzer Textetxt ...", 0, 0, false, -1);
+		display_text_proportional_len_clip_rgb(100, 120, "Dies ist ein kurzer Textetxt ...", 0, 0, false, -1);
 	}
 	dbg->message( "display_text_proportional_len_clip_rgb()", "%i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
+	ms = dr_time();
 	for (i = 0;  i < 300000;  i++) {
- 		display_fillbox_wh_rgb(100, 120, 300, 50, 0, false);
+		display_fillbox_wh_rgb(100, 120, 300, 50, 0, false);
 	}
 	dbg->message( "display_fillbox_wh_rgb()", "%i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
- 	for (i = 0; i < 2000; i++) {
- 		view->display(true);
- 	}
+	ms = dr_time();
+	for (i = 0; i < 2000; i++) {
+		view->display(true);
+	}
 	dbg->message( "view->display(true)", "%i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
- 	for (i = 0; i < 2000; i++) {
- 		view->display(true);
- 		win_display_flush(0.0);
- 	}
+	ms = dr_time();
+	for (i = 0; i < 2000; i++) {
+		view->display(true);
+		win_display_flush(0.0);
+	}
 	dbg->message( "view->display(true) and flush", "%i iterations took %li ms", i, dr_time() - ms );
 
- 	ms = dr_time();
- 	for (i = 0; i < 40000000/(int)weg_t::get_alle_wege().get_count(); i++) {
+	ms = dr_time();
+	for (i = 0; i < 40000000/(int)weg_t::get_alle_wege().get_count(); i++) {
 		FOR( slist_tpl<weg_t *>, const w, weg_t::get_alle_wege() ) {
 			grund_t *dummy;
 			welt->lookup( w->get_pos() )->get_neighbour( dummy, invalid_wt, ribi_t::north );
@@ -187,11 +195,11 @@ static void show_times(karte_t *welt, main_view_t *view)
 	}
 	dbg->message( "grund_t::get_neighbour()", "%i iterations took %li ms", i*weg_t::get_alle_wege().get_count(), dr_time() - ms );
 
- 	ms = dr_time();
+	ms = dr_time();
 	for (i = 0; i < 2000; i++) {
- 		welt->sync_step(200,true,true);
- 		welt->step();
- 	}
+		welt->sync_step(200,true,true);
+		welt->step();
+	}
 	dbg->message( "welt->sync_step/step(200,1,1)", "%i iterations took %li ms", i, dr_time() - ms );
 }
 
@@ -284,6 +292,7 @@ void modal_dialogue( gui_frame_t *gui, ptrdiff_t magic, karte_t *welt, bool (*qu
 					simgraph_resize( ev.size_x, ev.size_y );
 					dr_prepare_flush();
 					display_fillbox_wh_rgb( 0, 0, ev.size_x, ev.size_y, color_idx_to_rgb(COL_BLACK), true );
+					gui->draw(win_get_pos(gui), gui->get_windowsize());
 					dr_flush();
 				}
 				else if (ev.ev_code == SYSTEM_QUIT) {
@@ -348,7 +357,7 @@ static void ask_objfilename()
 	sel->infowin_event(&ev);
 
 	if(sel->has_pak()) {
-		destroy_all_win(true);	// since eventually the successful load message is still there ....
+		destroy_all_win(true); // since eventually the successful load message is still there ....
 		modal_dialogue( sel, magic_none, NULL, empty_objfilename );
 	}
 	else {
@@ -370,7 +379,7 @@ static void ask_language()
 	}
 	else {
 		sprachengui_t* sel = new sprachengui_t();
-		destroy_all_win(true);	// since eventually the successful load message is still there ....
+		destroy_all_win(true); // since eventually the successful load message is still there ....
 		modal_dialogue( sel, magic_none, NULL, no_language );
 		destroy_win( sel );
 	}
@@ -436,7 +445,7 @@ int simu_main(int argc, char** argv)
 			"  <markus@pristovsek.de>\n"
 			"\n"
 			"  Based on Simutrans 0.84.21.2\n"
-			"  by Hansjrg Malthaner et. al.\n"
+			"  by Hansjörg Malthaner et. al.\n"
 			"---------------------------------------\n"
 			"command line parameters available: \n"
 			" -addons             loads also addons (with -objects)\n"
@@ -462,6 +471,7 @@ int simu_main(int argc, char** argv)
 			" -nosound            turns off ambient sounds\n"
 			" -objects DIR_NAME/  load the pakset in specified directory\n"
 			" -pause              starts game with paused after loading\n"
+			"                     a server will pause if there are no clients\n"
 			" -res N              starts in specified resolution: \n"
 			"                      1=640x480, 2=800x600, 3=1024x768, 4=1280x1024\n"
 			" -screensize WxH     set screensize to width W and height H\n"
@@ -866,29 +876,29 @@ int simu_main(int argc, char** argv)
 	if(  const char *themestr = gimme_arg(argc, argv, "-theme", 1)  ) {
 		dr_chdir( env_t::user_dir );
 		dr_chdir( "themes" );
-		themes_ok = gui_theme_t::themes_init(themestr, true);
+		themes_ok = gui_theme_t::themes_init(themestr, true, false);
 		if(  !themes_ok  ) {
 			dr_chdir( env_t::program_dir );
 			dr_chdir( "themes" );
-			themes_ok = gui_theme_t::themes_init(themestr, true);
+			themes_ok = gui_theme_t::themes_init(themestr, true, false);
 		}
 	}
 	// next try the last used theme
 	if(  !themes_ok  &&  env_t::default_theme.c_str()!=NULL  ) {
 		dr_chdir( env_t::user_dir );
 		dr_chdir( "themes" );
-		themes_ok = gui_theme_t::themes_init( env_t::default_theme, true );
+		themes_ok = gui_theme_t::themes_init( env_t::default_theme, true, false );
 		if(  !themes_ok  ) {
 			dr_chdir( env_t::program_dir );
 			dr_chdir( "themes" );
-			themes_ok = gui_theme_t::themes_init( env_t::default_theme, true );
+			themes_ok = gui_theme_t::themes_init( env_t::default_theme, true, false );
 		}
 	}
 	// specified themes not found => try default themes
 	if(  !themes_ok  ) {
 		dr_chdir( env_t::program_dir );
 		dr_chdir( "themes" );
-		themes_ok = gui_theme_t::themes_init("themes.tab",true);
+		themes_ok = gui_theme_t::themes_init("themes.tab",true,false);
 	}
 	if(  !themes_ok  ) {
 		dbg->fatal( "simmain()", "No GUI themes found! Please re-install!" );
@@ -1058,7 +1068,7 @@ int simu_main(int argc, char** argv)
 		translator::set_language( env_t::language_iso );
 	}
 
-	// Hajo: simgraph init loads default fonts, now we need to load (if not set otherwise)
+	// simgraph_init loads default fonts, now we need to load (if not set otherwise)
 	sprachengui_t::init_font_from_lang( strcmp(env_t::fontname.c_str(), FONT_PATH_X "prop.fnt")==0 );
 	dr_chdir(env_t::program_dir);
 
@@ -1074,7 +1084,7 @@ int simu_main(int argc, char** argv)
 	// loading all objects in the pak
 	dbg->message("simmain()","Reading object data from %s...", env_t::objfilename.c_str());
 	obj_reader_t::load( env_t::objfilename.c_str(), translator::translate("Loading paks ...") );
-	std::string overlaid_warning;	// more prominent handling of double objects
+	std::string overlaid_warning; // more prominent handling of double objects
 	if(  dbg->had_overlaid()  ) {
 		overlaid_warning = translator::translate("<h1>Error</h1><p><strong>");
 		overlaid_warning.append( env_t::objfilename + translator::translate("contains the following doubled objects:</strong><p>") + dbg->get_overlaid() + "<p>" );
@@ -1106,9 +1116,31 @@ int simu_main(int argc, char** argv)
 		destroy_all_win(true);
 	}
 
+	// load tool scripts
+	dbg->message("simmain()","Reading tool scripts ...");
+	dr_chdir( env_t::program_dir );
+	script_tool_manager_t::load_scripts((env_t::objfilename + "tool/").c_str());
+	if(  env_t::default_settings.get_with_private_paks()  ) {
+		dr_chdir( env_t::user_dir );
+		script_tool_manager_t::load_scripts(("addons/" + env_t::objfilename + "tool/").c_str());
+	}
+
 	dbg->message("simmain()","Reading menu configuration ...");
+	dr_chdir( env_t::program_dir );
 	tool_t::read_menu(env_t::objfilename);
 
+	// reread theme
+	dr_chdir( env_t::user_dir );
+	dr_chdir( "themes" );
+	themes_ok = gui_theme_t::themes_init( env_t::default_theme, true, false );
+	if(  !themes_ok  ) {
+		dr_chdir( env_t::program_dir );
+		dr_chdir( "themes" );
+		themes_ok = gui_theme_t::themes_init( env_t::default_theme, true, false );
+	}
+	dr_chdir( env_t::program_dir );
+
+
 	if(  translator::get_language()==-1  ) {
 		ask_language();
 	}
@@ -1117,8 +1149,13 @@ int simu_main(int argc, char** argv)
 	std::string loadgame;
 
 	bool pause_after_load = false;
-	if (gimme_arg(argc, argv, "-pause", 0)) {
-		pause_after_load = true;
+	if(  gimme_arg(argc, argv, "-pause", 0)  ) {
+		if( env_t::server ) {
+			env_t::pause_server_no_clients = true;
+		}
+		else {
+			pause_after_load = true;
+		}
 	}
 
 	if(  gimme_arg(argc, argv, "-load", 0) != NULL  ) {
@@ -1235,13 +1272,13 @@ DBG_MESSAGE("simmain","loadgame file found at %s",path.c_str());
 
 	// restore previous sound settings ...
 	sound_set_shuffle_midi( env_t::shuffle_midi!=0 );
-	sound_set_mute(  env_t::mute_sound  ||  sound_get_mute() );
+	sound_set_mute(  env_t::global_mute_sound  ||  sound_get_mute() );
 	midi_set_mute(  env_t::mute_midi  ||  midi_get_mute() );
 	sound_set_global_volume( env_t::global_volume );
 	sound_set_midi_volume( env_t::midi_volume );
 	if(  !midi_get_mute()  ) {
 		// not muted => play random song
-		midi_play(-1);
+		midi_play( env_t::shuffle_midi ? -1 : 0 );
 		// reset volume after first play call else no/low sound or music with win32 and sdl
 		sound_set_midi_volume( env_t::midi_volume );
 	}
@@ -1298,7 +1335,7 @@ DBG_MESSAGE("simmain","loadgame file found at %s",path.c_str());
 
 	// reset random counter to true randomness
 	setsimrand(dr_time(), dr_time());
-	clear_random_mode( 7 );	// allow all
+	clear_random_mode( 7 ); // allow all
 
 	if(  loadgame==""  ||  !welt->load(loadgame.c_str())  ) {
 		// create a default map
@@ -1376,7 +1413,7 @@ DBG_MESSAGE("simmain","loadgame file found at %s",path.c_str());
 
 
 #ifdef USE_SOFTPOINTER
-	// Hajo: give user a mouse to work with
+	// give user a mouse to work with
 	if (skinverwaltung_t::mouse_cursor != NULL) {
 		// we must use our softpointer (only Allegro!)
 		display_set_pointer(skinverwaltung_t::mouse_cursor->get_image_id(0));
@@ -1387,7 +1424,7 @@ DBG_MESSAGE("simmain","loadgame file found at %s",path.c_str());
 
 	welt->set_dirty();
 
-	// Hajo: simgraph init loads default fonts, now we need to load
+	// simgraph_init loads default fonts, now we need to load
 	// the real fonts for the current language, if not set otherwise
 	sprachengui_t::init_font_from_lang( strcmp(env_t::fontname.c_str(), FONT_PATH_X "prop.fnt")==0 );
 
@@ -1447,7 +1484,7 @@ DBG_MESSAGE("simmain","loadgame file found at %s",path.c_str());
 
 	// save setting ...
 	dr_chdir( env_t::user_dir );
-	if(  file.wr_open("settings.xml",loadsave_t::xml,"settings only/",SAVEGAME_VER_NR)  ) {
+	if(  file.wr_open("settings.xml",loadsave_t::xml,0,"settings only/",SAVEGAME_VER_NR)  ) {
 		env_t::rdwr(&file);
 		env_t::default_settings.rdwr(&file);
 		file.close();
