@@ -1,9 +1,6 @@
 /*
- * Copyright (c) 2008 prissi
- *
- * This file is part of the Simutrans project under the artistic license.
- *
- * New configurable OOP tool system
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string>
@@ -18,6 +15,7 @@
 #include "simmenu.h"
 #include "simtool.h"
 #include "simtool-dialogs.h"
+#include "simtool-scripted.h"
 #include "simskin.h"
 #include "simsound.h"
 
@@ -25,6 +23,7 @@
 #include "bauer/wegbauer.h"
 #include "bauer/brueckenbauer.h"
 #include "bauer/tunnelbauer.h"
+#include "script/script_tool_manager.h"
 
 #include "descriptor/building_desc.h"
 #include "descriptor/bridge_desc.h"
@@ -69,8 +68,8 @@ public:
 	tool_dummy_t() : tool_t(dummy_id) {}
 
 	bool init(player_t*) OVERRIDE { return false; }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 	bool is_move_network_save(player_t*) const OVERRIDE { return true; }
 };
 tool_t *tool_t::dummy = new tool_dummy_t();
@@ -79,51 +78,55 @@ tool_t *create_general_tool(int toolnr)
 {
 	tool_t* tool = NULL;
 	switch(toolnr) {
-		case TOOL_QUERY:          tool = new tool_query_t(); break;
-		case TOOL_REMOVER:          tool = new tool_remover_t(); break;
-		case TOOL_RAISE_LAND:       tool = new tool_raise_t(); break;
-		case TOOL_LOWER_LAND:       tool = new tool_lower_t(); break;
-		case TOOL_SETSLOPE:         tool = new tool_setslope_t(); break;
-		case TOOL_RESTORESLOPE:     tool = new tool_restoreslope_t(); break;
-		case TOOL_MARKER:           tool = new tool_marker_t(); break;
-		case TOOL_CLEAR_RESERVATION:tool = new tool_clear_reservation_t(); break;
-		case TOOL_TRANSFORMER:      tool = new tool_transformer_t(); break;
-		case TOOL_ADD_CITY:         tool = new tool_add_city_t(); break;
-		case TOOL_CHANGE_CITY_SIZE: tool = new tool_change_city_size_t(); break;
-		case TOOL_PLANT_TREE:       tool = new tool_plant_tree_t(); break;
-		case TOOL_SCHEDULE_ADD:     tool = new tool_schedule_add_t(); break;
-		case TOOL_SCHEDULE_INS:     tool = new tool_schedule_ins_t(); break;
-		case TOOL_BUILD_WAY:          tool = new tool_build_way_t(); break;
-		case TOOL_BUILD_BRIDGE:      tool = new tool_build_bridge_t(); break;
-		case TOOL_BUILD_TUNNEL:        tool = new tool_build_tunnel_t(); break;
-		case TOOL_WAYREMOVER:       tool = new tool_wayremover_t(); break;
-		case TOOL_BUILD_WAYOBJ:           tool = new tool_build_wayobj_t(); break;
-		case TOOL_BUILD_STATION:          tool = new tool_build_station_t(); break;
-		case TOOL_BUILD_ROADSIGN:         tool = new tool_build_roadsign_t(); break;
-		case TOOL_BUILD_DEPOT:            tool = new tool_build_depot_t(); break;
-		case TOOL_BUILD_HOUSE:       tool = new tool_build_house_t(); break;
-		case TOOL_BUILD_LAND_CHAIN:       tool = new tool_build_land_chain_t(); break;
-		case TOOL_CITY_CHAIN:       tool = new tool_city_chain_t(); break;
-		case TOOL_BUILD_FACTORY:    tool = new tool_build_factory_t(); break;
-		case TOOL_LINK_FACTORY:     tool = new tool_link_factory_t(); break;
-		case TOOL_HEADQUARTER:      tool = new tool_headquarter_t(); break;
-		case TOOL_LOCK_GAME:        tool = new tool_lock_game_t(); break;
-		case TOOL_ADD_CITYCAR:      tool = new tool_add_citycar_t(); break;
-		case TOOL_FOREST:           tool = new tool_forest_t(); break;
-		case TOOL_STOP_MOVER:       tool = new tool_stop_mover_t(); break;
-		case TOOL_MAKE_STOP_PUBLIC: tool = new tool_make_stop_public_t(); break;
-		case TOOL_REMOVE_WAYOBJ:    tool = new tool_remove_wayobj_t(); break;
-		case TOOL_SLICED_AND_UNDERGROUND_VIEW: tool = new tool_show_underground_t(); break;
-		case TOOL_BUY_HOUSE:        tool = new tool_buy_house_t(); break;
-		case TOOL_BUILD_CITYROAD:         tool = new tool_build_cityroad(); break;
-		case TOOL_ERROR_MESSAGE: tool = new tool_error_message_t(); break;
-		case TOOL_CHANGE_WATER_HEIGHT: tool = new tool_change_water_height_t(); break;
-		case TOOL_SET_CLIMATE:      tool = new tool_set_climate_t(); break;
-		case TOOL_ROTATE_BUILDING:		tool = new tool_rotate_building_t(); break;
-		case TOOL_MERGE_STOP:		tool = new tool_merge_stop_t(); break;
-		default:                   dbg->error("create_general_tool()","cannot satisfy request for general_tool[%i]!",toolnr);
-		                           return NULL;
+		case TOOL_QUERY:                       tool = new tool_query_t();               break;
+		case TOOL_REMOVER:                     tool = new tool_remover_t();             break;
+		case TOOL_RAISE_LAND:                  tool = new tool_raise_t();               break;
+		case TOOL_LOWER_LAND:                  tool = new tool_lower_t();               break;
+		case TOOL_SETSLOPE:                    tool = new tool_setslope_t();            break;
+		case TOOL_RESTORESLOPE:                tool = new tool_restoreslope_t();        break;
+		case TOOL_MARKER:                      tool = new tool_marker_t();              break;
+		case TOOL_CLEAR_RESERVATION:           tool = new tool_clear_reservation_t();   break;
+		case TOOL_TRANSFORMER:                 tool = new tool_transformer_t();         break;
+		case TOOL_ADD_CITY:                    tool = new tool_add_city_t();            break;
+		case TOOL_CHANGE_CITY_SIZE:            tool = new tool_change_city_size_t();    break;
+		case TOOL_PLANT_TREE:                  tool = new tool_plant_tree_t();          break;
+		case TOOL_SCHEDULE_ADD:                tool = new tool_schedule_add_t();        break;
+		case TOOL_SCHEDULE_INS:                tool = new tool_schedule_ins_t();        break;
+		case TOOL_BUILD_WAY:                   tool = new tool_build_way_t();           break;
+		case TOOL_BUILD_BRIDGE:                tool = new tool_build_bridge_t();        break;
+		case TOOL_BUILD_TUNNEL:                tool = new tool_build_tunnel_t();        break;
+		case TOOL_WAYREMOVER:                  tool = new tool_wayremover_t();          break;
+		case TOOL_BUILD_WAYOBJ:                tool = new tool_build_wayobj_t();        break;
+		case TOOL_BUILD_STATION:               tool = new tool_build_station_t();       break;
+		case TOOL_BUILD_ROADSIGN:              tool = new tool_build_roadsign_t();      break;
+		case TOOL_BUILD_DEPOT:                 tool = new tool_build_depot_t();         break;
+		case TOOL_BUILD_HOUSE:                 tool = new tool_build_house_t();         break;
+		case TOOL_BUILD_LAND_CHAIN:            tool = new tool_build_land_chain_t();    break;
+		case TOOL_CITY_CHAIN:                  tool = new tool_city_chain_t();          break;
+		case TOOL_BUILD_FACTORY:               tool = new tool_build_factory_t();       break;
+		case TOOL_LINK_FACTORY:                tool = new tool_link_factory_t();        break;
+		case TOOL_HEADQUARTER:                 tool = new tool_headquarter_t();         break;
+		case TOOL_LOCK_GAME:                   tool = new tool_lock_game_t();           break;
+		case TOOL_ADD_CITYCAR:                 tool = new tool_add_citycar_t();         break;
+		case TOOL_FOREST:                      tool = new tool_forest_t();              break;
+		case TOOL_STOP_MOVER:                  tool = new tool_stop_mover_t();          break;
+		case TOOL_MAKE_STOP_PUBLIC:            tool = new tool_make_stop_public_t();    break;
+		case TOOL_REMOVE_WAYOBJ:               tool = new tool_remove_wayobj_t();       break;
+		case TOOL_SLICED_AND_UNDERGROUND_VIEW: tool = new tool_show_underground_t();    break;
+		case TOOL_BUY_HOUSE:                   tool = new tool_buy_house_t();           break;
+		case TOOL_BUILD_CITYROAD:              tool = new tool_build_cityroad();        break;
+		case TOOL_ERROR_MESSAGE:               tool = new tool_error_message_t();       break;
+		case TOOL_CHANGE_WATER_HEIGHT:         tool = new tool_change_water_height_t(); break;
+		case TOOL_SET_CLIMATE:                 tool = new tool_set_climate_t();         break;
+		case TOOL_ROTATE_BUILDING:             tool = new tool_rotate_building_t();     break;
+		case TOOL_MERGE_STOP:                  tool = new tool_merge_stop_t();          break;
+		case TOOL_EXEC_SCRIPT:                 tool = new tool_exec_script_t();         break;
+		case TOOL_EXEC_TWO_CLICK_SCRIPT:       tool = new tool_exec_two_click_script_t(); break;
+		default:
+			dbg->error("create_general_tool()","cannot satisfy request for general_tool[%i]!",toolnr);
+			return NULL;
 	}
+
 	// check for right id (exception: TOOL_SLICED_AND_UNDERGROUND_VIEW)
 	assert(tool->get_id()  ==  (toolnr | GENERAL_TOOL)  ||  toolnr==TOOL_SLICED_AND_UNDERGROUND_VIEW);
 	return tool;
@@ -134,45 +137,49 @@ tool_t *create_simple_tool(int toolnr)
 {
 	tool_t* tool = NULL;
 	switch(toolnr) {
-		case TOOL_PAUSE:             tool = new tool_pause_t(); break;
-		case TOOL_FASTFORWARD:       tool = new tool_fastforward_t(); break;
-		case TOOL_SCREENSHOT:        tool = new tool_screenshot_t(); break;
-		case TOOL_INCREASE_INDUSTRY: tool = new tool_increase_industry_t(); break;
-		case TOOL_UNDO:              tool = new tool_undo_t(); break;
-		case TOOL_SWITCH_PLAYER:     tool = new tool_switch_player_t(); break;
-		case TOOL_STEP_YEAR:         tool = new tool_step_year_t(); break;
-		case TOOL_CHANGE_GAME_SPEED: tool = new tool_change_game_speed_t(); break;
-		case TOOL_ZOOM_IN:           tool = new tool_zoom_in_t(); break;
-		case TOOL_ZOOM_OUT:          tool = new tool_zoom_out_t(); break;
-		case TOOL_SHOW_COVERAGE:     tool = new tool_show_coverage_t(); break;
-		case TOOL_SHOW_NAME:        tool = new tool_show_name_t(); break;
-		case TOOL_SHOW_GRID:         tool = new tool_show_grid_t(); break;
-		case TOOL_SHOW_TREES:        tool = new tool_show_trees_t(); break;
-		case TOOL_SHOW_HOUSES:       tool = new tool_show_houses_t(); break;
-		case TOOL_SHOW_UNDERGROUND:  tool = new tool_show_underground_t(); break;
-		case TOOL_ROTATE90:          tool = new tool_rotate90_t(); break;
-		case TOOL_QUIT:              tool = new tool_quit_t(); break;
-		case TOOL_FILL_TREES:        tool = new tool_fill_trees_t(); break;
-		case TOOL_DAYNIGHT_LEVEL:    tool = new tool_daynight_level_t(); break;
-		case TOOL_VEHICLE_TOOLTIPS:  tool = new tool_vehicle_tooltips_t(); break;
-		case TOOL_TOOGLE_PAX:        tool = new tool_toggle_pax_station_t(); break;
-		case TOOL_TOOGLE_PEDESTRIANS:tool = new tool_toggle_pedestrians_t(); break;
-		case TOOL_TRAFFIC_LEVEL:     tool = new tool_traffic_level_t(); break;
-		case TOOL_CHANGE_CONVOI:       tool = new tool_change_convoi_t(); break;
-		case TOOL_CHANGE_LINE:         tool = new tool_change_line_t(); break;
-		case TOOL_CHANGE_DEPOT:        tool = new tool_change_depot_t(); break;
-		case UNUSED_WKZ_PWDHASH_TOOL: dbg->warning("create_simple_tool()","deprecated tool [%i] requested", toolnr); return NULL;
-		case TOOL_CHANGE_PLAYER:   tool = new tool_change_player_t(); break;
-		case TOOL_CHANGE_TRAFFIC_LIGHT:tool = new tool_change_traffic_light_t(); break;
-		case TOOL_CHANGE_CITY:  tool = new tool_change_city_t(); break;
-		case TOOL_RENAME:       tool = new tool_rename_t(); break;
-		case TOOL_ADD_MESSAGE:  tool = new tool_add_message_t(); break;
-		case TOOL_TOGGLE_RESERVATION:tool = new tool_toggle_reservation_t(); break;
-		case TOOL_VIEW_OWNER:        tool = new tool_view_owner_t(); break;
-		case TOOL_HIDE_UNDER_CURSOR: tool = new tool_hide_under_cursor_t(); break;
-		default:                    dbg->error("create_simple_tool()","cannot satisfy request for simple_tool[%i]!",toolnr);
-		                            return NULL;
+		case TOOL_PAUSE:                tool = new tool_pause_t();                break;
+		case TOOL_FASTFORWARD:          tool = new tool_fastforward_t();          break;
+		case TOOL_SCREENSHOT:           tool = new tool_screenshot_t();           break;
+		case TOOL_INCREASE_INDUSTRY:    tool = new tool_increase_industry_t();    break;
+		case TOOL_UNDO:                 tool = new tool_undo_t();                 break;
+		case TOOL_SWITCH_PLAYER:        tool = new tool_switch_player_t();        break;
+		case TOOL_STEP_YEAR:            tool = new tool_step_year_t();            break;
+		case TOOL_CHANGE_GAME_SPEED:    tool = new tool_change_game_speed_t();    break;
+		case TOOL_ZOOM_IN:              tool = new tool_zoom_in_t();              break;
+		case TOOL_ZOOM_OUT:             tool = new tool_zoom_out_t();             break;
+		case TOOL_SHOW_COVERAGE:        tool = new tool_show_coverage_t();        break;
+		case TOOL_SHOW_NAME:            tool = new tool_show_name_t();            break;
+		case TOOL_SHOW_GRID:            tool = new tool_show_grid_t();            break;
+		case TOOL_SHOW_TREES:           tool = new tool_show_trees_t();           break;
+		case TOOL_SHOW_HOUSES:          tool = new tool_show_houses_t();          break;
+		case TOOL_SHOW_UNDERGROUND:     tool = new tool_show_underground_t();     break;
+		case TOOL_ROTATE90:             tool = new tool_rotate90_t();             break;
+		case TOOL_QUIT:                 tool = new tool_quit_t();                 break;
+		case TOOL_FILL_TREES:           tool = new tool_fill_trees_t();           break;
+		case TOOL_DAYNIGHT_LEVEL:       tool = new tool_daynight_level_t();       break;
+		case TOOL_VEHICLE_TOOLTIPS:     tool = new tool_vehicle_tooltips_t();     break;
+		case TOOL_TOOGLE_PAX:           tool = new tool_toggle_pax_station_t();   break;
+		case TOOL_TOOGLE_PEDESTRIANS:   tool = new tool_toggle_pedestrians_t();   break;
+		case TOOL_TRAFFIC_LEVEL:        tool = new tool_traffic_level_t();        break;
+		case TOOL_CHANGE_CONVOI:        tool = new tool_change_convoi_t();        break;
+		case TOOL_CHANGE_LINE:          tool = new tool_change_line_t();          break;
+		case TOOL_CHANGE_DEPOT:         tool = new tool_change_depot_t();         break;
+		case TOOL_CHANGE_PLAYER:        tool = new tool_change_player_t();        break;
+		case TOOL_CHANGE_TRAFFIC_LIGHT: tool = new tool_change_traffic_light_t(); break;
+		case TOOL_CHANGE_CITY:          tool = new tool_change_city_t();          break;
+		case TOOL_RENAME:               tool = new tool_rename_t();               break;
+		case TOOL_ADD_MESSAGE:          tool = new tool_add_message_t();          break;
+		case TOOL_TOGGLE_RESERVATION:   tool = new tool_toggle_reservation_t();   break;
+		case TOOL_VIEW_OWNER:           tool = new tool_view_owner_t();           break;
+		case TOOL_HIDE_UNDER_CURSOR:    tool = new tool_hide_under_cursor_t();    break;
+		case UNUSED_WKZ_PWDHASH_TOOL:
+			dbg->warning("create_simple_tool()","deprecated tool [%i] requested", toolnr);
+			return NULL;
+		default:
+			dbg->error("create_simple_tool()","cannot satisfy request for simple_tool[%i]!",toolnr);
+			return NULL;
 	}
+
 	assert(tool->get_id()  ==  (toolnr | SIMPLE_TOOL));
 	return tool;
 }
@@ -182,41 +189,46 @@ tool_t *create_dialog_tool(int toolnr)
 {
 	tool_t* tool = NULL;
 	switch(toolnr) {
-		case DIALOG_HELP:           tool = new dialog_help_t(); break;
-		case DIALOG_OPTIONS:        tool = new dialog_options_t(); break;
-		case DIALOG_MINIMAP:        tool = new dialog_minimap_t(); break;
-		case DIALOG_LINEOVERVIEW:   tool = new dialog_lines_t(); break;
-		case DIALOG_MESSAGES:       tool = new dialog_messages_t(); break;
-		case DIALOG_FINANCES:       tool = new dialog_finances_t(); break;
-		case DIALOG_PLAYERS:        tool = new dialog_players_t(); break;
-		case DIALOG_DISPLAYOPTIONS: tool = new dialog_displayoptions_t(); break;
-		case DIALOG_SOUND:          tool = new dialog_sound_t(); break;
-		case DIALOG_LANGUAGE:       tool = new dialog_language_t(); break;
-		case DIALOG_PLAYERCOLOR:    tool = new dialog_playercolor_t(); break;
-		case DIALOG_JUMP:           tool = new dialog_jump_t(); break;
-		case DIALOG_LOAD:           tool = new dialog_load_t(); break;
-		case DIALOG_SAVE:           tool = new dialog_save_t(); break;
-		case DIALOG_LIST_HALT:      tool = new dialog_list_halt_t(); break;
-		case DIALOG_LIST_CONVOI:    tool = new dialog_list_convoi_t(); break;
-		case DIALOG_LIST_TOWN:      tool = new dialog_list_town_t(); break;
-		case DIALOG_LIST_GOODS:     tool = new dialog_list_goods_t(); break;
-		case DIALOG_LIST_FACTORY:   tool = new dialog_list_factory_t(); break;
-		case DIALOG_LIST_CURIOSITY: tool = new dialog_list_curiosity_t(); break;
-		case DIALOG_EDIT_FACTORY:   tool = new dialog_edit_factory_t(); break;
-		case DIALOG_EDIT_ATTRACTION:tool = new dialog_edit_attraction_t(); break;
-		case DIALOG_EDIT_HOUSE:     tool = new dialog_edit_house_t(); break;
-		case DIALOG_EDIT_TREE:      tool = new dialog_edit_tree_t(); break;
-		case DIALOG_ENLARGE_MAP:    tool = new dialog_enlarge_map_t(); break;
-		case DIALOG_LIST_LABEL:     tool = new dialog_list_label_t(); break;
-		case DIALOG_CLIMATES:       tool = new dialog_climates_t(); break;
-		case DIALOG_SETTINGS:       tool = new dialog_settings_t(); break;
-		case DIALOG_GAMEINFO:       tool = new dialog_gameinfo_t(); break;
-		case DIALOG_THEMES:         tool = new dialog_themes_t(); break;
-		case DIALOG_SCENARIO:       tool = new dialog_scenario_t(); break;
-		case DIALOG_SCENARIO_INFO:  tool = new dialog_scenario_info_t(); break;
-		default:                 dbg->error("create_dialog_tool()","cannot satisfy request for dialog_tool[%i]!",toolnr);
-		                         return NULL;
+		case DIALOG_HELP:            tool = new dialog_help_t();            break;
+		case DIALOG_OPTIONS:         tool = new dialog_options_t();         break;
+		case DIALOG_MINIMAP:         tool = new dialog_minimap_t();         break;
+		case DIALOG_LINEOVERVIEW:    tool = new dialog_lines_t();           break;
+		case DIALOG_MESSAGES:        tool = new dialog_messages_t();        break;
+		case DIALOG_FINANCES:        tool = new dialog_finances_t();        break;
+		case DIALOG_PLAYERS:         tool = new dialog_players_t();         break;
+		case DIALOG_DISPLAYOPTIONS:  tool = new dialog_displayoptions_t();  break;
+		case DIALOG_SOUND:           tool = new dialog_sound_t();           break;
+		case DIALOG_LANGUAGE:        tool = new dialog_language_t();        break;
+		case DIALOG_PLAYERCOLOR:     tool = new dialog_playercolor_t();     break;
+		case DIALOG_JUMP:            tool = new dialog_jump_t();            break;
+		case DIALOG_LOAD:            tool = new dialog_load_t();            break;
+		case DIALOG_SAVE:            tool = new dialog_save_t();            break;
+		case DIALOG_LIST_HALT:       tool = new dialog_list_halt_t();       break;
+		case DIALOG_LIST_CONVOI:     tool = new dialog_list_convoi_t();     break;
+		case DIALOG_LIST_TOWN:       tool = new dialog_list_town_t();       break;
+		case DIALOG_LIST_GOODS:      tool = new dialog_list_goods_t();      break;
+		case DIALOG_LIST_FACTORY:    tool = new dialog_list_factory_t();    break;
+		case DIALOG_LIST_CURIOSITY:  tool = new dialog_list_curiosity_t();  break;
+		case DIALOG_EDIT_FACTORY:    tool = new dialog_edit_factory_t();    break;
+		case DIALOG_EDIT_ATTRACTION: tool = new dialog_edit_attraction_t(); break;
+		case DIALOG_EDIT_HOUSE:      tool = new dialog_edit_house_t();      break;
+		case DIALOG_EDIT_TREE:       tool = new dialog_edit_tree_t();       break;
+		case DIALOG_ENLARGE_MAP:     tool = new dialog_enlarge_map_t();     break;
+		case DIALOG_LIST_LABEL:      tool = new dialog_list_label_t();      break;
+		case DIALOG_CLIMATES:        tool = new dialog_climates_t();        break;
+		case DIALOG_SETTINGS:        tool = new dialog_settings_t();        break;
+		case DIALOG_GAMEINFO:        tool = new dialog_gameinfo_t();        break;
+		case DIALOG_THEMES:          tool = new dialog_themes_t();          break;
+		case DIALOG_SCENARIO:        tool = new dialog_scenario_t();        break;
+		case DIALOG_SCENARIO_INFO:   tool = new dialog_scenario_info_t();   break;
+		case DIALOG_LIST_DEPOT:      tool = new dialog_list_depot_t();      break;
+		case DIALOG_LIST_VEHICLE:    tool = new dialog_list_vehicle_t();    break;
+		case DIALOG_SCRIPT_TOOL:     tool = new dialog_script_tool_t();     break;
+		default:
+			dbg->error("create_dialog_tool()","cannot satisfy request for dialog_tool[%i]!",toolnr);
+			return NULL;
 	}
+
 	assert(tool->get_id() == (toolnr | DIALOGE_TOOL));
 	return tool;
 }
@@ -888,6 +900,13 @@ void toolbar_t::update(player_t *player)
 					waytype_t way = (waytype_t)(*c!=0 ? atoi(++c) : 0);
 					hausbauer_t::fill_menu( tool_selector, utype, way, get_sound(c));
 				}
+				else if (char const* const c = strstart(param, "scripts(")) {
+					const char* end = strchr(c, ')');
+					char buf[1000];
+					size_t len = end ? min(lengthof(buf)-1, end-c) : lengthof(buf)-1;
+					tstrncpy(buf, c, len+1);
+					script_tool_manager_t::fill_menu(tool_selector, buf, get_sound(c));
+				}
 				else if (param[0] == '-') {
 					// add dummy tool_t as seperator
 					tool_selector->add_tool_selector( dummy );
@@ -1052,7 +1071,7 @@ bool two_click_tool_t::is_work_here_network_save(player_t *player, koord3d pos )
 	if(  !is_first_click()  ) {
 		return false;
 	}
-	const char *error = "";	//default: nosound
+	const char *error = ""; //default: nosound
 	uint8 value = is_valid_pos( player, pos, error, koord3d::invalid );
 	DBG_MESSAGE("two_click_tool_t::is_work_here_network_save", "Position %s valid=%d", pos.get_str(), value );
 	if(  value == 0  ) {
@@ -1081,7 +1100,7 @@ const char *two_click_tool_t::work(player_t *player, koord3d pos )
 	// remove marker
 	cleanup( true );
 
-	const char *error = "";	//default: nosound
+	const char *error = NULL;
 	uint8 value = is_valid_pos( player, pos, error, !is_first_click() ? start : koord3d::invalid );
 	DBG_MESSAGE("two_click_tool_t::work", "Position %s valid=%d", pos.get_str(), value );
 	if(  value == 0  ) {
@@ -1104,6 +1123,7 @@ const char *two_click_tool_t::work(player_t *player, koord3d pos )
 			// set starting position.
 			DBG_MESSAGE("two_click_tool_t::work", "Setting start to %s", pos.get_str() );
 			start_at( pos );
+			error = NULL;
 		}
 	}
 	else {
@@ -1209,7 +1229,7 @@ void two_click_tool_t::cleanup( bool delete_start_marker )
 }
 
 
-image_id two_click_tool_t::get_marker_image()
+image_id two_click_tool_t::get_marker_image() const
 {
 	return skinverwaltung_t::bauigelsymbol->get_image_id(0);
 }
