@@ -1,10 +1,6 @@
 /*
- * Manages all gameplay-related messages of the games
- *
- * Copyright (c) 2005 Markus Pristovsek
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "macros.h"
@@ -25,6 +21,8 @@
 #include <string.h>
 
 
+#define MAX_SAVED_MESSAGES (2000)
+
 karte_ptr_t message_t::welt;
 
 void message_t::node::rdwr(loadsave_t *file)
@@ -54,7 +52,7 @@ FLAGGED_PIXVAL message_t::node::get_player_color(karte_t *welt) const
 	FLAGGED_PIXVAL colorval = color;
 	if(  color&PLAYER_FLAG  ) {
 		player_t *player = welt->get_player(color&(~PLAYER_FLAG));
-		colorval = player ? PLAYER_FLAG+color_idx_to_rgb(player->get_player_color1()+1) : color_idx_to_rgb(MN_GREY0);
+		colorval = player ? PLAYER_FLAG+color_idx_to_rgb(player->get_player_color1()+env_t::gui_player_color_dark) : color_idx_to_rgb(MN_GREY0);
 	}
 	return colorval;
 }
@@ -62,7 +60,7 @@ FLAGGED_PIXVAL message_t::node::get_player_color(karte_t *welt) const
 
 message_t::message_t()
 {
-	ticker_flags = 0xFF7F;	// everything on the ticker only
+	ticker_flags = 0xFF7F; // everything on the ticker only
 	win_flags = 0;
 	auto_win_flags = 0;
 	ignore_flags = 0;
@@ -113,15 +111,13 @@ void message_t::set_message_flags( sint32 t, sint32 w, sint32 a, sint32 i)
  * @param color  message color
  * @param where type of message
  * @param image image associated with message (will be ignored if pos!=koord::invalid)
- * @author prissi
  */
 void message_t::add_message(const char *text, koord pos, uint16 what_flags, FLAGGED_PIXVAL color, image_id image )
 {
 DBG_MESSAGE("message_t::add_msg()","%40s (at %i,%i)", text, pos.x, pos.y );
 
-	sint32 what = what_flags & ~local_flag;
-	sint32 art = (1<<what);
-	if(  art&ignore_flags  ) {
+	sint32 what_bit = 1<<(what_flags & ~(do_not_rdwr_flag|playermsg_flag|expire_after_one_month_flag));
+	if(  what_bit&ignore_flags  ) {
 		// wants us to ignore this completely
 		return;
 	}
@@ -131,7 +127,7 @@ DBG_MESSAGE("message_t::add_msg()","%40s (at %i,%i)", text, pos.x, pos.y );
 	 * or within last months
 	 * and is not a general (BLACK) message
 	 */
-	if(  what == traffic_jams  ) {
+	if(  what_bit == (1<<traffic_jams)  ) {
 		sint32 now = welt->get_current_month()-2;
 		uint32 i = 0;
 		FOR(slist_tpl<node*>, const iter, list) {
@@ -148,7 +144,7 @@ DBG_MESSAGE("message_t::add_msg()","%40s (at %i,%i)", text, pos.x, pos.y );
 	}
 
 	// filter out AI messages for a similar area to recent activity messages
-	if(  what == ai  &&  pos != koord::invalid  ) {
+	if(  what_bit == (1<<ai)  &&  pos != koord::invalid  &&  env_t::networkmode  ) {
 		uint32 i = 0;
 		FOR(slist_tpl<node*>, const iter, list) {
 			node const& n = *iter;
@@ -178,7 +174,7 @@ DBG_MESSAGE("message_t::add_msg()","%40s (at %i,%i)", text, pos.x, pos.y );
 
 	FLAGGED_PIXVAL colorval = n->get_player_color(welt);
 	// should we send this message to a ticker?
-	if(  art&ticker_flags  ) {
+	if(  what_bit&ticker_flags  ) {
 		ticker::add_msg(text, pos, colorval);
 	}
 
@@ -186,29 +182,29 @@ DBG_MESSAGE("message_t::add_msg()","%40s (at %i,%i)", text, pos.x, pos.y );
 	list.insert(n);
 	char* p = list.front()->msg;
 
-	// if local flag is set and we are not current player, do not open windows
-	if(  (art&(1<<ai))==0  &&   (color & PLAYER_FLAG) != 0  &&  welt->get_active_player_nr() != (color&(~PLAYER_FLAG))  ) {
+	// if we are not current player, do not open windows
+	if(  (what_bit&(1<<ai))==0  &&   (color & PLAYER_FLAG) != 0  &&  welt->get_active_player_nr() != (color&(~PLAYER_FLAG))  ) {
 		return;
 	}
 	// check if some window has focus
 	gui_frame_t *old_top = win_get_top();
-	gui_component_t *focus = win_get_focus();
 
 	// should we open a window?
-	if (  art & (auto_win_flags | win_flags)  ) {
+	if (  what_bit & (auto_win_flags | win_flags)  ) {
 		news_window* news;
 		if (pos == koord::invalid) {
 			news = new news_img(p, image, colorval);
-		} else {
+		}
+		else {
 			news = new news_loc(p, pos, colorval);
 		}
-		wintype w_t = art & win_flags ? w_info /* normal window */ : w_time_delete /* autoclose window */;
+		wintype w_t = what_bit & win_flags ? w_info /* normal window */ : w_time_delete /* autoclose window */;
 
 		create_win(  news, w_t, magic_none );
 	}
 
 	// restore focus
-	if(  old_top  &&  focus  ) {
+	if(  old_top    ) {
 		top_win( old_top, true );
 	}
 }
@@ -246,31 +242,41 @@ void message_t::rdwr( loadsave_t *file )
 {
 	uint16 msg_count;
 	if(  file->is_saving()  ) {
-		if(  env_t::server  ) {
-			// on server: do not save local messages
-			msg_count = 0;
+		msg_count = 0;
+		if( env_t::server ) {
+			// do not save local messages and expired messages
+			uint32 current_time = world()->get_current_month();
 			FOR(slist_tpl<node*>, const i, list) {
-				if (!(i->type & local_flag)) {
-					if (++msg_count == 2000) break;
+				if( i->type & do_not_rdwr_flag  ||  (i->type & expire_after_one_month_flag  &&  current_time - i->time > 1)  ) {
+					continue;
+				}
+				if (++msg_count == MAX_SAVED_MESSAGES) break;
+			}
+			file->rdwr_short( msg_count );
+			FOR(slist_tpl<node*>, const i, list) {
+				if (msg_count == 0) break;
+				if(  i->type & do_not_rdwr_flag  || (i->type & expire_after_one_month_flag  &&  current_time - i->time > 1)  ) {
+					continue;
+				}
+				i->rdwr(file);
+				msg_count --;
+			}
+		}
+		else {
+			// do not save discardable messages (like changing player)
+			FOR(slist_tpl<node*>, const i, list) {
+				if (!(i->type & do_not_rdwr_flag)) {
+					if (++msg_count == MAX_SAVED_MESSAGES) break;
 				}
 			}
 			file->rdwr_short( msg_count );
 			FOR(slist_tpl<node*>, const i, list) {
 				if (msg_count == 0) break;
-				if (!(i->type & local_flag)) {
+				if(  !(i->type & do_not_rdwr_flag)  ) {
 					i->rdwr(file);
 					msg_count --;
 				}
 			}
-			assert( msg_count == 0 );
-		}
-		else {
-			msg_count = min( 2000u, list.get_count() );
-			file->rdwr_short( msg_count );
-			FOR(slist_tpl<node*>, const i, list) {
-				i->rdwr(file);
-				if (--msg_count == 0) break;
-			}
 		}
 	}
 	else {
