@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -210,7 +208,7 @@ void pedestrian_t::generate_pedestrians_at(const koord3d k, int &count)
 			// we create maximal 4 pedestrians here for performance reasons
 			for (int i = 0; i < 4 && count > 0; i++) {
 				pedestrian_t* fg = new pedestrian_t(bd);
-				bool ok = bd->obj_add(fg) != 0;	// 256 limit reached
+				bool ok = bd->obj_add(fg) != 0; // 256 limit reached
 				if (ok) {
 					fg->calc_height(bd);
 					if (i > 0) {
@@ -384,3 +382,15 @@ void pedestrian_t::info(cbuffer_t & buf) const
 		buf.printf(translator::translate("Constructed by %s"), maker);
 	}
 }
+
+
+void *pedestrian_t::operator new(size_t /*s*/)
+{
+	return freelist_t::gimme_node(sizeof(pedestrian_t));
+}
+
+
+void pedestrian_t::operator delete(void *p)
+{
+	freelist_t::putback_node(sizeof(pedestrian_t),p);
+}
