@@ -1,11 +1,6 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
- *
- * Renovation in dec 2004 for other vehicles, timeline
- * @author prissi
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -41,6 +36,8 @@
 #include "../dataobj/translator.h"
 #include "../dataobj/environment.h"
 
+#include "../network/network_socket_list.h"
+
 #include "../obj/bruecke.h"
 #include "../obj/gebaeude.h"
 #include "../obj/leitung2.h"
@@ -70,8 +67,8 @@ player_t::player_t(uint8 nr) :
 	finance = new finance_t(this, welt);
 	player_nr = nr;
 	player_age = 0;
-	active = false;		// Don't start as an AI player
-	locked = false;			// allowed to change anything
+	active = false; // Don't start as an AI player
+	locked = false; // allowed to change anything
 	unlock_pending = false;
 
 	headquarter_pos = koord::invalid;
@@ -130,7 +127,7 @@ void player_t::add_money_message(const sint64 amount, const koord pos)
 
 			// and same for sound too ...
 			if(  amount>=10000  &&  !welt->is_fast_forward()  ) {
-				welt->play_sound_area_clipped(pos, SFX_CASH);
+				welt->play_sound_area_clipped(pos, SFX_CASH, CASH_SOUND );
 			}
 		}
 	}
@@ -292,8 +289,6 @@ bool player_t::new_month()
 
 	finance->calc_finance_history();
 
-	simlinemgmt.new_month();
-
 	// Bankrupt ?
 	if(  finance->get_account_balance() < 0  ) {
 		finance->increase_account_overdrawn();
@@ -374,6 +369,11 @@ bool player_t::new_month()
 			}
 			// never changed convoi, never built => abandoned
 			if(  abandoned  ) {
+				if (env_t::server) {
+					// server: unlock this player for all clients
+					socket_list_t::unlock_player_all(player_nr, true);
+				}
+				// clients: local unlock
 				pwd_hash.clear();
 				locked = false;
 				unlock_pending = false;
@@ -381,8 +381,12 @@ bool player_t::new_month()
 		}
 	}
 
+	// update line info
+	simlinemgmt.new_month();
+
 	// subtract maintenance after bankruptcy check
 	finance->book_account( -finance->get_maintenance_with_bits(TT_ALL) );
+
 	// company gets older ...
 	player_age ++;
 
@@ -807,7 +811,7 @@ DBG_MESSAGE("player_t::report_vehicle_problem","Vehicle %s, state %i!", cnv->get
 void player_t::init_undo( waytype_t wtype, unsigned short max )
 {
 	// only human player
-	// prissi: allow for UNDO for real player
+	// allow for UNDO for real player
 DBG_MESSAGE("player_t::int_undo()","undo tiles %i",max);
 	last_built.clear();
 	last_built.resize(max+1);
@@ -909,12 +913,12 @@ void player_t::tell_tool_result(tool_t *tool, koord3d, const char *err)
 	if (welt->get_active_player()==this) {
 		if(err==NULL) {
 			if(tool->ok_sound!=NO_SOUND) {
-				sound_play(tool->ok_sound);
+				sound_play(tool->ok_sound,255,TOOL_SOUND);
 			}
 		}
 		else if(*err!=0) {
 			// something went really wrong
-			sound_play(SFX_FAILURE);
+			sound_play( SFX_FAILURE, 255, TOOL_SOUND );
 			// look for coordinate in error message
 			// syntax: either @x,y or (x,y)
 			open_error_msg_win(err);
