@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include "simstring.h"
 
 #include <assert.h>
@@ -8,14 +13,13 @@
 static char thousand_sep = ',';
 static char fraction_sep = '.';
 static const char *large_number_string = "M";
-static double large_number_factor = 1e99;	// off
+static double large_number_factor = 1e99; // off
 static int thousand_sep_exponent = 3;
 
 
 /**
  * Set thousand separator, used in money_to_string and
  * number_to_string
- * @author Hj. Malthaner
  */
 void set_thousand_sep(char c)
 {
@@ -26,7 +30,6 @@ void set_thousand_sep(char c)
 /**
  * Set thousand exponent (3=1000, 4=10000), used in money_to_string and
  * number_to_string
- * @author prissi
  */
 void set_thousand_sep_exponent(int new_thousand_sep_exponent)
 {
@@ -34,10 +37,10 @@ void set_thousand_sep_exponent(int new_thousand_sep_exponent)
 }
 
 
+
 /**
  * Set fraction separator, used in money_to_string and
  * number_to_string
- * @author Hj. Malthaner
  */
 void set_fraction_sep(char c)
 {
@@ -59,7 +62,6 @@ const char *get_large_money_string()
 /**
  * Set large money abbreviation, used in money_to_string and
  * number_to_string
- * @author prissi
  */
 void set_large_amout(const char *s, const double v)
 {
@@ -72,7 +74,6 @@ void set_large_amout(const char *s, const double v)
  * Formats a money value. Uses thousand separator. Two digits precision.
  * Concludes format with $ sign. Buffer must be large enough, no checks
  * are made!
- * @author Hj. Malthaner
  */
 void money_to_string(char * p, double f, const bool show_decimal)
 {
@@ -87,12 +88,12 @@ void money_to_string(char * p, double f, const bool show_decimal)
 		sprintf( tp, "%.2f", f );
 	}
 
-	// Hajo: skip sign
+	// skip sign
 	if(*tp == '-') {
 		*p ++ = *tp++;
 	}
 
-	// Hajo: format string
+	// format string
 	l = (long)(size_t)(strchr(tp,'.') - tp);
 
 	i = l % thousand_sep_exponent;
@@ -148,12 +149,12 @@ int number_to_string(char * p, double f, int decimals  )
 		has_decimals = strchr(tp,'.')!=NULL;
 	}
 
-	// Hajo: skip sign
+	// skip sign
 	if(*tp == '-') {
 		*p ++ = *tp++;
 	}
 
-	// Hajo: format string
+	// format string
 	l = has_decimals ? (long)(size_t)(strchr(tp,'.') - tp) : strlen(tp);
 
 	i = l % thousand_sep_exponent;
@@ -225,8 +226,7 @@ void number_to_string_fit(char *ret, double f, int decimals, int max_length )
 
 
 
-// copies a n into a single line and maximum 128 characters
-// @author prissi
+/// copies a n into a single line and maximum 128 characters
 char *make_single_line_string(const char *in,int number_of_lines)
 {
 	static char buf[64];
@@ -268,10 +268,15 @@ char *make_single_line_string(const char *in,int number_of_lines)
  * Terminated, length limited string copy. Copies at most
  * n characters. Terminates dest string always by 0.
  * @return dest
- * @author Hj. Malthaner
  */
 char *tstrncpy(char *dest, const char *src, size_t n)
 {
+	if (dest == src) {
+		// source and destination are the same
+		// avoid copying overlapping memory regions
+		return dest;
+	}
+
 	strncpy(dest, src, n);
 	dest[n-1] = '\0';
 
@@ -282,7 +287,6 @@ char *tstrncpy(char *dest, const char *src, size_t n)
 /**
  * Removes whitespace from the end of the string.
  * Modifies the argument!
- * @author Hj. Malthaner
  */
 void rtrim(char * buf)
 {
@@ -295,7 +299,6 @@ void rtrim(char * buf)
 /**
  * Hands back a pointer to the first non-whitespace character
  * of the argument. The argument must be 0 terminated
- * @author Hj. Malthaner
  */
 const char * ltrim(const char *p)
 {
@@ -309,8 +312,6 @@ const char * ltrim(const char *p)
 /**
  * Trims a std::string by removing any beginning and ending space/tab characters.
  * (Move to simstring?)
- * @author  Max Kielland
- *
  * @retval std::string  The trimmed string.
  */
 std::string trim(const std::string &str_)
