@@ -1,11 +1,10 @@
 /*
- * Interface to connect the vehicle with its route
- *
- * 15.01.00, Hj. Malthaner
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef SIMTESTDRIVER_H
-#define SIMTESTDRIVER_H
+#ifndef IFC_SIMTESTDRIVER_H
+#define IFC_SIMTESTDRIVER_H
 
 
 class grund_t;
@@ -13,8 +12,6 @@ class weg_t;
 
 /**
  * Interface to connect the vehicle with its route
- *
- * @author Hj. Malthaner, 15.01.00
  */
 class test_driver_t
 {
@@ -26,8 +23,6 @@ public:
 	/**
 	 * Determine the direction bits (ribi) for the applicable vehicle,
 	 * Depends of the ground type.
-	 *
-	 * @author Hj. Malthaner, 03.01.01
 	 */
 	virtual ribi_t::ribi get_ribi(const grund_t* ) const = 0;
 
