@@ -1,15 +1,12 @@
 /*
-* This file is part of the Simutrans project under the artistic license.
-*/
-
-/* New OO tool system
-*
-* contains tools that will open windows
-*/
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
 
 #ifndef SIMTOOL_DIALOGS_H
 #define SIMTOOL_DIALOGS_H
 
+
 #include "simmenu.h"
 #include "gui/simwin.h"
 
@@ -49,6 +46,9 @@
 #include "gui/themeselector.h"
 #include "gui/scenario_frame.h"
 #include "gui/scenario_info.h"
+#include "gui/depotlist_frame.h"
+#include "gui/vehiclelist_frame.h"
+#include "gui/script_tool_frame.h"
 
 class player_t;
 
@@ -65,8 +65,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_mainhelp); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open info/quit dialog
@@ -80,8 +80,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_optionen_gui_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open minimap
@@ -95,8 +95,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_reliefmap); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open line management
@@ -113,8 +113,8 @@ public:
 		return false;
 	}
 	bool exit(player_t* const player) OVERRIDE{ destroy_win(win_get_magic(magic_line_management_t + player->get_player_nr())); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open messages
@@ -128,8 +128,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_messageframe); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open finance window
@@ -143,8 +143,8 @@ public:
 		return false;
 	}
 	bool exit(player_t* const player) OVERRIDE{ destroy_win(magic_finances_t + player->get_player_nr()); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open player dialog
@@ -158,8 +158,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_ki_kontroll_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open display options
@@ -173,8 +173,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_color_gui_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open sound dialog
@@ -188,8 +188,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_sound_kontroll_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open language dialog
@@ -203,8 +203,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_sprachengui_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // open player color dialog
@@ -218,8 +218,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_farbengui_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // jump to position dialog
@@ -233,8 +233,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_jump); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // load game dialog
@@ -257,7 +257,7 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_load_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
 };
 
 // save game dialog
@@ -271,7 +271,22 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_save_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+};
+
+// open scripted-tools dialog
+class dialog_script_tool_t : public tool_t {
+public:
+	dialog_script_tool_t() : tool_t(DIALOG_SCRIPT_TOOL | DIALOGE_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Load tool script"); }
+	bool is_selected() const OVERRIDE{ return win_get_magic(magic_load_t); }
+	bool init(player_t*) OVERRIDE{
+		destroy_win(magic_save_t);
+		create_win( new script_tool_frame_t(), w_info, magic_load_t );
+		return false;
+	}
+	bool exit(player_t*) OVERRIDE{ destroy_win(magic_load_t); return false; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
 };
 
 // open scenario dialog
@@ -294,7 +309,7 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_load_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
 };
 
 // open scenario info dialog
@@ -309,7 +324,7 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_scenario_info); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open the list of halt */
@@ -317,14 +332,14 @@ class dialog_list_halt_t : public tool_t {
 public:
 	dialog_list_halt_t() : tool_t(DIALOG_LIST_HALT | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("hl_title"); }
-	bool is_selected() const OVERRIDE{ return win_get_magic(magic_halt_list_t); }
+	bool is_selected() const OVERRIDE{ return win_get_magic(magic_halt_list_t + welt->get_active_player_nr()); }
 	bool init(player_t* player) OVERRIDE{
-		create_win(new halt_list_frame_t(player), w_info, magic_halt_list_t);
+		create_win(new halt_list_frame_t(player), w_info, magic_halt_list_t + player->get_player_nr());
 		return false;
 	}
-	bool exit(player_t*) OVERRIDE{ destroy_win(magic_halt_list_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool exit(player_t* player) OVERRIDE{ destroy_win(magic_halt_list_t + player->get_player_nr()); return false; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open the list of vehicle */
@@ -332,14 +347,46 @@ class dialog_list_convoi_t : public tool_t {
 public:
 	dialog_list_convoi_t() : tool_t(DIALOG_LIST_CONVOI | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("cl_title"); }
+	image_id get_icon(player_t*) const OVERRIDE{ return welt->get_active_player_nr() == 1 ? IMG_EMPTY : icon; }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_convoi_list + welt->get_active_player_nr()); }
 	bool init(player_t* player) OVERRIDE{
 		create_win(new convoi_frame_t(player), w_info, magic_convoi_list + player->get_player_nr());
 		return false;
 	}
 	bool exit(player_t* const player) OVERRIDE{ destroy_win(magic_convoi_list + player->get_player_nr()); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
+};
+
+/* open the list of depots */
+class dialog_list_depot_t : public tool_t {
+public:
+	dialog_list_depot_t() : tool_t(DIALOG_LIST_DEPOT | DIALOGE_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("dp_title"); }
+	bool is_selected() const OVERRIDE{ return win_get_magic(magic_depotlist + welt->get_active_player_nr()); }
+	image_id get_icon(player_t*) const OVERRIDE{ return welt->get_active_player_nr() == 1 ? IMG_EMPTY : icon; }
+	bool init(player_t* player) OVERRIDE{
+		create_win(new depotlist_frame_t(player), w_info, magic_depotlist + player->get_player_nr());
+		return false;
+	}
+	bool exit(player_t* player) OVERRIDE{ destroy_win(magic_depotlist + player->get_player_nr()); return false; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
+};
+
+/* open the list of vehicles */
+class dialog_list_vehicle_t : public tool_t {
+public:
+	dialog_list_vehicle_t() : tool_t(DIALOG_LIST_VEHICLE | DIALOGE_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("vh_title"); }
+	bool is_selected() const OVERRIDE{ return win_get_magic(magic_vehiclelist); }
+	bool init(player_t*) OVERRIDE{
+		create_win(new vehiclelist_frame_t(), w_info, magic_vehiclelist);
+		return false;
+	}
+	bool exit(player_t*) OVERRIDE{ destroy_win(magic_vehiclelist); return false; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open the list of towns */
@@ -353,8 +400,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_citylist_frame_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open the list of goods */
@@ -368,8 +415,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_goodslist); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open the list of factories */
@@ -383,8 +430,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_factorylist); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open the list of attraction */
@@ -398,8 +445,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_curiositylist); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* factory building dialog */
@@ -415,8 +462,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_edit_factory); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* attraction building dialog */
@@ -432,8 +479,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_edit_attraction); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* house building dialog */
@@ -449,8 +496,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_edit_house); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* tree placing dialog */
@@ -467,8 +514,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_edit_tree); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 // to increase map-size
@@ -499,8 +546,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_labellist); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open climate settings */
@@ -546,8 +593,8 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_server_frame_t); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 
 /* open themes selector settings */
@@ -561,7 +608,7 @@ public:
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_themes); return false; }
-	bool is_init_network_save() const OVERRIDE{ return true; }
-	bool is_work_network_save() const OVERRIDE{ return true; }
+	bool is_init_network_safe() const OVERRIDE{ return true; }
+	bool is_work_network_safe() const OVERRIDE{ return true; }
 };
 #endif
