@@ -1,12 +1,14 @@
 /*
- * New OO tool system
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #ifndef SIMTOOL_H
 #define SIMTOOL_H
 
+
+/// New OO tool system
+
 #include "simtypes.h"
 #include "simworld.h"
 #include "simmenu.h"
@@ -47,8 +49,8 @@ public:
 	tool_query_t() : tool_t(TOOL_QUERY | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Abfrage"); }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 
@@ -60,7 +62,7 @@ public:
 	tool_remover_t() : tool_t(TOOL_REMOVER | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Abriss"); }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 // alter land height tools
@@ -84,12 +86,12 @@ public:
 	char const* move(player_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
 	bool move_has_effects() const OVERRIDE { return true; }
 
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	/**
 	 * work() is only called when not dragging
 	 * if work() is called with is_dragging==true then is_dragging is reset
 	 */
-	bool is_work_network_save() const OVERRIDE { return is_dragging;}
+	bool is_work_network_safe() const OVERRIDE { return is_dragging;}
 
 	/**
 	 * @return true if this tool operates over the grid, not the map tiles.
@@ -120,28 +122,30 @@ public:
 /* slope tool definitions */
 class tool_setslope_t : public tool_t {
 public:
-	tool_setslope_t() : tool_t(TOOL_SETSLOPE | GENERAL_TOOL) {}
+	tool_setslope_t() : tool_t(TOOL_SETSLOPE | GENERAL_TOOL), old_slope_compatibility_mode(true) {}
+	// if true then slope by default_param will be translated to new double-height system
+	// true by default, can be set to false (used for scripts)
+	bool old_slope_compatibility_mode;
 	/**
 	 * Create an artificial slope
 	 * @param player the player doing the task
 	 * @param pos position where the slope will be generated
 	 * @param slope the slope type
-	 * @author Hj. Malthaner
 	 */
-	static const char *tool_set_slope_work( player_t *player, koord3d pos, int slope );
+	static const char *tool_set_slope_work( player_t *player, koord3d pos, int slope, bool old_slope_compatibility, bool just_check = false);
 	char const* get_tooltip(player_t const*) const OVERRIDE { return tooltip_with_price("Built artifical slopes", welt->get_settings().cst_set_slope); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	char const* check_pos(player_t*, koord3d) OVERRIDE;
-	char const* work(player_t* const player, koord3d const k) OVERRIDE { return tool_set_slope_work(player, k, atoi(default_param)); }
+	char const* work(player_t* const player, koord3d const k) OVERRIDE { return tool_set_slope_work(player, k, atoi(default_param), old_slope_compatibility_mode); }
 };
 
 class tool_restoreslope_t : public tool_t {
 public:
 	tool_restoreslope_t() : tool_t(TOOL_RESTORESLOPE | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return tooltip_with_price("Restore natural slope", welt->get_settings().cst_set_slope); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	char const* check_pos(player_t*, koord3d) OVERRIDE;
-	char const* work(player_t* const player, koord3d const k) OVERRIDE { return tool_setslope_t::tool_set_slope_work(player, k, RESTORE_SLOPE); }
+	char const* work(player_t* const player, koord3d const k) OVERRIDE { return tool_setslope_t::tool_set_slope_work(player, k, RESTORE_SLOPE, true); }
 };
 
 class tool_marker_t : public kartenboden_tool_t {
@@ -149,7 +153,7 @@ public:
 	tool_marker_t() : kartenboden_tool_t(TOOL_MARKER | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return tooltip_with_price("Marker", welt->get_settings().cst_buy_land); }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_clear_reservation_t : public tool_t {
@@ -159,7 +163,7 @@ public:
 	bool init(player_t*) OVERRIDE;
 	bool exit(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_transformer_t : public kartenboden_tool_t {
@@ -172,7 +176,7 @@ public:
 	bool init(player_t*) OVERRIDE;
 	char const* check_pos(player_t*, koord3d) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE { return powerline_wt; }
 };
 
@@ -181,7 +185,7 @@ public:
 	tool_add_city_t() : kartenboden_tool_t(TOOL_ADD_CITY | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return tooltip_with_price("Found new city", welt->get_settings().cst_found_city); }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 // buy a house to protect it from renovating
@@ -190,7 +194,7 @@ public:
 	tool_buy_house_t() : kartenboden_tool_t(TOOL_BUY_HOUSE | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Haus kaufen"); }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 /************** the following tools need a valid default_param ************************/
 
@@ -201,7 +205,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate( atoi(default_param)>=0 ? "Grow city" : "Shrink city" ); }
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 // height change by default_param
@@ -212,7 +216,7 @@ public:
 	bool init(player_t*) OVERRIDE;
 	image_id get_icon(player_t *player) const OVERRIDE { return (!env_t::networkmode  ||  player->is_public_service()) ? icon : IMG_EMPTY; }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 // height change by default_param
@@ -224,7 +228,7 @@ private:
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	uint8 is_valid_pos(player_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_plant_tree_t : public kartenboden_tool_t {
@@ -236,7 +240,7 @@ public:
 	char const* move(player_t* const player, uint16 const b, koord3d const k) OVERRIDE;
 	bool move_has_effects() const OVERRIDE { return true; }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 /* only called directly from schedule => no tooltip!
@@ -246,21 +250,21 @@ class tool_schedule_add_t : public tool_t {
 public:
 	tool_schedule_add_t() : tool_t(TOOL_SCHEDULE_ADD | GENERAL_TOOL) {}
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_schedule_ins_t : public tool_t {
 public:
 	tool_schedule_ins_t() : tool_t(TOOL_SCHEDULE_INS | GENERAL_TOOL) {}
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_build_way_t : public two_click_tool_t {
 private:
-	static const way_desc_t *defaults[17];	// default ways for all types
+	static const way_desc_t *defaults[17]; // default ways for all types
 
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE;
@@ -280,7 +284,7 @@ public:
 	char const* get_default_param(player_t*) const OVERRIDE;
 	bool is_selected() const OVERRIDE;
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 	// remove preview necessary while building elevated ways
 	bool remove_preview_necessary() const OVERRIDE { return !is_first_click()  &&  (desc  &&  (desc->get_styp() == type_elevated  &&  desc->get_wtyp() != air_wt)); }
@@ -294,7 +298,7 @@ public:
 	way_desc_t const* get_desc(uint16, bool) const OVERRIDE;
 	image_id get_icon(player_t* const player) const OVERRIDE { return tool_t::get_icon(player); }
 	bool is_selected() const OVERRIDE { return tool_t::is_selected(); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE { return road_wt; }
 };
 
@@ -309,7 +313,7 @@ public:
 	tool_build_bridge_t() : two_click_tool_t(TOOL_BUILD_BRIDGE | GENERAL_TOOL) {}
 	image_id get_icon(player_t*) const OVERRIDE { return grund_t::underground_mode==grund_t::ugm_all ? IMG_EMPTY : icon; }
 	char const* get_tooltip(player_t const*) const OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 	bool remove_preview_necessary() const OVERRIDE { return !is_first_click(); }
 	void rdwr_custom_data(memory_rw_t*) OVERRIDE;
@@ -326,7 +330,7 @@ public:
 	tool_build_tunnel_t() : two_click_tool_t(TOOL_BUILD_TUNNEL | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	char const* check_pos(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 	bool remove_preview_necessary() const OVERRIDE { return !is_first_click(); }
 	bool init(player_t*) OVERRIDE;
@@ -344,7 +348,7 @@ public:
 	tool_wayremover_t() : two_click_tool_t(TOOL_WAYREMOVER | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	image_id get_icon(player_t*) const OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 };
 
@@ -368,7 +372,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	bool is_selected() const OVERRIDE;
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 };
 
@@ -376,7 +380,7 @@ class tool_remove_wayobj_t : public tool_build_wayobj_t {
 public:
 	tool_remove_wayobj_t() : tool_build_wayobj_t(TOOL_REMOVE_WAYOBJ | GENERAL_TOOL, false) {}
 	bool is_selected() const OVERRIDE { return tool_t::is_selected(); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_build_station_t : public tool_t {
@@ -396,7 +400,7 @@ public:
 	char const* move(player_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
 	bool move_has_effects() const OVERRIDE { return true; }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 };
 
@@ -409,7 +413,7 @@ public:
 	tool_rotate_building_t() : tool_t(TOOL_ROTATE_BUILDING | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Rotate Building"); }
 	char const* work(player_t *, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 // builds roadsigns and signals
@@ -449,7 +453,7 @@ public:
 
 	void set_values(player_t *player, uint8 spacing, bool remove, bool replace );
 	void get_values(player_t *player, uint8 &spacing, bool &remove, bool &replace );
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	void draw_after(scr_coord, bool dirty) const OVERRIDE;
 	void rdwr_custom_data(memory_rw_t*) OVERRIDE;
 	waytype_t get_waytype() const OVERRIDE;
@@ -464,17 +468,17 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	waytype_t get_waytype() const OVERRIDE;
 };
 
-/* builds (random) tourist attraction (default_param==NULL) and maybe adds it to the next city
+/**
+ * builds (random) tourist attraction (default_param==NULL) and maybe adds it to the next city
  * the parameter string is a follow (or NULL):
  * 1#theater
  * first letter: ignore climates
  * second letter: rotation (0,1,2,3,#=random)
  * finally building name
- * @author prissi
  */
 class tool_build_house_t : public kartenboden_tool_t {
 public:
@@ -482,10 +486,11 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Built random attraction"); }
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
-/* builds an (if param=NULL random) industry chain starting here *
+/**
+ * builds an (if param=NULL random) industry chain starting here *
  * the parameter string is a follow (or NULL):
  * 1#34,oelfeld
  * first letter: ignore climates
@@ -500,7 +505,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Build land consumer"); }
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_city_chain_t : public kartenboden_tool_t {
@@ -509,7 +514,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Build city market"); }
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_build_factory_t : public kartenboden_tool_t {
@@ -518,19 +523,19 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Build city market"); }
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_link_factory_t : public two_click_tool_t {
 public:
 	tool_link_factory_t() : two_click_tool_t(TOOL_LINK_FACTORY | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Connect factory"); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 private:
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE {}
 	uint8 is_valid_pos(player_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
-	image_id get_marker_image() OVERRIDE;
+	image_id get_marker_image() const OVERRIDE;
 };
 
 class tool_headquarter_t : public kartenboden_tool_t {
@@ -541,7 +546,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	bool init(player_t*) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 /* protects map from further change (here because two clicks to confirm it!) */
@@ -553,7 +558,7 @@ public:
 	// deactivate in network mode
 	bool init(player_t *) OVERRIDE { return !env_t::networkmode; }
 	const char *work( player_t *, koord3d ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 /* add random citycar if no default is set; else add a certain city car */
@@ -562,7 +567,7 @@ public:
 	tool_add_citycar_t() : tool_t(TOOL_ADD_CITYCAR | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Add random citycar"); }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 /* make forest */
@@ -576,7 +581,7 @@ private:
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	uint8 is_valid_pos(player_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 /* stop moving tool */
@@ -587,13 +592,13 @@ private:
 public:
 	tool_stop_mover_t() : two_click_tool_t(TOOL_STOP_MOVER | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("replace stop"); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 
 private:
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE {}
 	uint8 is_valid_pos(player_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
-	image_id get_marker_image() OVERRIDE;
+	image_id get_marker_image() const OVERRIDE;
 
 	void read_start_position(player_t *player, const koord3d &pos);
 };
@@ -609,7 +614,7 @@ public:
 	char const* move(player_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
 	bool move_has_effects() const OVERRIDE { return true; }
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 };
 
 
@@ -621,12 +626,12 @@ private:
 public:
 	tool_merge_stop_t() : two_click_tool_t(TOOL_MERGE_STOP | GENERAL_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("merge stop"); }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 private:
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	uint8 is_valid_pos(player_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
-	image_id get_marker_image() OVERRIDE;
+	image_id get_marker_image() const OVERRIDE;
 };
 
 
@@ -636,10 +641,11 @@ class tool_error_message_t : public tool_t {
 public:
 	tool_error_message_t() : tool_t(TOOL_ERROR_MESSAGE | GENERAL_TOOL) {}
 	bool init(player_t*) OVERRIDE { return true; }
-	bool is_init_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
 	char const* work(player_t*, koord3d) OVERRIDE { return default_param ? default_param : ""; }
 };
 
+
 /********************* one click tools ****************************/
 
 class tool_pause_t : public tool_t {
@@ -656,8 +662,8 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
-	bool is_work_network_save() const OVERRIDE { return !env_t::networkmode; }
+	bool is_init_network_safe() const OVERRIDE { return !env_t::networkmode; }
+	bool is_work_network_safe() const OVERRIDE { return !env_t::networkmode; }
 };
 
 class tool_fastforward_t : public tool_t {
@@ -677,8 +683,8 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
-	bool is_work_network_save() const OVERRIDE { return !env_t::networkmode; }
+	bool is_init_network_safe() const OVERRIDE { return !env_t::networkmode; }
+	bool is_work_network_safe() const OVERRIDE { return !env_t::networkmode; }
 };
 
 class tool_screenshot_t : public tool_t {
@@ -686,8 +692,8 @@ public:
 	tool_screenshot_t() : tool_t(TOOL_SCREENSHOT | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Screenshot"); }
 	bool init(player_t * ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 // builds next chain
@@ -698,7 +704,7 @@ public:
 	bool init( player_t * ) OVERRIDE;
 };
 
-/* prissi: undo building */
+/* undo building */
 class tool_undo_t : public tool_t {
 public:
 	tool_undo_t() : tool_t(TOOL_UNDO | SIMPLE_TOOL) {}
@@ -707,7 +713,6 @@ public:
 };
 
 /* switch to next player
- * @author prissi
  */
 class tool_switch_player_t : public tool_t {
 public:
@@ -718,8 +723,8 @@ public:
 		return false;
 	}
 	// since it is handled internally
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 // step one year forward
@@ -755,8 +760,8 @@ public:
 	tool_zoom_in_t() : tool_t(TOOL_ZOOM_IN | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("zooming in"); }
 	bool init( player_t * ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_zoom_out_t : public tool_t {
@@ -764,8 +769,8 @@ public:
 	tool_zoom_out_t() : tool_t(TOOL_ZOOM_OUT | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("zooming out"); }
 	bool init( player_t * ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_show_coverage_t : public tool_t {
@@ -779,8 +784,8 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_show_name_t : public tool_t {
@@ -812,8 +817,8 @@ public:
 		welt->set_dirty();
 		return false;
 	}
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_show_grid_t : public tool_t {
@@ -827,8 +832,8 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_show_trees_t : public tool_t {
@@ -838,8 +843,8 @@ public:
 	bool is_selected() const OVERRIDE {return env_t::hide_trees; }
 	bool init( player_t * ) OVERRIDE;
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_show_houses_t : public tool_t {
@@ -858,8 +863,8 @@ public:
 		welt->set_dirty();
 		return false;
 	}
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_show_underground_t : public tool_t {
@@ -872,8 +877,8 @@ public:
 	bool init( player_t * ) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
 	bool exit(player_t * ) OVERRIDE { return false; }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_rotate90_t : public tool_t {
@@ -883,8 +888,8 @@ public:
 	void draw_after(scr_coord pos, bool dirty) const OVERRIDE; /* may draw a compass on top */
 	char const* get_tooltip(player_t const*) const OVERRIDE { return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Rotate map"); }
 	bool init( player_t * ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
-	bool is_work_network_save() const OVERRIDE { return !env_t::networkmode; }
+	bool is_init_network_safe() const OVERRIDE { return !env_t::networkmode; }
+	bool is_work_network_safe() const OVERRIDE { return !env_t::networkmode; }
 };
 
 class tool_quit_t : public tool_t {
@@ -892,8 +897,8 @@ public:
 	tool_quit_t() : tool_t(TOOL_QUIT | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Beenden"); }
 	bool init( player_t * ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 // step size by default_param
@@ -904,7 +909,7 @@ public:
 	image_id get_icon(player_t *) const OVERRIDE { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
 	bool init(player_t * ) OVERRIDE {
 		if(  baum_t::get_count() > 0  &&  default_param  ) {
-			baum_t::fill_trees( atoi(default_param) );
+			baum_t::fill_trees( atoi(default_param), 0, 0, welt->get_size().x, welt->get_size().y );
 		}
 		return false;
 	}
@@ -916,8 +921,8 @@ public:
 	tool_daynight_level_t() : tool_t(TOOL_DAYNIGHT_LEVEL | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	bool init(player_t * ) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_vehicle_tooltips_t : public tool_t {
@@ -925,12 +930,12 @@ public:
 	tool_vehicle_tooltips_t() : tool_t(TOOL_VEHICLE_TOOLTIPS | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Toggle vehicle tooltips"); }
 	bool init( player_t * ) OVERRIDE {
-		env_t::show_vehicle_states = (env_t::show_vehicle_states+1)%3;
+		env_t::show_vehicle_states = (env_t::show_vehicle_states+1)%4;
 		welt->set_dirty();
 		return false;
 	}
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_toggle_pax_station_t : public tool_t {
@@ -946,7 +951,7 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 class tool_toggle_pedestrians_t : public tool_t {
@@ -962,7 +967,7 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 class tool_toggle_reservation_t : public tool_t {
@@ -975,8 +980,8 @@ public:
 		welt->set_dirty();
 		return false;
 	}
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_view_owner_t : public tool_t {
@@ -989,8 +994,8 @@ public:
 		welt->set_dirty();
 		return false;
 	}
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 class tool_hide_under_cursor_t : public tool_t {
@@ -1004,8 +1009,8 @@ public:
 		return false;
 	}
 	bool exit(player_t *s ) OVERRIDE { return init(s); }
-	bool is_init_network_save() const OVERRIDE { return true; }
-	bool is_work_network_save() const OVERRIDE { return true; }
+	bool is_init_network_safe() const OVERRIDE { return true; }
+	bool is_work_network_safe() const OVERRIDE { return true; }
 };
 
 /******************************** Internal tools ***********/
@@ -1017,32 +1022,32 @@ public:
 	bool is_selected() const OVERRIDE { return false; }
 	bool init( player_t * ) OVERRIDE {
 		assert(  default_param  );
-		sint16 level = min( max( atoi(default_param), 0), 16);
+		sint16 level = clamp(atoi(default_param), 0, 16);
 		welt->get_settings().set_traffic_level(level);
 		return false;
 	}
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 class tool_change_convoi_t : public tool_t {
 public:
 	tool_change_convoi_t() : tool_t(TOOL_CHANGE_CONVOI | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 class tool_change_line_t : public tool_t {
 public:
 	tool_change_line_t() : tool_t(TOOL_CHANGE_LINE | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 class tool_change_depot_t : public tool_t {
 public:
 	tool_change_depot_t() : tool_t(TOOL_CHANGE_DEPOT | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 // adds a new player of certain type to the map
@@ -1057,7 +1062,7 @@ class tool_change_traffic_light_t : public tool_t {
 public:
 	tool_change_traffic_light_t() : tool_t(TOOL_CHANGE_TRAFFIC_LIGHT | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 // change city: (dis)allow growth
@@ -1065,7 +1070,7 @@ class tool_change_city_t : public tool_t {
 public:
 	tool_change_city_t() : tool_t(TOOL_CHANGE_CITY | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 // internal tool: rename stuff
@@ -1073,7 +1078,7 @@ class tool_rename_t : public tool_t {
 public:
 	tool_rename_t() : tool_t(TOOL_RENAME | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 // internal tool: send message
@@ -1081,7 +1086,7 @@ class tool_add_message_t : public tool_t {
 public:
 	tool_add_message_t() : tool_t(TOOL_ADD_MESSAGE | SIMPLE_TOOL) {}
 	bool init(player_t*) OVERRIDE;
-	bool is_init_network_save() const OVERRIDE { return false; }
+	bool is_init_network_safe() const OVERRIDE { return false; }
 };
 
 #endif
