@@ -1,16 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Vehicle base type.
- */
+#ifndef VEHICLE_SIMVEHICLE_H
+#define VEHICLE_SIMVEHICLE_H
 
-#ifndef SIMVEHICLE_H
-#define SIMVEHICLE_H
 
 #include "../simtypes.h"
 #include "../simobj.h"
@@ -32,8 +27,6 @@ class route_t;
 
 /**
  * Base class for all vehicles
- *
- * @author Hj. Malthaner
  */
 class vehicle_base_t : public obj_t
 {
@@ -54,7 +47,6 @@ protected:
 
 	/**
 	 * Actual travel direction in screen coordinates
-	 * @author Hj. Malthaner
 	 */
 	ribi_t::ribi direction;
 
@@ -81,7 +73,6 @@ protected:
 
 	/**
 	 * Next position on our path
-	 * @author Hj. Malthaner
 	 */
 	koord3d pos_next;
 
@@ -126,7 +117,7 @@ public:
 	// if true, this convoi needs to restart for correct alignment
 	bool need_realignment() const;
 
-	uint32 do_drive(uint32 dist);	// basis movement code
+	uint32 do_drive(uint32 dist); // basis movement code
 
 	inline void set_image( image_id b ) { image = b; }
 	image_id get_image() const OVERRIDE {return image;}
@@ -196,23 +187,19 @@ template<> inline vehicle_base_t* obj_cast<vehicle_base_t>(obj_t* const d)
 
 /**
  * Class for all vehicles with route
- *
- * @author Hj. Malthaner
  */
-
 class vehicle_t : public vehicle_base_t, public test_driver_t
 {
 private:
 	/**
 	* Date of purchase in months
-	* @author Hj. Malthaner
 	*/
 	sint32 purchase_time;
 
-	/* For the more physical acceleration model friction is introduced
+	/**
+	* For the more physical acceleration model friction is introduced
 	* frictionforce = gamma*speed*weight
 	* since the total weight is needed a lot of times, we save it
-	* @author prissi
 	*/
 	uint32 sum_weight;
 
@@ -234,28 +221,26 @@ protected:
 	// for target reservation and search
 	halthandle_t target_halt;
 
-	/* The friction is calculated new every step, so we save it too
-	* @author prissi
+	/** The friction is calculated new every step, so we save it too
 	*/
 	sint16 current_friction;
 
 	/**
 	* Current index on the route
-	* @author Hj. Malthaner
 	*/
 	uint16 route_index;
 
-	uint16 total_freight;	// since the sum is needed quite often, it is cached
+	uint16 total_freight; // since the sum is needed quite often, it is cached
 	slist_tpl<ware_t> fracht;   // list of goods being transported
 
 	const vehicle_desc_t *desc;
 
-	convoi_t *cnv;		// != NULL if the vehicle is part of a Convoi
+	convoi_t *cnv;  // != NULL if the vehicle is part of a Convoi
 
-	bool leading:1;	// true, if vehicle is first vehicle of a convoi
-	bool last:1;	// true, if vehicle is last vehicle of a convoi
+	bool leading:1; // true, if vehicle is first vehicle of a convoi
+	bool last:1;    // true, if vehicle is last vehicle of a convoi
 	bool smoke:1;
-	bool check_for_finish:1;		// true, if on the last tile
+	bool check_for_finish:1; // true, if on the last tile
 	bool has_driven:1;
 
 	bool check_next_tile(const grund_t* ) const OVERRIDE {return false;}
@@ -291,8 +276,6 @@ public:
 
 	/**
 	* Determine the direction bits for this kind of vehicle.
-	*
-	* @author Hj. Malthaner, 04.01.01
 	*/
 	ribi_t::ribi get_ribi(const grund_t* gr) const OVERRIDE { return gr->get_weg_ribi(get_waytype()); }
 
@@ -305,7 +288,6 @@ public:
 
 	/**
 	* Get the base image.
-	* @author Hj. Malthaner
 	*/
 	image_id get_base_image() const { return desc->get_base_image(); }
 
@@ -316,19 +298,16 @@ public:
 
 	/**
 	* @return vehicle description object
-	* @author Hj. Malthaner
 	*/
 	const vehicle_desc_t *get_desc() const {return desc; }
 
 	/**
 	* @return die running_cost in Cr/100Km
-	* @author Hj. Malthaner
 	*/
 	int get_operating_cost() const { return desc->get_running_cost(); }
 
 	/**
 	* Play sound, when the vehicle is visible on screen
-	* @author Hj. Malthaner
 	*/
 	void play_sound() const;
 
@@ -336,7 +315,6 @@ public:
 	 * Prepare vehicle for new ride.
 	 * Sets route_index, pos_next, steps_next.
 	 * If @p recalc is true this sets position and recalculates/resets movement parameters.
-	 * @author Hj. Malthaner
 	 */
 	void initialise_journey( uint16 start_route_index, bool recalc );
 
@@ -351,14 +329,14 @@ public:
 
 	void info(cbuffer_t & buf) const OVERRIDE;
 
-	/* return friction constant: changes in hill and curves; may even negative downhill *
-	* @author prissi
-	*/
+	/**
+	 * return friction constant: changes in hill and curves; may even negative downhill *
+	 */
 	inline sint16 get_frictionfactor() const { return current_friction; }
 
-	/* Return total weight including freight (in kg!)
-	* @author prissi
-	*/
+	/**
+	 * Return total weight including freight (in kg!)
+	 */
 	inline uint32 get_total_weight() const { return sum_weight; }
 
 	// returns speedlimit of ways (and if convoi enters station etc)
@@ -379,7 +357,6 @@ public:
 
 	/**
 	* Calculate transported cargo total weight in KG
-	* @author Hj. Malthaner
 	*/
 	uint32 get_cargo_weight() const;
 
@@ -398,13 +375,11 @@ public:
 	/**
 	* create an info text for the freight
 	* e.g. to display in a info window
-	* @author Hj. Malthaner
 	*/
 	void get_cargo_info(cbuffer_t & buf) const;
 
 	/**
 	* Delete all vehicle load
-	* @author Hj. Malthaner
 	*/
 	void discard_cargo();
 
@@ -413,7 +388,6 @@ public:
 	* the income for the last hop. This method must be called upon
 	* every stop.
 	* @return income total for last hop
-	* @author Hj. Malthaner
 	*/
 	sint64 calc_revenue(const koord3d& start, const koord3d& end) const;
 
@@ -444,13 +418,11 @@ public:
 	/**
 	* Remove freight that no longer can reach it's destination
 	* i.e. because of a changed schedule
-	* @author Hj. Malthaner
 	*/
 	void remove_stale_cargo();
 
 	/**
 	* Generate a matching schedule for the vehicle type
-	* @author Hj. Malthaner
 	*/
 	virtual schedule_t *generate_new_schedule() const = 0;
 
@@ -482,8 +454,6 @@ template<> inline vehicle_t* obj_cast<vehicle_t>(obj_t* const d)
 /**
  * A class for road vehicles. Manages the look of the vehicles
  * and the navigability of tiles.
- *
- * @author Hj. Malthaner
  * @see vehicle_t
  */
 class road_vehicle_t : public vehicle_t
@@ -536,8 +506,6 @@ public:
 /**
  * A class for rail vehicles (trains). Manages the look of the vehicles
  * and the navigability of tiles.
- *
- * @author Hj. Malthaner
  * @see vehicle_t
  */
 class rail_vehicle_t : public vehicle_t
@@ -591,7 +559,6 @@ public:
 
 /**
  * very similar to normal railroad, so we can implement it here completely ...
- * @author prissi
  * @see vehicle_t
  */
 class monorail_vehicle_t : public rail_vehicle_t
@@ -612,7 +579,6 @@ public:
 
 /**
  * very similar to normal railroad, so we can implement it here completely ...
- * @author prissi
  * @see vehicle_t
  */
 class maglev_vehicle_t : public rail_vehicle_t
@@ -632,8 +598,7 @@ public:
 
 
 /**
- * very similar to normal railroad, so we can implement it here completely ...
- * @author prissi
+ * very similar to normal railroad, so we can implement it here completely
  * @see vehicle_t
  */
 class narrowgauge_vehicle_t : public rail_vehicle_t
@@ -655,8 +620,6 @@ public:
 /**
  * A class for naval vehicles. Manages the look of the vehicles
  * and the navigability of tiles.
- *
- * @author Hj. Malthaner
  * @see vehicle_t
  */
 class water_vehicle_t : public vehicle_t
@@ -691,8 +654,6 @@ public:
 /**
  * A class for aircrafts. Manages the look of the vehicles
  * and the navigability of tiles.
- *
- * @author hsiegeln
  * @see vehicle_t
  */
 class air_vehicle_t : public vehicle_t
@@ -710,7 +671,7 @@ private:
 	koord3d search_start;
 	koord3d search_end;
 
-	flight_state state;	// functions needed for the search without destination from find_route
+	flight_state state; // functions needed for the search without destination from find_route
 
 	sint16 flying_height;
 	sint16 target_height;
