@@ -1,11 +1,11 @@
 /*
- * Copyright (c) 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef simview_h
-#define simview_h
+#ifndef DISPLAY_SIMVIEW_H
+#define DISPLAY_SIMVIEW_H
+
 
 class karte_t;
 class viewport_t;
@@ -13,7 +13,6 @@ class viewport_t;
 /**
  * World view class, it contains the routines that handle world display to the pixel buffer.
  * @brief View for the simulated world.
- * @author Hj. Malthaner
  */
 class main_view_t
 {
