@@ -1,21 +1,6 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
- */
-
-/*
- * Sub-window for Sim
- * keine Klasse, da die funktionen von C-Code aus aufgerufen werden koennen
- *
- * The function implements a WindowManager 'Object'
- * There's only one WindowManager
- *
- * 17.11.97, Hj. Malthaner
- *
- * Window now typified
- * 21.06.98, Hj. Malthaner
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <stdio.h>
@@ -28,7 +13,7 @@
 #include "../display/viewport.h"
 #include "../simmenu.h"
 #include "../simskin.h"
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../simticker.h"
 #include "simwin.h"
 #include "../simintr.h"
@@ -85,7 +70,6 @@ class inthashtable_tpl<ptrdiff_t, scr_size> saved_windowsizes;
 
 #define dragger_size 12
 
-// (Mathew Hounsell)
 // I added a button to the map window to fix it's size to the best one.
 // This struct is the flow back to the object of the refactoring.
 class simwin_gadget_flags_t
@@ -106,17 +90,17 @@ public:
 class simwin_t
 {
 public:
-	scr_coord pos;              // Window position
+	scr_coord pos;          // Window position
 	uint32 dauer;           // How long should the window stay open?
 	uint8 wt;               // the flags for the window type
 	ptrdiff_t magic_number; // either magic number or this pointer (which is unique too)
 	gui_frame_t *gui;
-	uint16	gadget_state;	// which buttons to hilite
+	uint16 gadget_state;    // which buttons to hilite
 	bool sticky;            // true if window is sticky
 	bool rollup;
 	bool dirty;
 
-	simwin_gadget_flags_t flags; // (Mathew Hounsell) See Above.
+	simwin_gadget_flags_t flags; // See Above.
 
 	simwin_t() : flags() {}
 
@@ -136,20 +120,21 @@ static int top_win(int win, bool keep_state );
 static void display_win(int win);
 
 
-// Hajo: tooltip data
+// tooltip data
 static int tooltip_xpos = 0;
 static int tooltip_ypos = 0;
 static const char * tooltip_text = 0;
 static const char * static_tooltip_text = 0;
-// Knightly :	For timed tooltip with initial delay and finite visible duration.
-//				Valid owners are required for timing. Invalid (NULL) owners disable timing.
-static const void * tooltip_owner = 0;	// owner of the registered tooltip
-static const void * tooltip_group = 0;	// group to which the owner belongs
-static uint32 tooltip_register_time = 0;	// time at which a tooltip is initially registered
+
+// For timed tooltip with initial delay and finite visible duration.
+// Valid owners are required for timing. Invalid (NULL) owners disable timing.
+static const void * tooltip_owner = 0;   // owner of the registered tooltip
+static const void * tooltip_group = 0;   // group to which the owner belongs
+static uint32 tooltip_register_time = 0; // time at which a tooltip is initially registered
 
 static bool show_ticker=0;
 
-/* Hajo: if we are inside the event handler,
+/* if we are inside the event handler,
  * the window handler has gui pointer as value,
  * to defer destruction if this window
  */
@@ -167,7 +152,6 @@ static bool destroy_framed_win(simwin_t *win);
 
 /**
  * Display a window gadget
- * @author Hj. Malthaner
  */
 static int display_gadget_box(sint8 code,
 			      int const x, int const y,
@@ -178,7 +162,7 @@ static int display_gadget_box(sint8 code,
 	// If we have a skin, get gadget image data
 	const image_t *img = NULL;
 	if(  skinverwaltung_t::gadget  ) {
-		// "x", "?", "=", "", ""
+		// "x", "?", "=", "<<", ">>"
 		img = skinverwaltung_t::gadget->get_image(code);
 	}
 
@@ -202,13 +186,13 @@ static int display_gadget_box(sint8 code,
 			gadget_text = gadget_texts[code];
 		}
 		else if(  code == SKIN_GADGET_GOTOPOS  ) {
-			gadget_text	= "*";
+			gadget_text = "*";
 		}
 		else if(  code == SKIN_GADGET_NOTPINNED  ) {
-			gadget_text	= "s";
+			gadget_text = "s";
 		}
 		else if(  code == SKIN_GADGET_PINNED  ) {
-			gadget_text	= "S";
+			gadget_text = "S";
 		}
 		display_proportional_rgb( x+4, y+4, gadget_text, ALIGN_LEFT, color_idx_to_rgb(COL_BLACK), false );
 	}
@@ -217,13 +201,11 @@ static int display_gadget_box(sint8 code,
 	display_vline_wh_clip_rgb(side+1, y+1, D_TITLEBAR_HEIGHT-2, lighter, false);
 	display_vline_wh_clip_rgb(side,   y+1, D_TITLEBAR_HEIGHT-2, darker,  false);
 
-	// Hajo: return width of gadget
+	// return width of gadget
 	return D_GADGET_WIDTH;
 }
 
 
-//-------------------------------------------------------------------------
-// (Mathew Hounsell) Created
 static int display_gadget_boxes(
 	simwin_gadget_flags_t* flags,
 	int x, int y,
@@ -263,11 +245,8 @@ static int display_gadget_boxes(
 }
 
 
-static sint8 decode_gadget_boxes(
-               simwin_gadget_flags_t const * const flags,
-               int const x,
-               int const px
-) {
+static sint8 decode_gadget_boxes(simwin_gadget_flags_t const * const flags, int const x,int const px)
+{
 	int offset = px-x;
 	const int w=(REVERSE_GADGETS?-D_GADGET_WIDTH:D_GADGET_WIDTH);
 
@@ -322,8 +301,7 @@ static sint8 decode_gadget_boxes(
 	return SKIN_GADGET_COUNT;
 }
 
-//-------------------------------------------------------------------------
-// (Mathew Hounsell) Re-factored
+
 static void win_draw_window_title(const scr_coord pos, const scr_size size,
 		const FLAGGED_PIXVAL title_color,
 		const char * const text,
@@ -362,7 +340,6 @@ static void win_draw_window_title(const scr_coord pos, const scr_size size,
 
 /**
  * Draw dragger widget
- * @author Hj. Malthaner
  */
 static void win_draw_window_dragger(scr_coord pos, scr_size size)
 {
@@ -502,7 +479,6 @@ bool win_set_magic( gui_frame_t *gui, ptrdiff_t magic )
 
 /**
  * Returns top window
- * @author prissi
  */
 gui_frame_t *win_get_top()
 {
@@ -512,7 +488,6 @@ gui_frame_t *win_get_top()
 
 /**
  * returns the focused component of the top window
- * @author Knightly
  */
 gui_component_t *win_get_focus()
 {
@@ -542,7 +517,6 @@ bool top_win( const gui_frame_t *gui, bool keep_rollup )
 
 /**
  * Checks if a window is a top level window
- * @author Hj. Malthaner
  */
 bool win_is_top(const gui_frame_t *ig)
 {
@@ -706,7 +680,7 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, ptrdiff_t
 
 		sint16 const menu_height = env_t::iconsize.h;
 
-		// (Mathew Hounsell) Make Sure Closes Aren't Forgotten.
+		// Make Sure Closes Aren't Forgotten.
 		// Must Reset as the entries and thus flags are reused
 		win.flags.close = true;
 		win.flags.title = gui->has_title();
@@ -726,7 +700,7 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, ptrdiff_t
 		win.sticky = false;
 		win.dirty = true;
 
-		// Hajo: Notify window to be shown
+		// Notify window to be shown
 		assert(gui);
 		event_t ev;
 
@@ -831,7 +805,6 @@ static void process_kill_list()
 
 /**
  * Destroy a framed window
- * @author Hj. Malthaner
  */
 static bool destroy_framed_win(simwin_t *wins)
 {
@@ -844,7 +817,9 @@ static bool destroy_framed_win(simwin_t *wins)
 	// save windowsize for later
 	save_windowsize(wins);
 
-	gui_frame_t* gui = wins->gui; // save pointer to gui window: might be modified in event handling, or could be modified if wins points to value in kill_list and kill_list is modified! nasty surprise
+	// save pointer to gui window: might be modified in event handling,
+	// or could be modified if wins points to value in kill_list and kill_list is modified! nasty surprise
+	gui_frame_t* gui = wins->gui;
 	if(  gui  ) {
 		event_t ev;
 
@@ -970,7 +945,7 @@ int top_win(int win, bool keep_state )
 	simwin_t tmp = wins[win];
 	wins.remove_at(win);
 	if(  !keep_state  ) {
-		tmp.rollup = false;	// make visible when topping
+		tmp.rollup = false; // make visible when topping
 	}
 	wins.append(tmp);
 
@@ -1012,7 +987,7 @@ void display_win(int win)
 	}
 	bool need_dragger = comp->get_resizemode() != gui_frame_t::no_resize;
 
-	// %HACK (Mathew Hounsell) So draw will know if gadget is needed.
+	// HACK  So draw will know if gadget is needed.
 	wins[win].flags.help = ( comp->get_help_filename() != NULL );
 	if(  wins[win].flags.title  ) {
 		win_draw_window_title(wins[win].pos,
@@ -1240,8 +1215,8 @@ void move_win(int win, event_t *ev)
 	}
 
 	// CLIP(wert,min,max)
-	to_pos.x = CLIP( to_pos.x, 8-to_size.x, display_get_width()-16 );
-	to_pos.y = CLIP( to_pos.y, env_t::iconsize.h, display_get_height() - D_TITLEBAR_HEIGHT - win_get_statusbar_height() - TICKER_HEIGHT);
+	to_pos.x = clamp( to_pos.x, 8-to_size.x, display_get_width()-16 );
+	to_pos.y = clamp( to_pos.y, env_t::iconsize.h, display_get_height() - D_TITLEBAR_HEIGHT - win_get_statusbar_height() - TICKER_HEIGHT);
 
 	// delta is actual window movement.
 	const scr_coord delta = to_pos - from_pos;
@@ -1335,9 +1310,8 @@ void win_set_pos(gui_frame_t *gui, int x, int y)
 }
 
 
-/* main window event handler
- * renovated may 2005 by prissi to take care of irregularly shaped windows
- * also remove some unnecessary calls
+/*
+ * main window event handler
  */
 bool check_pos_win(event_t *ev)
 {
@@ -1360,13 +1334,13 @@ bool check_pos_win(event_t *ev)
 		is_resizing = -1;
 		is_moving = -1;
 		if(  IS_LEFTRELEASE(ev)  ) {
-			// Knightly :	should not proceed, otherwise the left release event will be fed to other components;
-			//				return true (i.e. event swallowed) to prevent propagation back to the main view
+			// should not proceed, otherwise the left release event will be fed to other components;
+			// return true (i.e. event swallowed) to prevent propagation back to the main view
 			return true;
 		}
 	}
 
-	// Knightly : disable any active tooltip upon mouse click by forcing expiration of tooltip duration
+	// disable any active tooltip upon mouse click by forcing expiration of tooltip duration
 	if(  ev->ev_class==EVENT_CLICK  ) {
 		tooltip_register_time = 0;
 	}
@@ -1442,14 +1416,14 @@ bool check_pos_win(event_t *ev)
 				i = top_win(i,false);
 			}
 
-			// Hajo: if within title bar && window needs decoration
+			// if within title bar && window needs decoration
 			// Max Kielland: Use title height
 			if(  y<wins[i].pos.y+D_TITLEBAR_HEIGHT  &&  wins[i].flags.title  ) {
 				// no more moving
 				is_moving = -1;
 				wins[i].dirty = true;
 
-				// %HACK (Mathew Hounsell) So decode will know if gadget is needed.
+				// HACK So decode will know if gadget is needed.
 				wins[i].flags.help = ( wins[i].gui->get_help_filename() != NULL );
 
 				// Where Was It ?
@@ -1486,7 +1460,8 @@ bool check_pos_win(event_t *ev)
 									wins[i].gui->infowin_event( ev );
 									break;
 								case SKIN_GADGET_GOTOPOS:
-									{	// change position on map (or follow)
+									{
+										// change position on map (or follow)
 										koord3d k = wins[i].gui->get_weltpos(true);
 										if(  k!=koord3d::invalid  ) {
 											wl->get_viewport()->change_world_position( k );
@@ -1577,7 +1552,7 @@ void win_poll_event(event_t* const ev)
 	if(  ev->ev_class==EVENT_SYSTEM  &&  ev->ev_code==SYSTEM_RELOAD_WINDOWS  ) {
 		dr_chdir( env_t::user_dir );
 		loadsave_t dlg;
-		if(  dlg.wr_open( "dlgpos.xml", loadsave_t::xml_zipped, "temp", SERVER_SAVEGAME_VER_NR )  ) {
+		if(  dlg.wr_open( "dlgpos.xml", loadsave_t::xml_zipped, 1, "temp", SERVER_SAVEGAME_VER_NR )  ) {
 			// save all
 			rdwr_all_win( &dlg );
 			dlg.close();
@@ -1675,9 +1650,9 @@ void win_display_flush(double konto)
 		remove_old_win();
 
 		if(env_t::show_tooltips) {
-			// Hajo: check if there is a tooltip to display
+			// check if there is a tooltip to display
 			if(  tooltip_text  &&  *tooltip_text  ) {
-				// Knightly : display tooltip when current owner is invalid or when it is within visible duration
+				// display tooltip when current owner is invalid or when it is within visible duration
 				uint32 elapsed_time;
 				if(  !tooltip_owner  ||  ((elapsed_time=dr_time()-tooltip_register_time)>env_t::tooltip_delay  &&  elapsed_time<=env_t::tooltip_delay+env_t::tooltip_duration)  ) {
 					const sint16 width = proportional_string_width(tooltip_text)+7;
@@ -1694,12 +1669,12 @@ void win_display_flush(double konto)
 					wl->set_background_dirty();
 				}
 			}
-			// Knightly : reset owner and group if no tooltip has been registered
+			// reset owner and group if no tooltip has been registered
 			if(  !tooltip_text  ) {
 				tooltip_owner = 0;
 				tooltip_group = 0;
 			}
-			// Hajo : clear tooltip text to avoid sticky tooltips
+			// clear tooltip text to avoid sticky tooltips
 			tooltip_text = 0;
 		}
 
@@ -1824,7 +1799,7 @@ void win_display_flush(double konto)
 
 	if(wl->get_active_player()) {
 		char buffer[256];
-		display_proportional_rgb( middle-5, status_bar_text_y, wl->get_active_player()->get_name(), ALIGN_RIGHT, PLAYER_FLAG|color_idx_to_rgb(wl->get_active_player()->get_player_color1()+0), true);
+		display_proportional_rgb( middle-5, status_bar_text_y, wl->get_active_player()->get_name(), ALIGN_RIGHT, PLAYER_FLAG|color_idx_to_rgb(wl->get_active_player()->get_player_color1()+env_t::gui_player_color_dark), true);
 		money_to_string(buffer, konto );
 		display_proportional_rgb( middle+5, status_bar_text_y, buffer, ALIGN_LEFT, konto >= 0.0?MONEY_PLUS:MONEY_MINUS, true);
 	}
@@ -1864,7 +1839,7 @@ void win_load_font(const char *fname, uint16 fontsize)
 
 	if (display_load_font(fname, force_reload) ) {
 		// successfull
-		gui_theme_t::themes_init( env_t::default_theme, false );
+		gui_theme_t::themes_init( env_t::default_theme, false, false );
 
 		event_t *ev = new event_t();
 		ev->ev_class = EVENT_SYSTEM;
@@ -1883,7 +1858,6 @@ void win_load_font(const char *fname, uint16 fontsize)
  * Sets the tooltip to display.
  * Has to be called from within gui_frame_t::draw
  * @param owner : owner==NULL disables timing (initial delay and visible duration)
- * @author Hj. Malthaner, Knightly
  */
 void win_set_tooltip(int xpos, int ypos, const char *text, const void *const owner, const void *const group)
 {
@@ -1903,7 +1877,7 @@ void win_set_tooltip(int xpos, int ypos, const char *text, const void *const own
 			if(  group  &&  group==tooltip_group  ) {
 				// case : same group
 				const uint32 elapsed_time = current_time - tooltip_register_time;
-				const uint32 threshold = env_t::tooltip_delay - (env_t::tooltip_delay>>2);	// 3/4 of delay
+				const uint32 threshold = env_t::tooltip_delay - (env_t::tooltip_delay>>2); // 3/4 of delay
 				if(  elapsed_time>threshold  &&  elapsed_time<=env_t::tooltip_delay+env_t::tooltip_duration  ) {
 					// case : threshold was reached and duration not expired -> delay time is reduced to 1/4
 					tooltip_register_time = current_time - threshold;
@@ -1932,7 +1906,6 @@ void win_set_tooltip(int xpos, int ypos, const char *text, const void *const own
 
 /**
  * Sets the tooltip to display.
- * @author Hj. Malthaner
  */
 void win_set_static_tooltip(const char *text)
 {
