@@ -1,22 +1,24 @@
 /*
- * Copyright (c) 1997 - 2003 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * The function implements a WindowManager 'Object'
- */
+#ifndef GUI_SIMWIN_H
+#define GUI_SIMWIN_H
 
-#ifndef simwin_h
-#define simwin_h
 
 #include <stddef.h> // for ptrdiff_t
 
 #include "../simtypes.h"
 #include "../simconst.h"
 
+
+/*
+ * The function implements a WindowManager 'Object'
+ * There's only one WindowManager
+ */
+
+
 class karte_t;
 class scr_coord;
 class loadsave_t;
@@ -62,7 +64,7 @@ enum magic_numbers {
 	magic_UNUSED_listtools,
 	magic_UNUSED_edittools,
 	magic_UNUSED_slopetools,
-	magic_halt_list_t,
+	magic_UNUSED_halt_list_t,
 	magic_UNUSED_label_frame,
 	magic_city_info_t,
 	magic_citylist_frame_t,
@@ -96,8 +98,8 @@ enum magic_numbers {
 	magic_station_building_select,
 	magic_server_frame_t,
 	magic_pakset_info_t,
-	magic_schedule_rdwr_dummy,	// only used to save/load schedules
-	magic_line_schedule_rdwr_dummy,	// only used to save/load line schedules
+	magic_schedule_rdwr_dummy, // only used to save/load schedules
+	magic_line_schedule_rdwr_dummy, // only used to save/load line schedules
 	magic_motd,
 	magic_factory_info, // only used to load/save
 	magic_font,
@@ -110,6 +112,9 @@ enum magic_numbers {
 	magic_script_error=magic_toolbar+256,
 	magic_haltlist_filter,
 	magic_depot, // only used to load/save
+	magic_halt_list_t,
+	magic_depotlist = magic_halt_list_t + MAX_PLAYER_COUNT,
+	magic_vehiclelist = magic_depotlist + MAX_PLAYER_COUNT,
 	magic_max
 };
 
@@ -137,7 +142,7 @@ void win_set_pos(gui_frame_t *ig, int x, int y);
 
 gui_frame_t *win_get_top();
 
-// Knightly : returns the focused component of the top window
+// returns the focused component of the top window
 gui_component_t *win_get_focus();
 
 int win_get_open_count();
@@ -150,8 +155,6 @@ bool win_set_magic( gui_frame_t *gui, ptrdiff_t magic );
 
 /**
  * Checks if a window is a top level window
- *
- * @author Hj. Malthaner
  */
 bool win_is_top(const gui_frame_t *ig);
 
@@ -193,14 +196,12 @@ void win_load_font(const char *fname, uint16 fontsize);
 /**
  * Sets the tooltip to display.
  * @param owner : owner==NULL disables timing (initial delay and visible duration)
- * @author Hj. Malthaner, Knightly
  */
 void win_set_tooltip(int xpos, int ypos, const char *text, const void *const owner = 0, const void *const group = 0);
 
 /**
  * Sets a static tooltip that follows the mouse
  * *MUST* be explicitly unset!
- * @author Hj. Malthaner
  */
 void win_set_static_tooltip(const char *text);
 
