@@ -1,17 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hj. Malthaner
- *
- * This file is part of the Simutrans project under the artistic license.
- * (see license.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * zentrale Datenstruktur von Simutrans
- * von Hj. Malthaner 1998
- */
+#ifndef SIMWORLD_H
+#define SIMWORLD_H
 
-#ifndef simworld_h
-#define simworld_h
 
 #include "simconst.h"
 #include "simtypes.h"
@@ -21,6 +15,7 @@
 #include "halthandle_t.h"
 
 #include "tpl/weighted_vector_tpl.h"
+#include "tpl/array2d_tpl.h"
 #include "tpl/vector_tpl.h"
 #include "tpl/slist_tpl.h"
 
@@ -84,7 +79,6 @@ typedef void (karte_t::*xy_loop_func)(sint16, sint16, sint16, sint16);
 /**
  * The map is the central part of the simulation. It stores all data and objects.
  * @brief Stores all data and objects of the simulated world.
- * @author Hj. Malthaner
  */
 class karte_t
 {
@@ -99,7 +93,6 @@ public:
 	 *
 	 * @param frequency in 0..1.0 roughness, the higher the rougher
 	 * @param amplitude in 0..160.0 top height of mountains, may not exceed 160.0!!!
-	 * @author Hj. Malthaner
 	 */
 	static sint32 perlin_hoehe(settings_t const*, koord k, koord size);
 
@@ -109,22 +102,22 @@ public:
 	void perlin_hoehe_loop(sint16, sint16, sint16, sint16);
 
 	enum player_cost {
-		WORLD_CITICENS=0,		//!< total people
-		WORLD_GROWTH,			//!< growth (just for convenience)
-		WORLD_TOWNS,			//!< number of all cities
-		WORLD_FACTORIES,		//!< number of all consuming only factories
-		WORLD_CONVOIS,			//!< total number of convois
-		WORLD_CITYCARS,			//!< number of citycars generated
-		WORLD_PAS_RATIO,		//!< percentage of passengers that started successful
-		WORLD_PAS_GENERATED,	//!< total number generated
-		WORLD_MAIL_RATIO,		//!< percentage of mail that started successful
-		WORLD_MAIL_GENERATED,	//!< all letters generated
-		WORLD_GOODS_RATIO,		//!< ratio of chain completeness
-		WORLD_TRANSPORTED_GOODS,//!< all transported goods
+		WORLD_CITICENS=0,        ///< total people
+		WORLD_GROWTH,            ///< growth (just for convenience)
+		WORLD_TOWNS,             ///< number of all cities
+		WORLD_FACTORIES,         ///< number of all consuming only factories
+		WORLD_CONVOIS,           ///< total number of convois
+		WORLD_CITYCARS,          ///< number of citycars generated
+		WORLD_PAS_RATIO,         ///< percentage of passengers that started successful
+		WORLD_PAS_GENERATED,     ///< total number generated
+		WORLD_MAIL_RATIO,        ///< percentage of mail that started successful
+		WORLD_MAIL_GENERATED,    ///< all letters generated
+		WORLD_GOODS_RATIO,       ///< ratio of chain completeness
+		WORLD_TRANSPORTED_GOODS, ///< all transported goods
 		MAX_WORLD_COST
 	};
 
-	#define MAX_WORLD_HISTORY_YEARS  (12) // number of years to keep history
+	#define MAX_WORLD_HISTORY_YEARS   (12) // number of years to keep history
 	#define MAX_WORLD_HISTORY_MONTHS  (12) // number of months to keep history
 
 	enum { NORMAL=0, PAUSE_FLAG = 0x01, FAST_FORWARD=0x02, FIX_RATIO=0x04 };
@@ -202,7 +195,6 @@ private:
 
 	/**
 	 * @name Mouse pointer and cursor management
-	 * @author Hj. Malthaner
 	 * @{
 	 */
 
@@ -236,20 +228,17 @@ private:
 
 	/**
 	 * Water level height.
-	 * @author Hj. Malthaner
 	 */
 	sint8 groundwater;
 
 	/**
 	 * Current snow height.
 	 * @note Might change during the game.
-	 * @author prissi
 	 */
 	sint16 snowline;
 
 	/**
 	 * Changes the season and/or snowline height
-	 * @author prissi
 	 */
 	void recalc_season_snowline(bool set_pending);
 
@@ -266,9 +255,21 @@ private:
 
 	/**
 	 * Table for fast conversion from height to climate.
-	 * @author prissi
 	 */
 	uint8 height_to_climate[128];
+	uint8 num_climates_at_height[128];
+
+	/**
+	* Contains the intended climate for a tile
+	* (needed to restore tiles after height changes)
+	*/
+	array2d_tpl<uint8>climate_map;
+
+	/**
+	* Contains the intended climate for a tile
+	* (needed to restore tiles after height changes)
+	*/
+	array2d_tpl<uint8>humidity_map;
 
 	/**
 	 * Array containing the convois.
@@ -386,7 +387,6 @@ private:
 	/**
 	 * The fractal generation of the map is not perfect.
 	 * cleanup_karte() eliminates errors.
-	 * @author Hj. Malthaner
 	 */
 	void cleanup_karte( int xoff, int yoff );
 
@@ -418,7 +418,6 @@ private:
 	/**
 	 * @name Player management
 	 *       Variables related to the player management in game.
-	 * @author Hj. Malthaner
 	 * @{
 	 */
 	/**
@@ -443,11 +442,10 @@ private:
 	pwd_hash_t player_password_hash[MAX_PLAYER_COUNT];
 	/** @} */
 
-	/*
+	/**
 	 * Counter for schedules.
 	 * If a new schedule is active, this counter will increment
 	 * stations check this counter and will reroute their goods if changed.
-	 * @author prissi
 	 */
 	uint8 schedule_counter;
 
@@ -462,21 +460,18 @@ private:
 	/**
 	 * ms since creation.
 	 * @note The time is in ms (milliseconds)
-	 * @author Hj. Malthaner
 	 */
 	uint32 ticks;
 
 	/**
 	 * Ticks counter at last steps.
 	 * @note The time is in ms (milliseconds)
-	 * @author Hj. Malthaner
 	 */
 	uint32 last_step_ticks;
 
 	/**
 	 * From now on is next month.
 	 * @note The time is in ms (milliseconds)
-	 * @author Hj. Malthaner
 	 */
 	uint32 next_month_ticks;
 
@@ -506,13 +501,11 @@ private:
 
 	/**
 	 * For performance comparison.
-	 * @author Hj. Malthaner
 	 */
 	uint32 realFPS;
 
 	/**
 	 * For performance comparison.
-	 * @author Hj. Malthaner
 	 */
 	uint32 simloops;
 
@@ -646,19 +639,16 @@ private:
 
 	/**
 	 * Internal saving method.
-	 * @author Hj. Malthaner
 	 */
-	void save(loadsave_t *file,bool silent);
+	void save(loadsave_t *file, bool silent);
 
 	/**
 	 * Internal loading method.
-	 * @author Hj. Malthaner
 	 */
 	void load(loadsave_t *file);
 
 	/**
 	 * Removes all objects, deletes all data structures and frees all accessible memory.
-	 * @author Hj. Malthaner
 	 */
 	void destroy();
 
@@ -672,10 +662,15 @@ private:
 	 */
 	void create_rivers(sint16 number);
 
+	/**
+	 * Will create lakes (multithreaded).
+	 */
+	void create_lakes_loop(sint16, sint16, sint16, sint16);
+
 	/**
 	 * Will create lakes.
 	 */
-	void create_lakes( int xoff, int yoff );
+	void create_lakes( int xoff, int yoff, sint8 max_lake_height );
 
 	/**
 	 * Will create beaches.
@@ -686,7 +681,6 @@ private:
 	 * Distribute groundobjs and cities on the map but not
 	 * in the rectangle from (0,0) till (old_x, old_y).
 	 * It's now an extra function so we don't need the code twice.
-	 * @author Gerd Wachsmuth
 	 */
 	void distribute_groundobjs_cities(int new_cities, sint32 new_mean_citizen_count, sint16 old_x, sint16 old_y );
 
@@ -740,31 +734,26 @@ public:
 
 	/**
 	 * Absolute month.
-	 * @author prissi
 	 */
 	inline uint32 get_last_month() const { return last_month; }
 
 	/**
 	 * Returns last year.
-	 * @author hsiegeln
 	 */
 	inline sint32 get_last_year() const { return last_year; }
 
 	/**
 	 * dirty: redraw whole screen.
-	 * @author Hj. Malthaner
 	 */
 	void set_dirty() {dirty=true;}
 
 	/**
 	 * dirty: redraw whole screen.
-	 * @author Hj. Malthaner
 	 */
 	void unset_dirty() {dirty=false;}
 
 	/**
 	 * dirty: redraw whole screen.
-	 * @author Hj. Malthaner
 	 */
 	bool is_dirty() const {return dirty;}
 
@@ -794,25 +783,21 @@ public:
 
 	/**
 	 * Returns the finance history for player.
-	 * @author hsiegeln
 	 */
 	sint64 get_finance_history_year(int year, int type) const { return finance_history_year[year][type]; }
 
 	/**
 	 * Returns the finance history for player.
-	 * @author hsiegeln
 	 */
 	sint64 get_finance_history_month(int month, int type) const { return finance_history_month[month][type]; }
 
 	/**
 	 * Returns pointer to finance history for player.
-	 * @author hsiegeln
 	 */
 	const sint64* get_finance_history_year() const { return *finance_history_year; }
 
 	/**
 	 * Returns pointer to finance history for player.
-	 * @author hsiegeln
 	 */
 	const sint64* get_finance_history_month() const { return *finance_history_month; }
 
@@ -885,12 +870,10 @@ public:
 	/**
 	 * @return The active mouse cursor.
 	 */
-
 	zeiger_t * get_zeiger() const { return zeiger; }
 
 	/**
 	 * Marks an area using the grund_t mark flag.
-	 * @author prissi
 	 */
 	void mark_area( const koord3d center, const koord radius, const bool mark ) const;
 
@@ -921,7 +904,7 @@ public:
 	 */
 	void call_change_player_tool(uint8 cmd, uint8 player_nr, uint16 param, bool scripted_call=false);
 
-	enum change_player_tool_cmds { new_player=1, toggle_freeplay=2, delete_player=3 };
+	enum change_player_tool_cmds { new_player=1, toggle_freeplay=2, delete_player=3, toggle_player_active=4 };
 	/**
 	 * @param exec If false checks whether execution is allowed, if true executes tool.
 	 * @returns Whether execution is allowed.
@@ -963,13 +946,11 @@ public:
 	/**
 	 * Number of ticks per day in bits.
 	 * @see ticks_per_world_month
-	 * @author Hj. Malthaner
 	 */
 	uint32 ticks_per_world_month_shift;
 
 	/**
 	 * Number of ticks per MONTH!
-	 * @author Hj. Malthaner
 	 */
 	uint32 ticks_per_world_month;
 
@@ -983,8 +964,6 @@ public:
 	 *          >> yards_per_tile_shift (which is 12 + 8 = 20, see above)
 	 * This is hard to do with full generality, because shift operators
 	 * take positive numbers!
-	 *
-	 * @author neroden
 	 */
 	uint32 speed_to_tiles_per_month(uint32 speed) const
 	{
@@ -1035,13 +1014,11 @@ public:
 
 	/**
 	 * @return 0=winter, 1=spring, 2=summer, 3=autumn
-	 * @author prissi
 	 */
 	uint8 get_season() const { return season; }
 
 	/**
 	 * Time since map creation or the last load in ms.
-	 * @author Hj. Malthaner
 	 */
 	uint32 get_ticks() const { return ticks; }
 
@@ -1050,43 +1027,37 @@ public:
 
 	/**
 	 * Absolute month (count start year zero).
-	 * @author prissi
 	 */
 	uint32 get_current_month() const { return current_month; }
 
 	/**
-	 * prissi: current city road.
+	 * current city road.
 	 * @note May change due to timeline.
 	 */
 	const way_desc_t* get_city_road() const { return city_road; }
 
 	/**
 	 * Number of steps elapsed since the map was generated.
-	 * @author Hj. Malthaner
 	 */
 	sint32 get_steps() const { return steps; }
 
 	/**
 	 * Idle time. Nur zur Anzeige verwenden!
-	 * @author Hj. Malthaner
 	 */
 	uint32 get_idle_time() const { return idle_time; }
 
 	/**
 	 * Number of frames displayed in the last real time second.
-	 * @author prissi
 	 */
 	uint32 get_realFPS() const { return realFPS; }
 
 	/**
 	 * Number of simulation loops in the last second. Can be very inaccurate!
-	 * @author Hj. Malthaner
 	 */
 	uint32 get_simloops() const { return simloops; }
 
 	/**
 	 * Returns the current waterline height.
-	 * @author Hj. Malthaner
 	 */
 	sint8 get_groundwater() const { return groundwater; }
 
@@ -1097,13 +1068,11 @@ public:
 
 	/**
 	 * Returns the maximum allowed world height.
-	 * @author Hj. Malthaner
 	 */
 	sint8 get_maximumheight() const { return world_maximum_height; }
 
 	/**
 	 * Returns the current snowline height.
-	 * @author prissi
 	 */
 	sint16 get_snowline() const { return snowline; }
 
@@ -1130,7 +1099,6 @@ public:
 
 	/**
 	 * returns the current climate for a given koordinate
-	 * @author Kieron Green
 	 */
 	inline climate get_climate(koord k) const {
 		const planquadrat_t *plan = access(k);
@@ -1139,7 +1107,6 @@ public:
 
 	/**
 	 * sets the current climate for a given koordinate
-	 * @author Kieron Green
 	 */
 	inline void set_climate(koord k, climate cl, bool recalc) {
 		planquadrat_t *plan = access(k);
@@ -1167,10 +1134,9 @@ private:
 	/**
 	 * iterates over the map starting from k setting the water height
 	 * lakes are left where there is no drainage
-	 * @author Kieron Green
 	 */
 	void drain_tile(koord k, sint8 water_height);
-	bool can_flood_to_depth(koord k, sint8 new_water_height, sint8 *stage, sint8 *our_stage) const;
+	bool can_flood_to_depth(koord k, sint8 new_water_height, sint8 *stage, sint8 *our_stage, sint16, sint16, sint16, sint16) const;
 
 public:
 	void flood_to_depth(sint8 new_water_height, sint8 *stage);
@@ -1213,7 +1179,7 @@ public:
 	 * @note Inline because called very frequently!
 	 */
 	inline bool is_within_limits(sint16 x, sint16 y) const {
-	// prissi: since negative values will make the whole result negative, we can use bitwise or
+	// since negative values will make the whole result negative, we can use bitwise or
 	// faster, since pentiums and other long pipeline processors do not like jumps
 		return (x|y|(cached_size.x-x)|(cached_size.y-y))>=0;
 //		return x>=0 &&  y>=0  &&  cached_groesse_karte_x>=x  &&  cached_groesse_karte_y>=y;
@@ -1233,7 +1199,7 @@ public:
 	 * @note Inline because called very frequently!
 	 */
 	inline bool is_within_grid_limits(sint16 x, sint16 y) const {
-	// prissi: since negative values will make the whole result negative, we can use bitwise or
+	// since negative values will make the whole result negative, we can use bitwise or
 	// faster, since pentiums and other long pipeline processors do not like jumps
 		return (x|y|(cached_grid_size.x-x)|(cached_grid_size.y-y))>=0;
 //		return x>=0 &&  y>=0  &&  cached_groesse_gitter_x>=x  &&  cached_groesse_gitter_y>=y;
@@ -1264,7 +1230,6 @@ public:
 	/**
 	 * @return grund an pos/hoehe
 	 * @note Inline because called very frequently!
-	 * @author Hj. Malthaner
 	 */
 	inline grund_t *lookup(const koord3d &pos) const
 	{
@@ -1373,21 +1338,18 @@ public:
 	/**
 	 * @return The natural slope at a position.
 	 * @note Uses the corner height for the best slope.
-	 * @author prissi
 	 */
-	uint8	recalc_natural_slope( const koord k, sint8 &new_height ) const;
+	uint8 recalc_natural_slope( const koord k, sint8 &new_height ) const;
 
 	/**
 	 * Returns the natural slope a a position using the grid.
 	 * @note No checking, and only using the grind for calculation.
 	 */
-	uint8	calc_natural_slope( const koord k ) const;
+	uint8 calc_natural_slope( const koord k ) const;
 
 	 /**
 	  * Initialize map.
 	  * @param sets Game settings.
-	  * @param preselected_players Defines which players the user has selected before he started the game.
-	  * @author Hj. Malthaner
 	  */
 	void init(settings_t*, sint8 const* heights);
 
@@ -1399,8 +1361,6 @@ public:
 
 	~karte_t();
 
-
-
 	/**
 	 * File version used when loading (or current if generated)
 	 * @note Useful for finish_rd
@@ -1410,21 +1370,18 @@ public:
 	/**
 	 * Checks if the planquadrat (tile) at coordinate (x,y)
 	 * can be lowered at the specified height.
-	 * @author V. Meyer
 	 */
 	const char* can_lower_plan_to(const player_t *player, sint16 x, sint16 y, sint8 h) const;
 
 	/**
 	 * Checks if the planquadrat (tile) at coordinate (x,y)
 	 * can be raised at the specified height.
-	 * @author V. Meyer
 	 */
 	const char* can_raise_plan_to(const player_t *player, sint16 x, sint16 y, sint8 h) const;
 
 	/**
 	 * Checks if the whole planquadrat (tile) at coordinates (x,y) height can
 	 * be changed ( for example, water height can't be changed ).
-	 * @author Hj. Malthaner
 	 */
 	bool is_plan_height_changeable(sint16 x, sint16 y) const;
 
@@ -1519,14 +1476,12 @@ public:
 
 	/**
 	 * To access the cities array.
-	 * @author Hj. Malthaner
 	 */
 	const weighted_vector_tpl<stadt_t*>& get_cities() const { return stadt; }
 	void add_city(stadt_t *s);
 
 	/**
 	 * Removes town from map, houses will be left overs.
-	 * @author prissi
 	 */
 	bool remove_city(stadt_t *s);
 
@@ -1553,7 +1508,6 @@ public:
 	/**
 	 * Searches and returns the closest city
 	 * but prefers even farther cities if within their city limits
-	 * @author Hj. Malthaner
 	 */
 	stadt_t *find_nearest_city(koord k) const;
 
@@ -1590,7 +1544,8 @@ public:
 	/**
 	 * Synchronous stepping of objects like vehicles.
 	 */
-	void sync_step(uint32 delta_t, bool sync, bool display );	// advance also the timer
+	void sync_step(uint32 delta_t, bool sync, bool display ); // advance also the timer
+
 	/**
 	 * Tasks that are more time-consuming, like route search of vehicles and production of factories.
 	 */
@@ -1613,7 +1568,6 @@ public:
 private:
 	/**
 	 * @return Height at the grid point i, j - versions without checks for speed
-	 * @author Hj. Malthaner
 	 */
 	inline sint8 lookup_hgt_nocheck(sint16 x, sint16 y) const {
 		return grid_hgts[x + y*(cached_grid_size.x+1)];
@@ -1624,7 +1578,6 @@ private:
 public:
 	/**
 	 * @return Height at the grid point i, j
-	 * @author Hj. Malthaner
 	 */
 	inline sint8 lookup_hgt(sint16 x, sint16 y) const {
 		return is_within_grid_limits(x, y) ? grid_hgts[x + y*(cached_grid_size.x+1)] : groundwater;
@@ -1635,7 +1588,6 @@ public:
 	/**
 	 * Sets grid height.
 	 * Never set grid_hgts manually, always use this method!
-	 * @author Hj. Malthaner
 	 */
 	void set_grid_hgt(sint16 x, sint16 y, sint8 hgt) { grid_hgts[x + y*(uint32)(cached_grid_size.x+1)] = hgt; }
 
@@ -1645,7 +1597,6 @@ public:
 private:
 	/**
 	 * @return water height - versions without checks for speed
-	 * @author Kieron Green
 	 */
 	inline sint8 get_water_hgt_nocheck(sint16 x, sint16 y) const {
 		return water_hgts[x + y * (cached_grid_size.x)];
@@ -1656,7 +1607,6 @@ private:
 public:
 	/**
 	 * @return water height
-	 * @author Kieron Green
 	 */
 	inline sint8 get_water_hgt(sint16 x, sint16 y) const {
 		return is_within_limits( x, y ) ? water_hgts[x + y * (cached_grid_size.x)] : groundwater;
@@ -1667,7 +1617,6 @@ public:
 
 	/**
 	 * Sets water height.
-	 * @author Kieron Green
 	 */
 	void set_water_hgt(sint16 x, sint16 y, sint8 hgt) { water_hgts[x + y * (cached_grid_size.x)] = (hgt); }
 
@@ -1675,88 +1624,89 @@ public:
 
 	/**
 	 * Fills array with corner heights of neighbours
-	 * @author Kieron Green
 	 */
 	void get_neighbour_heights(const koord k, sint8 neighbour_height[8][4]) const;
 
 	/**
 	 * Calculates appropriate climate for a tile
-	 * @author Kieron Green
 	 */
 	void calc_climate(koord k, bool recalc);
 
+	/**
+	* Calculates appropriate climate for a region using elliptic areas for each
+	*/
+	void calc_climate_map_region( sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
+
+	/**
+	* Calculates appropriate climate for a region using elliptic areas for each
+	*/
+	void calc_humidity_map_region( sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
+
+	/**
+	 * assign climated from the climate map to a region
+	 */
+	void assign_climate_map_region( sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
+
+	/**
+	 * Since the trees follow humidity, we have to redistribute them only in the new region
+	 */
+	void distribute_trees_region( sint16 xtop, sint16 ytop, sint16 xbottom, sint16 ybottom );
+
 	/**
 	 * Rotates climate and water transitions for a tile
-	 * @author Kieron Green
 	 */
 	void rotate_transitions(koord k);
 
 	/**
 	 * Recalculate climate and water transitions for a tile
-	 * @author Kieron Green
 	 */
 	void recalc_transitions(koord k);
 
 	/**
 	 * Loop recalculating transitions - suitable for multithreading
-	 * @author Kieron Green
 	 */
 	void recalc_transitions_loop(sint16, sint16, sint16, sint16);
 
-	/**
-	 * Loop creating grounds on all plans from height and water height - suitable for multithreading
-	 * @author Kieron Green
-	 */
-	void create_grounds_loop(sint16, sint16, sint16, sint16);
-
 	/**
 	 * Loop cleans grounds so that they have correct boden and slope - suitable for multithreading
-	 * @author Kieron Green
 	 */
 	void cleanup_grounds_loop(sint16, sint16, sint16, sint16);
 
 private:
 	/**
 	 * @return Minimum height of the planquadrats (tile) at i, j. - for speed no checks performed that coordinates are valid
-	 * @author Hj. Malthaner
 	 */
 	sint8 min_hgt_nocheck(koord k) const;
 
 	/**
 	 * @return Maximum height of the planquadrats (tile) at i, j. - for speed no checks performed that coordinates are valid
-	 * @author Hj. Malthaner
 	 */
 	sint8 max_hgt_nocheck(koord k) const;
 
 public:
 	/**
 	 * @return Minimum height of the planquadrats (tile) at i, j.
-	 * @author Hj. Malthaner
 	 */
 	sint8 min_hgt(koord k) const;
 
 	/**
 	 * @return Maximum height of the planquadrats (tile) at i, j.
-	 * @author Hj. Malthaner
 	 */
 	sint8 max_hgt(koord k) const;
 
 	/**
 	 * @return true, wenn Platz an Stelle pos mit Groesse dim Water ist
-	 * @author V. Meyer
 	 */
 	bool is_water(koord k, koord dim) const;
 
 	/**
 	 * @return true, if square in place (i,j) with size w, h is constructible.
-	 * @author Hj. Malthaner
 	 */
 	bool square_is_free(koord k, sint16 w, sint16 h, int *last_y, climate_bits cl) const;
 
 	/**
 	 * @return A list of all buildable squares with size w, h.
 	 * @note Only used for town creation at the moment.
-	 * @author Hj. Malthaner
 	 */
 	slist_tpl<koord> * find_squares(sint16 w, sint16 h, climate_bits cl, sint16 old_x, sint16 old_y) const;
 
@@ -1765,9 +1715,9 @@ public:
 	 * The sound plays lower when the position is outside the visible region.
 	 * @param pos Position at which the event took place.
 	 * @param idx Index of the sound
-	 * @author Hj. Malthaner
+	 * @param idx t is the type of sound (for selective muting etc.)
 	 */
-	bool play_sound_area_clipped(koord k, uint16 idx) const;
+	bool play_sound_area_clipped(koord k, uint16 idx, sound_type_t t) const;
 
 	void mute_sound( bool state ) { is_sound = !state; }
 
@@ -1779,21 +1729,18 @@ public:
 	/**
 	 * Saves the map to a file.
 	 * @param Filename name of the file to write.
-	 * @author Hj. Malthaner
 	 */
-	void save(const char *filename, const loadsave_t::mode_t savemode, const char *version, bool silent);
+	void save(const char *filename, bool autosave, const char *version, bool silent);
 
 	/**
 	 * Loads a map from a file.
 	 * @param Filename name of the file to read.
-	 * @author Hj. Malthaner
 	 */
 	bool load(const char *filename);
 
 	/**
 	 * Creates a map from a heightfield.
 	 * @param sets game settings.
-	 * @author Hj. Malthaner
 	 */
 	void load_heightfield(settings_t*);
 
@@ -1806,7 +1753,6 @@ public:
 	/**
 	 * Main loop with event handling.
 	 * @return false to exit.
-	 * @author Hj. Malthaner
 	 */
 	bool interactive(uint32 quit_month);
 
