@@ -1,28 +1,30 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-/*
- * Dialog for sound settings
- *
- * @author Hj. Malthaner, Owen Rudge
- * @date 09-Apr-01
- */
+#ifndef GUI_SOUND_FRAME_H
+#define GUI_SOUND_FRAME_H
+
 
 #include "gui_frame.h"
 #include "components/gui_scrollbar.h"
 #include "components/gui_label.h"
 #include "components/gui_button.h"
+#include "components/gui_numberinput.h"
 #include "components/action_listener.h"
 
+/**
+ * Dialog for sound settings
+ */
 class sound_frame_t : public gui_frame_t, action_listener_t
 {
 private:
 	scrollbar_t sound_volume_scrollbar;
 	scrollbar_t music_volume_scrollbar;
+	scrollbar_t *specific_volume_scrollbar[MAX_SOUND_TYPES+1];
+	gui_numberinput_t sound_range;
+
 	button_t sound_mute_button;
 	button_t music_mute_button;
 	button_t next_song_button;
@@ -33,28 +35,16 @@ private:
 	void update_song_name();
 
 public:
+	const char *get_help_filename() const OVERRIDE {return "sound.txt";}
 
-	/**
-	 * Set the window associated helptext
-	 * @return the filename for the helptext, or NULL
-	 * @author Hj. Malthaner
-	 */
-	const char * get_help_filename() const OVERRIDE {return "sound.txt";}
+	sound_frame_t();
 
+	virtual ~sound_frame_t();
 
-	/**
-	 * Constructor. Adds all necessary Subcomponents.
-	 * @author Hj. Malthaner
-	 */
-    sound_frame_t();
-
-	/**
-	 * Draw new component. The values to be passed refer to the window
-	 * i.e. It's the screen coordinates of the window where the
-	 * component is displayed.
-	 * @author Hj. Malthaner
-	 */
+	// used for updating the song title
 	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 };
+
+#endif
