@@ -1,5 +1,11 @@
-#ifndef tpl_sparse_tpl_h
-#define tpl_sparse_tpl_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef TPL_SPARSE_TPL_H
+#define TPL_SPARSE_TPL_H
+
 
 #include "../dataobj/koord.h"
 #include "../simtypes.h"
