@@ -1,5 +1,11 @@
-#ifndef sync_steppable_h
-#define sync_steppable_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef IFC_SYNC_STEPPABLE_H
+#define IFC_SYNC_STEPPABLE_H
+
 
 #include "../simtypes.h"
 
@@ -11,18 +17,16 @@ enum sync_result {
 
 /**
  * All synchronously moving things must implement this interface.
- *
- * @author Hj. Malthaner
  */
 class sync_steppable
 {
 public:
-    /**
-     * Method for real-time features of an object.
-     */
-    virtual sync_result sync_step(uint32 delta_t) = 0;
+	/**
+	 * Method for real-time features of an object.
+	 */
+	virtual sync_result sync_step(uint32 delta_t) = 0;
 
-    virtual ~sync_steppable() {}
+	virtual ~sync_steppable() {}
 };
 
 #endif
