@@ -1,12 +1,13 @@
 /*
- * selection of paks at the start time
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <string>
 
 #include "themeselector.h"
 #include "simwin.h"
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../simevent.h"
 #include "gui_theme.h"
 #include "../utils/simstring.h"
@@ -44,7 +45,7 @@ bool themeselector_t::check_file(const char *filename, const char *suffix)
 // A theme button was pressed
 bool themeselector_t::item_action(const char *fullpath)
 {
-	gui_theme_t::themes_init(fullpath,true);
+	gui_theme_t::themes_init(fullpath,true,true);
 
 	event_t *ev = new event_t();
 	ev->ev_class = EVENT_SYSTEM;
