@@ -1,15 +1,20 @@
 /*
- * selection of paks at the start time
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef themeselector_h
-#define themeselector_h
+#ifndef GUI_THEMESELECTOR_H
+#define GUI_THEMESELECTOR_H
+
 
 #include "simwin.h"
 #include "savegame_frame.h"
 #include "components/gui_textarea.h"
 #include "../utils/cbuffer_t.h"
 
+/*
+ * selection of paks at the start time
+ */
 class themeselector_t : public savegame_frame_t
 {
 protected:
