@@ -1,9 +1,8 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
+
 #include <string>
 #include <stdio.h>
 #include <string.h>
@@ -11,7 +10,7 @@
 
 #include "../macros.h"
 #include "../simdebug.h"
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../simtypes.h"
 #include "../display/simgraph.h" // for unicode stuff
 #include "translator.h"
@@ -90,14 +89,13 @@ static void dump_hashtable(stringhashtable_tpl<const char*>* tbl)
 
 /* first two file functions needed in connection with utf */
 
-/* checks, if we need a unicode translation (during load only done for identifying strings like "Auflsen")
- * @date 2.1.2005
- * @author prissi
+/**
+ * checks, if we need a unicode translation
  */
 static bool is_unicode_file(FILE* f)
 {
-	unsigned char	str[2];
-	int	pos = ftell(f);
+	unsigned char str[2];
+	int pos = ftell(f);
 //	DBG_DEBUG("is_unicode_file()", "checking for unicode");
 //	fflush(NULL);
 	fread( str, 1, 2,  f );
@@ -213,7 +211,7 @@ void translator::load_custom_list( int lang, vector_tpl<char *>&name_list, const
 	}
 	name_list.clear();
 
-	// @author prissi: first try in pakset
+	// first try in pakset
 	{
 		string local_file_name(env_t::user_dir);
 		local_file_name = local_file_name + "addons/" + pakset_path + "text/" + fileprefix + langs[lang].iso_base + ".txt";
@@ -265,13 +263,13 @@ void translator::load_custom_list( int lang, vector_tpl<char *>&name_list, const
 }
 
 
-/* the city list is now reloaded after the language is changed
+/**
+ * the city list is now reloaded after the language is changed
  * new cities will get their appropriate names
- * @author hajo, prissi
  */
 void translator::init_custom_names(int lang)
 {
-	// Hajo: init names. There are two options:
+	// init names. There are two options:
 	//
 	// 1.) read list from file
 	// 2.) create random names (only for cities)
@@ -282,7 +280,7 @@ void translator::init_custom_names(int lang)
 
 	if (city_name_list.empty()) {
 		DBG_MESSAGE("translator::init_city_names", "reading failed, creating random names.");
-		// Hajo: try to read list failed, create random names
+		// try to read list failed, create random names
 		for(  uint i = 0;  i < 36;  i++  ) {
 			char name[32];
 			sprintf( name, "%%%c_CITY_SYLL", i+(i<10 ? '0' : 'A'-10 ) );
