@@ -1,3 +1,8 @@
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
 #include <string.h>
 
 #include "tunnelboden.h"
@@ -75,7 +80,7 @@ void tunnelboden_t::calc_image_internal(const bool calc_only_snowline_change)
 		// default tunnel ground images
 		// single or double slope? (single slopes are not divisible by 8)
 		const uint8 slope_this =  get_disp_slope();
-		const uint8 imageid = (!slope_this  ||  (slope_this & 7)) ? ground_desc_t::slopetable[slope_this] : ground_desc_t::slopetable[slope_this >> 1] + 12;
+		const uint8 imageid = (!slope_this  ||  is_one_high(slope_this)) ? ground_desc_t::slopetable[slope_this] : ground_desc_t::slopetable[slope_this >> 1] + 12;
 		set_image( skinverwaltung_t::tunnel_texture->get_image_id( imageid ) );
 	}
 }
