@@ -1,5 +1,11 @@
-#ifndef tunnelboden_h
-#define tunnelboden_h
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef BODEN_TUNNELBODEN_H
+#define BODEN_TUNNELBODEN_H
+
 
 #include "boden.h"
 
