@@ -1,11 +1,11 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef __VEHICLE_DESC_H
-#define __VEHICLE_DESC_H
+#ifndef DESCRIPTOR_VEHICLE_DESC_H
+#define DESCRIPTOR_VEHICLE_DESC_H
+
 
 #include "obj_base_desc.h"
 #include "goods_desc.h"
@@ -23,33 +23,30 @@ class checksum_t;
 /**
  * Vehicle type description - all attributes of a vehicle type
  *
- *  child nodes:
- *	0   Name
- *	1   Copyright
- *	2   freight
- *	3   smoke
- *	4   empty 1d image list
- *	5   either 1d (freight_image_type==0) or 2d image list
- *	6   required leading vehicle 1
- *	7   required leading vehicle 2
- *	... ...
- *	n+5 required leading vehicle n
- *	n+6 allowed trailing vehicle 1
- *	n+7 allowed trailing vehicle 2
- *	... ...
- *	n+m+5 allowed trailing vehicle m
+ * Child nodes:
+ *  0   Name
+ *  1   Copyright
+ *  2   freight
+ *  3   smoke
+ *  4   empty 1d image list
+ *  5   either 1d (freight_image_type==0) or 2d image list
+ *  6   required leading vehicle 1
+ *  7   required leading vehicle 2
+ * ... ...
+ *  n+5 required leading vehicle n
+ *  n+6 allowed trailing vehicle 1
+ *  n+7 allowed trailing vehicle 2
+ * ... ...
+ *  n+m+5 allowed trailing vehicle m
  *  n+m+6 freight for which special images are defined
- *
- * @author Volker Meyer, Hj. Malthaner, kierongreen
  */
 class vehicle_desc_t : public obj_desc_transport_related_t {
-    friend class vehicle_reader_t;
-    friend class vehicle_builder_t;
+	friend class vehicle_reader_t;
+	friend class vehicle_builder_t;
 
 public:
 	/**
 	 * Engine type
-	 * @author Hj. Malthaner
 	 */
 	enum engine_t {
 		unknown=-1,
@@ -66,24 +63,22 @@ public:
 
 private:
 	uint16  capacity;
-	uint16  loading_time;	// time per full loading/unloading
+	uint16  loading_time; // time per full loading/unloading
 	uint32  weight;
 	uint32  power;
 	uint16  running_cost;
-	uint32  fixed_cost;
 
 	uint16  gear;       // engine gear (power multiplier), 64=100
 
-	uint8 len;			// length (=8 is half a tile, the old default)
+	uint8 len;          // length (=8 is half a tile, the old default)
 	sint8 sound;
 
-	uint8  leader_count;	// all defined leading vehicles
-	uint8  trailer_count;	// all defined trailer
+	uint8  leader_count;  // all defined leading vehicles
+	uint8  trailer_count; // all defined trailer
 
 	uint8  engine_type; // diesel, steam, electric (requires electrified ways), fuel_cell, etc.
 
-	sint8 freight_image_type;	// number of freight images (displayed for different goods)
-
+	sint8 freight_image_type; // number of freight images (displayed for different goods)
 
 public:
 	// dummy vehicle for the XREF reader
@@ -95,7 +90,7 @@ public:
 	// default vehicle (used for way search and similar tasks)
 	// since it has no images and not even a name node any calls to this will case a crash
 	vehicle_desc_t(uint8 wtype, uint16 speed, engine_t engine) {
-		freight_image_type = price = capacity = axle_load = running_cost = fixed_cost = intro_date = leader_count = trailer_count = 0;
+		maintenance = freight_image_type = price = capacity = axle_load = running_cost = intro_date = leader_count = trailer_count = 0;
 		power = weight = 1;
 		loading_time = 1000;
 		gear = 64;
@@ -252,25 +247,23 @@ public:
 	uint32 get_weight() const { return weight; }
 	uint32 get_power() const { return power; }
 	uint32 get_running_cost() const { return running_cost; }
-	uint16 get_maintenance() const { return fixed_cost; }
+	sint32 get_fixed_cost() const { return get_maintenance(); }
 	sint8 get_sound() const { return sound; }
 
 	/**
 	* 64 = 1.00
 	* @return gear value
-	* @author Hj. Malthaner
 	*/
 	uint16 get_gear() const { return gear; }
 
 	/**
 	* @return engine type
 	* eletric engines require an electrified way to run
-	* @author Hj. Malthaner
 	*/
 	uint8 get_engine_type() const { return engine_type; }
 
-	/* @return the vehicles length in 1/8 of the normal len
-	* @author prissi
+	/**
+	 * @return the vehicles length in 1/8 of the normal len
 	*/
 	uint8 get_length() const { return len; }
 	uint32 get_length_in_steps() const { return get_length() * VEHICLE_STEPS_PER_CARUNIT; }
