@@ -1,8 +1,6 @@
 /*
- * Copyright (c) 1997 - 2002 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include <algorithm>
@@ -25,11 +23,39 @@
 #include "../tpl/stringhashtable_tpl.h"
 
 
+const char* vehicle_builder_t::engine_type_names[9] =
+{
+	"unknown",
+	"steam",
+	"diesel",
+	"electric",
+	"bio",
+	"sail",
+	"fuel_cell",
+	"hydrogene",
+	"battery"
+};
+
+const char *vehicle_builder_t::vehicle_sort_by[vehicle_builder_t::sb_length] =
+{
+	"Fracht",
+	"Vehicle Name",
+	"Capacity",
+	"Price",
+	"Cost",
+	"Cost per unit",
+	"Max. speed",
+	"Vehicle Power",
+	"Weight",
+	"Intro. date",
+	"Retire date"
+};
+
 static stringhashtable_tpl<const vehicle_desc_t*> name_fahrzeuge;
 
 // index 0 aur, 1...8 at normal waytype index
 #define GET_WAYTYPE_INDEX(wt) ((int)(wt)>8 ? 0 : (wt))
-static slist_tpl<const vehicle_desc_t*> typ_fahrzeuge[depot_frame_t::sb_length][9];
+static slist_tpl<const vehicle_desc_t*> typ_fahrzeuge[vehicle_builder_t::sb_length][9];
 static uint8 tmp_sort_idx;
 
 class bonus_record_t {
@@ -51,14 +77,14 @@ static vector_tpl<bonus_record_t>speedbonus[8];
 
 static sint32 default_speedbonus[8] =
 {
-	60,	// road
-	80,	// track
-	35,	// water
-	350,	// air
-	80,	// monorail
-	200,	// maglev
-	60,	// tram
-	60	// narrowgauge
+	60,  // road
+	80,  // track
+	35,  // water
+	350, // air
+	80,  // monorail
+	200, // maglev
+	60,  // tram
+	60   // narrowgauge
 };
 
 bool vehicle_builder_t::speedbonus_init(const std::string &objfilename)
@@ -201,12 +227,13 @@ bool vehicle_builder_t::register_desc(const vehicle_desc_t *desc)
 	name_fahrzeuge.put(desc->get_name(), desc);
 
 	// now add it to sorter (may be more than once!)
-	for(  int sort_idx = 0;  sort_idx < depot_frame_t::sb_length;  sort_idx++  ) {
+	for(  int sort_idx = 0;  sort_idx < vehicle_builder_t::sb_length;  sort_idx++  ) {
 		if(  old_desc  ) {
 			typ_fahrzeuge[sort_idx][wt_idx].remove(old_desc);
 		}
 		typ_fahrzeuge[sort_idx][wt_idx].append(desc);
 	}
+	// we cannot delete old_desc, since then xref-resolving will crash
 
 	return true;
 }
@@ -231,57 +258,63 @@ static int compare_price(const vehicle_desc_t* a, const vehicle_desc_t* b) { ret
 static int compare_cost(const vehicle_desc_t* a, const vehicle_desc_t* b) { return a->get_running_cost() - b->get_running_cost(); }
 static int compare_cost_per_unit(const vehicle_desc_t* a, const vehicle_desc_t* b) { return a->get_running_cost()*b->get_capacity() - b->get_running_cost()*a->get_capacity(); }
 static int compare_topspeed(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_topspeed() - b->get_topspeed();}
-static int compare_power(const vehicle_desc_t* a, const vehicle_desc_t* b)	{return (a->get_power() == 0 ? 0x7FFFFFF : a->get_power()) - (b->get_power() == 0 ? 0x7FFFFFF : b->get_power());}
+static int compare_power(const vehicle_desc_t* a, const vehicle_desc_t* b) {return (a->get_power() == 0 ? 0x7FFFFFF : a->get_power()) - (b->get_power() == 0 ? 0x7FFFFFF : b->get_power());}
 static int compare_weight(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_weight() - b->get_weight();}
 static int compare_intro_year_month(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_intro_year_month() - b->get_intro_year_month();}
 static int compare_retire_year_month(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_retire_year_month() - b->get_retire_year_month();}
 
 
 
-// default compare function
-static bool compare_vehicles(const vehicle_desc_t* a, const vehicle_desc_t* b)
+// default compare function with mode parameter
+bool vehicle_builder_t::compare_vehicles(const vehicle_desc_t* a, const vehicle_desc_t* b, sort_mode_t mode )
 {
-	int cmp = compare_freight(a, b);
-	if (cmp != 0) return cmp < 0;
-	switch (tmp_sort_idx) {
-		case depot_frame_t::sb_name:
+	int cmp = 0;
+	switch (mode) {
+		case sb_freight:
+			cmp = compare_freight(a, b);
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_name:
 			cmp = strcmp(translator::translate(a->get_name()), translator::translate(b->get_name()));
 			if (cmp != 0) return cmp < 0;
 			break;
-		case depot_frame_t::sb_price:
+		case sb_price:
 			cmp = compare_price(a, b);
 			if (cmp != 0) return cmp < 0;
-		case depot_frame_t::sb_cost:
+			// fall-through
+		case sb_cost:
 			cmp = compare_cost(a, b);
 			if (cmp != 0) return cmp < 0;
 			cmp = compare_price(a, b);
 			if (cmp != 0) return cmp < 0;
 			break;
-		case depot_frame_t::sb_cost_per_unit:
+		case sb_cost_per_unit:
 			cmp = compare_cost_per_unit(a,b);
 			if (cmp != 0) return cmp < 0;
 			break;
-		case depot_frame_t::sb_speed:
+		case sb_speed:
 			cmp = compare_topspeed(a, b);
 			if (cmp != 0) return cmp < 0;
 			break;
-		case depot_frame_t::sb_weight:
+		case sb_weight:
 			cmp = compare_weight(a, b);
 			if (cmp != 0) return cmp < 0;
 			break;
-		case depot_frame_t::sb_power:
+		case sb_power:
 			cmp = compare_power(a, b);
 			if (cmp != 0) return cmp < 0;
 			break;
-		case depot_frame_t::sb_intro_date:
+		case sb_intro_date:
 			cmp = compare_intro_year_month(a, b);
 			if (cmp != 0) return cmp < 0;
-		case depot_frame_t::sb_retire_date:
+			// fall-through
+		case sb_retire_date:
 			cmp = compare_retire_year_month(a, b);
 			if (cmp != 0) return cmp < 0;
 			cmp = compare_intro_year_month(a, b);
 			if (cmp != 0) return cmp < 0;
 			break;
+		default: ;
 	}
 	// Sort by:
 	//  1. cargo category
@@ -291,6 +324,8 @@ static bool compare_vehicles(const vehicle_desc_t* a, const vehicle_desc_t* b)
 	//  5. power
 	//  6. intro date
 	//  7. name
+	cmp = compare_freight(a, b);
+	if (cmp != 0) return cmp < 0;
 	cmp = compare_capacity(a, b);
 	if (cmp != 0) return cmp < 0;
 	cmp = compare_engine(a, b);
@@ -306,12 +341,17 @@ static bool compare_vehicles(const vehicle_desc_t* a, const vehicle_desc_t* b)
 }
 
 
+static bool compare( const vehicle_desc_t* a, const vehicle_desc_t* b )
+{
+	return vehicle_builder_t::compare_vehicles( a, b, (vehicle_builder_t::sort_mode_t)tmp_sort_idx );
+}
+
 
 bool vehicle_builder_t::successfully_loaded()
 {
 	// first: check for bonus tables
 	DBG_MESSAGE("vehicle_builder_t::sort_lists()","called");
-	for (  int sort_idx = 0; sort_idx < depot_frame_t::sb_length; sort_idx++  ) {
+	for (  int sort_idx = 0; sort_idx < vehicle_builder_t::sb_length; sort_idx++  ) {
 		for(  int wt_idx=0;  wt_idx<9;  wt_idx++  ) {
 			tmp_sort_idx = sort_idx;
 			slist_tpl<const vehicle_desc_t*>& typ_liste = typ_fahrzeuge[sort_idx][wt_idx];
@@ -324,7 +364,7 @@ bool vehicle_builder_t::successfully_loaded()
 			for(  const vehicle_desc_t** tmpptr = tmp;  tmpptr != tmp_end;  tmpptr++  ) {
 				*tmpptr = typ_liste.remove_first();
 			}
-			std::sort(tmp, tmp_end, compare_vehicles);
+			std::sort(tmp, tmp_end, compare);
 			for(  const vehicle_desc_t** tmpptr = tmp;  tmpptr != tmp_end;  tmpptr++  ) {
 				typ_liste.append(*tmpptr);
 			}
@@ -348,10 +388,10 @@ slist_tpl<vehicle_desc_t const*> const & vehicle_builder_t::get_info(waytype_t c
 }
 
 
-/* extended search for vehicles for KI *
+/**
+ * extended search for vehicles for AI
  * checks also timeline and constraints
  * tries to get best with but adds a little random action
- * @author prissi
  */
 const vehicle_desc_t *vehicle_builder_t::vehikel_search( waytype_t wt, const uint16 month_now, const uint32 target_weight, const sint32 target_speed, const goods_desc_t * target_freight, bool include_electric, bool not_obsolete )
 {
@@ -397,7 +437,7 @@ const vehicle_desc_t *vehicle_builder_t::vehikel_search( waytype_t wt, const uin
 				continue;
 			}
 
-			sint32 difference=0;	// smaller is better
+			sint32 difference=0; // smaller is better
 			// assign this vehicle if we have not found one yet, or we only found one too weak
 			if(  desc!=NULL  ) {
 				// is it cheaper to run? (this is most important)
@@ -460,10 +500,10 @@ const vehicle_desc_t *vehicle_builder_t::vehikel_search( waytype_t wt, const uin
 
 
 
-/* extended search for vehicles for replacement on load time
+/**
+ * extended search for vehicles for replacement on load time
  * tries to get best match (no random action)
  * if prev_desc==NULL, then the convoi must be able to lead a convoi
- * @author prissi
  */
 const vehicle_desc_t *vehicle_builder_t::get_best_matching( waytype_t wt, const uint16 month_now, const uint32 target_weight, const uint32 target_power, const sint32 target_speed, const goods_desc_t * target_freight, bool not_obsolete, const vehicle_desc_t *prev_veh, bool is_last )
 {
@@ -519,7 +559,7 @@ const vehicle_desc_t *vehicle_builder_t::get_best_matching( waytype_t wt, const
 				continue;
 			}
 
-			sint32 difference=0;	// smaller is better
+			sint32 difference=0; // smaller is better
 			// assign this vehicle if we have not found one yet, or we only found one too weak
 			if(  desc!=NULL  ) {
 				// is it cheaper to run? (this is most important)
@@ -581,9 +621,9 @@ sint32 vehicle_builder_t::get_fastest_vehicle_speed(waytype_t wt, uint16 const m
 
 	FOR(slist_tpl<vehicle_desc_t const*>, const vehicle_descriptor, typ_fahrzeuge[0][GET_WAYTYPE_INDEX(wt)]) {
 		if (vehicle_descriptor->get_power() == 0 ||
-			use_timeline && (
+			(use_timeline && (
 				vehicle_descriptor->is_future(month_now) ||
-				!allow_obsolete && vehicle_descriptor->is_retired(month_now))) {
+				(!allow_obsolete && vehicle_descriptor->is_retired(month_now))))) {
 			continue;
 		}
 
