@@ -1,11 +1,11 @@
 /*
- * Copyright (c) 2013 The Simutrans Community
- *
- * This file is part of the Simutrans project under the artistic license.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef simviewport_h
-#define simviewport_h
+#ifndef DISPLAY_VIEWPORT_H
+#define DISPLAY_VIEWPORT_H
+
 
 #include "../simtypes.h"
 #include "scr_coord.h"
@@ -84,18 +84,17 @@ private:
 	 * @}
 	 */
 
-	sint16 cached_disp_width;	//!< Cached window width
-	sint16 cached_disp_height;	//!< Cached window height
-	sint16 cached_img_size;		//!< Cached base raster image size
+	sint16 cached_disp_width;  ///< Cached window width
+	sint16 cached_disp_height; ///< Cached window height
+	sint16 cached_img_size;    ///< Cached base raster image size
 
 	/**
 	 * Sets current ij offsets of this viewport, depends of its proportions and the zoom level.
 	 */
 	void set_viewport_ij_offset( const koord &k );
 
-	/*
+	/**
 	 * The current convoi to follow.
-	 * @author prissi
 	 */
 	convoihandle_t follow_convoi;
 
@@ -168,7 +167,6 @@ public:
 
 	/**
 	 * Set center viewport position.
-	 * @author prissi
 	 */
 	void change_world_position( koord ij, sint16 x=0, sint16 y=0 );
 
