@@ -1,12 +1,11 @@
 /*
- * Copyright (c) 1997 - 2001 Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
- * (see licence.txt)
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef boden_wege_runway_h
-#define boden_wege_runway_h
+#ifndef BODEN_WEGE_RUNWAY_H
+#define BODEN_WEGE_RUNWAY_H
+
 
 #include "../../tpl/vector_tpl.h"
 #include "../../convoihandle_t.h"
@@ -34,7 +33,6 @@ public:
 
 	/**
 	* @return additional info is reservation!
-	* @author prissi
 	*/
 	void info(cbuffer_t & buf) const OVERRIDE;
 
