@@ -1,16 +1,6 @@
 /*
- * dialog to enter values ??for map generation
- *
- * Hj. Malthaner
- *
- * April 2000
- *
- * Max Kielland 2013
- * Added theme support
- */
-
-/*
- * Dialog to configure the generation of a new map
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
 #include "welt.h"
@@ -47,7 +37,7 @@
 
 #include "../display/simgraph.h"
 
-#include "../simsys.h"
+#include "../sys/simsys.h"
 #include "../utils/simstring.h"
 #include "../utils/simrandom.h"
 
@@ -279,7 +269,6 @@ welt_gui_t::welt_gui_t(settings_t* const sets_par) :
 /**
  * Calculates preview from height map
  * @param filename name of heightfield file
- * @author Hajo/prissi
  */
 bool welt_gui_t::update_from_heightfield(const char *filename)
 {
@@ -349,7 +338,7 @@ void welt_gui_t::update_memory(gui_label_buf_t *label, const settings_t* sets)
 		(
 			sizeof(grund_t) +
 			sizeof(planquadrat_t) +
-			sizeof(baum_t)*(1-sets->get_no_trees()) + /* only one since a lot will be water */
+			sizeof(baum_t)*(sets->get_tree()>0) + /* only one since a lot will be water */
 			sizeof(void*)*2
 		) * (uint64)sx * (uint64)sy
 	) / (1024ll * 1024ll);
@@ -361,7 +350,6 @@ void welt_gui_t::update_memory(gui_label_buf_t *label, const settings_t* sets)
 
 /**
  * Calculate the new Map-Preview. Initialize the new RNG!
- * @author Hj. Malthaner
  */
 void welt_gui_t::update_preview(bool load_heightfield)
 {
@@ -405,7 +393,6 @@ void welt_gui_t::resize_preview()
 
 /**
  * This method is called if an action is triggered
- * @author Hj. Malthaner
  */
 bool welt_gui_t::action_triggered( gui_action_creator_t *comp,value_t v)
 {
@@ -473,7 +460,7 @@ bool welt_gui_t::action_triggered( gui_action_creator_t *comp,value_t v)
 		load_relief_frame_t* lrf = new load_relief_frame_t(sets);
 		create_win(lrf, w_info, magic_load_t );
 		win_set_pos(lrf, (display_get_width() - lrf->get_windowsize().w-10), env_t::iconsize.h);
-		knr = sets->get_map_number();	// otherwise using cancel would not show the normal generated map again
+		knr = sets->get_map_number(); // otherwise using cancel would not show the normal generated map again
 	}
 	else if(comp==&use_intro_dates) {
 		// 0,1 should force setting to new game as well. don't allow to change
@@ -536,7 +523,7 @@ bool welt_gui_t::action_triggered( gui_action_creator_t *comp,value_t v)
 		welt->set_pause(false);
 		// save setting ...
 		loadsave_t file;
-		if(file.wr_open("default.sve",loadsave_t::binary,"settings only",SAVEGAME_VER_NR)) {
+		if(file.wr_open("default.sve",loadsave_t::binary,0,"settings only",SAVEGAME_VER_NR)) {
 			// save default setting
 			env_t::default_settings.rdwr(&file);
 			file.close();
