@@ -1,5 +1,11 @@
-#ifndef GROUNDOBJ_WRITER_H
-#define GROUNDOBJ_WRITER_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_WRITER_GROUNDOBJ_WRITER_H
+#define DESCRIPTOR_WRITER_GROUNDOBJ_WRITER_H
+
 
 #include <string>
 #include "obj_writer.h"
