@@ -1,11 +1,11 @@
 /*
- *  Copyright (c) 1997 - 2002 by Volker Meyer & Hansjrg Malthaner
- *
- * This file is part of the Simutrans project under the artistic licence.
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
  */
 
-#ifndef PEDESTRIAN_WRITER_H
-#define PEDESTRIAN_WRITER_H
+#ifndef DESCRIPTOR_WRITER_PEDESTRIAN_WRITER_H
+#define DESCRIPTOR_WRITER_PEDESTRIAN_WRITER_H
+
 
 #include <string>
 #include "obj_writer.h"
