@@ -1,5 +1,11 @@
-#ifndef VEHICLE_WRITER_H
-#define VEHICLE_WRITER_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_WRITER_VEHICLE_WRITER_H
+#define DESCRIPTOR_WRITER_VEHICLE_WRITER_H
+
 
 #include <string>
 #include "obj_writer.h"
@@ -18,7 +24,6 @@ class vehicle_writer_t : public obj_writer_t {
 	public:
 		/**
 		 * Writes vehicle node data to file
-		 * @author Hj. Malthaner
 		 */
 		virtual void write_obj(FILE* fp, obj_node_t& parent, tabfileobj_t& obj);
 
