@@ -1,5 +1,11 @@
-#ifndef XREF_WRITER_H
-#define XREF_WRITER_H
+/*
+ * This file is part of the Simutrans project under the Artistic License.
+ * (see LICENSE.txt)
+ */
+
+#ifndef DESCRIPTOR_WRITER_XREF_WRITER_H
+#define DESCRIPTOR_WRITER_XREF_WRITER_H
+
 
 #include <stdio.h>
 #include "obj_writer.h"
